#pragma once
#include <unordered_map>
#include <string>
#include <ATen/Functions.h>
#include <c10/macros/Macros.h>
#include <c10/util/irange.h>
#include <caffe2/core/context.h>
#include <caffe2/core/operator.h>
#include <caffe2/utils/math.h>
#include <iostream>

// a map from descriptor strings (see [DESCRIPTORS])
// to the key in the switch statement that implements them
static std::unordered_map<std::string, int> op_to_key = {
  { "_cast_Byte-non_blocking-1", 0 },
  { "_cast_Byte-1", 1 },
  { "_cast_Char-non_blocking-1", 2 },
  { "_cast_Char-1", 3 },
  { "_cast_Double-non_blocking-1", 4 },
  { "_cast_Double-1", 5 },
  { "_cast_Float-non_blocking-1", 6 },
  { "_cast_Float-1", 7 },
  { "_cast_Int-non_blocking-1", 8 },
  { "_cast_Int-1", 9 },
  { "_cast_Long-non_blocking-1", 10 },
  { "_cast_Long-1", 11 },
  { "_cast_Short-non_blocking-1", 12 },
  { "_cast_Short-1", 13 },
  { "_cast_Half-non_blocking-1", 14 },
  { "_cast_Half-1", 15 },
  { "data-1", 16 },
  { "is_leaf-1", 17 },
  { "output_nr-1", 18 },
  { "_version-1", 19 },
  { "retains_grad-1", 20 },
  { "_fw_primal-level-1", 21 },
  { "_make_dual-level-2", 22 },
  { "_unpack_dual-level-1", 23 },
  { "_new_zeros_with_same_feature_meta-self_num_batch_dims-2", 24 },
  { "_new_zeros_with_same_feature_meta-2", 25 },
  { "_has_same_storage_numel-2", 26 },
  { "align_as-2", 27 },
  { "align_tensors-*", 28 },
  { "_use_cudnn_ctc_loss-blank-input_lengths-target_lengths-2", 29 },
  { "_use_cudnn_ctc_loss-blank-4", 30 },
  { "_cudnn_ctc_loss-blank-deterministic-input_lengths-target_lengths-zero_infinity-2", 31 },
  { "_cudnn_ctc_loss-blank-deterministic-zero_infinity-4", 32 },
  { "_use_cudnn_rnn_flatten_weight-0", 33 },
  { "_cudnn_rnn_flatten_weight-batch_first-bidirectional-hidden_size-input_size-mode-num_layers-proj_size-weight_stride0-*", 34 },
  { "_cudnn_rnn-batch_first-batch_sizes-bidirectional-dropout-hidden_size-mode-num_layers-proj_size-train-weight_stride0-*", 35 },
  { "_debug_has_internal_overlap-1", 36 },
  { "_fused_dropout-p-1", 37 },
  { "_masked_scale-scale-2", 38 },
  { "native_dropout_backward-scale-2", 39 },
  { "_reshape_from_tensor-2", 40 },
  { "_shape_as_tensor-1", 41 },
  { "dropout-p-train-1", 42 },
  { "feature_dropout-p-train-1", 43 },
  { "alpha_dropout-p-train-1", 44 },
  { "feature_alpha_dropout-p-train-1", 45 },
  { "abs-1", 46 },
  { "absolute-1", 47 },
  { "angle-1", 48 },
  { "view_as_real-1", 49 },
  { "view_as_complex-1", 50 },
  { "sgn-1", 51 },
  { "chalf-1", 52 },
  { "real-1", 53 },
  { "imag-1", 54 },
  { "_conj-1", 55 },
  { "conj-1", 56 },
  { "_conj_physical-1", 57 },
  { "conj_physical-1", 58 },
  { "resolve_conj-1", 59 },
  { "resolve_neg-1", 60 },
  { "_neg_view-1", 61 },
  { "acos-1", 62 },
  { "arccos-1", 63 },
  { "avg_pool1d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 64 },
  { "avg_pool1d-ceil_mode-kernel_size-padding-stride-1", 65 },
  { "avg_pool1d-kernel_size-padding-stride-1", 66 },
  { "avg_pool1d-kernel_size-stride-1", 67 },
  { "avg_pool1d-kernel_size-1", 68 },
  { "adaptive_avg_pool1d-output_size-1", 69 },
  { "adaptive_max_pool1d-output_size-1", 70 },
  { "add-alpha-2", 71 },
  { "add-2", 72 },
  { "_add_relu-alpha-2", 73 },
  { "_add_relu-2", 74 },
  { "_add_relu-alpha-other-1", 75 },
  { "_add_relu-other-1", 76 },
  { "add-alpha-other-1", 77 },
  { "add-other-1", 78 },
  { "addmv-alpha-beta-3", 79 },
  { "addmv-beta-3", 80 },
  { "addmv-3", 81 },
  { "addr-alpha-beta-3", 82 },
  { "addr-beta-3", 83 },
  { "addr-3", 84 },
  { "affine_grid_generator-align_corners-size-1", 85 },
  { "affine_grid_generator_backward-align_corners-size-1", 86 },
  { "_is_all_true-1", 87 },
  { "_is_any_true-1", 88 },
  { "_test_check_tensor-1", 89 },
  { "_test_functorch_fallback-2", 90 },
  { "all-dim-keepdim-1", 91 },
  { "all-dim-1", 92 },
  { "all-1", 93 },
  { "allclose-atol-equal_nan-rtol-2", 94 },
  { "allclose-atol-rtol-2", 95 },
  { "allclose-rtol-2", 96 },
  { "allclose-2", 97 },
  { "any-dim-keepdim-1", 98 },
  { "any-dim-1", 99 },
  { "any-1", 100 },
  { "_dim_arange-dim-1", 101 },
  { "argmax-1", 102 },
  { "argmin-1", 103 },
  { "acosh-1", 104 },
  { "arccosh-1", 105 },
  { "asinh-1", 106 },
  { "arcsinh-1", 107 },
  { "atanh-1", 108 },
  { "arctanh-1", 109 },
  { "as_strided-size-stride-1", 110 },
  { "asin-1", 111 },
  { "arcsin-1", 112 },
  { "atan-1", 113 },
  { "arctan-1", 114 },
  { "atleast_1d-1", 115 },
  { "atleast_1d-*", 116 },
  { "atleast_2d-1", 117 },
  { "atleast_2d-*", 118 },
  { "atleast_3d-1", 119 },
  { "atleast_3d-*", 120 },
  { "baddbmm-alpha-beta-3", 121 },
  { "baddbmm-beta-3", 122 },
  { "baddbmm-3", 123 },
  { "batch_norm-cudnn_enabled-eps-momentum-training-5", 124 },
  { "quantized_batch_norm-eps-output_scale-output_zero_point-5", 125 },
  { "_batch_norm_impl_index-cudnn_enabled-eps-momentum-training-5", 126 },
  { "_batch_norm_impl_index_backward-eps-impl_index-output_mask-train-8", 127 },
  { "bernoulli-1", 128 },
  { "bernoulli-p-1", 129 },
  { "bilinear-4", 130 },
  { "bilinear-3", 131 },
  { "binary_cross_entropy-reduction-3", 132 },
  { "binary_cross_entropy-3", 133 },
  { "binary_cross_entropy-2", 134 },
  { "binary_cross_entropy_backward-reduction-4", 135 },
  { "binary_cross_entropy_backward-4", 136 },
  { "binary_cross_entropy_backward-3", 137 },
  { "binary_cross_entropy_with_logits-reduction-4", 138 },
  { "binary_cross_entropy_with_logits-4", 139 },
  { "binary_cross_entropy_with_logits-3", 140 },
  { "binary_cross_entropy_with_logits-2", 141 },
  { "bincount-minlength-2", 142 },
  { "bincount-2", 143 },
  { "bincount-1", 144 },
  { "bitwise_not-1", 145 },
  { "copysign-2", 146 },
  { "copysign-other-1", 147 },
  { "_lazy_clone-1", 148 },
  { "logical_not-1", 149 },
  { "logical_xor-2", 150 },
  { "logical_and-2", 151 },
  { "logical_or-2", 152 },
  { "bmm-2", 153 },
  { "broadcast_tensors-*", 154 },
  { "broadcast_to-size-1", 155 },
  { "_sparse_broadcast_to-size-1", 156 },
  { "cat-dim-*", 157 },
  { "cat-*", 158 },
  { "concat-dim-*", 159 },
  { "concat-*", 160 },
  { "concatenate-dim-*", 161 },
  { "concatenate-*", 162 },
  { "block_diag-*", 163 },
  { "ceil-1", 164 },
  { "chain_matmul-*", 165 },
  { "unsafe_chunk-chunks-dim-1", 166 },
  { "unsafe_chunk-chunks-1", 167 },
  { "chunk-chunks-dim-1", 168 },
  { "chunk-chunks-1", 169 },
  { "tensor_split-dim-sections-1", 170 },
  { "tensor_split-sections-1", 171 },
  { "tensor_split-dim-indices-1", 172 },
  { "tensor_split-indices-1", 173 },
  { "tensor_split-dim-2", 174 },
  { "tensor_split-2", 175 },
  { "clamp-1", 176 },
  { "clamp-3", 177 },
  { "clamp-2", 178 },
  { "clamp_max-max-1", 179 },
  { "clamp_max-2", 180 },
  { "clamp_min-min-1", 181 },
  { "clamp_min-2", 182 },
  { "clip-1", 183 },
  { "clip-3", 184 },
  { "clip-2", 185 },
  { "cudnn_is_acceptable-1", 186 },
  { "complex-2", 187 },
  { "polar-2", 188 },
  { "constant_pad_nd-pad-value-1", 189 },
  { "constant_pad_nd-pad-1", 190 },
  { "contiguous-1", 191 },
  { "convolution-dilation-groups-output_padding-padding-stride-transposed-3", 192 },
  { "convolution_overrideable-dilation-groups-output_padding-padding-stride-transposed-3", 193 },
  { "convolution_backward_overrideable-dilation-groups-output_mask-output_padding-padding-stride-transposed-3", 194 },
  { "_convolution-allow_tf32-benchmark-cudnn_enabled-deterministic-dilation-groups-output_padding-padding-stride-transposed-3", 195 },
  { "_convolution-benchmark-cudnn_enabled-deterministic-dilation-groups-output_padding-padding-stride-transposed-3", 196 },
  { "_convolution_double_backward-dilation-groups-output_mask-output_padding-padding-stride-transposed-6", 197 },
  { "conv1d-dilation-groups-padding-stride-3", 198 },
  { "conv1d-dilation-padding-stride-3", 199 },
  { "conv1d-padding-stride-3", 200 },
  { "conv1d-stride-3", 201 },
  { "conv1d-3", 202 },
  { "conv1d-2", 203 },
  { "conv2d-dilation-groups-padding-stride-3", 204 },
  { "conv2d-dilation-padding-stride-3", 205 },
  { "conv2d-padding-stride-3", 206 },
  { "conv2d-stride-3", 207 },
  { "conv2d-3", 208 },
  { "conv2d-2", 209 },
  { "conv3d-dilation-groups-padding-stride-3", 210 },
  { "conv3d-dilation-padding-stride-3", 211 },
  { "conv3d-padding-stride-3", 212 },
  { "conv3d-stride-3", 213 },
  { "conv3d-3", 214 },
  { "conv3d-2", 215 },
  { "conv_tbc-pad-3", 216 },
  { "conv_tbc-3", 217 },
  { "conv_tbc_backward-pad-4", 218 },
  { "conv_transpose1d-dilation-groups-output_padding-padding-stride-3", 219 },
  { "conv_transpose1d-groups-output_padding-padding-stride-3", 220 },
  { "conv_transpose1d-output_padding-padding-stride-3", 221 },
  { "conv_transpose1d-padding-stride-3", 222 },
  { "conv_transpose1d-stride-3", 223 },
  { "conv_transpose1d-3", 224 },
  { "conv_transpose1d-2", 225 },
  { "conv_transpose2d-dilation-groups-output_padding-padding-stride-3", 226 },
  { "conv_transpose2d-groups-output_padding-padding-stride-3", 227 },
  { "conv_transpose2d-output_padding-padding-stride-3", 228 },
  { "conv_transpose2d-padding-stride-3", 229 },
  { "conv_transpose2d-stride-3", 230 },
  { "conv_transpose2d-3", 231 },
  { "conv_transpose2d-2", 232 },
  { "conv_transpose3d-dilation-groups-output_padding-padding-stride-3", 233 },
  { "conv_transpose3d-groups-output_padding-padding-stride-3", 234 },
  { "conv_transpose3d-output_padding-padding-stride-3", 235 },
  { "conv_transpose3d-padding-stride-3", 236 },
  { "conv_transpose3d-stride-3", 237 },
  { "conv_transpose3d-3", 238 },
  { "conv_transpose3d-2", 239 },
  { "copy-non_blocking-2", 240 },
  { "copy-2", 241 },
  { "_copy_from-non_blocking-2", 242 },
  { "_copy_from-2", 243 },
  { "_copy_from_and_resize-2", 244 },
  { "cos-1", 245 },
  { "cosh-1", 246 },
  { "cosine_embedding_loss-margin-reduction-3", 247 },
  { "cosine_embedding_loss-margin-3", 248 },
  { "cosine_embedding_loss-3", 249 },
  { "count_nonzero-dim-1", 250 },
  { "count_nonzero-1", 251 },
  { "cov-correction-3", 252 },
  { "cov-correction-2", 253 },
  { "cov-correction-1", 254 },
  { "cov-1", 255 },
  { "corrcoef-1", 256 },
  { "cudnn_affine_grid_generator-C-H-N-W-1", 257 },
  { "cudnn_affine_grid_generator_backward-C-H-N-W-1", 258 },
  { "cudnn_batch_norm-epsilon-exponential_average_factor-training-5", 259 },
  { "cudnn_batch_norm_backward-epsilon-8", 260 },
  { "cudnn_convolution-allow_tf32-benchmark-deterministic-dilation-groups-padding-stride-2", 261 },
  { "cudnn_convolution_transpose-allow_tf32-benchmark-deterministic-dilation-groups-output_padding-padding-stride-2", 262 },
  { "_mps_convolution_transpose-dilation-groups-output_padding-padding-stride-2", 263 },
  { "mps_convolution_transpose_backward-dilation-groups-output_mask-output_padding-padding-stride-3", 264 },
  { "cudnn_convolution_relu-dilation-groups-padding-stride-3", 265 },
  { "cudnn_grid_sampler-2", 266 },
  { "cudnn_grid_sampler_backward-3", 267 },
  { "cummax-dim-1", 268 },
  { "cummin-dim-1", 269 },
  { "cummaxmin_backward-dim-3", 270 },
  { "cumprod-dim-1", 271 },
  { "cumprod_backward-dim-3", 272 },
  { "cumsum-dim-1", 273 },
  { "cumulative_trapezoid-dim-2", 274 },
  { "cumulative_trapezoid-2", 275 },
  { "cumulative_trapezoid-dim-dx-1", 276 },
  { "cumulative_trapezoid-dx-1", 277 },
  { "cumulative_trapezoid-1", 278 },
  { "ctc_loss-blank-input_lengths-reduction-target_lengths-zero_infinity-2", 279 },
  { "ctc_loss-blank-input_lengths-reduction-target_lengths-2", 280 },
  { "ctc_loss-blank-input_lengths-target_lengths-2", 281 },
  { "ctc_loss-input_lengths-target_lengths-2", 282 },
  { "ctc_loss-blank-reduction-zero_infinity-4", 283 },
  { "ctc_loss-blank-reduction-4", 284 },
  { "ctc_loss-blank-4", 285 },
  { "ctc_loss-4", 286 },
  { "_ctc_loss-blank-input_lengths-target_lengths-zero_infinity-2", 287 },
  { "_ctc_loss-blank-input_lengths-target_lengths-2", 288 },
  { "_ctc_loss-input_lengths-target_lengths-2", 289 },
  { "_ctc_loss-blank-zero_infinity-4", 290 },
  { "_ctc_loss-blank-4", 291 },
  { "_ctc_loss-4", 292 },
  { "_ctc_loss_backward-blank-input_lengths-target_lengths-zero_infinity-5", 293 },
  { "_ctc_loss_backward-blank-input_lengths-target_lengths-5", 294 },
  { "_ctc_loss_backward-blank-zero_infinity-7", 295 },
  { "_ctc_loss_backward-blank-7", 296 },
  { "diag_embed-dim1-dim2-offset-1", 297 },
  { "diag_embed-dim1-offset-1", 298 },
  { "diag_embed-offset-1", 299 },
  { "diag_embed-1", 300 },
  { "diagflat-offset-1", 301 },
  { "diagflat-1", 302 },
  { "diagonal-dim1-dim2-offset-1", 303 },
  { "diagonal-dim1-offset-1", 304 },
  { "diagonal-offset-1", 305 },
  { "diagonal-1", 306 },
  { "linalg_diagonal-dim1-dim2-offset-1", 307 },
  { "linalg_diagonal-dim1-offset-1", 308 },
  { "linalg_diagonal-offset-1", 309 },
  { "linalg_diagonal-1", 310 },
  { "diagonal_backward-dim1-dim2-input_sizes-offset-1", 311 },
  { "diff-dim-n-3", 312 },
  { "diff-dim-n-2", 313 },
  { "diff-dim-n-1", 314 },
  { "diff-n-1", 315 },
  { "diff-1", 316 },
  { "gradient-1", 317 },
  { "gradient-dim-edge_order-spacing-1", 318 },
  { "gradient-dim-spacing-1", 319 },
  { "gradient-dim-edge_order-1", 320 },
  { "gradient-dim-1", 321 },
  { "gradient-*", 322 },
  { "gradient-dim-edge_order-*", 323 },
  { "gradient-dim-*", 324 },
  { "div-2", 325 },
  { "div-other-1", 326 },
  { "divide-2", 327 },
  { "divide-other-1", 328 },
  { "true_divide-2", 329 },
  { "true_divide-other-1", 330 },
  { "dot-2", 331 },
  { "vdot-2", 332 },
  { "embedding-padding_idx-scale_grad_by_freq-sparse-2", 333 },
  { "embedding-padding_idx-scale_grad_by_freq-2", 334 },
  { "embedding-padding_idx-2", 335 },
  { "embedding-2", 336 },
  { "embedding_backward-num_weights-padding_idx-scale_grad_by_freq-sparse-2", 337 },
  { "embedding_dense_backward-num_weights-padding_idx-scale_grad_by_freq-2", 338 },
  { "embedding_sparse_backward-num_weights-padding_idx-scale_grad_by_freq-2", 339 },
  { "_embedding_bag_forward_only-include_last_offset-mode-padding_idx-scale_grad_by_freq-sparse-4", 340 },
  { "_embedding_bag_forward_only-include_last_offset-mode-scale_grad_by_freq-sparse-4", 341 },
  { "_embedding_bag_forward_only-mode-scale_grad_by_freq-sparse-4", 342 },
  { "_embedding_bag_forward_only-mode-scale_grad_by_freq-sparse-3", 343 },
  { "_embedding_bag_forward_only-mode-scale_grad_by_freq-3", 344 },
  { "_embedding_bag_forward_only-scale_grad_by_freq-3", 345 },
  { "_embedding_bag_forward_only-3", 346 },
  { "row_stack-*", 347 },
  { "embedding_bag-include_last_offset-mode-scale_grad_by_freq-sparse-4", 348 },
  { "embedding_bag-mode-scale_grad_by_freq-sparse-4", 349 },
  { "embedding_bag-mode-scale_grad_by_freq-sparse-3", 350 },
  { "embedding_bag-mode-scale_grad_by_freq-3", 351 },
  { "embedding_bag-scale_grad_by_freq-3", 352 },
  { "embedding_bag-3", 353 },
  { "_embedding_bag-include_last_offset-mode-padding_idx-scale_grad_by_freq-sparse-4", 354 },
  { "_embedding_bag-include_last_offset-mode-scale_grad_by_freq-sparse-4", 355 },
  { "_embedding_bag-mode-scale_grad_by_freq-sparse-4", 356 },
  { "_embedding_bag-mode-scale_grad_by_freq-sparse-3", 357 },
  { "_embedding_bag-mode-scale_grad_by_freq-3", 358 },
  { "_embedding_bag-scale_grad_by_freq-3", 359 },
  { "_embedding_bag-3", 360 },
  { "_embedding_bag_backward-mode-num_weights-padding_idx-scale_grad_by_freq-sparse-7", 361 },
  { "_embedding_bag_backward-mode-num_weights-scale_grad_by_freq-sparse-7", 362 },
  { "_embedding_bag_sparse_backward-mode-num_weights-padding_idx-scale_grad_by_freq-6", 363 },
  { "_embedding_bag_sparse_backward-mode-num_weights-scale_grad_by_freq-6", 364 },
  { "_embedding_bag_dense_backward-mode-num_weights-padding_idx-scale_grad_by_freq-6", 365 },
  { "_embedding_bag_dense_backward-mode-num_weights-scale_grad_by_freq-6", 366 },
  { "_embedding_bag_per_sample_weights_backward-mode-padding_idx-5", 367 },
  { "_embedding_bag_per_sample_weights_backward-mode-5", 368 },
  { "erf-1", 369 },
  { "erfc-1", 370 },
  { "exp-1", 371 },
  { "exp2-1", 372 },
  { "expm1-1", 373 },
  { "expand-implicit-size-1", 374 },
  { "expand-size-1", 375 },
  { "expand_as-2", 376 },
  { "flatten-end_dim-start_dim-1", 377 },
  { "flatten-start_dim-1", 378 },
  { "flatten-1", 379 },
  { "unflatten-dim-sizes-1", 380 },
  { "fill-value-1", 381 },
  { "fill-2", 382 },
  { "floor-1", 383 },
  { "floor_divide-2", 384 },
  { "floor_divide-other-1", 385 },
  { "frac-1", 386 },
  { "gcd-2", 387 },
  { "lcm-2", 388 },
  { "grid_sampler-align_corners-interpolation_mode-padding_mode-2", 389 },
  { "grid_sampler_2d-align_corners-interpolation_mode-padding_mode-2", 390 },
  { "grid_sampler_2d_backward-align_corners-interpolation_mode-output_mask-padding_mode-3", 391 },
  { "_grid_sampler_2d_cpu_fallback-align_corners-interpolation_mode-padding_mode-2", 392 },
  { "_grid_sampler_2d_cpu_fallback_backward-align_corners-interpolation_mode-padding_mode-3", 393 },
  { "grid_sampler_3d-align_corners-interpolation_mode-padding_mode-2", 394 },
  { "grid_sampler_3d_backward-align_corners-interpolation_mode-output_mask-padding_mode-3", 395 },
  { "hinge_embedding_loss-margin-reduction-2", 396 },
  { "hinge_embedding_loss-margin-2", 397 },
  { "hinge_embedding_loss-2", 398 },
  { "group_norm-cudnn_enabled-eps-num_groups-3", 399 },
  { "group_norm-eps-num_groups-3", 400 },
  { "group_norm-num_groups-3", 401 },
  { "group_norm-num_groups-2", 402 },
  { "group_norm-num_groups-1", 403 },
  { "native_group_norm-C-HxW-N-eps-group-3", 404 },
  { "native_group_norm_backward-C-HxW-N-group-output_mask-5", 405 },
  { "_fft_r2c-dim-normalization-onesided-1", 406 },
  { "_fft_c2r-dim-last_dim_size-normalization-1", 407 },
  { "_fft_c2c-dim-forward-normalization-1", 408 },
  { "index-*", 409 },
  { "_unsafe_index-*", 410 },
  { "index_copy-dim-3", 411 },
  { "index_put-accumulate-*", 412 },
  { "index_put-*", 413 },
  { "_unsafe_index_put-accumulate-*", 414 },
  { "_unsafe_index_put-*", 415 },
  { "instance_norm-cudnn_enabled-eps-momentum-use_input_stats-5", 416 },
  { "isclose-atol-equal_nan-rtol-2", 417 },
  { "isclose-atol-rtol-2", 418 },
  { "isclose-rtol-2", 419 },
  { "isclose-2", 420 },
  { "isin-assume_unique-invert-2", 421 },
  { "isin-assume_unique-2", 422 },
  { "isin-2", 423 },
  { "isin-assume_unique-invert-test_element-1", 424 },
  { "isin-assume_unique-test_element-1", 425 },
  { "isin-test_element-1", 426 },
  { "isin-assume_unique-element-invert-1", 427 },
  { "isin-assume_unique-element-1", 428 },
  { "isin-element-1", 429 },
  { "isnan-1", 430 },
  { "is_distributed-1", 431 },
  { "is_floating_point-1", 432 },
  { "is_complex-1", 433 },
  { "is_conj-1", 434 },
  { "_is_zerotensor-1", 435 },
  { "is_neg-1", 436 },
  { "isreal-1", 437 },
  { "is_nonzero-1", 438 },
  { "is_same_size-2", 439 },
  { "is_signed-1", 440 },
  { "is_inference-1", 441 },
  { "kl_div-log_target-reduction-2", 442 },
  { "kl_div-reduction-2", 443 },
  { "kl_div-2", 444 },
  { "kron-2", 445 },
  { "kthvalue-dim-k-keepdim-1", 446 },
  { "kthvalue-dim-k-1", 447 },
  { "kthvalue-k-1", 448 },
  { "layer_norm-cudnn_enable-eps-normalized_shape-3", 449 },
  { "layer_norm-eps-normalized_shape-3", 450 },
  { "layer_norm-normalized_shape-3", 451 },
  { "layer_norm-normalized_shape-2", 452 },
  { "layer_norm-normalized_shape-1", 453 },
  { "native_layer_norm-eps-normalized_shape-3", 454 },
  { "native_layer_norm_backward-normalized_shape-output_mask-6", 455 },
  { "nan_to_num-1", 456 },
  { "linear-3", 457 },
  { "linear-2", 458 },
  { "linear_backward-output_mask-3", 459 },
  { "mkldnn_linear-3", 460 },
  { "mkldnn_linear-2", 461 },
  { "mkldnn_linear_backward_input-input_size-2", 462 },
  { "mkldnn_linear_backward_weights-bias_defined-3", 463 },
  { "mkldnn_linear_backward-output_mask-3", 464 },
  { "_cslt_compress-1", 465 },
  { "_cslt_sparse_mm-4", 466 },
  { "_cslt_sparse_mm-3", 467 },
  { "_cslt_sparse_mm-2", 468 },
  { "_cslt_sparse_mm_search-4", 469 },
  { "_cslt_sparse_mm_search-3", 470 },
  { "_cslt_sparse_mm_search-2", 471 },
  { "_sparse_semi_structured_linear-4", 472 },
  { "_sparse_semi_structured_linear-3", 473 },
  { "_mixed_dtypes_linear-4", 474 },
  { "_mixed_dtypes_linear-3", 475 },
  { "fbgemm_linear_int8_weight_fp32_activation-weight_scale-weight_zero_point-5", 476 },
  { "fbgemm_linear_int8_weight-weight_scale-weight_zero_point-5", 477 },
  { "fbgemm_pack_gemm_matrix_fp16-1", 478 },
  { "fbgemm_linear_fp16_weight_fp32_activation-3", 479 },
  { "fbgemm_linear_fp16_weight-3", 480 },
  { "fbgemm_pack_quantized_matrix-1", 481 },
  { "fbgemm_pack_quantized_matrix-K-N-1", 482 },
  { "ldexp-2", 483 },
  { "log-1", 484 },
  { "log10-1", 485 },
  { "log1p-1", 486 },
  { "log2-1", 487 },
  { "logaddexp-2", 488 },
  { "logaddexp2-2", 489 },
  { "xlogy-2", 490 },
  { "xlogy-self-1", 491 },
  { "xlogy-other-1", 492 },
  { "log_softmax-dim-1", 493 },
  { "_log_softmax-dim-half_to_float-1", 494 },
  { "_logcumsumexp-dim-1", 495 },
  { "logcumsumexp-dim-1", 496 },
  { "logsumexp-dim-keepdim-1", 497 },
  { "logsumexp-dim-1", 498 },
  { "margin_ranking_loss-margin-reduction-3", 499 },
  { "margin_ranking_loss-margin-3", 500 },
  { "margin_ranking_loss-3", 501 },
  { "matmul-2", 502 },
  { "matmul_backward-mask-3", 503 },
  { "matrix_power-n-1", 504 },
  { "matrix_exp-1", 505 },
  { "matrix_exp_backward-2", 506 },
  { "_aminmax-1", 507 },
  { "_aminmax-dim-keepdim-1", 508 },
  { "_aminmax-dim-1", 509 },
  { "aminmax-1", 510 },
  { "_compute_linear_combination-2", 511 },
  { "max-dim-keepdim-1", 512 },
  { "max-dim-1", 513 },
  { "value_selecting_reduction_backward-dim-keepdim-sizes-2", 514 },
  { "amax-dim-keepdim-1", 515 },
  { "amax-dim-1", 516 },
  { "amax-1", 517 },
  { "max_pool1d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 518 },
  { "max_pool1d_with_indices-dilation-kernel_size-padding-stride-1", 519 },
  { "max_pool1d_with_indices-kernel_size-padding-stride-1", 520 },
  { "max_pool1d_with_indices-kernel_size-stride-1", 521 },
  { "max_pool1d_with_indices-kernel_size-1", 522 },
  { "max_pool1d-ceil_mode-dilation-kernel_size-padding-stride-1", 523 },
  { "max_pool1d-dilation-kernel_size-padding-stride-1", 524 },
  { "max_pool1d-kernel_size-padding-stride-1", 525 },
  { "max_pool1d-kernel_size-stride-1", 526 },
  { "max_pool1d-kernel_size-1", 527 },
  { "max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 528 },
  { "max_pool2d-dilation-kernel_size-padding-stride-1", 529 },
  { "max_pool2d-kernel_size-padding-stride-1", 530 },
  { "max_pool2d-kernel_size-stride-1", 531 },
  { "max_pool2d-kernel_size-1", 532 },
  { "max_pool2d_backward-ceil_mode-dilation-kernel_size-padding-stride-2", 533 },
  { "max_pool2d_backward-dilation-kernel_size-padding-stride-2", 534 },
  { "max_pool2d_backward-kernel_size-padding-stride-2", 535 },
  { "max_pool2d_backward-kernel_size-stride-2", 536 },
  { "max_pool2d_backward-kernel_size-2", 537 },
  { "mkldnn_max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 538 },
  { "mkldnn_max_pool2d-dilation-kernel_size-padding-stride-1", 539 },
  { "mkldnn_max_pool2d-kernel_size-padding-stride-1", 540 },
  { "mkldnn_max_pool2d-kernel_size-stride-1", 541 },
  { "mkldnn_max_pool2d-kernel_size-1", 542 },
  { "mkldnn_max_pool2d_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 543 },
  { "mkldnn_max_pool2d_backward-dilation-kernel_size-padding-stride-3", 544 },
  { "mkldnn_max_pool2d_backward-kernel_size-padding-stride-3", 545 },
  { "mkldnn_max_pool2d_backward-kernel_size-stride-3", 546 },
  { "mkldnn_max_pool2d_backward-kernel_size-3", 547 },
  { "mkldnn_max_pool3d-ceil_mode-dilation-kernel_size-padding-stride-1", 548 },
  { "mkldnn_max_pool3d-dilation-kernel_size-padding-stride-1", 549 },
  { "mkldnn_max_pool3d-kernel_size-padding-stride-1", 550 },
  { "mkldnn_max_pool3d-kernel_size-stride-1", 551 },
  { "mkldnn_max_pool3d-kernel_size-1", 552 },
  { "mkldnn_max_pool3d_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 553 },
  { "mkldnn_max_pool3d_backward-dilation-kernel_size-padding-stride-3", 554 },
  { "mkldnn_max_pool3d_backward-kernel_size-padding-stride-3", 555 },
  { "mkldnn_max_pool3d_backward-kernel_size-stride-3", 556 },
  { "mkldnn_max_pool3d_backward-kernel_size-3", 557 },
  { "quantized_max_pool1d-ceil_mode-dilation-kernel_size-padding-stride-1", 558 },
  { "quantized_max_pool1d-dilation-kernel_size-padding-stride-1", 559 },
  { "quantized_max_pool1d-kernel_size-padding-stride-1", 560 },
  { "quantized_max_pool1d-kernel_size-stride-1", 561 },
  { "quantized_max_pool1d-kernel_size-1", 562 },
  { "quantized_max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 563 },
  { "quantized_max_pool2d-dilation-kernel_size-padding-stride-1", 564 },
  { "quantized_max_pool2d-kernel_size-padding-stride-1", 565 },
  { "quantized_max_pool2d-kernel_size-stride-1", 566 },
  { "quantized_max_pool2d-kernel_size-1", 567 },
  { "quantized_max_pool3d-ceil_mode-dilation-kernel_size-padding-stride-1", 568 },
  { "quantized_max_pool3d-dilation-kernel_size-padding-stride-1", 569 },
  { "quantized_max_pool3d-kernel_size-padding-stride-1", 570 },
  { "quantized_max_pool3d-kernel_size-stride-1", 571 },
  { "quantized_max_pool3d-kernel_size-1", 572 },
  { "max_pool3d-ceil_mode-dilation-kernel_size-padding-stride-1", 573 },
  { "max_pool3d-dilation-kernel_size-padding-stride-1", 574 },
  { "max_pool3d-kernel_size-padding-stride-1", 575 },
  { "max_pool3d-kernel_size-stride-1", 576 },
  { "max_pool3d-kernel_size-1", 577 },
  { "mean-1", 578 },
  { "nanmean-1", 579 },
  { "median-1", 580 },
  { "median-dim-keepdim-1", 581 },
  { "median-dim-1", 582 },
  { "nanmedian-1", 583 },
  { "nanmedian-dim-keepdim-1", 584 },
  { "nanmedian-dim-1", 585 },
  { "min-dim-keepdim-1", 586 },
  { "min-dim-1", 587 },
  { "amin-dim-keepdim-1", 588 },
  { "amin-dim-1", 589 },
  { "amin-1", 590 },
  { "_mps_convolution-dilation-groups-padding-stride-3", 591 },
  { "mps_convolution_backward-dilation-groups-output_mask-padding-stride-3", 592 },
  { "mkldnn_convolution-dilation-groups-padding-stride-3", 593 },
  { "mkldnn_rnn_layer-batch_first-batch_sizes-bidirectional-has_biases-hidden_size-mode-num_layers-reverse-train-7", 594 },
  { "mkldnn_rnn_layer_backward-batch_first-batch_sizes-bidirectional-has_biases-hidden_size-mode-num_layers-reverse-train-14", 595 },
  { "miopen_batch_norm-epsilon-exponential_average_factor-training-5", 596 },
  { "miopen_batch_norm_backward-epsilon-7", 597 },
  { "miopen_convolution-benchmark-deterministic-dilation-groups-padding-stride-3", 598 },
  { "miopen_convolution_transpose-benchmark-deterministic-dilation-groups-output_padding-padding-stride-3", 599 },
  { "miopen_depthwise_convolution-benchmark-deterministic-dilation-groups-padding-stride-3", 600 },
  { "miopen_convolution_relu-dilation-groups-padding-stride-3", 601 },
  { "miopen_rnn-batch_first-batch_sizes-bidirectional-dropout-hidden_size-mode-num_layers-train-weight_stride0-*", 602 },
  { "mm-2", 603 },
  { "_int_mm-2", 604 },
  { "_convert_weight_to_int4pack-innerKTiles-1", 605 },
  { "_weight_int4pack_mm-qGroupSize-3", 606 },
  { "_weight_int8pack_mm-3", 607 },
  { "_sparse_mm-2", 608 },
  { "_sparse_sparse_matmul-2", 609 },
  { "mode-dim-keepdim-1", 610 },
  { "mode-dim-1", 611 },
  { "mode-1", 612 },
  { "mul-2", 613 },
  { "mul-other-1", 614 },
  { "multiply-2", 615 },
  { "multiply-other-1", 616 },
  { "mv-2", 617 },
  { "mvlgamma-p-1", 618 },
  { "narrow_copy-dim-length-start-1", 619 },
  { "narrow-dim-length-start-1", 620 },
  { "narrow-dim-length-2", 621 },
  { "native_batch_norm-eps-momentum-training-5", 622 },
  { "_native_batch_norm_legit-eps-momentum-training-5", 623 },
  { "_native_batch_norm_legit_no_training-eps-momentum-5", 624 },
  { "_native_batch_norm_legit-eps-momentum-training-3", 625 },
  { "batch_norm_stats-eps-1", 626 },
  { "batch_norm_elemt-eps-5", 627 },
  { "batch_norm_gather_stats-count-eps-momentum-5", 628 },
  { "batch_norm_gather_stats_with_counts-eps-momentum-6", 629 },
  { "native_batch_norm_backward-eps-output_mask-train-7", 630 },
  { "batch_norm_backward_reduce-bias_g-input_g-weight_g-5", 631 },
  { "batch_norm_backward_elemt-8", 632 },
  { "batch_norm_update_stats-momentum-3", 633 },
  { "is_vulkan_available-0", 634 },
  { "_nnpack_available-0", 635 },
  { "_nnpack_spatial_convolution-padding-stride-3", 636 },
  { "_nnpack_spatial_convolution-padding-3", 637 },
  { "pairwise_distance-eps-keepdim-p-2", 638 },
  { "pairwise_distance-eps-p-2", 639 },
  { "pairwise_distance-p-2", 640 },
  { "pairwise_distance-2", 641 },
  { "cdist-p-2", 642 },
  { "cdist-2", 643 },
  { "_euclidean_dist-2", 644 },
  { "_cdist_backward-p-4", 645 },
  { "pdist-p-1", 646 },
  { "pdist-1", 647 },
  { "_pdist_forward-p-1", 648 },
  { "_pdist_forward-1", 649 },
  { "_pdist_backward-p-3", 650 },
  { "cosine_similarity-dim-eps-2", 651 },
  { "cosine_similarity-dim-2", 652 },
  { "cosine_similarity-2", 653 },
  { "permute-dims-1", 654 },
  { "movedim-destination-source-1", 655 },
  { "moveaxis-destination-source-1", 656 },
  { "numpy_T-1", 657 },
  { "matrix_H-1", 658 },
  { "mT-1", 659 },
  { "mH-1", 660 },
  { "adjoint-1", 661 },
  { "pixel_shuffle-upscale_factor-1", 662 },
  { "pixel_unshuffle-downscale_factor-1", 663 },
  { "channel_shuffle-groups-1", 664 },
  { "native_channel_shuffle-groups-1", 665 },
  { "is_pinned-1", 666 },
  { "pin_memory-1", 667 },
  { "_pin_memory-1", 668 },
  { "pinverse-rcond-1", 669 },
  { "pinverse-1", 670 },
  { "poisson_nll_loss-eps-full-log_input-reduction-2", 671 },
  { "rad2deg-1", 672 },
  { "deg2rad-1", 673 },
  { "ravel-1", 674 },
  { "reciprocal-1", 675 },
  { "neg-1", 676 },
  { "negative-1", 677 },
  { "repeat-repeats-1", 678 },
  { "repeat_interleave-1", 679 },
  { "repeat_interleave-2", 680 },
  { "repeat_interleave-repeats-1", 681 },
  { "reshape-shape-1", 682 },
  { "_reshape_copy-size-1", 683 },
  { "_reshape_alias-size-stride-1", 684 },
  { "_mkldnn_reshape-shape-1", 685 },
  { "reshape_as-2", 686 },
  { "round-1", 687 },
  { "round-decimals-1", 688 },
  { "rrelu-lower-training-upper-1", 689 },
  { "rrelu-lower-upper-1", 690 },
  { "rrelu-lower-1", 691 },
  { "rrelu-1", 692 },
  { "relu-1", 693 },
  { "relu6-1", 694 },
  { "prelu-2", 695 },
  { "_prelu_kernel-2", 696 },
  { "_prelu_kernel_backward-3", 697 },
  { "gelu-1", 698 },
  { "gelu_backward-2", 699 },
  { "infinitely_differentiable_gelu_backward-2", 700 },
  { "hardshrink-lambd-1", 701 },
  { "hardshrink-1", 702 },
  { "hardshrink_backward-lambd-2", 703 },
  { "rsqrt-1", 704 },
  { "select-dim-index-1", 705 },
  { "select_backward-dim-index-input_sizes-1", 706 },
  { "_nested_select_backward-dim-index-2", 707 },
  { "selu-1", 708 },
  { "celu-alpha-1", 709 },
  { "celu-1", 710 },
  { "silu-1", 711 },
  { "silu_backward-2", 712 },
  { "mish-1", 713 },
  { "mish_backward-2", 714 },
  { "sigmoid-1", 715 },
  { "logit-1", 716 },
  { "sin-1", 717 },
  { "sinc-1", 718 },
  { "sinh-1", 719 },
  { "detach-1", 720 },
  { "size-dim-1", 721 },
  { "slice-dim-1", 722 },
  { "slice-1", 723 },
  { "slice_backward-dim-end-input_sizes-start-step-1", 724 },
  { "slice_inverse-dim-2", 725 },
  { "slice_inverse-2", 726 },
  { "slice_scatter-dim-2", 727 },
  { "slice_scatter-2", 728 },
  { "select_scatter-dim-index-2", 729 },
  { "diagonal_scatter-dim1-dim2-offset-2", 730 },
  { "diagonal_scatter-dim1-offset-2", 731 },
  { "diagonal_scatter-offset-2", 732 },
  { "diagonal_scatter-2", 733 },
  { "as_strided_scatter-size-stride-2", 734 },
  { "smm-2", 735 },
  { "softmax-dim-1", 736 },
  { "_softmax-dim-half_to_float-1", 737 },
  { "unsafe_split-dim-split_size-1", 738 },
  { "unsafe_split-split_size-1", 739 },
  { "split-dim-split_size-1", 740 },
  { "split-split_size-1", 741 },
  { "unsafe_split_with_sizes-dim-split_sizes-1", 742 },
  { "unsafe_split_with_sizes-split_sizes-1", 743 },
  { "split_with_sizes-dim-split_sizes-1", 744 },
  { "split_with_sizes-split_sizes-1", 745 },
  { "hsplit-sections-1", 746 },
  { "hsplit-indices-1", 747 },
  { "vsplit-sections-1", 748 },
  { "vsplit-indices-1", 749 },
  { "dsplit-sections-1", 750 },
  { "dsplit-indices-1", 751 },
  { "squeeze-1", 752 },
  { "squeeze-dim-1", 753 },
  { "sspaddmm-alpha-beta-3", 754 },
  { "sspaddmm-beta-3", 755 },
  { "sspaddmm-3", 756 },
  { "_chunk_cat-dim-num_chunks-*", 757 },
  { "stack-dim-*", 758 },
  { "stack-*", 759 },
  { "_stack-dim-*", 760 },
  { "_stack-*", 761 },
  { "hstack-*", 762 },
  { "vstack-*", 763 },
  { "dstack-*", 764 },
  { "stft-n_fft-1", 765 },
  { "istft-n_fft-1", 766 },
  { "stride-dim-1", 767 },
  { "sum-1", 768 },
  { "nansum-1", 769 },
  { "sum_to_size-size-1", 770 },
  { "sqrt-1", 771 },
  { "square-1", 772 },
  { "std-unbiased-1", 773 },
  { "std-1", 774 },
  { "std_mean-unbiased-1", 775 },
  { "std_mean-1", 776 },
  { "prod-1", 777 },
  { "prod-dim-keepdim-1", 778 },
  { "prod-dim-1", 779 },
  { "t-1", 780 },
  { "tan-1", 781 },
  { "tanh-1", 782 },
  { "tensordot-dims_other-dims_self-2", 783 },
  { "threshold-threshold-value-1", 784 },
  { "threshold_backward-threshold-2", 785 },
  { "tile-dims-1", 786 },
  { "transpose-dim0-dim1-1", 787 },
  { "_mkldnn_transpose-dim0-dim1-1", 788 },
  { "one_hot-num_classes-1", 789 },
  { "one_hot-1", 790 },
  { "flip-dims-1", 791 },
  { "fliplr-1", 792 },
  { "flipud-1", 793 },
  { "roll-dims-shifts-1", 794 },
  { "roll-shifts-1", 795 },
  { "rot90-dims-k-1", 796 },
  { "rot90-k-1", 797 },
  { "rot90-1", 798 },
  { "trapezoid-dim-2", 799 },
  { "trapezoid-2", 800 },
  { "trapezoid-dim-dx-1", 801 },
  { "trapezoid-dx-1", 802 },
  { "trapezoid-1", 803 },
  { "trapz-dim-2", 804 },
  { "trapz-2", 805 },
  { "trapz-dim-dx-1", 806 },
  { "trapz-dx-1", 807 },
  { "trapz-1", 808 },
  { "_transform_bias_rescale_qkv-num_heads-2", 809 },
  { "_nested_tensor_from_mask-mask_check-2", 810 },
  { "_nested_tensor_from_mask-2", 811 },
  { "_nested_tensor_from_mask_left_aligned-2", 812 },
  { "_nested_from_padded-fuse_transform_0213-2", 813 },
  { "_nested_from_padded-2", 814 },
  { "_nested_tensor_size-1", 815 },
  { "_nested_tensor_strides-1", 816 },
  { "_nested_tensor_storage_offsets-1", 817 },
  { "_nested_from_padded_and_nested_example-2", 818 },
  { "_nested_view_from_buffer-4", 819 },
  { "_nested_view_from_buffer_copy-4", 820 },
  { "_nested_view_from_jagged-ragged_idx-4", 821 },
  { "_nested_view_from_jagged-4", 822 },
  { "_nested_view_from_jagged-3", 823 },
  { "_nested_view_from_jagged_copy-ragged_idx-4", 824 },
  { "_nested_view_from_jagged_copy-4", 825 },
  { "_nested_view_from_jagged_copy-3", 826 },
  { "_nested_get_values-1", 827 },
  { "_nested_get_values_copy-1", 828 },
  { "_nested_get_offsets-1", 829 },
  { "_nested_get_lengths-1", 830 },
  { "_nested_get_ragged_idx-1", 831 },
  { "_nested_get_jagged_dummy-1", 832 },
  { "_trilinear-expand1-expand2-expand3-sumdim-unroll_dim-3", 833 },
  { "_trilinear-expand1-expand2-expand3-sumdim-3", 834 },
  { "triplet_margin_loss-eps-margin-p-reduction-swap-3", 835 },
  { "triplet_margin_loss-eps-margin-p-swap-3", 836 },
  { "triplet_margin_loss-eps-margin-p-3", 837 },
  { "triplet_margin_loss-margin-p-3", 838 },
  { "triplet_margin_loss-margin-3", 839 },
  { "triplet_margin_loss-3", 840 },
  { "trunc-1", 841 },
  { "fix-1", 842 },
  { "type_as-2", 843 },
  { "_has_compatible_shallow_copy_type-2", 844 },
  { "_unique-return_inverse-sorted-1", 845 },
  { "_unique-sorted-1", 846 },
  { "_unique-1", 847 },
  { "unique_dim-dim-return_counts-return_inverse-sorted-1", 848 },
  { "unique_dim-dim-return_inverse-sorted-1", 849 },
  { "unique_dim-dim-sorted-1", 850 },
  { "unique_dim-dim-1", 851 },
  { "unique_consecutive-return_counts-return_inverse-1", 852 },
  { "unique_consecutive-return_inverse-1", 853 },
  { "unique_consecutive-1", 854 },
  { "unique_dim_consecutive-dim-return_counts-return_inverse-1", 855 },
  { "unique_dim_consecutive-dim-return_inverse-1", 856 },
  { "unique_dim_consecutive-dim-1", 857 },
  { "_unique2-return_counts-return_inverse-sorted-1", 858 },
  { "_unique2-return_inverse-sorted-1", 859 },
  { "_unique2-sorted-1", 860 },
  { "_unique2-1", 861 },
  { "_unsafe_view-size-1", 862 },
  { "unsqueeze-dim-1", 863 },
  { "vander-1", 864 },
  { "var-unbiased-1", 865 },
  { "var-1", 866 },
  { "var_mean-unbiased-1", 867 },
  { "var_mean-1", 868 },
  { "view_as-2", 869 },
  { "where-3", 870 },
  { "where-self-2", 871 },
  { "where-other-2", 872 },
  { "where-other-self-1", 873 },
  { "where-1", 874 },
  { "norm_except_dim-dim-pow-1", 875 },
  { "norm_except_dim-pow-1", 876 },
  { "norm_except_dim-1", 877 },
  { "_weight_norm-dim-2", 878 },
  { "_weight_norm-2", 879 },
  { "_weight_norm_interface-dim-2", 880 },
  { "_weight_norm_interface-2", 881 },
  { "_weight_norm_interface_backward-dim-4", 882 },
  { "_weight_norm_differentiable_backward-dim-4", 883 },
  { "_standard_gamma_grad-2", 884 },
  { "_standard_gamma-1", 885 },
  { "_dirichlet_grad-3", 886 },
  { "_sample_dirichlet-1", 887 },
  { "poisson-1", 888 },
  { "binomial-2", 889 },
  { "native_norm-p-1", 890 },
  { "native_norm-1", 891 },
  { "_sparse_sum-1", 892 },
  { "_sparse_sum-dim-1", 893 },
  { "_sparse_sum_backward-dim-2", 894 },
  { "_sparse_csr_sum-dim-keepdim-1", 895 },
  { "_sparse_csr_sum-dim-1", 896 },
  { "_sparse_csr_prod-dim-keepdim-1", 897 },
  { "_sparse_csr_prod-dim-1", 898 },
  { "_sparse_softmax-dim-1", 899 },
  { "_sparse_softmax-dim-half_to_float-1", 900 },
  { "_sparse_softmax_backward_data-dim-3", 901 },
  { "_sparse_log_softmax-dim-1", 902 },
  { "_sparse_log_softmax-dim-half_to_float-1", 903 },
  { "_sparse_log_softmax_backward_data-dim-3", 904 },
  { "_spdiags-shape-2", 905 },
  { "norm-p-1", 906 },
  { "norm-1", 907 },
  { "frexp-1", 908 },
  { "frobenius_norm-dim-keepdim-1", 909 },
  { "frobenius_norm-dim-1", 910 },
  { "nuclear_norm-keepdim-1", 911 },
  { "nuclear_norm-1", 912 },
  { "nuclear_norm-dim-keepdim-1", 913 },
  { "nuclear_norm-dim-1", 914 },
  { "clone-1", 915 },
  { "positive-1", 916 },
  { "sub-alpha-2", 917 },
  { "sub-2", 918 },
  { "sub-alpha-other-1", 919 },
  { "sub-other-1", 920 },
  { "subtract-alpha-2", 921 },
  { "subtract-2", 922 },
  { "subtract-alpha-other-1", 923 },
  { "subtract-other-1", 924 },
  { "rsub-alpha-2", 925 },
  { "rsub-2", 926 },
  { "heaviside-2", 927 },
  { "rsub-alpha-other-1", 928 },
  { "rsub-other-1", 929 },
  { "_sparse_addmm-alpha-beta-3", 930 },
  { "_sparse_addmm-beta-3", 931 },
  { "_sparse_addmm-3", 932 },
  { "sparse_sampled_addmm-alpha-beta-3", 933 },
  { "sparse_sampled_addmm-beta-3", 934 },
  { "sparse_sampled_addmm-3", 935 },
  { "addmm-alpha-beta-3", 936 },
  { "addmm-beta-3", 937 },
  { "addmm-3", 938 },
  { "_addmm_activation-alpha-beta-use_gelu-3", 939 },
  { "_addmm_activation-alpha-beta-3", 940 },
  { "_addmm_activation-beta-3", 941 },
  { "_addmm_activation-3", 942 },
  { "_scaled_mm-3", 943 },
  { "_scaled_mm-2", 944 },
  { "sparse_mask-2", 945 },
  { "_sparse_mask_projection-accumulate_matches-2", 946 },
  { "_sparse_mask_projection-2", 947 },
  { "_to_cpu-*", 948 },
  { "to_dense-1", 949 },
  { "_to_dense-1", 950 },
  { "to_dense_backward-2", 951 },
  { "sparse_dim-1", 952 },
  { "_dimI-1", 953 },
  { "dense_dim-1", 954 },
  { "_dimV-1", 955 },
  { "_nnz-1", 956 },
  { "coalesce-1", 957 },
  { "_coalesce-1", 958 },
  { "is_coalesced-1", 959 },
  { "_indices-1", 960 },
  { "_values-1", 961 },
  { "indices-1", 962 },
  { "values-1", 963 },
  { "crow_indices-1", 964 },
  { "col_indices-1", 965 },
  { "ccol_indices-1", 966 },
  { "row_indices-1", 967 },
  { "hspmm-2", 968 },
  { "unbind-dim-1", 969 },
  { "unbind-1", 970 },
  { "to_sparse-sparse_dim-1", 971 },
  { "_to_sparse-sparse_dim-1", 972 },
  { "to_sparse-1", 973 },
  { "_to_sparse-1", 974 },
  { "to_sparse_csr-1", 975 },
  { "_to_sparse_csr-1", 976 },
  { "to_sparse_csc-1", 977 },
  { "_to_sparse_csc-1", 978 },
  { "to_sparse_bsr-blocksize-1", 979 },
  { "_to_sparse_bsr-blocksize-1", 980 },
  { "to_sparse_bsc-blocksize-1", 981 },
  { "_to_sparse_bsc-blocksize-1", 982 },
  { "_to_sparse_semi_structured-1", 983 },
  { "to_mkldnn-1", 984 },
  { "mkldnn_reorder_conv2d_weight-dilation-groups-padding-stride-1", 985 },
  { "mkldnn_reorder_conv2d_weight-dilation-padding-stride-1", 986 },
  { "mkldnn_reorder_conv2d_weight-padding-stride-1", 987 },
  { "mkldnn_reorder_conv2d_weight-padding-1", 988 },
  { "mkldnn_reorder_conv2d_weight-1", 989 },
  { "mkldnn_reorder_conv3d_weight-dilation-groups-padding-stride-1", 990 },
  { "mkldnn_reorder_conv3d_weight-dilation-padding-stride-1", 991 },
  { "mkldnn_reorder_conv3d_weight-padding-stride-1", 992 },
  { "mkldnn_reorder_conv3d_weight-padding-1", 993 },
  { "mkldnn_reorder_conv3d_weight-1", 994 },
  { "to_mkldnn_backward-2", 995 },
  { "dequantize-1", 996 },
  { "dequantize-*", 997 },
  { "q_zero_point-1", 998 },
  { "q_per_channel_scales-1", 999 },
  { "q_per_channel_zero_points-1", 1000 },
  { "q_per_channel_axis-1", 1001 },
  { "int_repr-1", 1002 },
  { "_make_per_tensor_quantized_tensor-scale-zero_point-1", 1003 },
  { "_make_per_channel_quantized_tensor-axis-3", 1004 },
  { "fake_quantize_per_tensor_affine-quant_max-quant_min-scale-zero_point-1", 1005 },
  { "fake_quantize_per_tensor_affine-quant_max-quant_min-3", 1006 },
  { "fake_quantize_per_tensor_affine_cachemask-quant_max-quant_min-scale-zero_point-1", 1007 },
  { "_fake_quantize_per_tensor_affine_cachemask_tensor_qparams-quant_max-quant_min-4", 1008 },
  { "fake_quantize_per_tensor_affine_cachemask_backward-2", 1009 },
  { "_fake_quantize_learnable_per_tensor_affine-grad_factor-quant_max-quant_min-3", 1010 },
  { "_fake_quantize_learnable_per_tensor_affine-quant_max-quant_min-3", 1011 },
  { "_fake_quantize_learnable_per_tensor_affine_backward-grad_factor-quant_max-quant_min-4", 1012 },
  { "_fake_quantize_learnable_per_tensor_affine_backward-quant_max-quant_min-4", 1013 },
  { "fake_quantize_per_channel_affine-axis-quant_max-quant_min-3", 1014 },
  { "fake_quantize_per_channel_affine_cachemask-axis-quant_max-quant_min-3", 1015 },
  { "fake_quantize_per_channel_affine_cachemask_backward-2", 1016 },
  { "_fake_quantize_learnable_per_channel_affine-axis-grad_factor-quant_max-quant_min-3", 1017 },
  { "_fake_quantize_learnable_per_channel_affine-axis-quant_max-quant_min-3", 1018 },
  { "_fake_quantize_learnable_per_channel_affine_backward-axis-grad_factor-quant_max-quant_min-4", 1019 },
  { "_fake_quantize_learnable_per_channel_affine_backward-axis-quant_max-quant_min-4", 1020 },
  { "fused_moving_avg_obs_fake_quant-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-symmetric_quant-7", 1021 },
  { "fused_moving_avg_obs_fake_quant-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-7", 1022 },
  { "fused_moving_avg_obs_fake_quant-averaging_const-ch_axis-quant_max-quant_min-7", 1023 },
  { "_fused_moving_avg_obs_fq_helper-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-symmetric_quant-7", 1024 },
  { "_fused_moving_avg_obs_fq_helper-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-7", 1025 },
  { "_fused_moving_avg_obs_fq_helper-averaging_const-ch_axis-quant_max-quant_min-7", 1026 },
  { "_saturate_weight_to_fp16-1", 1027 },
  { "choose_qparams_optimized-bit_width-n_bins-numel-ratio-1", 1028 },
  { "_autocast_to_full_precision-cpu_enabled-cuda_enabled-1", 1029 },
  { "meshgrid-*", 1030 },
  { "cartesian_prod-*", 1031 },
  { "combinations-r-with_replacement-1", 1032 },
  { "combinations-r-1", 1033 },
  { "combinations-1", 1034 },
  { "item-1", 1035 },
  { "_local_scalar_dense-1", 1036 },
  { "_lstm_mps-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1037 },
  { "lstm_mps_backward-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1038 },
  { "_thnn_fused_lstm_cell-5", 1039 },
  { "_thnn_fused_lstm_cell-4", 1040 },
  { "_thnn_fused_lstm_cell-3", 1041 },
  { "_thnn_fused_lstm_cell_backward_impl-has_bias-5", 1042 },
  { "_thnn_fused_lstm_cell_backward-has_bias-5", 1043 },
  { "_thnn_differentiable_lstm_cell_backward-8", 1044 },
  { "_thnn_fused_gru_cell-5", 1045 },
  { "_thnn_fused_gru_cell-4", 1046 },
  { "_thnn_fused_gru_cell-3", 1047 },
  { "_thnn_fused_gru_cell_backward-has_bias-2", 1048 },
  { "_thnn_differentiable_gru_cell_backward-6", 1049 },
  { "lstm-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1050 },
  { "lstm-bidirectional-dropout-has_biases-num_layers-train-*", 1051 },
  { "gru-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1052 },
  { "gru-bidirectional-dropout-has_biases-num_layers-train-*", 1053 },
  { "rnn_tanh-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1054 },
  { "rnn_tanh-bidirectional-dropout-has_biases-num_layers-train-*", 1055 },
  { "rnn_relu-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 1056 },
  { "rnn_relu-bidirectional-dropout-has_biases-num_layers-train-*", 1057 },
  { "lstm_cell-*", 1058 },
  { "gru_cell-6", 1059 },
  { "gru_cell-5", 1060 },
  { "gru_cell-4", 1061 },
  { "rnn_tanh_cell-6", 1062 },
  { "rnn_tanh_cell-5", 1063 },
  { "rnn_tanh_cell-4", 1064 },
  { "rnn_relu_cell-6", 1065 },
  { "rnn_relu_cell-5", 1066 },
  { "rnn_relu_cell-4", 1067 },
  { "quantized_lstm_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-*", 1068 },
  { "quantized_gru_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 1069 },
  { "quantized_rnn_relu_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 1070 },
  { "quantized_rnn_tanh_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 1071 },
  { "_pack_padded_sequence-batch_first-2", 1072 },
  { "_pack_padded_sequence_backward-batch_first-input_size-2", 1073 },
  { "_pad_packed_sequence-batch_first-padding_value-total_length-2", 1074 },
  { "lift-1", 1075 },
  { "lift_fresh-1", 1076 },
  { "lift_fresh_copy-1", 1077 },
  { "is_set_to-2", 1078 },
  { "masked_fill-value-2", 1079 },
  { "masked_fill-3", 1080 },
  { "masked_scatter-3", 1081 },
  { "masked_scatter_backward-sizes-2", 1082 },
  { "_masked_softmax-2", 1083 },
  { "_masked_softmax_backward-3", 1084 },
  { "view-size-1", 1085 },
  { "put-accumulate-3", 1086 },
  { "put-3", 1087 },
  { "index_add-alpha-dim-3", 1088 },
  { "index_add-dim-3", 1089 },
  { "index_fill-dim-value-2", 1090 },
  { "index_fill-dim-3", 1091 },
  { "scatter-dim-3", 1092 },
  { "scatter-dim-value-2", 1093 },
  { "scatter_add-dim-3", 1094 },
  { "bitwise_and-other-1", 1095 },
  { "bitwise_and-self-1", 1096 },
  { "bitwise_and-2", 1097 },
  { "__and__-other-1", 1098 },
  { "__and__-2", 1099 },
  { "bitwise_or-other-1", 1100 },
  { "bitwise_or-self-1", 1101 },
  { "bitwise_or-2", 1102 },
  { "__or__-other-1", 1103 },
  { "__or__-2", 1104 },
  { "bitwise_xor-other-1", 1105 },
  { "bitwise_xor-self-1", 1106 },
  { "bitwise_xor-2", 1107 },
  { "__xor__-other-1", 1108 },
  { "__xor__-2", 1109 },
  { "__lshift__-other-1", 1110 },
  { "__lshift__-2", 1111 },
  { "bitwise_left_shift-2", 1112 },
  { "bitwise_left_shift-other-1", 1113 },
  { "bitwise_left_shift-self-1", 1114 },
  { "__rshift__-other-1", 1115 },
  { "__rshift__-2", 1116 },
  { "bitwise_right_shift-2", 1117 },
  { "bitwise_right_shift-other-1", 1118 },
  { "bitwise_right_shift-self-1", 1119 },
  { "addbmm-alpha-beta-3", 1120 },
  { "addbmm-beta-3", 1121 },
  { "addbmm-3", 1122 },
  { "diag-diagonal-1", 1123 },
  { "diag-1", 1124 },
  { "cross-2", 1125 },
  { "triu-diagonal-1", 1126 },
  { "triu-1", 1127 },
  { "tril-diagonal-1", 1128 },
  { "tril-1", 1129 },
  { "trace-1", 1130 },
  { "trace_backward-sizes-1", 1131 },
  { "ne-other-1", 1132 },
  { "ne-2", 1133 },
  { "not_equal-other-1", 1134 },
  { "not_equal-2", 1135 },
  { "eq-other-1", 1136 },
  { "eq-2", 1137 },
  { "ge-other-1", 1138 },
  { "ge-2", 1139 },
  { "greater_equal-other-1", 1140 },
  { "greater_equal-2", 1141 },
  { "le-other-1", 1142 },
  { "le-2", 1143 },
  { "less_equal-other-1", 1144 },
  { "less_equal-2", 1145 },
  { "gt-other-1", 1146 },
  { "gt-2", 1147 },
  { "greater-other-1", 1148 },
  { "greater-2", 1149 },
  { "lt-other-1", 1150 },
  { "lt-2", 1151 },
  { "less-other-1", 1152 },
  { "less-2", 1153 },
  { "take-2", 1154 },
  { "take_along_dim-2", 1155 },
  { "index_select-dim-2", 1156 },
  { "index_select_backward-dim-self_sizes-2", 1157 },
  { "masked_select-2", 1158 },
  { "masked_select_backward-3", 1159 },
  { "nonzero-1", 1160 },
  { "nonzero_static-fill_value-size-1", 1161 },
  { "nonzero_static-size-1", 1162 },
  { "nonzero_numpy-1", 1163 },
  { "argwhere-1", 1164 },
  { "gather-dim-sparse_grad-2", 1165 },
  { "gather-dim-2", 1166 },
  { "gather_backward-dim-sparse_grad-3", 1167 },
  { "_gather_sparse_backward-dim-3", 1168 },
  { "addcmul-value-3", 1169 },
  { "addcmul-3", 1170 },
  { "addcdiv-value-3", 1171 },
  { "addcdiv-3", 1172 },
  { "cross_entropy_loss-ignore_index-label_smoothing-reduction-3", 1173 },
  { "cross_entropy_loss-ignore_index-reduction-3", 1174 },
  { "cross_entropy_loss-reduction-3", 1175 },
  { "cross_entropy_loss-3", 1176 },
  { "cross_entropy_loss-2", 1177 },
  { "triangular_solve-transpose-unitriangular-upper-2", 1178 },
  { "triangular_solve-transpose-upper-2", 1179 },
  { "triangular_solve-upper-2", 1180 },
  { "triangular_solve-2", 1181 },
  { "linalg_solve_triangular-left-unitriangular-upper-2", 1182 },
  { "linalg_solve_triangular-left-upper-2", 1183 },
  { "linalg_solve_triangular-upper-2", 1184 },
  { "linalg_vander-1", 1185 },
  { "svd-compute_uv-some-1", 1186 },
  { "svd-some-1", 1187 },
  { "svd-1", 1188 },
  { "swapaxes-axis0-axis1-1", 1189 },
  { "swapdims-dim0-dim1-1", 1190 },
  { "cholesky-upper-1", 1191 },
  { "cholesky-1", 1192 },
  { "cholesky_solve-upper-2", 1193 },
  { "cholesky_solve-2", 1194 },
  { "_cholesky_solve_helper-upper-2", 1195 },
  { "cholesky_inverse-upper-1", 1196 },
  { "cholesky_inverse-1", 1197 },
  { "qr-some-1", 1198 },
  { "qr-1", 1199 },
  { "geqrf-1", 1200 },
  { "orgqr-2", 1201 },
  { "ormqr-left-transpose-3", 1202 },
  { "ormqr-left-3", 1203 },
  { "ormqr-3", 1204 },
  { "_lu_with_info-check_errors-pivot-1", 1205 },
  { "_lu_with_info-pivot-1", 1206 },
  { "_lu_with_info-1", 1207 },
  { "lu_solve-3", 1208 },
  { "lu_unpack-unpack_data-unpack_pivots-2", 1209 },
  { "lu_unpack-unpack_data-2", 1210 },
  { "lu_unpack-2", 1211 },
  { "multinomial-num_samples-replacement-1", 1212 },
  { "multinomial-num_samples-1", 1213 },
  { "lgamma-1", 1214 },
  { "digamma-1", 1215 },
  { "polygamma-n-1", 1216 },
  { "erfinv-1", 1217 },
  { "i0-1", 1218 },
  { "sign-1", 1219 },
  { "signbit-1", 1220 },
  { "dist-p-2", 1221 },
  { "dist-2", 1222 },
  { "atan2-2", 1223 },
  { "arctan2-2", 1224 },
  { "lerp-weight-2", 1225 },
  { "lerp-3", 1226 },
  { "histc-bins-max-min-1", 1227 },
  { "histc-bins-min-1", 1228 },
  { "histc-bins-1", 1229 },
  { "histc-1", 1230 },
  { "histogram-density-3", 1231 },
  { "histogram-3", 1232 },
  { "histogram-2", 1233 },
  { "histogram-bins-1", 1234 },
  { "histogram-1", 1235 },
  { "_histogramdd_bin_edges-bins-1", 1236 },
  { "_histogramdd_from_bin_cts-bins-1", 1237 },
  { "_histogramdd_from_bin_tensors-density-*", 1238 },
  { "_histogramdd_from_bin_tensors-*", 1239 },
  { "histogramdd-bins-1", 1240 },
  { "histogramdd-*", 1241 },
  { "fmod-other-1", 1242 },
  { "fmod-2", 1243 },
  { "hypot-2", 1244 },
  { "igamma-2", 1245 },
  { "igammac-2", 1246 },
  { "nextafter-2", 1247 },
  { "remainder-other-1", 1248 },
  { "remainder-2", 1249 },
  { "remainder-self-1", 1250 },
  { "min-1", 1251 },
  { "fmin-2", 1252 },
  { "max-1", 1253 },
  { "fmax-2", 1254 },
  { "maximum-2", 1255 },
  { "max-2", 1256 },
  { "minimum-2", 1257 },
  { "min-2", 1258 },
  { "quantile-2", 1259 },
  { "quantile-q-1", 1260 },
  { "nanquantile-2", 1261 },
  { "nanquantile-q-1", 1262 },
  { "sort-descending-dim-1", 1263 },
  { "sort-dim-1", 1264 },
  { "sort-1", 1265 },
  { "msort-1", 1266 },
  { "argsort-descending-dim-1", 1267 },
  { "argsort-dim-1", 1268 },
  { "argsort-1", 1269 },
  { "argsort-descending-dim-stable-1", 1270 },
  { "argsort-dim-stable-1", 1271 },
  { "argsort-stable-1", 1272 },
  { "topk-dim-k-largest-sorted-1", 1273 },
  { "topk-dim-k-largest-1", 1274 },
  { "topk-dim-k-1", 1275 },
  { "topk-k-1", 1276 },
  { "renorm-dim-maxnorm-p-1", 1277 },
  { "unfold-dimension-size-step-1", 1278 },
  { "unfold_backward-dim-input_sizes-size-step-1", 1279 },
  { "equal-2", 1280 },
  { "pow-2", 1281 },
  { "pow-self-1", 1282 },
  { "pow-exponent-1", 1283 },
  { "float_power-2", 1284 },
  { "float_power-self-1", 1285 },
  { "float_power-exponent-1", 1286 },
  { "normal_functional-mean-std-1", 1287 },
  { "normal_functional-mean-1", 1288 },
  { "normal_functional-1", 1289 },
  { "alias-1", 1290 },
  { "_foreach_add-scalar-*", 1291 },
  { "_foreach_add-alpha-*", 1292 },
  { "_foreach_add-*", 1293 },
  { "_foreach_sub-scalar-*", 1294 },
  { "_foreach_sub-alpha-*", 1295 },
  { "_foreach_sub-*", 1296 },
  { "_foreach_mul-scalar-*", 1297 },
  { "_foreach_mul-*", 1298 },
  { "_foreach_div-scalar-*", 1299 },
  { "_foreach_div-*", 1300 },
  { "_foreach_clamp_max-scalar-*", 1301 },
  { "_foreach_clamp_max-*", 1302 },
  { "_foreach_clamp_min-scalar-*", 1303 },
  { "_foreach_clamp_min-*", 1304 },
  { "_foreach_maximum-scalar-*", 1305 },
  { "_foreach_maximum-*", 1306 },
  { "_foreach_minimum-scalar-*", 1307 },
  { "_foreach_minimum-*", 1308 },
  { "_foreach_addcdiv-value-*", 1309 },
  { "_foreach_addcdiv-*", 1310 },
  { "_foreach_addcmul-value-*", 1311 },
  { "_foreach_addcmul-*", 1312 },
  { "_foreach_abs-*", 1313 },
  { "_foreach_acos-*", 1314 },
  { "_foreach_asin-*", 1315 },
  { "_foreach_atan-*", 1316 },
  { "_foreach_ceil-*", 1317 },
  { "_foreach_cos-*", 1318 },
  { "_foreach_cosh-*", 1319 },
  { "_foreach_erf-*", 1320 },
  { "_foreach_erfc-*", 1321 },
  { "_foreach_exp-*", 1322 },
  { "_foreach_expm1-*", 1323 },
  { "_foreach_floor-*", 1324 },
  { "_foreach_frac-*", 1325 },
  { "_foreach_lerp-*", 1326 },
  { "_foreach_lerp-weight-*", 1327 },
  { "_foreach_lgamma-*", 1328 },
  { "_foreach_log-*", 1329 },
  { "_foreach_log10-*", 1330 },
  { "_foreach_log1p-*", 1331 },
  { "_foreach_log2-*", 1332 },
  { "_foreach_neg-*", 1333 },
  { "_foreach_norm-ord-*", 1334 },
  { "_foreach_norm-*", 1335 },
  { "_foreach_pow-*", 1336 },
  { "_foreach_pow-exponent-*", 1337 },
  { "_foreach_pow-self-*", 1338 },
  { "_foreach_reciprocal-*", 1339 },
  { "_foreach_round-*", 1340 },
  { "_foreach_sigmoid-*", 1341 },
  { "_foreach_sign-*", 1342 },
  { "_foreach_sin-*", 1343 },
  { "_foreach_sinh-*", 1344 },
  { "_foreach_sqrt-*", 1345 },
  { "_foreach_tan-*", 1346 },
  { "_foreach_tanh-*", 1347 },
  { "_foreach_trunc-*", 1348 },
  { "bucketize-out_int32-right-2", 1349 },
  { "bucketize-out_int32-2", 1350 },
  { "bucketize-2", 1351 },
  { "bucketize-out_int32-right-self-1", 1352 },
  { "bucketize-out_int32-self-1", 1353 },
  { "bucketize-self-1", 1354 },
  { "searchsorted-out_int32-right-2", 1355 },
  { "searchsorted-out_int32-2", 1356 },
  { "searchsorted-2", 1357 },
  { "searchsorted-out_int32-right-self-1", 1358 },
  { "searchsorted-out_int32-self-1", 1359 },
  { "searchsorted-self-1", 1360 },
  { "_convert_indices_from_coo_to_csr-out_int32-size-1", 1361 },
  { "_convert_indices_from_coo_to_csr-size-1", 1362 },
  { "_convert_indices_from_csr_to_coo-out_int32-transpose-2", 1363 },
  { "_convert_indices_from_csr_to_coo-out_int32-2", 1364 },
  { "_convert_indices_from_csr_to_coo-2", 1365 },
  { "mse_loss-reduction-2", 1366 },
  { "mse_loss-2", 1367 },
  { "mse_loss_backward-reduction-3", 1368 },
  { "l1_loss-reduction-2", 1369 },
  { "l1_loss-2", 1370 },
  { "multi_margin_loss-margin-p-reduction-3", 1371 },
  { "multi_margin_loss-margin-p-3", 1372 },
  { "multi_margin_loss-margin-p-2", 1373 },
  { "multi_margin_loss-p-2", 1374 },
  { "multi_margin_loss-2", 1375 },
  { "multi_margin_loss_backward-margin-p-reduction-4", 1376 },
  { "multi_margin_loss_backward-margin-p-4", 1377 },
  { "multi_margin_loss_backward-margin-p-3", 1378 },
  { "multilabel_margin_loss-reduction-2", 1379 },
  { "multilabel_margin_loss-2", 1380 },
  { "multilabel_margin_loss_forward-reduction-2", 1381 },
  { "multilabel_margin_loss_backward-reduction-4", 1382 },
  { "nll_loss_nd-ignore_index-reduction-3", 1383 },
  { "nll_loss_nd-reduction-3", 1384 },
  { "nll_loss_nd-3", 1385 },
  { "nll_loss_nd-2", 1386 },
  { "nll_loss-ignore_index-reduction-3", 1387 },
  { "nll_loss-reduction-3", 1388 },
  { "nll_loss-3", 1389 },
  { "nll_loss-2", 1390 },
  { "nll_loss_forward-ignore_index-reduction-3", 1391 },
  { "nll_loss_backward-ignore_index-reduction-5", 1392 },
  { "nll_loss2d-ignore_index-reduction-3", 1393 },
  { "nll_loss2d-reduction-3", 1394 },
  { "nll_loss2d-3", 1395 },
  { "nll_loss2d-2", 1396 },
  { "nll_loss2d_forward-ignore_index-reduction-3", 1397 },
  { "nll_loss2d_backward-ignore_index-reduction-5", 1398 },
  { "smooth_l1_loss-beta-reduction-2", 1399 },
  { "smooth_l1_loss-reduction-2", 1400 },
  { "smooth_l1_loss-2", 1401 },
  { "smooth_l1_loss_backward-beta-reduction-3", 1402 },
  { "huber_loss-delta-reduction-2", 1403 },
  { "huber_loss-reduction-2", 1404 },
  { "huber_loss-2", 1405 },
  { "huber_loss_backward-delta-reduction-3", 1406 },
  { "soft_margin_loss-reduction-2", 1407 },
  { "soft_margin_loss-2", 1408 },
  { "soft_margin_loss_backward-reduction-3", 1409 },
  { "elu-alpha-input_scale-scale-1", 1410 },
  { "elu-alpha-scale-1", 1411 },
  { "elu-alpha-1", 1412 },
  { "elu-1", 1413 },
  { "elu_backward-alpha-input_scale-is_result-scale-2", 1414 },
  { "glu-dim-1", 1415 },
  { "glu-1", 1416 },
  { "glu_backward-dim-2", 1417 },
  { "glu_jvp-dim-3", 1418 },
  { "glu_backward_jvp-dim-5", 1419 },
  { "hardsigmoid-1", 1420 },
  { "hardsigmoid_backward-2", 1421 },
  { "hardtanh-max_val-min_val-1", 1422 },
  { "hardtanh-min_val-1", 1423 },
  { "hardtanh-1", 1424 },
  { "hardtanh_backward-max_val-min_val-2", 1425 },
  { "hardswish-1", 1426 },
  { "hardswish_backward-2", 1427 },
  { "leaky_relu-negative_slope-1", 1428 },
  { "leaky_relu-1", 1429 },
  { "leaky_relu_backward-negative_slope-self_is_result-2", 1430 },
  { "log_sigmoid-1", 1431 },
  { "log_sigmoid_forward-1", 1432 },
  { "log_sigmoid_backward-3", 1433 },
  { "rrelu_with_noise-lower-training-upper-2", 1434 },
  { "rrelu_with_noise-lower-upper-2", 1435 },
  { "rrelu_with_noise-lower-2", 1436 },
  { "rrelu_with_noise-2", 1437 },
  { "rrelu_with_noise_backward-lower-self_is_result-training-upper-3", 1438 },
  { "softplus-beta-threshold-1", 1439 },
  { "softplus-beta-1", 1440 },
  { "softplus-1", 1441 },
  { "softplus_backward-beta-threshold-2", 1442 },
  { "softshrink-lambd-1", 1443 },
  { "softshrink-1", 1444 },
  { "softshrink_backward-lambd-2", 1445 },
  { "adaptive_avg_pool2d-output_size-1", 1446 },
  { "mkldnn_adaptive_avg_pool2d-output_size-1", 1447 },
  { "mkldnn_adaptive_avg_pool2d_backward-2", 1448 },
  { "_adaptive_avg_pool2d-output_size-1", 1449 },
  { "_adaptive_avg_pool2d_backward-2", 1450 },
  { "adaptive_avg_pool3d-output_size-1", 1451 },
  { "_adaptive_avg_pool3d-output_size-1", 1452 },
  { "_adaptive_avg_pool3d_backward-2", 1453 },
  { "adaptive_max_pool2d-output_size-1", 1454 },
  { "adaptive_max_pool2d_backward-3", 1455 },
  { "adaptive_max_pool3d-output_size-1", 1456 },
  { "adaptive_max_pool3d_backward-3", 1457 },
  { "avg_pool2d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 1458 },
  { "avg_pool2d-ceil_mode-kernel_size-padding-stride-1", 1459 },
  { "avg_pool2d-kernel_size-padding-stride-1", 1460 },
  { "avg_pool2d-kernel_size-stride-1", 1461 },
  { "avg_pool2d-kernel_size-1", 1462 },
  { "avg_pool3d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 1463 },
  { "avg_pool3d-ceil_mode-kernel_size-padding-stride-1", 1464 },
  { "avg_pool3d-kernel_size-padding-stride-1", 1465 },
  { "avg_pool3d-kernel_size-stride-1", 1466 },
  { "avg_pool3d-kernel_size-1", 1467 },
  { "fractional_max_pool2d-kernel_size-output_size-2", 1468 },
  { "fractional_max_pool2d_backward-kernel_size-output_size-3", 1469 },
  { "fractional_max_pool3d-kernel_size-output_size-2", 1470 },
  { "fractional_max_pool3d_backward-kernel_size-output_size-3", 1471 },
  { "max_pool2d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 1472 },
  { "max_pool2d_with_indices-dilation-kernel_size-padding-stride-1", 1473 },
  { "max_pool2d_with_indices-kernel_size-padding-stride-1", 1474 },
  { "max_pool2d_with_indices-kernel_size-stride-1", 1475 },
  { "max_pool2d_with_indices-kernel_size-1", 1476 },
  { "max_pool2d_with_indices_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 1477 },
  { "max_pool3d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 1478 },
  { "max_pool3d_with_indices-dilation-kernel_size-padding-stride-1", 1479 },
  { "max_pool3d_with_indices-kernel_size-padding-stride-1", 1480 },
  { "max_pool3d_with_indices-kernel_size-stride-1", 1481 },
  { "max_pool3d_with_indices-kernel_size-1", 1482 },
  { "max_pool3d_with_indices_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 1483 },
  { "max_unpool2d-output_size-2", 1484 },
  { "max_unpool3d-output_size-padding-stride-2", 1485 },
  { "reflection_pad1d-padding-1", 1486 },
  { "reflection_pad1d_backward-padding-2", 1487 },
  { "reflection_pad2d-padding-1", 1488 },
  { "reflection_pad2d_backward-padding-2", 1489 },
  { "reflection_pad3d-padding-1", 1490 },
  { "reflection_pad3d_backward-padding-2", 1491 },
  { "replication_pad1d-padding-1", 1492 },
  { "replication_pad1d_backward-padding-2", 1493 },
  { "replication_pad2d-padding-1", 1494 },
  { "replication_pad2d_backward-padding-2", 1495 },
  { "replication_pad3d-padding-1", 1496 },
  { "replication_pad3d_backward-padding-2", 1497 },
  { "_pad_circular-pad-1", 1498 },
  { "_pad_enum-mode-pad-1", 1499 },
  { "pad-pad-1", 1500 },
  { "upsample_linear1d-align_corners-output_size-1", 1501 },
  { "upsample_linear1d_backward-align_corners-input_size-output_size-1", 1502 },
  { "upsample_bilinear2d-align_corners-output_size-1", 1503 },
  { "upsample_bilinear2d_backward-align_corners-input_size-output_size-1", 1504 },
  { "_upsample_bilinear2d_aa-align_corners-output_size-1", 1505 },
  { "_upsample_bilinear2d_aa_backward-align_corners-input_size-output_size-1", 1506 },
  { "upsample_bicubic2d-align_corners-output_size-1", 1507 },
  { "upsample_bicubic2d_backward-align_corners-input_size-output_size-1", 1508 },
  { "_upsample_bicubic2d_aa-align_corners-output_size-1", 1509 },
  { "_upsample_bicubic2d_aa_backward-align_corners-input_size-output_size-1", 1510 },
  { "upsample_trilinear3d-align_corners-output_size-1", 1511 },
  { "upsample_trilinear3d_backward-align_corners-input_size-output_size-1", 1512 },
  { "upsample_nearest1d-output_size-1", 1513 },
  { "_upsample_nearest_exact1d-output_size-1", 1514 },
  { "upsample_nearest1d_backward-input_size-output_size-1", 1515 },
  { "_upsample_nearest_exact1d_backward-input_size-output_size-1", 1516 },
  { "upsample_nearest2d-output_size-1", 1517 },
  { "_upsample_nearest_exact2d-output_size-1", 1518 },
  { "upsample_nearest2d_backward-input_size-output_size-1", 1519 },
  { "_upsample_nearest_exact2d_backward-input_size-output_size-1", 1520 },
  { "upsample_nearest3d-output_size-1", 1521 },
  { "_upsample_nearest_exact3d-output_size-1", 1522 },
  { "upsample_nearest3d_backward-input_size-output_size-1", 1523 },
  { "_upsample_nearest_exact3d_backward-input_size-output_size-1", 1524 },
  { "sigmoid_backward-2", 1525 },
  { "logit_backward-2", 1526 },
  { "tanh_backward-2", 1527 },
  { "slow_conv_transpose2d-dilation-kernel_size-output_padding-padding-stride-3", 1528 },
  { "slow_conv_transpose2d-kernel_size-output_padding-padding-stride-3", 1529 },
  { "slow_conv_transpose2d-kernel_size-padding-stride-3", 1530 },
  { "slow_conv_transpose2d-kernel_size-stride-3", 1531 },
  { "slow_conv_transpose2d-kernel_size-3", 1532 },
  { "slow_conv_transpose2d-kernel_size-2", 1533 },
  { "slow_conv_transpose3d-dilation-kernel_size-output_padding-padding-stride-3", 1534 },
  { "slow_conv_transpose3d-kernel_size-output_padding-padding-stride-3", 1535 },
  { "slow_conv_transpose3d-kernel_size-padding-stride-3", 1536 },
  { "slow_conv_transpose3d-kernel_size-stride-3", 1537 },
  { "slow_conv_transpose3d-kernel_size-3", 1538 },
  { "slow_conv_transpose3d-kernel_size-2", 1539 },
  { "thnn_conv2d-kernel_size-padding-stride-3", 1540 },
  { "thnn_conv2d-kernel_size-stride-3", 1541 },
  { "thnn_conv2d-kernel_size-3", 1542 },
  { "thnn_conv2d-kernel_size-2", 1543 },
  { "_slow_conv2d_forward-kernel_size-padding-stride-3", 1544 },
  { "_slow_conv2d_backward-kernel_size-output_mask-padding-stride-3", 1545 },
  { "_conv_depthwise2d-dilation-kernel_size-padding-stride-3", 1546 },
  { "conv_depthwise3d-dilation-kernel_size-padding-stride-3", 1547 },
  { "slow_conv3d-kernel_size-padding-stride-3", 1548 },
  { "slow_conv3d-kernel_size-stride-3", 1549 },
  { "slow_conv3d-kernel_size-3", 1550 },
  { "slow_conv3d-kernel_size-2", 1551 },
  { "slow_conv3d_forward-kernel_size-padding-stride-3", 1552 },
  { "slow_conv_dilated2d-dilation-kernel_size-padding-stride-3", 1553 },
  { "slow_conv_dilated2d-kernel_size-padding-stride-3", 1554 },
  { "slow_conv_dilated2d-kernel_size-stride-3", 1555 },
  { "slow_conv_dilated2d-kernel_size-3", 1556 },
  { "slow_conv_dilated2d-kernel_size-2", 1557 },
  { "slow_conv_dilated3d-dilation-kernel_size-padding-stride-3", 1558 },
  { "slow_conv_dilated3d-kernel_size-padding-stride-3", 1559 },
  { "slow_conv_dilated3d-kernel_size-stride-3", 1560 },
  { "slow_conv_dilated3d-kernel_size-3", 1561 },
  { "slow_conv_dilated3d-kernel_size-2", 1562 },
  { "col2im-dilation-kernel_size-output_size-padding-stride-1", 1563 },
  { "column_stack-*", 1564 },
  { "im2col-dilation-kernel_size-padding-stride-1", 1565 },
  { "isfinite-1", 1566 },
  { "isinf-1", 1567 },
  { "isposinf-1", 1568 },
  { "isneginf-1", 1569 },
  { "_add_batch_dim-batch_dim-level-1", 1570 },
  { "_remove_batch_dim-batch_size-level-out_dim-1", 1571 },
  { "special_entr-1", 1572 },
  { "special_ndtri-1", 1573 },
  { "special_log_ndtr-1", 1574 },
  { "special_expm1-1", 1575 },
  { "special_exp2-1", 1576 },
  { "special_psi-1", 1577 },
  { "special_digamma-1", 1578 },
  { "special_gammaln-1", 1579 },
  { "special_erf-1", 1580 },
  { "special_erfc-1", 1581 },
  { "special_erfcx-1", 1582 },
  { "special_erfinv-1", 1583 },
  { "special_ndtr-1", 1584 },
  { "special_xlog1py-2", 1585 },
  { "special_xlog1py-self-1", 1586 },
  { "special_xlog1py-other-1", 1587 },
  { "special_xlogy-2", 1588 },
  { "special_xlogy-self-1", 1589 },
  { "special_xlogy-other-1", 1590 },
  { "special_zeta-2", 1591 },
  { "special_zeta-self-1", 1592 },
  { "special_zeta-other-1", 1593 },
  { "special_i0-1", 1594 },
  { "special_i0e-1", 1595 },
  { "special_i1-1", 1596 },
  { "special_i1e-1", 1597 },
  { "special_logit-1", 1598 },
  { "special_polygamma-n-1", 1599 },
  { "special_logsumexp-dim-keepdim-1", 1600 },
  { "special_logsumexp-dim-1", 1601 },
  { "special_expit-1", 1602 },
  { "special_sinc-1", 1603 },
  { "special_round-decimals-1", 1604 },
  { "special_round-1", 1605 },
  { "special_log1p-1", 1606 },
  { "special_log_softmax-dim-1", 1607 },
  { "special_gammainc-2", 1608 },
  { "special_gammaincc-2", 1609 },
  { "special_multigammaln-p-1", 1610 },
  { "special_softmax-dim-1", 1611 },
  { "fft_fft-1", 1612 },
  { "fft_ifft-1", 1613 },
  { "fft_rfft-1", 1614 },
  { "fft_irfft-1", 1615 },
  { "fft_hfft-1", 1616 },
  { "fft_ihfft-1", 1617 },
  { "fft_fft2-1", 1618 },
  { "fft_ifft2-1", 1619 },
  { "fft_rfft2-1", 1620 },
  { "fft_irfft2-1", 1621 },
  { "fft_hfft2-1", 1622 },
  { "fft_ihfft2-1", 1623 },
  { "fft_fftn-1", 1624 },
  { "fft_ifftn-1", 1625 },
  { "fft_rfftn-1", 1626 },
  { "fft_irfftn-1", 1627 },
  { "fft_hfftn-1", 1628 },
  { "fft_ihfftn-1", 1629 },
  { "fft_fftshift-1", 1630 },
  { "fft_ifftshift-1", 1631 },
  { "linalg_cholesky_ex-check_errors-upper-1", 1632 },
  { "linalg_cholesky_ex-upper-1", 1633 },
  { "linalg_cholesky_ex-1", 1634 },
  { "linalg_cholesky-upper-1", 1635 },
  { "linalg_cholesky-1", 1636 },
  { "linalg_cross-dim-2", 1637 },
  { "linalg_cross-2", 1638 },
  { "linalg_lu_factor-pivot-1", 1639 },
  { "linalg_lu_factor-1", 1640 },
  { "linalg_lu_factor_ex-check_errors-pivot-1", 1641 },
  { "linalg_lu_factor_ex-pivot-1", 1642 },
  { "linalg_lu_factor_ex-1", 1643 },
  { "linalg_lu-pivot-1", 1644 },
  { "linalg_lu-1", 1645 },
  { "linalg_lu_solve-adjoint-left-3", 1646 },
  { "linalg_lu_solve-left-3", 1647 },
  { "linalg_lu_solve-3", 1648 },
  { "_linalg_det-1", 1649 },
  { "linalg_det-1", 1650 },
  { "det-1", 1651 },
  { "linalg_ldl_factor_ex-check_errors-hermitian-1", 1652 },
  { "linalg_ldl_factor_ex-hermitian-1", 1653 },
  { "linalg_ldl_factor_ex-1", 1654 },
  { "linalg_ldl_factor-hermitian-1", 1655 },
  { "linalg_ldl_factor-1", 1656 },
  { "linalg_ldl_solve-hermitian-3", 1657 },
  { "linalg_ldl_solve-3", 1658 },
  { "linalg_lstsq-2", 1659 },
  { "linalg_matmul-2", 1660 },
  { "linalg_vecdot-dim-2", 1661 },
  { "linalg_vecdot-2", 1662 },
  { "linalg_matrix_exp-1", 1663 },
  { "_linalg_slogdet-1", 1664 },
  { "linalg_slogdet-1", 1665 },
  { "slogdet-1", 1666 },
  { "logdet-1", 1667 },
  { "linalg_eig-1", 1668 },
  { "_linalg_eigvals-1", 1669 },
  { "linalg_eigvals-1", 1670 },
  { "_linalg_eigh-1", 1671 },
  { "linalg_eigh-1", 1672 },
  { "linalg_eigvalsh-1", 1673 },
  { "linalg_householder_product-2", 1674 },
  { "linalg_inv_ex-check_errors-1", 1675 },
  { "linalg_inv_ex-1", 1676 },
  { "linalg_inv-1", 1677 },
  { "inverse-1", 1678 },
  { "inner-2", 1679 },
  { "outer-2", 1680 },
  { "ger-2", 1681 },
  { "linalg_norm-1", 1682 },
  { "linalg_vector_norm-ord-1", 1683 },
  { "linalg_vector_norm-1", 1684 },
  { "linalg_matrix_norm-dim-keepdim-ord-1", 1685 },
  { "linalg_matrix_norm-dim-ord-1", 1686 },
  { "linalg_matrix_norm-ord-1", 1687 },
  { "linalg_matrix_norm-1", 1688 },
  { "_linalg_svd-compute_uv-full_matrices-1", 1689 },
  { "_linalg_svd-full_matrices-1", 1690 },
  { "_linalg_svd-1", 1691 },
  { "linalg_svd-full_matrices-1", 1692 },
  { "linalg_svd-1", 1693 },
  { "linalg_svdvals-1", 1694 },
  { "linalg_cond-1", 1695 },
  { "linalg_pinv-hermitian-3", 1696 },
  { "linalg_pinv-3", 1697 },
  { "linalg_pinv-2", 1698 },
  { "linalg_pinv-1", 1699 },
  { "linalg_pinv-hermitian-rcond-1", 1700 },
  { "linalg_pinv-rcond-1", 1701 },
  { "linalg_pinv-hermitian-2", 1702 },
  { "_linalg_solve_ex-check_errors-left-2", 1703 },
  { "_linalg_solve_ex-left-2", 1704 },
  { "_linalg_solve_ex-2", 1705 },
  { "linalg_solve_ex-check_errors-left-2", 1706 },
  { "linalg_solve_ex-left-2", 1707 },
  { "linalg_solve_ex-2", 1708 },
  { "linalg_solve-left-2", 1709 },
  { "linalg_solve-2", 1710 },
  { "linalg_tensorinv-ind-1", 1711 },
  { "linalg_tensorinv-1", 1712 },
  { "linalg_tensorsolve-2", 1713 },
  { "linalg_qr-1", 1714 },
  { "linalg_matrix_power-n-1", 1715 },
  { "linalg_matrix_rank-hermitian-3", 1716 },
  { "linalg_matrix_rank-3", 1717 },
  { "linalg_matrix_rank-2", 1718 },
  { "linalg_matrix_rank-1", 1719 },
  { "linalg_matrix_rank-hermitian-tol-1", 1720 },
  { "linalg_matrix_rank-tol-1", 1721 },
  { "linalg_matrix_rank-hermitian-2", 1722 },
  { "linalg_multi_dot-*", 1723 },
  { "nested_to_padded_tensor-padding-1", 1724 },
  { "_test_serialization_subcmul-alpha-2", 1725 },
  { "_test_serialization_subcmul-2", 1726 },
  { "_test_parallel_materialize-num_parallel-skip_first-1", 1727 },
  { "_test_parallel_materialize-num_parallel-1", 1728 },
  { "_test_string_default-1", 1729 },
  { "_test_ambiguous_defaults-a-b-1", 1730 },
  { "_test_ambiguous_defaults-a-1", 1731 },
  { "_test_ambiguous_defaults-1", 1732 },
  { "_test_warn_in_autograd-1", 1733 },
  { "_test_autograd_multiple_dispatch-1", 1734 },
  { "_test_autograd_multiple_dispatch-b-1", 1735 },
  { "_test_autograd_multiple_dispatch_view-1", 1736 },
  { "_test_autograd_multiple_dispatch_view_copy-1", 1737 },
  { "pad_sequence-batch_first-padding_value-*", 1738 },
  { "pad_sequence-batch_first-*", 1739 },
  { "pad_sequence-*", 1740 },
  { "flatten_dense_tensors-*", 1741 },
  { "unflatten_dense_tensors-*", 1742 },
  { "_nested_tensor_from_tensor_list-*", 1743 },
  { "_fw_primal_copy-level-1", 1744 },
  { "_make_dual_copy-level-2", 1745 },
  { "view_as_real_copy-1", 1746 },
  { "view_as_complex_copy-1", 1747 },
  { "_conj_copy-1", 1748 },
  { "_neg_view_copy-1", 1749 },
  { "as_strided_copy-size-stride-1", 1750 },
  { "_sparse_broadcast_to_copy-size-1", 1751 },
  { "diagonal_copy-dim1-dim2-offset-1", 1752 },
  { "diagonal_copy-dim1-offset-1", 1753 },
  { "diagonal_copy-offset-1", 1754 },
  { "diagonal_copy-1", 1755 },
  { "expand_copy-implicit-size-1", 1756 },
  { "expand_copy-size-1", 1757 },
  { "permute_copy-dims-1", 1758 },
  { "_reshape_alias_copy-size-stride-1", 1759 },
  { "select_copy-dim-index-1", 1760 },
  { "detach_copy-1", 1761 },
  { "slice_copy-dim-1", 1762 },
  { "slice_copy-1", 1763 },
  { "split_copy-dim-split_size-1", 1764 },
  { "split_copy-split_size-1", 1765 },
  { "split_with_sizes_copy-dim-split_sizes-1", 1766 },
  { "split_with_sizes_copy-split_sizes-1", 1767 },
  { "squeeze_copy-1", 1768 },
  { "squeeze_copy-dim-1", 1769 },
  { "t_copy-1", 1770 },
  { "transpose_copy-dim0-dim1-1", 1771 },
  { "unsqueeze_copy-dim-1", 1772 },
  { "_indices_copy-1", 1773 },
  { "_values_copy-1", 1774 },
  { "indices_copy-1", 1775 },
  { "values_copy-1", 1776 },
  { "crow_indices_copy-1", 1777 },
  { "col_indices_copy-1", 1778 },
  { "ccol_indices_copy-1", 1779 },
  { "row_indices_copy-1", 1780 },
  { "unbind_copy-dim-1", 1781 },
  { "unbind_copy-1", 1782 },
  { "view_copy-size-1", 1783 },
  { "unfold_copy-dimension-size-step-1", 1784 },
  { "alias_copy-1", 1785 },
  { "to_padded_tensor-padding-1", 1786 },
  { "_nested_tensor_softmax_with_shape-2", 1787 },
  { "_transformer_encoder_layer_fwd-embed_dim-eps-norm_first-num_heads-use_gelu-14", 1788 },
  { "_transformer_encoder_layer_fwd-embed_dim-eps-norm_first-num_heads-use_gelu-13", 1789 },
  { "_native_multi_head_attention-average_attn_weights-embed_dim-need_weights-num_head-8", 1790 },
  { "_native_multi_head_attention-embed_dim-need_weights-num_head-8", 1791 },
  { "_native_multi_head_attention-embed_dim-num_head-8", 1792 },
  { "_native_multi_head_attention-embed_dim-num_head-7", 1793 },
  { "scaled_dot_product_attention-dropout_p-is_causal-4", 1794 },
  { "scaled_dot_product_attention-dropout_p-4", 1795 },
  { "scaled_dot_product_attention-4", 1796 },
  { "scaled_dot_product_attention-3", 1797 },
  { "_fused_sdp_choice-dropout_p-is_causal-4", 1798 },
  { "_fused_sdp_choice-dropout_p-4", 1799 },
  { "_fused_sdp_choice-4", 1800 },
  { "_fused_sdp_choice-3", 1801 },
  { "_scaled_dot_product_attention_math-dropout_p-is_causal-5", 1802 },
  { "_scaled_dot_product_attention_math-dropout_p-is_causal-4", 1803 },
  { "_scaled_dot_product_attention_math-dropout_p-4", 1804 },
  { "_scaled_dot_product_attention_math-4", 1805 },
  { "_scaled_dot_product_attention_math-3", 1806 },
  { "_scaled_dot_product_flash_attention_for_cpu-dropout_p-is_causal-4", 1807 },
  { "_scaled_dot_product_flash_attention_for_cpu-dropout_p-is_causal-3", 1808 },
  { "_scaled_dot_product_flash_attention_for_cpu-dropout_p-3", 1809 },
  { "_scaled_dot_product_flash_attention_for_cpu-3", 1810 },
  { "_scaled_dot_product_flash_attention_backward-dropout_p-is_causal-max_k-max_q-10", 1811 },
  { "_scaled_dot_product_flash_attention_for_cpu_backward-dropout_p-is_causal-7", 1812 },
  { "_scaled_dot_product_flash_attention_for_cpu_backward-dropout_p-is_causal-6", 1813 },
  { "_scaled_dot_product_efficient_attention-compute_log_sumexp-dropout_p-is_causal-4", 1814 },
  { "_scaled_dot_product_efficient_attention-compute_log_sumexp-dropout_p-4", 1815 },
  { "_scaled_dot_product_efficient_attention-compute_log_sumexp-4", 1816 },
  { "_scaled_dot_product_cudnn_attention-dropout_p-is_causal-return_debug_mask-3", 1817 },
  { "_scaled_dot_product_cudnn_attention-dropout_p-is_causal-3", 1818 },
  { "_scaled_dot_product_cudnn_attention-dropout_p-3", 1819 },
  { "_scaled_dot_product_cudnn_attention-3", 1820 },
  { "_flash_attention_forward-dropout_p-is_causal-max_k-max_q-return_debug_mask-5", 1821 },
  { "_flash_attention_backward-dropout_p-is_causal-max_k-max_q-10", 1822 },
  { "_efficient_attention_backward-bias_requires_grad-custom_mask_type-dropout_p-max_seqlen_k-max_seqlen_q-11", 1823 },
  { "_triton_scaled_dot_attention-dropout_p-3", 1824 },
  { "_triton_scaled_dot_attention-3", 1825 },
  { "_triton_multi_head_attention-embed_dim-num_head-8", 1826 },
  { "_triton_multi_head_attention-embed_dim-num_head-7", 1827 },
  { "special_airy_ai-1", 1828 },
  { "special_bessel_j0-1", 1829 },
  { "special_bessel_j1-1", 1830 },
  { "special_bessel_y0-1", 1831 },
  { "special_bessel_y1-1", 1832 },
  { "special_chebyshev_polynomial_t-2", 1833 },
  { "special_chebyshev_polynomial_t-x-1", 1834 },
  { "special_chebyshev_polynomial_t-n-1", 1835 },
  { "special_chebyshev_polynomial_u-2", 1836 },
  { "special_chebyshev_polynomial_u-x-1", 1837 },
  { "special_chebyshev_polynomial_u-n-1", 1838 },
  { "special_chebyshev_polynomial_v-2", 1839 },
  { "special_chebyshev_polynomial_v-x-1", 1840 },
  { "special_chebyshev_polynomial_v-n-1", 1841 },
  { "special_chebyshev_polynomial_w-2", 1842 },
  { "special_chebyshev_polynomial_w-x-1", 1843 },
  { "special_chebyshev_polynomial_w-n-1", 1844 },
  { "special_hermite_polynomial_h-2", 1845 },
  { "special_hermite_polynomial_h-x-1", 1846 },
  { "special_hermite_polynomial_h-n-1", 1847 },
  { "special_hermite_polynomial_he-2", 1848 },
  { "special_hermite_polynomial_he-x-1", 1849 },
  { "special_hermite_polynomial_he-n-1", 1850 },
  { "special_laguerre_polynomial_l-2", 1851 },
  { "special_laguerre_polynomial_l-x-1", 1852 },
  { "special_laguerre_polynomial_l-n-1", 1853 },
  { "special_legendre_polynomial_p-2", 1854 },
  { "special_legendre_polynomial_p-x-1", 1855 },
  { "special_legendre_polynomial_p-n-1", 1856 },
  { "special_modified_bessel_i0-1", 1857 },
  { "special_modified_bessel_i1-1", 1858 },
  { "special_modified_bessel_k0-1", 1859 },
  { "special_modified_bessel_k1-1", 1860 },
  { "special_scaled_modified_bessel_k0-1", 1861 },
  { "special_scaled_modified_bessel_k1-1", 1862 },
  { "special_shifted_chebyshev_polynomial_t-2", 1863 },
  { "special_shifted_chebyshev_polynomial_t-x-1", 1864 },
  { "special_shifted_chebyshev_polynomial_t-n-1", 1865 },
  { "special_shifted_chebyshev_polynomial_u-2", 1866 },
  { "special_shifted_chebyshev_polynomial_u-x-1", 1867 },
  { "special_shifted_chebyshev_polynomial_u-n-1", 1868 },
  { "special_shifted_chebyshev_polynomial_v-2", 1869 },
  { "special_shifted_chebyshev_polynomial_v-x-1", 1870 },
  { "special_shifted_chebyshev_polynomial_v-n-1", 1871 },
  { "special_shifted_chebyshev_polynomial_w-2", 1872 },
  { "special_shifted_chebyshev_polynomial_w-x-1", 1873 },
  { "special_shifted_chebyshev_polynomial_w-n-1", 1874 },
  { "special_spherical_bessel_j0-1", 1875 },
  { "_foobar-arg1-arg2-arg3-1", 1876 },
  { "_foobar-arg1-arg2-1", 1877 },
  { "_foobar-arg1-1", 1878 },
  { "_foobar-1", 1879 },
  { "bernoulli-2", 1880 },
  { "embedding_renorm-max_norm-norm_type-2", 1881 },
  { "resize-size-1", 1882 },
  { "_index_put_impl-accumulate-unsafe-*", 1883 },
  { "_index_put_impl-accumulate-*", 1884 },
  { "_index_put_impl-*", 1885 },
  { "_native_batch_norm_legit_functional-eps-momentum-training-5", 1886 },
  { "resize_as-2", 1887 },
  { "resize_as_sparse-2", 1888 },
  { "zero-1", 1889 },
  { "sparse_resize-dense_dim-size-sparse_dim-1", 1890 },
  { "sparse_resize_and_clear-dense_dim-size-sparse_dim-1", 1891 },
  { "_coalesced-coalesced-1", 1892 },
  { "copy_sparse_to_sparse-non_blocking-2", 1893 },
  { "copy_sparse_to_sparse-2", 1894 },
  { "_fused_moving_avg_obs_fq_helper_functional-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-symmetric_quant-7", 1895 },
  { "_fused_moving_avg_obs_fq_helper_functional-averaging_const-ch_axis-per_row_fake_quant-quant_max-quant_min-7", 1896 },
  { "_fused_moving_avg_obs_fq_helper_functional-averaging_const-ch_axis-quant_max-quant_min-7", 1897 },
  { "set-2", 1898 },
  { "set-1", 1899 },
  { "random-to-1", 1900 },
  { "random-1", 1901 },
  { "uniform-from-to-1", 1902 },
  { "uniform-from-1", 1903 },
  { "uniform-1", 1904 },
  { "cauchy-median-sigma-1", 1905 },
  { "cauchy-median-1", 1906 },
  { "cauchy-1", 1907 },
  { "log_normal-mean-std-1", 1908 },
  { "log_normal-mean-1", 1909 },
  { "log_normal-1", 1910 },
  { "exponential-lambd-1", 1911 },
  { "exponential-1", 1912 },
  { "geometric-p-1", 1913 },
  { "_amp_foreach_non_finite_check_and_unscale-*", 1914 },
  { "_amp_update_scale-growth_interval-scale_backoff_factor-scale_growth_factor-3", 1915 },
  { "_foreach_zero-*", 1916 },
  { "_foreach_copy-non_blocking-*", 1917 },
  { "_foreach_copy-*", 1918 },
  { "_fused_adam-amsgrad-beta1-beta2-eps-lr-maximize-weight_decay-*", 1919 },
  { "_fused_adam-amsgrad-beta1-beta2-eps-maximize-weight_decay-*", 1920 },
  { "_fused_adamw-amsgrad-beta1-beta2-eps-lr-maximize-weight_decay-*", 1921 },
  { "_fused_adamw-amsgrad-beta1-beta2-eps-maximize-weight_decay-*", 1922 },
  { "_fused_sgd-dampening-is_first_step-lr-maximize-momentum-nesterov-weight_decay-*", 1923 },
  { "_fused_sgd-dampening-is_first_step-maximize-momentum-nesterov-weight_decay-*", 1924 },
};

namespace caffe2 {

using at::Half; // for AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, ...)

namespace internal {
TORCH_API at::Tensor index_with_uint8_handling(
    const at::Tensor& self,
    const torch::List<c10::optional<at::Tensor>>& indices);
}

template <class Context>
class ATenOp : public Operator<Context> {
 public:
  ATenOp(const OperatorDef& operator_def, Workspace* ws)
  : Operator<Context>(operator_def, ws) {
    VLOG(2) << "ATen OpDef: " << ProtoDebugString(operator_def) << "\n";
    switch(findImplementation(operator_def)) {
      case 0: // _cast_Byte
        implementation_0();
        break;
      case 1: // _cast_Byte
        implementation_1();
        break;
      case 2: // _cast_Char
        implementation_2();
        break;
      case 3: // _cast_Char
        implementation_3();
        break;
      case 4: // _cast_Double
        implementation_4();
        break;
      case 5: // _cast_Double
        implementation_5();
        break;
      case 6: // _cast_Float
        implementation_6();
        break;
      case 7: // _cast_Float
        implementation_7();
        break;
      case 8: // _cast_Int
        implementation_8();
        break;
      case 9: // _cast_Int
        implementation_9();
        break;
      case 10: // _cast_Long
        implementation_10();
        break;
      case 11: // _cast_Long
        implementation_11();
        break;
      case 12: // _cast_Short
        implementation_12();
        break;
      case 13: // _cast_Short
        implementation_13();
        break;
      case 14: // _cast_Half
        implementation_14();
        break;
      case 15: // _cast_Half
        implementation_15();
        break;
      case 16: // data
        implementation_16();
        break;
      case 17: // is_leaf
        implementation_17();
        break;
      case 18: // output_nr
        implementation_18();
        break;
      case 19: // _version
        implementation_19();
        break;
      case 20: // retains_grad
        implementation_20();
        break;
      case 21: // _fw_primal
        implementation_21();
        break;
      case 22: // _make_dual
        implementation_22();
        break;
      case 23: // _unpack_dual
        implementation_23();
        break;
      case 24: // _new_zeros_with_same_feature_meta
        implementation_24();
        break;
      case 25: // _new_zeros_with_same_feature_meta
        implementation_25();
        break;
      case 26: // _has_same_storage_numel
        implementation_26();
        break;
      case 27: // align_as
        implementation_27();
        break;
      case 28: // align_tensors
        implementation_28();
        break;
      case 29: // _use_cudnn_ctc_loss
        implementation_29();
        break;
      case 30: // _use_cudnn_ctc_loss
        implementation_30();
        break;
      case 31: // _cudnn_ctc_loss
        implementation_31();
        break;
      case 32: // _cudnn_ctc_loss
        implementation_32();
        break;
      case 33: // _use_cudnn_rnn_flatten_weight
        implementation_33();
        break;
      case 34: // _cudnn_rnn_flatten_weight
        implementation_34();
        break;
      case 35: // _cudnn_rnn
        implementation_35();
        break;
      case 36: // _debug_has_internal_overlap
        implementation_36();
        break;
      case 37: // _fused_dropout
        implementation_37();
        break;
      case 38: // _masked_scale
        implementation_38();
        break;
      case 39: // native_dropout_backward
        implementation_39();
        break;
      case 40: // _reshape_from_tensor
        implementation_40();
        break;
      case 41: // _shape_as_tensor
        implementation_41();
        break;
      case 42: // dropout
        implementation_42();
        break;
      case 43: // feature_dropout
        implementation_43();
        break;
      case 44: // alpha_dropout
        implementation_44();
        break;
      case 45: // feature_alpha_dropout
        implementation_45();
        break;
      case 46: // abs
        implementation_46();
        break;
      case 47: // absolute
        implementation_47();
        break;
      case 48: // angle
        implementation_48();
        break;
      case 49: // view_as_real
        implementation_49();
        break;
      case 50: // view_as_complex
        implementation_50();
        break;
      case 51: // sgn
        implementation_51();
        break;
      case 52: // chalf
        implementation_52();
        break;
      case 53: // real
        implementation_53();
        break;
      case 54: // imag
        implementation_54();
        break;
      case 55: // _conj
        implementation_55();
        break;
      case 56: // conj
        implementation_56();
        break;
      case 57: // _conj_physical
        implementation_57();
        break;
      case 58: // conj_physical
        implementation_58();
        break;
      case 59: // resolve_conj
        implementation_59();
        break;
      case 60: // resolve_neg
        implementation_60();
        break;
      case 61: // _neg_view
        implementation_61();
        break;
      case 62: // acos
        implementation_62();
        break;
      case 63: // arccos
        implementation_63();
        break;
      case 64: // avg_pool1d
        implementation_64();
        break;
      case 65: // avg_pool1d
        implementation_65();
        break;
      case 66: // avg_pool1d
        implementation_66();
        break;
      case 67: // avg_pool1d
        implementation_67();
        break;
      case 68: // avg_pool1d
        implementation_68();
        break;
      case 69: // adaptive_avg_pool1d
        implementation_69();
        break;
      case 70: // adaptive_max_pool1d
        implementation_70();
        break;
      case 71: // add
        implementation_71();
        break;
      case 72: // add
        implementation_72();
        break;
      case 73: // _add_relu
        implementation_73();
        break;
      case 74: // _add_relu
        implementation_74();
        break;
      case 75: // _add_relu
        implementation_75();
        break;
      case 76: // _add_relu
        implementation_76();
        break;
      case 77: // add
        implementation_77();
        break;
      case 78: // add
        implementation_78();
        break;
      case 79: // addmv
        implementation_79();
        break;
      case 80: // addmv
        implementation_80();
        break;
      case 81: // addmv
        implementation_81();
        break;
      case 82: // addr
        implementation_82();
        break;
      case 83: // addr
        implementation_83();
        break;
      case 84: // addr
        implementation_84();
        break;
      case 85: // affine_grid_generator
        implementation_85();
        break;
      case 86: // affine_grid_generator_backward
        implementation_86();
        break;
      case 87: // _is_all_true
        implementation_87();
        break;
      case 88: // _is_any_true
        implementation_88();
        break;
      case 89: // _test_check_tensor
        implementation_89();
        break;
      case 90: // _test_functorch_fallback
        implementation_90();
        break;
      case 91: // all
        implementation_91();
        break;
      case 92: // all
        implementation_92();
        break;
      case 93: // all
        implementation_93();
        break;
      case 94: // allclose
        implementation_94();
        break;
      case 95: // allclose
        implementation_95();
        break;
      case 96: // allclose
        implementation_96();
        break;
      case 97: // allclose
        implementation_97();
        break;
      case 98: // any
        implementation_98();
        break;
      case 99: // any
        implementation_99();
        break;
      case 100: // any
        implementation_100();
        break;
      case 101: // _dim_arange
        implementation_101();
        break;
      case 102: // argmax
        implementation_102();
        break;
      case 103: // argmin
        implementation_103();
        break;
      case 104: // acosh
        implementation_104();
        break;
      case 105: // arccosh
        implementation_105();
        break;
      case 106: // asinh
        implementation_106();
        break;
      case 107: // arcsinh
        implementation_107();
        break;
      case 108: // atanh
        implementation_108();
        break;
      case 109: // arctanh
        implementation_109();
        break;
      case 110: // as_strided
        implementation_110();
        break;
      case 111: // asin
        implementation_111();
        break;
      case 112: // arcsin
        implementation_112();
        break;
      case 113: // atan
        implementation_113();
        break;
      case 114: // arctan
        implementation_114();
        break;
      case 115: // atleast_1d
        implementation_115();
        break;
      case 116: // atleast_1d
        implementation_116();
        break;
      case 117: // atleast_2d
        implementation_117();
        break;
      case 118: // atleast_2d
        implementation_118();
        break;
      case 119: // atleast_3d
        implementation_119();
        break;
      case 120: // atleast_3d
        implementation_120();
        break;
      case 121: // baddbmm
        implementation_121();
        break;
      case 122: // baddbmm
        implementation_122();
        break;
      case 123: // baddbmm
        implementation_123();
        break;
      case 124: // batch_norm
        implementation_124();
        break;
      case 125: // quantized_batch_norm
        implementation_125();
        break;
      case 126: // _batch_norm_impl_index
        implementation_126();
        break;
      case 127: // _batch_norm_impl_index_backward
        implementation_127();
        break;
      case 128: // bernoulli
        implementation_128();
        break;
      case 129: // bernoulli
        implementation_129();
        break;
      case 130: // bilinear
        implementation_130();
        break;
      case 131: // bilinear
        implementation_131();
        break;
      case 132: // binary_cross_entropy
        implementation_132();
        break;
      case 133: // binary_cross_entropy
        implementation_133();
        break;
      case 134: // binary_cross_entropy
        implementation_134();
        break;
      case 135: // binary_cross_entropy_backward
        implementation_135();
        break;
      case 136: // binary_cross_entropy_backward
        implementation_136();
        break;
      case 137: // binary_cross_entropy_backward
        implementation_137();
        break;
      case 138: // binary_cross_entropy_with_logits
        implementation_138();
        break;
      case 139: // binary_cross_entropy_with_logits
        implementation_139();
        break;
      case 140: // binary_cross_entropy_with_logits
        implementation_140();
        break;
      case 141: // binary_cross_entropy_with_logits
        implementation_141();
        break;
      case 142: // bincount
        implementation_142();
        break;
      case 143: // bincount
        implementation_143();
        break;
      case 144: // bincount
        implementation_144();
        break;
      case 145: // bitwise_not
        implementation_145();
        break;
      case 146: // copysign
        implementation_146();
        break;
      case 147: // copysign
        implementation_147();
        break;
      case 148: // _lazy_clone
        implementation_148();
        break;
      case 149: // logical_not
        implementation_149();
        break;
      case 150: // logical_xor
        implementation_150();
        break;
      case 151: // logical_and
        implementation_151();
        break;
      case 152: // logical_or
        implementation_152();
        break;
      case 153: // bmm
        implementation_153();
        break;
      case 154: // broadcast_tensors
        implementation_154();
        break;
      case 155: // broadcast_to
        implementation_155();
        break;
      case 156: // _sparse_broadcast_to
        implementation_156();
        break;
      case 157: // cat
        implementation_157();
        break;
      case 158: // cat
        implementation_158();
        break;
      case 159: // concat
        implementation_159();
        break;
      case 160: // concat
        implementation_160();
        break;
      case 161: // concatenate
        implementation_161();
        break;
      case 162: // concatenate
        implementation_162();
        break;
      case 163: // block_diag
        implementation_163();
        break;
      case 164: // ceil
        implementation_164();
        break;
      case 165: // chain_matmul
        implementation_165();
        break;
      case 166: // unsafe_chunk
        implementation_166();
        break;
      case 167: // unsafe_chunk
        implementation_167();
        break;
      case 168: // chunk
        implementation_168();
        break;
      case 169: // chunk
        implementation_169();
        break;
      case 170: // tensor_split
        implementation_170();
        break;
      case 171: // tensor_split
        implementation_171();
        break;
      case 172: // tensor_split
        implementation_172();
        break;
      case 173: // tensor_split
        implementation_173();
        break;
      case 174: // tensor_split
        implementation_174();
        break;
      case 175: // tensor_split
        implementation_175();
        break;
      case 176: // clamp
        implementation_176();
        break;
      case 177: // clamp
        implementation_177();
        break;
      case 178: // clamp
        implementation_178();
        break;
      case 179: // clamp_max
        implementation_179();
        break;
      case 180: // clamp_max
        implementation_180();
        break;
      case 181: // clamp_min
        implementation_181();
        break;
      case 182: // clamp_min
        implementation_182();
        break;
      case 183: // clip
        implementation_183();
        break;
      case 184: // clip
        implementation_184();
        break;
      case 185: // clip
        implementation_185();
        break;
      case 186: // cudnn_is_acceptable
        implementation_186();
        break;
      case 187: // complex
        implementation_187();
        break;
      case 188: // polar
        implementation_188();
        break;
      case 189: // constant_pad_nd
        implementation_189();
        break;
      case 190: // constant_pad_nd
        implementation_190();
        break;
      case 191: // contiguous
        implementation_191();
        break;
      case 192: // convolution
        implementation_192();
        break;
      case 193: // convolution_overrideable
        implementation_193();
        break;
      case 194: // convolution_backward_overrideable
        implementation_194();
        break;
      case 195: // _convolution
        implementation_195();
        break;
      case 196: // _convolution
        implementation_196();
        break;
      case 197: // _convolution_double_backward
        implementation_197();
        break;
      case 198: // conv1d
        implementation_198();
        break;
      case 199: // conv1d
        implementation_199();
        break;
      case 200: // conv1d
        implementation_200();
        break;
      case 201: // conv1d
        implementation_201();
        break;
      case 202: // conv1d
        implementation_202();
        break;
      case 203: // conv1d
        implementation_203();
        break;
      case 204: // conv2d
        implementation_204();
        break;
      case 205: // conv2d
        implementation_205();
        break;
      case 206: // conv2d
        implementation_206();
        break;
      case 207: // conv2d
        implementation_207();
        break;
      case 208: // conv2d
        implementation_208();
        break;
      case 209: // conv2d
        implementation_209();
        break;
      case 210: // conv3d
        implementation_210();
        break;
      case 211: // conv3d
        implementation_211();
        break;
      case 212: // conv3d
        implementation_212();
        break;
      case 213: // conv3d
        implementation_213();
        break;
      case 214: // conv3d
        implementation_214();
        break;
      case 215: // conv3d
        implementation_215();
        break;
      case 216: // conv_tbc
        implementation_216();
        break;
      case 217: // conv_tbc
        implementation_217();
        break;
      case 218: // conv_tbc_backward
        implementation_218();
        break;
      case 219: // conv_transpose1d
        implementation_219();
        break;
      case 220: // conv_transpose1d
        implementation_220();
        break;
      case 221: // conv_transpose1d
        implementation_221();
        break;
      case 222: // conv_transpose1d
        implementation_222();
        break;
      case 223: // conv_transpose1d
        implementation_223();
        break;
      case 224: // conv_transpose1d
        implementation_224();
        break;
      case 225: // conv_transpose1d
        implementation_225();
        break;
      case 226: // conv_transpose2d
        implementation_226();
        break;
      case 227: // conv_transpose2d
        implementation_227();
        break;
      case 228: // conv_transpose2d
        implementation_228();
        break;
      case 229: // conv_transpose2d
        implementation_229();
        break;
      case 230: // conv_transpose2d
        implementation_230();
        break;
      case 231: // conv_transpose2d
        implementation_231();
        break;
      case 232: // conv_transpose2d
        implementation_232();
        break;
      case 233: // conv_transpose3d
        implementation_233();
        break;
      case 234: // conv_transpose3d
        implementation_234();
        break;
      case 235: // conv_transpose3d
        implementation_235();
        break;
      case 236: // conv_transpose3d
        implementation_236();
        break;
      case 237: // conv_transpose3d
        implementation_237();
        break;
      case 238: // conv_transpose3d
        implementation_238();
        break;
      case 239: // conv_transpose3d
        implementation_239();
        break;
      case 240: // copy
        implementation_240();
        break;
      case 241: // copy
        implementation_241();
        break;
      case 242: // _copy_from
        implementation_242();
        break;
      case 243: // _copy_from
        implementation_243();
        break;
      case 244: // _copy_from_and_resize
        implementation_244();
        break;
      case 245: // cos
        implementation_245();
        break;
      case 246: // cosh
        implementation_246();
        break;
      case 247: // cosine_embedding_loss
        implementation_247();
        break;
      case 248: // cosine_embedding_loss
        implementation_248();
        break;
      case 249: // cosine_embedding_loss
        implementation_249();
        break;
      case 250: // count_nonzero
        implementation_250();
        break;
      case 251: // count_nonzero
        implementation_251();
        break;
      case 252: // cov
        implementation_252();
        break;
      case 253: // cov
        implementation_253();
        break;
      case 254: // cov
        implementation_254();
        break;
      case 255: // cov
        implementation_255();
        break;
      case 256: // corrcoef
        implementation_256();
        break;
      case 257: // cudnn_affine_grid_generator
        implementation_257();
        break;
      case 258: // cudnn_affine_grid_generator_backward
        implementation_258();
        break;
      case 259: // cudnn_batch_norm
        implementation_259();
        break;
      case 260: // cudnn_batch_norm_backward
        implementation_260();
        break;
      case 261: // cudnn_convolution
        implementation_261();
        break;
      case 262: // cudnn_convolution_transpose
        implementation_262();
        break;
      case 263: // _mps_convolution_transpose
        implementation_263();
        break;
      case 264: // mps_convolution_transpose_backward
        implementation_264();
        break;
      case 265: // cudnn_convolution_relu
        implementation_265();
        break;
      case 266: // cudnn_grid_sampler
        implementation_266();
        break;
      case 267: // cudnn_grid_sampler_backward
        implementation_267();
        break;
      case 268: // cummax
        implementation_268();
        break;
      case 269: // cummin
        implementation_269();
        break;
      case 270: // cummaxmin_backward
        implementation_270();
        break;
      case 271: // cumprod
        implementation_271();
        break;
      case 272: // cumprod_backward
        implementation_272();
        break;
      case 273: // cumsum
        implementation_273();
        break;
      case 274: // cumulative_trapezoid
        implementation_274();
        break;
      case 275: // cumulative_trapezoid
        implementation_275();
        break;
      case 276: // cumulative_trapezoid
        implementation_276();
        break;
      case 277: // cumulative_trapezoid
        implementation_277();
        break;
      case 278: // cumulative_trapezoid
        implementation_278();
        break;
      case 279: // ctc_loss
        implementation_279();
        break;
      case 280: // ctc_loss
        implementation_280();
        break;
      case 281: // ctc_loss
        implementation_281();
        break;
      case 282: // ctc_loss
        implementation_282();
        break;
      case 283: // ctc_loss
        implementation_283();
        break;
      case 284: // ctc_loss
        implementation_284();
        break;
      case 285: // ctc_loss
        implementation_285();
        break;
      case 286: // ctc_loss
        implementation_286();
        break;
      case 287: // _ctc_loss
        implementation_287();
        break;
      case 288: // _ctc_loss
        implementation_288();
        break;
      case 289: // _ctc_loss
        implementation_289();
        break;
      case 290: // _ctc_loss
        implementation_290();
        break;
      case 291: // _ctc_loss
        implementation_291();
        break;
      case 292: // _ctc_loss
        implementation_292();
        break;
      case 293: // _ctc_loss_backward
        implementation_293();
        break;
      case 294: // _ctc_loss_backward
        implementation_294();
        break;
      case 295: // _ctc_loss_backward
        implementation_295();
        break;
      case 296: // _ctc_loss_backward
        implementation_296();
        break;
      case 297: // diag_embed
        implementation_297();
        break;
      case 298: // diag_embed
        implementation_298();
        break;
      case 299: // diag_embed
        implementation_299();
        break;
      case 300: // diag_embed
        implementation_300();
        break;
      case 301: // diagflat
        implementation_301();
        break;
      case 302: // diagflat
        implementation_302();
        break;
      case 303: // diagonal
        implementation_303();
        break;
      case 304: // diagonal
        implementation_304();
        break;
      case 305: // diagonal
        implementation_305();
        break;
      case 306: // diagonal
        implementation_306();
        break;
      case 307: // linalg_diagonal
        implementation_307();
        break;
      case 308: // linalg_diagonal
        implementation_308();
        break;
      case 309: // linalg_diagonal
        implementation_309();
        break;
      case 310: // linalg_diagonal
        implementation_310();
        break;
      case 311: // diagonal_backward
        implementation_311();
        break;
      case 312: // diff
        implementation_312();
        break;
      case 313: // diff
        implementation_313();
        break;
      case 314: // diff
        implementation_314();
        break;
      case 315: // diff
        implementation_315();
        break;
      case 316: // diff
        implementation_316();
        break;
      case 317: // gradient
        implementation_317();
        break;
      case 318: // gradient
        implementation_318();
        break;
      case 319: // gradient
        implementation_319();
        break;
      case 320: // gradient
        implementation_320();
        break;
      case 321: // gradient
        implementation_321();
        break;
      case 322: // gradient
        implementation_322();
        break;
      case 323: // gradient
        implementation_323();
        break;
      case 324: // gradient
        implementation_324();
        break;
      case 325: // div
        implementation_325();
        break;
      case 326: // div
        implementation_326();
        break;
      case 327: // divide
        implementation_327();
        break;
      case 328: // divide
        implementation_328();
        break;
      case 329: // true_divide
        implementation_329();
        break;
      case 330: // true_divide
        implementation_330();
        break;
      case 331: // dot
        implementation_331();
        break;
      case 332: // vdot
        implementation_332();
        break;
      case 333: // embedding
        implementation_333();
        break;
      case 334: // embedding
        implementation_334();
        break;
      case 335: // embedding
        implementation_335();
        break;
      case 336: // embedding
        implementation_336();
        break;
      case 337: // embedding_backward
        implementation_337();
        break;
      case 338: // embedding_dense_backward
        implementation_338();
        break;
      case 339: // embedding_sparse_backward
        implementation_339();
        break;
      case 340: // _embedding_bag_forward_only
        implementation_340();
        break;
      case 341: // _embedding_bag_forward_only
        implementation_341();
        break;
      case 342: // _embedding_bag_forward_only
        implementation_342();
        break;
      case 343: // _embedding_bag_forward_only
        implementation_343();
        break;
      case 344: // _embedding_bag_forward_only
        implementation_344();
        break;
      case 345: // _embedding_bag_forward_only
        implementation_345();
        break;
      case 346: // _embedding_bag_forward_only
        implementation_346();
        break;
      case 347: // row_stack
        implementation_347();
        break;
      case 348: // embedding_bag
        implementation_348();
        break;
      case 349: // embedding_bag
        implementation_349();
        break;
      case 350: // embedding_bag
        implementation_350();
        break;
      case 351: // embedding_bag
        implementation_351();
        break;
      case 352: // embedding_bag
        implementation_352();
        break;
      case 353: // embedding_bag
        implementation_353();
        break;
      case 354: // _embedding_bag
        implementation_354();
        break;
      case 355: // _embedding_bag
        implementation_355();
        break;
      case 356: // _embedding_bag
        implementation_356();
        break;
      case 357: // _embedding_bag
        implementation_357();
        break;
      case 358: // _embedding_bag
        implementation_358();
        break;
      case 359: // _embedding_bag
        implementation_359();
        break;
      case 360: // _embedding_bag
        implementation_360();
        break;
      case 361: // _embedding_bag_backward
        implementation_361();
        break;
      case 362: // _embedding_bag_backward
        implementation_362();
        break;
      case 363: // _embedding_bag_sparse_backward
        implementation_363();
        break;
      case 364: // _embedding_bag_sparse_backward
        implementation_364();
        break;
      case 365: // _embedding_bag_dense_backward
        implementation_365();
        break;
      case 366: // _embedding_bag_dense_backward
        implementation_366();
        break;
      case 367: // _embedding_bag_per_sample_weights_backward
        implementation_367();
        break;
      case 368: // _embedding_bag_per_sample_weights_backward
        implementation_368();
        break;
      case 369: // erf
        implementation_369();
        break;
      case 370: // erfc
        implementation_370();
        break;
      case 371: // exp
        implementation_371();
        break;
      case 372: // exp2
        implementation_372();
        break;
      case 373: // expm1
        implementation_373();
        break;
      case 374: // expand
        implementation_374();
        break;
      case 375: // expand
        implementation_375();
        break;
      case 376: // expand_as
        implementation_376();
        break;
      case 377: // flatten
        implementation_377();
        break;
      case 378: // flatten
        implementation_378();
        break;
      case 379: // flatten
        implementation_379();
        break;
      case 380: // unflatten
        implementation_380();
        break;
      case 381: // fill
        implementation_381();
        break;
      case 382: // fill
        implementation_382();
        break;
      case 383: // floor
        implementation_383();
        break;
      case 384: // floor_divide
        implementation_384();
        break;
      case 385: // floor_divide
        implementation_385();
        break;
      case 386: // frac
        implementation_386();
        break;
      case 387: // gcd
        implementation_387();
        break;
      case 388: // lcm
        implementation_388();
        break;
      case 389: // grid_sampler
        implementation_389();
        break;
      case 390: // grid_sampler_2d
        implementation_390();
        break;
      case 391: // grid_sampler_2d_backward
        implementation_391();
        break;
      case 392: // _grid_sampler_2d_cpu_fallback
        implementation_392();
        break;
      case 393: // _grid_sampler_2d_cpu_fallback_backward
        implementation_393();
        break;
      case 394: // grid_sampler_3d
        implementation_394();
        break;
      case 395: // grid_sampler_3d_backward
        implementation_395();
        break;
      case 396: // hinge_embedding_loss
        implementation_396();
        break;
      case 397: // hinge_embedding_loss
        implementation_397();
        break;
      case 398: // hinge_embedding_loss
        implementation_398();
        break;
      case 399: // group_norm
        implementation_399();
        break;
      case 400: // group_norm
        implementation_400();
        break;
      case 401: // group_norm
        implementation_401();
        break;
      case 402: // group_norm
        implementation_402();
        break;
      case 403: // group_norm
        implementation_403();
        break;
      case 404: // native_group_norm
        implementation_404();
        break;
      case 405: // native_group_norm_backward
        implementation_405();
        break;
      case 406: // _fft_r2c
        implementation_406();
        break;
      case 407: // _fft_c2r
        implementation_407();
        break;
      case 408: // _fft_c2c
        implementation_408();
        break;
      case 409: // index
        implementation_409();
        break;
      case 410: // _unsafe_index
        implementation_410();
        break;
      case 411: // index_copy
        implementation_411();
        break;
      case 412: // index_put
        implementation_412();
        break;
      case 413: // index_put
        implementation_413();
        break;
      case 414: // _unsafe_index_put
        implementation_414();
        break;
      case 415: // _unsafe_index_put
        implementation_415();
        break;
      case 416: // instance_norm
        implementation_416();
        break;
      case 417: // isclose
        implementation_417();
        break;
      case 418: // isclose
        implementation_418();
        break;
      case 419: // isclose
        implementation_419();
        break;
      case 420: // isclose
        implementation_420();
        break;
      case 421: // isin
        implementation_421();
        break;
      case 422: // isin
        implementation_422();
        break;
      case 423: // isin
        implementation_423();
        break;
      case 424: // isin
        implementation_424();
        break;
      case 425: // isin
        implementation_425();
        break;
      case 426: // isin
        implementation_426();
        break;
      case 427: // isin
        implementation_427();
        break;
      case 428: // isin
        implementation_428();
        break;
      case 429: // isin
        implementation_429();
        break;
      case 430: // isnan
        implementation_430();
        break;
      case 431: // is_distributed
        implementation_431();
        break;
      case 432: // is_floating_point
        implementation_432();
        break;
      case 433: // is_complex
        implementation_433();
        break;
      case 434: // is_conj
        implementation_434();
        break;
      case 435: // _is_zerotensor
        implementation_435();
        break;
      case 436: // is_neg
        implementation_436();
        break;
      case 437: // isreal
        implementation_437();
        break;
      case 438: // is_nonzero
        implementation_438();
        break;
      case 439: // is_same_size
        implementation_439();
        break;
      case 440: // is_signed
        implementation_440();
        break;
      case 441: // is_inference
        implementation_441();
        break;
      case 442: // kl_div
        implementation_442();
        break;
      case 443: // kl_div
        implementation_443();
        break;
      case 444: // kl_div
        implementation_444();
        break;
      case 445: // kron
        implementation_445();
        break;
      case 446: // kthvalue
        implementation_446();
        break;
      case 447: // kthvalue
        implementation_447();
        break;
      case 448: // kthvalue
        implementation_448();
        break;
      case 449: // layer_norm
        implementation_449();
        break;
      case 450: // layer_norm
        implementation_450();
        break;
      case 451: // layer_norm
        implementation_451();
        break;
      case 452: // layer_norm
        implementation_452();
        break;
      case 453: // layer_norm
        implementation_453();
        break;
      case 454: // native_layer_norm
        implementation_454();
        break;
      case 455: // native_layer_norm_backward
        implementation_455();
        break;
      case 456: // nan_to_num
        implementation_456();
        break;
      case 457: // linear
        implementation_457();
        break;
      case 458: // linear
        implementation_458();
        break;
      case 459: // linear_backward
        implementation_459();
        break;
      case 460: // mkldnn_linear
        implementation_460();
        break;
      case 461: // mkldnn_linear
        implementation_461();
        break;
      case 462: // mkldnn_linear_backward_input
        implementation_462();
        break;
      case 463: // mkldnn_linear_backward_weights
        implementation_463();
        break;
      case 464: // mkldnn_linear_backward
        implementation_464();
        break;
      case 465: // _cslt_compress
        implementation_465();
        break;
      case 466: // _cslt_sparse_mm
        implementation_466();
        break;
      case 467: // _cslt_sparse_mm
        implementation_467();
        break;
      case 468: // _cslt_sparse_mm
        implementation_468();
        break;
      case 469: // _cslt_sparse_mm_search
        implementation_469();
        break;
      case 470: // _cslt_sparse_mm_search
        implementation_470();
        break;
      case 471: // _cslt_sparse_mm_search
        implementation_471();
        break;
      case 472: // _sparse_semi_structured_linear
        implementation_472();
        break;
      case 473: // _sparse_semi_structured_linear
        implementation_473();
        break;
      case 474: // _mixed_dtypes_linear
        implementation_474();
        break;
      case 475: // _mixed_dtypes_linear
        implementation_475();
        break;
      case 476: // fbgemm_linear_int8_weight_fp32_activation
        implementation_476();
        break;
      case 477: // fbgemm_linear_int8_weight
        implementation_477();
        break;
      case 478: // fbgemm_pack_gemm_matrix_fp16
        implementation_478();
        break;
      case 479: // fbgemm_linear_fp16_weight_fp32_activation
        implementation_479();
        break;
      case 480: // fbgemm_linear_fp16_weight
        implementation_480();
        break;
      case 481: // fbgemm_pack_quantized_matrix
        implementation_481();
        break;
      case 482: // fbgemm_pack_quantized_matrix
        implementation_482();
        break;
      case 483: // ldexp
        implementation_483();
        break;
      case 484: // log
        implementation_484();
        break;
      case 485: // log10
        implementation_485();
        break;
      case 486: // log1p
        implementation_486();
        break;
      case 487: // log2
        implementation_487();
        break;
      case 488: // logaddexp
        implementation_488();
        break;
      case 489: // logaddexp2
        implementation_489();
        break;
      case 490: // xlogy
        implementation_490();
        break;
      case 491: // xlogy
        implementation_491();
        break;
      case 492: // xlogy
        implementation_492();
        break;
      case 493: // log_softmax
        implementation_493();
        break;
      case 494: // _log_softmax
        implementation_494();
        break;
      case 495: // _logcumsumexp
        implementation_495();
        break;
      case 496: // logcumsumexp
        implementation_496();
        break;
      case 497: // logsumexp
        implementation_497();
        break;
      case 498: // logsumexp
        implementation_498();
        break;
      case 499: // margin_ranking_loss
        implementation_499();
        break;
      case 500: // margin_ranking_loss
        implementation_500();
        break;
      case 501: // margin_ranking_loss
        implementation_501();
        break;
      case 502: // matmul
        implementation_502();
        break;
      case 503: // matmul_backward
        implementation_503();
        break;
      case 504: // matrix_power
        implementation_504();
        break;
      case 505: // matrix_exp
        implementation_505();
        break;
      case 506: // matrix_exp_backward
        implementation_506();
        break;
      case 507: // _aminmax
        implementation_507();
        break;
      case 508: // _aminmax
        implementation_508();
        break;
      case 509: // _aminmax
        implementation_509();
        break;
      case 510: // aminmax
        implementation_510();
        break;
      case 511: // _compute_linear_combination
        implementation_511();
        break;
      case 512: // max
        implementation_512();
        break;
      case 513: // max
        implementation_513();
        break;
      case 514: // value_selecting_reduction_backward
        implementation_514();
        break;
      case 515: // amax
        implementation_515();
        break;
      case 516: // amax
        implementation_516();
        break;
      case 517: // amax
        implementation_517();
        break;
      case 518: // max_pool1d_with_indices
        implementation_518();
        break;
      case 519: // max_pool1d_with_indices
        implementation_519();
        break;
      case 520: // max_pool1d_with_indices
        implementation_520();
        break;
      case 521: // max_pool1d_with_indices
        implementation_521();
        break;
      case 522: // max_pool1d_with_indices
        implementation_522();
        break;
      case 523: // max_pool1d
        implementation_523();
        break;
      case 524: // max_pool1d
        implementation_524();
        break;
      case 525: // max_pool1d
        implementation_525();
        break;
      case 526: // max_pool1d
        implementation_526();
        break;
      case 527: // max_pool1d
        implementation_527();
        break;
      case 528: // max_pool2d
        implementation_528();
        break;
      case 529: // max_pool2d
        implementation_529();
        break;
      case 530: // max_pool2d
        implementation_530();
        break;
      case 531: // max_pool2d
        implementation_531();
        break;
      case 532: // max_pool2d
        implementation_532();
        break;
      case 533: // max_pool2d_backward
        implementation_533();
        break;
      case 534: // max_pool2d_backward
        implementation_534();
        break;
      case 535: // max_pool2d_backward
        implementation_535();
        break;
      case 536: // max_pool2d_backward
        implementation_536();
        break;
      case 537: // max_pool2d_backward
        implementation_537();
        break;
      case 538: // mkldnn_max_pool2d
        implementation_538();
        break;
      case 539: // mkldnn_max_pool2d
        implementation_539();
        break;
      case 540: // mkldnn_max_pool2d
        implementation_540();
        break;
      case 541: // mkldnn_max_pool2d
        implementation_541();
        break;
      case 542: // mkldnn_max_pool2d
        implementation_542();
        break;
      case 543: // mkldnn_max_pool2d_backward
        implementation_543();
        break;
      case 544: // mkldnn_max_pool2d_backward
        implementation_544();
        break;
      case 545: // mkldnn_max_pool2d_backward
        implementation_545();
        break;
      case 546: // mkldnn_max_pool2d_backward
        implementation_546();
        break;
      case 547: // mkldnn_max_pool2d_backward
        implementation_547();
        break;
      case 548: // mkldnn_max_pool3d
        implementation_548();
        break;
      case 549: // mkldnn_max_pool3d
        implementation_549();
        break;
      case 550: // mkldnn_max_pool3d
        implementation_550();
        break;
      case 551: // mkldnn_max_pool3d
        implementation_551();
        break;
      case 552: // mkldnn_max_pool3d
        implementation_552();
        break;
      case 553: // mkldnn_max_pool3d_backward
        implementation_553();
        break;
      case 554: // mkldnn_max_pool3d_backward
        implementation_554();
        break;
      case 555: // mkldnn_max_pool3d_backward
        implementation_555();
        break;
      case 556: // mkldnn_max_pool3d_backward
        implementation_556();
        break;
      case 557: // mkldnn_max_pool3d_backward
        implementation_557();
        break;
      case 558: // quantized_max_pool1d
        implementation_558();
        break;
      case 559: // quantized_max_pool1d
        implementation_559();
        break;
      case 560: // quantized_max_pool1d
        implementation_560();
        break;
      case 561: // quantized_max_pool1d
        implementation_561();
        break;
      case 562: // quantized_max_pool1d
        implementation_562();
        break;
      case 563: // quantized_max_pool2d
        implementation_563();
        break;
      case 564: // quantized_max_pool2d
        implementation_564();
        break;
      case 565: // quantized_max_pool2d
        implementation_565();
        break;
      case 566: // quantized_max_pool2d
        implementation_566();
        break;
      case 567: // quantized_max_pool2d
        implementation_567();
        break;
      case 568: // quantized_max_pool3d
        implementation_568();
        break;
      case 569: // quantized_max_pool3d
        implementation_569();
        break;
      case 570: // quantized_max_pool3d
        implementation_570();
        break;
      case 571: // quantized_max_pool3d
        implementation_571();
        break;
      case 572: // quantized_max_pool3d
        implementation_572();
        break;
      case 573: // max_pool3d
        implementation_573();
        break;
      case 574: // max_pool3d
        implementation_574();
        break;
      case 575: // max_pool3d
        implementation_575();
        break;
      case 576: // max_pool3d
        implementation_576();
        break;
      case 577: // max_pool3d
        implementation_577();
        break;
      case 578: // mean
        implementation_578();
        break;
      case 579: // nanmean
        implementation_579();
        break;
      case 580: // median
        implementation_580();
        break;
      case 581: // median
        implementation_581();
        break;
      case 582: // median
        implementation_582();
        break;
      case 583: // nanmedian
        implementation_583();
        break;
      case 584: // nanmedian
        implementation_584();
        break;
      case 585: // nanmedian
        implementation_585();
        break;
      case 586: // min
        implementation_586();
        break;
      case 587: // min
        implementation_587();
        break;
      case 588: // amin
        implementation_588();
        break;
      case 589: // amin
        implementation_589();
        break;
      case 590: // amin
        implementation_590();
        break;
      case 591: // _mps_convolution
        implementation_591();
        break;
      case 592: // mps_convolution_backward
        implementation_592();
        break;
      case 593: // mkldnn_convolution
        implementation_593();
        break;
      case 594: // mkldnn_rnn_layer
        implementation_594();
        break;
      case 595: // mkldnn_rnn_layer_backward
        implementation_595();
        break;
      case 596: // miopen_batch_norm
        implementation_596();
        break;
      case 597: // miopen_batch_norm_backward
        implementation_597();
        break;
      case 598: // miopen_convolution
        implementation_598();
        break;
      case 599: // miopen_convolution_transpose
        implementation_599();
        break;
      case 600: // miopen_depthwise_convolution
        implementation_600();
        break;
      case 601: // miopen_convolution_relu
        implementation_601();
        break;
      case 602: // miopen_rnn
        implementation_602();
        break;
      case 603: // mm
        implementation_603();
        break;
      case 604: // _int_mm
        implementation_604();
        break;
      case 605: // _convert_weight_to_int4pack
        implementation_605();
        break;
      case 606: // _weight_int4pack_mm
        implementation_606();
        break;
      case 607: // _weight_int8pack_mm
        implementation_607();
        break;
      case 608: // _sparse_mm
        implementation_608();
        break;
      case 609: // _sparse_sparse_matmul
        implementation_609();
        break;
      case 610: // mode
        implementation_610();
        break;
      case 611: // mode
        implementation_611();
        break;
      case 612: // mode
        implementation_612();
        break;
      case 613: // mul
        implementation_613();
        break;
      case 614: // mul
        implementation_614();
        break;
      case 615: // multiply
        implementation_615();
        break;
      case 616: // multiply
        implementation_616();
        break;
      case 617: // mv
        implementation_617();
        break;
      case 618: // mvlgamma
        implementation_618();
        break;
      case 619: // narrow_copy
        implementation_619();
        break;
      case 620: // narrow
        implementation_620();
        break;
      case 621: // narrow
        implementation_621();
        break;
      case 622: // native_batch_norm
        implementation_622();
        break;
      case 623: // _native_batch_norm_legit
        implementation_623();
        break;
      case 624: // _native_batch_norm_legit_no_training
        implementation_624();
        break;
      case 625: // _native_batch_norm_legit
        implementation_625();
        break;
      case 626: // batch_norm_stats
        implementation_626();
        break;
      case 627: // batch_norm_elemt
        implementation_627();
        break;
      case 628: // batch_norm_gather_stats
        implementation_628();
        break;
      case 629: // batch_norm_gather_stats_with_counts
        implementation_629();
        break;
      case 630: // native_batch_norm_backward
        implementation_630();
        break;
      case 631: // batch_norm_backward_reduce
        implementation_631();
        break;
      case 632: // batch_norm_backward_elemt
        implementation_632();
        break;
      case 633: // batch_norm_update_stats
        implementation_633();
        break;
      case 634: // is_vulkan_available
        implementation_634();
        break;
      case 635: // _nnpack_available
        implementation_635();
        break;
      case 636: // _nnpack_spatial_convolution
        implementation_636();
        break;
      case 637: // _nnpack_spatial_convolution
        implementation_637();
        break;
      case 638: // pairwise_distance
        implementation_638();
        break;
      case 639: // pairwise_distance
        implementation_639();
        break;
      case 640: // pairwise_distance
        implementation_640();
        break;
      case 641: // pairwise_distance
        implementation_641();
        break;
      case 642: // cdist
        implementation_642();
        break;
      case 643: // cdist
        implementation_643();
        break;
      case 644: // _euclidean_dist
        implementation_644();
        break;
      case 645: // _cdist_backward
        implementation_645();
        break;
      case 646: // pdist
        implementation_646();
        break;
      case 647: // pdist
        implementation_647();
        break;
      case 648: // _pdist_forward
        implementation_648();
        break;
      case 649: // _pdist_forward
        implementation_649();
        break;
      case 650: // _pdist_backward
        implementation_650();
        break;
      case 651: // cosine_similarity
        implementation_651();
        break;
      case 652: // cosine_similarity
        implementation_652();
        break;
      case 653: // cosine_similarity
        implementation_653();
        break;
      case 654: // permute
        implementation_654();
        break;
      case 655: // movedim
        implementation_655();
        break;
      case 656: // moveaxis
        implementation_656();
        break;
      case 657: // numpy_T
        implementation_657();
        break;
      case 658: // matrix_H
        implementation_658();
        break;
      case 659: // mT
        implementation_659();
        break;
      case 660: // mH
        implementation_660();
        break;
      case 661: // adjoint
        implementation_661();
        break;
      case 662: // pixel_shuffle
        implementation_662();
        break;
      case 663: // pixel_unshuffle
        implementation_663();
        break;
      case 664: // channel_shuffle
        implementation_664();
        break;
      case 665: // native_channel_shuffle
        implementation_665();
        break;
      case 666: // is_pinned
        implementation_666();
        break;
      case 667: // pin_memory
        implementation_667();
        break;
      case 668: // _pin_memory
        implementation_668();
        break;
      case 669: // pinverse
        implementation_669();
        break;
      case 670: // pinverse
        implementation_670();
        break;
      case 671: // poisson_nll_loss
        implementation_671();
        break;
      case 672: // rad2deg
        implementation_672();
        break;
      case 673: // deg2rad
        implementation_673();
        break;
      case 674: // ravel
        implementation_674();
        break;
      case 675: // reciprocal
        implementation_675();
        break;
      case 676: // neg
        implementation_676();
        break;
      case 677: // negative
        implementation_677();
        break;
      case 678: // repeat
        implementation_678();
        break;
      case 679: // repeat_interleave
        implementation_679();
        break;
      case 680: // repeat_interleave
        implementation_680();
        break;
      case 681: // repeat_interleave
        implementation_681();
        break;
      case 682: // reshape
        implementation_682();
        break;
      case 683: // _reshape_copy
        implementation_683();
        break;
      case 684: // _reshape_alias
        implementation_684();
        break;
      case 685: // _mkldnn_reshape
        implementation_685();
        break;
      case 686: // reshape_as
        implementation_686();
        break;
      case 687: // round
        implementation_687();
        break;
      case 688: // round
        implementation_688();
        break;
      case 689: // rrelu
        implementation_689();
        break;
      case 690: // rrelu
        implementation_690();
        break;
      case 691: // rrelu
        implementation_691();
        break;
      case 692: // rrelu
        implementation_692();
        break;
      case 693: // relu
        implementation_693();
        break;
      case 694: // relu6
        implementation_694();
        break;
      case 695: // prelu
        implementation_695();
        break;
      case 696: // _prelu_kernel
        implementation_696();
        break;
      case 697: // _prelu_kernel_backward
        implementation_697();
        break;
      case 698: // gelu
        implementation_698();
        break;
      case 699: // gelu_backward
        implementation_699();
        break;
      case 700: // infinitely_differentiable_gelu_backward
        implementation_700();
        break;
      case 701: // hardshrink
        implementation_701();
        break;
      case 702: // hardshrink
        implementation_702();
        break;
      case 703: // hardshrink_backward
        implementation_703();
        break;
      case 704: // rsqrt
        implementation_704();
        break;
      case 705: // select
        implementation_705();
        break;
      case 706: // select_backward
        implementation_706();
        break;
      case 707: // _nested_select_backward
        implementation_707();
        break;
      case 708: // selu
        implementation_708();
        break;
      case 709: // celu
        implementation_709();
        break;
      case 710: // celu
        implementation_710();
        break;
      case 711: // silu
        implementation_711();
        break;
      case 712: // silu_backward
        implementation_712();
        break;
      case 713: // mish
        implementation_713();
        break;
      case 714: // mish_backward
        implementation_714();
        break;
      case 715: // sigmoid
        implementation_715();
        break;
      case 716: // logit
        implementation_716();
        break;
      case 717: // sin
        implementation_717();
        break;
      case 718: // sinc
        implementation_718();
        break;
      case 719: // sinh
        implementation_719();
        break;
      case 720: // detach
        implementation_720();
        break;
      case 721: // size
        implementation_721();
        break;
      case 722: // slice
        implementation_722();
        break;
      case 723: // slice
        implementation_723();
        break;
      case 724: // slice_backward
        implementation_724();
        break;
      case 725: // slice_inverse
        implementation_725();
        break;
      case 726: // slice_inverse
        implementation_726();
        break;
      case 727: // slice_scatter
        implementation_727();
        break;
      case 728: // slice_scatter
        implementation_728();
        break;
      case 729: // select_scatter
        implementation_729();
        break;
      case 730: // diagonal_scatter
        implementation_730();
        break;
      case 731: // diagonal_scatter
        implementation_731();
        break;
      case 732: // diagonal_scatter
        implementation_732();
        break;
      case 733: // diagonal_scatter
        implementation_733();
        break;
      case 734: // as_strided_scatter
        implementation_734();
        break;
      case 735: // smm
        implementation_735();
        break;
      case 736: // softmax
        implementation_736();
        break;
      case 737: // _softmax
        implementation_737();
        break;
      case 738: // unsafe_split
        implementation_738();
        break;
      case 739: // unsafe_split
        implementation_739();
        break;
      case 740: // split
        implementation_740();
        break;
      case 741: // split
        implementation_741();
        break;
      case 742: // unsafe_split_with_sizes
        implementation_742();
        break;
      case 743: // unsafe_split_with_sizes
        implementation_743();
        break;
      case 744: // split_with_sizes
        implementation_744();
        break;
      case 745: // split_with_sizes
        implementation_745();
        break;
      case 746: // hsplit
        implementation_746();
        break;
      case 747: // hsplit
        implementation_747();
        break;
      case 748: // vsplit
        implementation_748();
        break;
      case 749: // vsplit
        implementation_749();
        break;
      case 750: // dsplit
        implementation_750();
        break;
      case 751: // dsplit
        implementation_751();
        break;
      case 752: // squeeze
        implementation_752();
        break;
      case 753: // squeeze
        implementation_753();
        break;
      case 754: // sspaddmm
        implementation_754();
        break;
      case 755: // sspaddmm
        implementation_755();
        break;
      case 756: // sspaddmm
        implementation_756();
        break;
      case 757: // _chunk_cat
        implementation_757();
        break;
      case 758: // stack
        implementation_758();
        break;
      case 759: // stack
        implementation_759();
        break;
      case 760: // _stack
        implementation_760();
        break;
      case 761: // _stack
        implementation_761();
        break;
      case 762: // hstack
        implementation_762();
        break;
      case 763: // vstack
        implementation_763();
        break;
      case 764: // dstack
        implementation_764();
        break;
      case 765: // stft
        implementation_765();
        break;
      case 766: // istft
        implementation_766();
        break;
      case 767: // stride
        implementation_767();
        break;
      case 768: // sum
        implementation_768();
        break;
      case 769: // nansum
        implementation_769();
        break;
      case 770: // sum_to_size
        implementation_770();
        break;
      case 771: // sqrt
        implementation_771();
        break;
      case 772: // square
        implementation_772();
        break;
      case 773: // std
        implementation_773();
        break;
      case 774: // std
        implementation_774();
        break;
      case 775: // std_mean
        implementation_775();
        break;
      case 776: // std_mean
        implementation_776();
        break;
      case 777: // prod
        implementation_777();
        break;
      case 778: // prod
        implementation_778();
        break;
      case 779: // prod
        implementation_779();
        break;
      case 780: // t
        implementation_780();
        break;
      case 781: // tan
        implementation_781();
        break;
      case 782: // tanh
        implementation_782();
        break;
      case 783: // tensordot
        implementation_783();
        break;
      case 784: // threshold
        implementation_784();
        break;
      case 785: // threshold_backward
        implementation_785();
        break;
      case 786: // tile
        implementation_786();
        break;
      case 787: // transpose
        implementation_787();
        break;
      case 788: // _mkldnn_transpose
        implementation_788();
        break;
      case 789: // one_hot
        implementation_789();
        break;
      case 790: // one_hot
        implementation_790();
        break;
      case 791: // flip
        implementation_791();
        break;
      case 792: // fliplr
        implementation_792();
        break;
      case 793: // flipud
        implementation_793();
        break;
      case 794: // roll
        implementation_794();
        break;
      case 795: // roll
        implementation_795();
        break;
      case 796: // rot90
        implementation_796();
        break;
      case 797: // rot90
        implementation_797();
        break;
      case 798: // rot90
        implementation_798();
        break;
      case 799: // trapezoid
        implementation_799();
        break;
      case 800: // trapezoid
        implementation_800();
        break;
      case 801: // trapezoid
        implementation_801();
        break;
      case 802: // trapezoid
        implementation_802();
        break;
      case 803: // trapezoid
        implementation_803();
        break;
      case 804: // trapz
        implementation_804();
        break;
      case 805: // trapz
        implementation_805();
        break;
      case 806: // trapz
        implementation_806();
        break;
      case 807: // trapz
        implementation_807();
        break;
      case 808: // trapz
        implementation_808();
        break;
      case 809: // _transform_bias_rescale_qkv
        implementation_809();
        break;
      case 810: // _nested_tensor_from_mask
        implementation_810();
        break;
      case 811: // _nested_tensor_from_mask
        implementation_811();
        break;
      case 812: // _nested_tensor_from_mask_left_aligned
        implementation_812();
        break;
      case 813: // _nested_from_padded
        implementation_813();
        break;
      case 814: // _nested_from_padded
        implementation_814();
        break;
      case 815: // _nested_tensor_size
        implementation_815();
        break;
      case 816: // _nested_tensor_strides
        implementation_816();
        break;
      case 817: // _nested_tensor_storage_offsets
        implementation_817();
        break;
      case 818: // _nested_from_padded_and_nested_example
        implementation_818();
        break;
      case 819: // _nested_view_from_buffer
        implementation_819();
        break;
      case 820: // _nested_view_from_buffer_copy
        implementation_820();
        break;
      case 821: // _nested_view_from_jagged
        implementation_821();
        break;
      case 822: // _nested_view_from_jagged
        implementation_822();
        break;
      case 823: // _nested_view_from_jagged
        implementation_823();
        break;
      case 824: // _nested_view_from_jagged_copy
        implementation_824();
        break;
      case 825: // _nested_view_from_jagged_copy
        implementation_825();
        break;
      case 826: // _nested_view_from_jagged_copy
        implementation_826();
        break;
      case 827: // _nested_get_values
        implementation_827();
        break;
      case 828: // _nested_get_values_copy
        implementation_828();
        break;
      case 829: // _nested_get_offsets
        implementation_829();
        break;
      case 830: // _nested_get_lengths
        implementation_830();
        break;
      case 831: // _nested_get_ragged_idx
        implementation_831();
        break;
      case 832: // _nested_get_jagged_dummy
        implementation_832();
        break;
      case 833: // _trilinear
        implementation_833();
        break;
      case 834: // _trilinear
        implementation_834();
        break;
      case 835: // triplet_margin_loss
        implementation_835();
        break;
      case 836: // triplet_margin_loss
        implementation_836();
        break;
      case 837: // triplet_margin_loss
        implementation_837();
        break;
      case 838: // triplet_margin_loss
        implementation_838();
        break;
      case 839: // triplet_margin_loss
        implementation_839();
        break;
      case 840: // triplet_margin_loss
        implementation_840();
        break;
      case 841: // trunc
        implementation_841();
        break;
      case 842: // fix
        implementation_842();
        break;
      case 843: // type_as
        implementation_843();
        break;
      case 844: // _has_compatible_shallow_copy_type
        implementation_844();
        break;
      case 845: // _unique
        implementation_845();
        break;
      case 846: // _unique
        implementation_846();
        break;
      case 847: // _unique
        implementation_847();
        break;
      case 848: // unique_dim
        implementation_848();
        break;
      case 849: // unique_dim
        implementation_849();
        break;
      case 850: // unique_dim
        implementation_850();
        break;
      case 851: // unique_dim
        implementation_851();
        break;
      case 852: // unique_consecutive
        implementation_852();
        break;
      case 853: // unique_consecutive
        implementation_853();
        break;
      case 854: // unique_consecutive
        implementation_854();
        break;
      case 855: // unique_dim_consecutive
        implementation_855();
        break;
      case 856: // unique_dim_consecutive
        implementation_856();
        break;
      case 857: // unique_dim_consecutive
        implementation_857();
        break;
      case 858: // _unique2
        implementation_858();
        break;
      case 859: // _unique2
        implementation_859();
        break;
      case 860: // _unique2
        implementation_860();
        break;
      case 861: // _unique2
        implementation_861();
        break;
      case 862: // _unsafe_view
        implementation_862();
        break;
      case 863: // unsqueeze
        implementation_863();
        break;
      case 864: // vander
        implementation_864();
        break;
      case 865: // var
        implementation_865();
        break;
      case 866: // var
        implementation_866();
        break;
      case 867: // var_mean
        implementation_867();
        break;
      case 868: // var_mean
        implementation_868();
        break;
      case 869: // view_as
        implementation_869();
        break;
      case 870: // where
        implementation_870();
        break;
      case 871: // where
        implementation_871();
        break;
      case 872: // where
        implementation_872();
        break;
      case 873: // where
        implementation_873();
        break;
      case 874: // where
        implementation_874();
        break;
      case 875: // norm_except_dim
        implementation_875();
        break;
      case 876: // norm_except_dim
        implementation_876();
        break;
      case 877: // norm_except_dim
        implementation_877();
        break;
      case 878: // _weight_norm
        implementation_878();
        break;
      case 879: // _weight_norm
        implementation_879();
        break;
      case 880: // _weight_norm_interface
        implementation_880();
        break;
      case 881: // _weight_norm_interface
        implementation_881();
        break;
      case 882: // _weight_norm_interface_backward
        implementation_882();
        break;
      case 883: // _weight_norm_differentiable_backward
        implementation_883();
        break;
      case 884: // _standard_gamma_grad
        implementation_884();
        break;
      case 885: // _standard_gamma
        implementation_885();
        break;
      case 886: // _dirichlet_grad
        implementation_886();
        break;
      case 887: // _sample_dirichlet
        implementation_887();
        break;
      case 888: // poisson
        implementation_888();
        break;
      case 889: // binomial
        implementation_889();
        break;
      case 890: // native_norm
        implementation_890();
        break;
      case 891: // native_norm
        implementation_891();
        break;
      case 892: // _sparse_sum
        implementation_892();
        break;
      case 893: // _sparse_sum
        implementation_893();
        break;
      case 894: // _sparse_sum_backward
        implementation_894();
        break;
      case 895: // _sparse_csr_sum
        implementation_895();
        break;
      case 896: // _sparse_csr_sum
        implementation_896();
        break;
      case 897: // _sparse_csr_prod
        implementation_897();
        break;
      case 898: // _sparse_csr_prod
        implementation_898();
        break;
      case 899: // _sparse_softmax
        implementation_899();
        break;
      case 900: // _sparse_softmax
        implementation_900();
        break;
      case 901: // _sparse_softmax_backward_data
        implementation_901();
        break;
      case 902: // _sparse_log_softmax
        implementation_902();
        break;
      case 903: // _sparse_log_softmax
        implementation_903();
        break;
      case 904: // _sparse_log_softmax_backward_data
        implementation_904();
        break;
      case 905: // _spdiags
        implementation_905();
        break;
      case 906: // norm
        implementation_906();
        break;
      case 907: // norm
        implementation_907();
        break;
      case 908: // frexp
        implementation_908();
        break;
      case 909: // frobenius_norm
        implementation_909();
        break;
      case 910: // frobenius_norm
        implementation_910();
        break;
      case 911: // nuclear_norm
        implementation_911();
        break;
      case 912: // nuclear_norm
        implementation_912();
        break;
      case 913: // nuclear_norm
        implementation_913();
        break;
      case 914: // nuclear_norm
        implementation_914();
        break;
      case 915: // clone
        implementation_915();
        break;
      case 916: // positive
        implementation_916();
        break;
      case 917: // sub
        implementation_917();
        break;
      case 918: // sub
        implementation_918();
        break;
      case 919: // sub
        implementation_919();
        break;
      case 920: // sub
        implementation_920();
        break;
      case 921: // subtract
        implementation_921();
        break;
      case 922: // subtract
        implementation_922();
        break;
      case 923: // subtract
        implementation_923();
        break;
      case 924: // subtract
        implementation_924();
        break;
      case 925: // rsub
        implementation_925();
        break;
      case 926: // rsub
        implementation_926();
        break;
      case 927: // heaviside
        implementation_927();
        break;
      case 928: // rsub
        implementation_928();
        break;
      case 929: // rsub
        implementation_929();
        break;
      case 930: // _sparse_addmm
        implementation_930();
        break;
      case 931: // _sparse_addmm
        implementation_931();
        break;
      case 932: // _sparse_addmm
        implementation_932();
        break;
      case 933: // sparse_sampled_addmm
        implementation_933();
        break;
      case 934: // sparse_sampled_addmm
        implementation_934();
        break;
      case 935: // sparse_sampled_addmm
        implementation_935();
        break;
      case 936: // addmm
        implementation_936();
        break;
      case 937: // addmm
        implementation_937();
        break;
      case 938: // addmm
        implementation_938();
        break;
      case 939: // _addmm_activation
        implementation_939();
        break;
      case 940: // _addmm_activation
        implementation_940();
        break;
      case 941: // _addmm_activation
        implementation_941();
        break;
      case 942: // _addmm_activation
        implementation_942();
        break;
      case 943: // _scaled_mm
        implementation_943();
        break;
      case 944: // _scaled_mm
        implementation_944();
        break;
      case 945: // sparse_mask
        implementation_945();
        break;
      case 946: // _sparse_mask_projection
        implementation_946();
        break;
      case 947: // _sparse_mask_projection
        implementation_947();
        break;
      case 948: // _to_cpu
        implementation_948();
        break;
      case 949: // to_dense
        implementation_949();
        break;
      case 950: // _to_dense
        implementation_950();
        break;
      case 951: // to_dense_backward
        implementation_951();
        break;
      case 952: // sparse_dim
        implementation_952();
        break;
      case 953: // _dimI
        implementation_953();
        break;
      case 954: // dense_dim
        implementation_954();
        break;
      case 955: // _dimV
        implementation_955();
        break;
      case 956: // _nnz
        implementation_956();
        break;
      case 957: // coalesce
        implementation_957();
        break;
      case 958: // _coalesce
        implementation_958();
        break;
      case 959: // is_coalesced
        implementation_959();
        break;
      case 960: // _indices
        implementation_960();
        break;
      case 961: // _values
        implementation_961();
        break;
      case 962: // indices
        implementation_962();
        break;
      case 963: // values
        implementation_963();
        break;
      case 964: // crow_indices
        implementation_964();
        break;
      case 965: // col_indices
        implementation_965();
        break;
      case 966: // ccol_indices
        implementation_966();
        break;
      case 967: // row_indices
        implementation_967();
        break;
      case 968: // hspmm
        implementation_968();
        break;
      case 969: // unbind
        implementation_969();
        break;
      case 970: // unbind
        implementation_970();
        break;
      case 971: // to_sparse
        implementation_971();
        break;
      case 972: // _to_sparse
        implementation_972();
        break;
      case 973: // to_sparse
        implementation_973();
        break;
      case 974: // _to_sparse
        implementation_974();
        break;
      case 975: // to_sparse_csr
        implementation_975();
        break;
      case 976: // _to_sparse_csr
        implementation_976();
        break;
      case 977: // to_sparse_csc
        implementation_977();
        break;
      case 978: // _to_sparse_csc
        implementation_978();
        break;
      case 979: // to_sparse_bsr
        implementation_979();
        break;
      case 980: // _to_sparse_bsr
        implementation_980();
        break;
      case 981: // to_sparse_bsc
        implementation_981();
        break;
      case 982: // _to_sparse_bsc
        implementation_982();
        break;
      case 983: // _to_sparse_semi_structured
        implementation_983();
        break;
      case 984: // to_mkldnn
        implementation_984();
        break;
      case 985: // mkldnn_reorder_conv2d_weight
        implementation_985();
        break;
      case 986: // mkldnn_reorder_conv2d_weight
        implementation_986();
        break;
      case 987: // mkldnn_reorder_conv2d_weight
        implementation_987();
        break;
      case 988: // mkldnn_reorder_conv2d_weight
        implementation_988();
        break;
      case 989: // mkldnn_reorder_conv2d_weight
        implementation_989();
        break;
      case 990: // mkldnn_reorder_conv3d_weight
        implementation_990();
        break;
      case 991: // mkldnn_reorder_conv3d_weight
        implementation_991();
        break;
      case 992: // mkldnn_reorder_conv3d_weight
        implementation_992();
        break;
      case 993: // mkldnn_reorder_conv3d_weight
        implementation_993();
        break;
      case 994: // mkldnn_reorder_conv3d_weight
        implementation_994();
        break;
      case 995: // to_mkldnn_backward
        implementation_995();
        break;
      case 996: // dequantize
        implementation_996();
        break;
      case 997: // dequantize
        implementation_997();
        break;
      case 998: // q_zero_point
        implementation_998();
        break;
      case 999: // q_per_channel_scales
        implementation_999();
        break;
      case 1000: // q_per_channel_zero_points
        implementation_1000();
        break;
      case 1001: // q_per_channel_axis
        implementation_1001();
        break;
      case 1002: // int_repr
        implementation_1002();
        break;
      case 1003: // _make_per_tensor_quantized_tensor
        implementation_1003();
        break;
      case 1004: // _make_per_channel_quantized_tensor
        implementation_1004();
        break;
      case 1005: // fake_quantize_per_tensor_affine
        implementation_1005();
        break;
      case 1006: // fake_quantize_per_tensor_affine
        implementation_1006();
        break;
      case 1007: // fake_quantize_per_tensor_affine_cachemask
        implementation_1007();
        break;
      case 1008: // _fake_quantize_per_tensor_affine_cachemask_tensor_qparams
        implementation_1008();
        break;
      case 1009: // fake_quantize_per_tensor_affine_cachemask_backward
        implementation_1009();
        break;
      case 1010: // _fake_quantize_learnable_per_tensor_affine
        implementation_1010();
        break;
      case 1011: // _fake_quantize_learnable_per_tensor_affine
        implementation_1011();
        break;
      case 1012: // _fake_quantize_learnable_per_tensor_affine_backward
        implementation_1012();
        break;
      case 1013: // _fake_quantize_learnable_per_tensor_affine_backward
        implementation_1013();
        break;
      case 1014: // fake_quantize_per_channel_affine
        implementation_1014();
        break;
      case 1015: // fake_quantize_per_channel_affine_cachemask
        implementation_1015();
        break;
      case 1016: // fake_quantize_per_channel_affine_cachemask_backward
        implementation_1016();
        break;
      case 1017: // _fake_quantize_learnable_per_channel_affine
        implementation_1017();
        break;
      case 1018: // _fake_quantize_learnable_per_channel_affine
        implementation_1018();
        break;
      case 1019: // _fake_quantize_learnable_per_channel_affine_backward
        implementation_1019();
        break;
      case 1020: // _fake_quantize_learnable_per_channel_affine_backward
        implementation_1020();
        break;
      case 1021: // fused_moving_avg_obs_fake_quant
        implementation_1021();
        break;
      case 1022: // fused_moving_avg_obs_fake_quant
        implementation_1022();
        break;
      case 1023: // fused_moving_avg_obs_fake_quant
        implementation_1023();
        break;
      case 1024: // _fused_moving_avg_obs_fq_helper
        implementation_1024();
        break;
      case 1025: // _fused_moving_avg_obs_fq_helper
        implementation_1025();
        break;
      case 1026: // _fused_moving_avg_obs_fq_helper
        implementation_1026();
        break;
      case 1027: // _saturate_weight_to_fp16
        implementation_1027();
        break;
      case 1028: // choose_qparams_optimized
        implementation_1028();
        break;
      case 1029: // _autocast_to_full_precision
        implementation_1029();
        break;
      case 1030: // meshgrid
        implementation_1030();
        break;
      case 1031: // cartesian_prod
        implementation_1031();
        break;
      case 1032: // combinations
        implementation_1032();
        break;
      case 1033: // combinations
        implementation_1033();
        break;
      case 1034: // combinations
        implementation_1034();
        break;
      case 1035: // item
        implementation_1035();
        break;
      case 1036: // _local_scalar_dense
        implementation_1036();
        break;
      case 1037: // _lstm_mps
        implementation_1037();
        break;
      case 1038: // lstm_mps_backward
        implementation_1038();
        break;
      case 1039: // _thnn_fused_lstm_cell
        implementation_1039();
        break;
      case 1040: // _thnn_fused_lstm_cell
        implementation_1040();
        break;
      case 1041: // _thnn_fused_lstm_cell
        implementation_1041();
        break;
      case 1042: // _thnn_fused_lstm_cell_backward_impl
        implementation_1042();
        break;
      case 1043: // _thnn_fused_lstm_cell_backward
        implementation_1043();
        break;
      case 1044: // _thnn_differentiable_lstm_cell_backward
        implementation_1044();
        break;
      case 1045: // _thnn_fused_gru_cell
        implementation_1045();
        break;
      case 1046: // _thnn_fused_gru_cell
        implementation_1046();
        break;
      case 1047: // _thnn_fused_gru_cell
        implementation_1047();
        break;
      case 1048: // _thnn_fused_gru_cell_backward
        implementation_1048();
        break;
      case 1049: // _thnn_differentiable_gru_cell_backward
        implementation_1049();
        break;
      case 1050: // lstm
        implementation_1050();
        break;
      case 1051: // lstm
        implementation_1051();
        break;
      case 1052: // gru
        implementation_1052();
        break;
      case 1053: // gru
        implementation_1053();
        break;
      case 1054: // rnn_tanh
        implementation_1054();
        break;
      case 1055: // rnn_tanh
        implementation_1055();
        break;
      case 1056: // rnn_relu
        implementation_1056();
        break;
      case 1057: // rnn_relu
        implementation_1057();
        break;
      case 1058: // lstm_cell
        implementation_1058();
        break;
      case 1059: // gru_cell
        implementation_1059();
        break;
      case 1060: // gru_cell
        implementation_1060();
        break;
      case 1061: // gru_cell
        implementation_1061();
        break;
      case 1062: // rnn_tanh_cell
        implementation_1062();
        break;
      case 1063: // rnn_tanh_cell
        implementation_1063();
        break;
      case 1064: // rnn_tanh_cell
        implementation_1064();
        break;
      case 1065: // rnn_relu_cell
        implementation_1065();
        break;
      case 1066: // rnn_relu_cell
        implementation_1066();
        break;
      case 1067: // rnn_relu_cell
        implementation_1067();
        break;
      case 1068: // quantized_lstm_cell
        implementation_1068();
        break;
      case 1069: // quantized_gru_cell
        implementation_1069();
        break;
      case 1070: // quantized_rnn_relu_cell
        implementation_1070();
        break;
      case 1071: // quantized_rnn_tanh_cell
        implementation_1071();
        break;
      case 1072: // _pack_padded_sequence
        implementation_1072();
        break;
      case 1073: // _pack_padded_sequence_backward
        implementation_1073();
        break;
      case 1074: // _pad_packed_sequence
        implementation_1074();
        break;
      case 1075: // lift
        implementation_1075();
        break;
      case 1076: // lift_fresh
        implementation_1076();
        break;
      case 1077: // lift_fresh_copy
        implementation_1077();
        break;
      case 1078: // is_set_to
        implementation_1078();
        break;
      case 1079: // masked_fill
        implementation_1079();
        break;
      case 1080: // masked_fill
        implementation_1080();
        break;
      case 1081: // masked_scatter
        implementation_1081();
        break;
      case 1082: // masked_scatter_backward
        implementation_1082();
        break;
      case 1083: // _masked_softmax
        implementation_1083();
        break;
      case 1084: // _masked_softmax_backward
        implementation_1084();
        break;
      case 1085: // view
        implementation_1085();
        break;
      case 1086: // put
        implementation_1086();
        break;
      case 1087: // put
        implementation_1087();
        break;
      case 1088: // index_add
        implementation_1088();
        break;
      case 1089: // index_add
        implementation_1089();
        break;
      case 1090: // index_fill
        implementation_1090();
        break;
      case 1091: // index_fill
        implementation_1091();
        break;
      case 1092: // scatter
        implementation_1092();
        break;
      case 1093: // scatter
        implementation_1093();
        break;
      case 1094: // scatter_add
        implementation_1094();
        break;
      case 1095: // bitwise_and
        implementation_1095();
        break;
      case 1096: // bitwise_and
        implementation_1096();
        break;
      case 1097: // bitwise_and
        implementation_1097();
        break;
      case 1098: // __and__
        implementation_1098();
        break;
      case 1099: // __and__
        implementation_1099();
        break;
      case 1100: // bitwise_or
        implementation_1100();
        break;
      case 1101: // bitwise_or
        implementation_1101();
        break;
      case 1102: // bitwise_or
        implementation_1102();
        break;
      case 1103: // __or__
        implementation_1103();
        break;
      case 1104: // __or__
        implementation_1104();
        break;
      case 1105: // bitwise_xor
        implementation_1105();
        break;
      case 1106: // bitwise_xor
        implementation_1106();
        break;
      case 1107: // bitwise_xor
        implementation_1107();
        break;
      case 1108: // __xor__
        implementation_1108();
        break;
      case 1109: // __xor__
        implementation_1109();
        break;
      case 1110: // __lshift__
        implementation_1110();
        break;
      case 1111: // __lshift__
        implementation_1111();
        break;
      case 1112: // bitwise_left_shift
        implementation_1112();
        break;
      case 1113: // bitwise_left_shift
        implementation_1113();
        break;
      case 1114: // bitwise_left_shift
        implementation_1114();
        break;
      case 1115: // __rshift__
        implementation_1115();
        break;
      case 1116: // __rshift__
        implementation_1116();
        break;
      case 1117: // bitwise_right_shift
        implementation_1117();
        break;
      case 1118: // bitwise_right_shift
        implementation_1118();
        break;
      case 1119: // bitwise_right_shift
        implementation_1119();
        break;
      case 1120: // addbmm
        implementation_1120();
        break;
      case 1121: // addbmm
        implementation_1121();
        break;
      case 1122: // addbmm
        implementation_1122();
        break;
      case 1123: // diag
        implementation_1123();
        break;
      case 1124: // diag
        implementation_1124();
        break;
      case 1125: // cross
        implementation_1125();
        break;
      case 1126: // triu
        implementation_1126();
        break;
      case 1127: // triu
        implementation_1127();
        break;
      case 1128: // tril
        implementation_1128();
        break;
      case 1129: // tril
        implementation_1129();
        break;
      case 1130: // trace
        implementation_1130();
        break;
      case 1131: // trace_backward
        implementation_1131();
        break;
      case 1132: // ne
        implementation_1132();
        break;
      case 1133: // ne
        implementation_1133();
        break;
      case 1134: // not_equal
        implementation_1134();
        break;
      case 1135: // not_equal
        implementation_1135();
        break;
      case 1136: // eq
        implementation_1136();
        break;
      case 1137: // eq
        implementation_1137();
        break;
      case 1138: // ge
        implementation_1138();
        break;
      case 1139: // ge
        implementation_1139();
        break;
      case 1140: // greater_equal
        implementation_1140();
        break;
      case 1141: // greater_equal
        implementation_1141();
        break;
      case 1142: // le
        implementation_1142();
        break;
      case 1143: // le
        implementation_1143();
        break;
      case 1144: // less_equal
        implementation_1144();
        break;
      case 1145: // less_equal
        implementation_1145();
        break;
      case 1146: // gt
        implementation_1146();
        break;
      case 1147: // gt
        implementation_1147();
        break;
      case 1148: // greater
        implementation_1148();
        break;
      case 1149: // greater
        implementation_1149();
        break;
      case 1150: // lt
        implementation_1150();
        break;
      case 1151: // lt
        implementation_1151();
        break;
      case 1152: // less
        implementation_1152();
        break;
      case 1153: // less
        implementation_1153();
        break;
      case 1154: // take
        implementation_1154();
        break;
      case 1155: // take_along_dim
        implementation_1155();
        break;
      case 1156: // index_select
        implementation_1156();
        break;
      case 1157: // index_select_backward
        implementation_1157();
        break;
      case 1158: // masked_select
        implementation_1158();
        break;
      case 1159: // masked_select_backward
        implementation_1159();
        break;
      case 1160: // nonzero
        implementation_1160();
        break;
      case 1161: // nonzero_static
        implementation_1161();
        break;
      case 1162: // nonzero_static
        implementation_1162();
        break;
      case 1163: // nonzero_numpy
        implementation_1163();
        break;
      case 1164: // argwhere
        implementation_1164();
        break;
      case 1165: // gather
        implementation_1165();
        break;
      case 1166: // gather
        implementation_1166();
        break;
      case 1167: // gather_backward
        implementation_1167();
        break;
      case 1168: // _gather_sparse_backward
        implementation_1168();
        break;
      case 1169: // addcmul
        implementation_1169();
        break;
      case 1170: // addcmul
        implementation_1170();
        break;
      case 1171: // addcdiv
        implementation_1171();
        break;
      case 1172: // addcdiv
        implementation_1172();
        break;
      case 1173: // cross_entropy_loss
        implementation_1173();
        break;
      case 1174: // cross_entropy_loss
        implementation_1174();
        break;
      case 1175: // cross_entropy_loss
        implementation_1175();
        break;
      case 1176: // cross_entropy_loss
        implementation_1176();
        break;
      case 1177: // cross_entropy_loss
        implementation_1177();
        break;
      case 1178: // triangular_solve
        implementation_1178();
        break;
      case 1179: // triangular_solve
        implementation_1179();
        break;
      case 1180: // triangular_solve
        implementation_1180();
        break;
      case 1181: // triangular_solve
        implementation_1181();
        break;
      case 1182: // linalg_solve_triangular
        implementation_1182();
        break;
      case 1183: // linalg_solve_triangular
        implementation_1183();
        break;
      case 1184: // linalg_solve_triangular
        implementation_1184();
        break;
      case 1185: // linalg_vander
        implementation_1185();
        break;
      case 1186: // svd
        implementation_1186();
        break;
      case 1187: // svd
        implementation_1187();
        break;
      case 1188: // svd
        implementation_1188();
        break;
      case 1189: // swapaxes
        implementation_1189();
        break;
      case 1190: // swapdims
        implementation_1190();
        break;
      case 1191: // cholesky
        implementation_1191();
        break;
      case 1192: // cholesky
        implementation_1192();
        break;
      case 1193: // cholesky_solve
        implementation_1193();
        break;
      case 1194: // cholesky_solve
        implementation_1194();
        break;
      case 1195: // _cholesky_solve_helper
        implementation_1195();
        break;
      case 1196: // cholesky_inverse
        implementation_1196();
        break;
      case 1197: // cholesky_inverse
        implementation_1197();
        break;
      case 1198: // qr
        implementation_1198();
        break;
      case 1199: // qr
        implementation_1199();
        break;
      case 1200: // geqrf
        implementation_1200();
        break;
      case 1201: // orgqr
        implementation_1201();
        break;
      case 1202: // ormqr
        implementation_1202();
        break;
      case 1203: // ormqr
        implementation_1203();
        break;
      case 1204: // ormqr
        implementation_1204();
        break;
      case 1205: // _lu_with_info
        implementation_1205();
        break;
      case 1206: // _lu_with_info
        implementation_1206();
        break;
      case 1207: // _lu_with_info
        implementation_1207();
        break;
      case 1208: // lu_solve
        implementation_1208();
        break;
      case 1209: // lu_unpack
        implementation_1209();
        break;
      case 1210: // lu_unpack
        implementation_1210();
        break;
      case 1211: // lu_unpack
        implementation_1211();
        break;
      case 1212: // multinomial
        implementation_1212();
        break;
      case 1213: // multinomial
        implementation_1213();
        break;
      case 1214: // lgamma
        implementation_1214();
        break;
      case 1215: // digamma
        implementation_1215();
        break;
      case 1216: // polygamma
        implementation_1216();
        break;
      case 1217: // erfinv
        implementation_1217();
        break;
      case 1218: // i0
        implementation_1218();
        break;
      case 1219: // sign
        implementation_1219();
        break;
      case 1220: // signbit
        implementation_1220();
        break;
      case 1221: // dist
        implementation_1221();
        break;
      case 1222: // dist
        implementation_1222();
        break;
      case 1223: // atan2
        implementation_1223();
        break;
      case 1224: // arctan2
        implementation_1224();
        break;
      case 1225: // lerp
        implementation_1225();
        break;
      case 1226: // lerp
        implementation_1226();
        break;
      case 1227: // histc
        implementation_1227();
        break;
      case 1228: // histc
        implementation_1228();
        break;
      case 1229: // histc
        implementation_1229();
        break;
      case 1230: // histc
        implementation_1230();
        break;
      case 1231: // histogram
        implementation_1231();
        break;
      case 1232: // histogram
        implementation_1232();
        break;
      case 1233: // histogram
        implementation_1233();
        break;
      case 1234: // histogram
        implementation_1234();
        break;
      case 1235: // histogram
        implementation_1235();
        break;
      case 1236: // _histogramdd_bin_edges
        implementation_1236();
        break;
      case 1237: // _histogramdd_from_bin_cts
        implementation_1237();
        break;
      case 1238: // _histogramdd_from_bin_tensors
        implementation_1238();
        break;
      case 1239: // _histogramdd_from_bin_tensors
        implementation_1239();
        break;
      case 1240: // histogramdd
        implementation_1240();
        break;
      case 1241: // histogramdd
        implementation_1241();
        break;
      case 1242: // fmod
        implementation_1242();
        break;
      case 1243: // fmod
        implementation_1243();
        break;
      case 1244: // hypot
        implementation_1244();
        break;
      case 1245: // igamma
        implementation_1245();
        break;
      case 1246: // igammac
        implementation_1246();
        break;
      case 1247: // nextafter
        implementation_1247();
        break;
      case 1248: // remainder
        implementation_1248();
        break;
      case 1249: // remainder
        implementation_1249();
        break;
      case 1250: // remainder
        implementation_1250();
        break;
      case 1251: // min
        implementation_1251();
        break;
      case 1252: // fmin
        implementation_1252();
        break;
      case 1253: // max
        implementation_1253();
        break;
      case 1254: // fmax
        implementation_1254();
        break;
      case 1255: // maximum
        implementation_1255();
        break;
      case 1256: // max
        implementation_1256();
        break;
      case 1257: // minimum
        implementation_1257();
        break;
      case 1258: // min
        implementation_1258();
        break;
      case 1259: // quantile
        implementation_1259();
        break;
      case 1260: // quantile
        implementation_1260();
        break;
      case 1261: // nanquantile
        implementation_1261();
        break;
      case 1262: // nanquantile
        implementation_1262();
        break;
      case 1263: // sort
        implementation_1263();
        break;
      case 1264: // sort
        implementation_1264();
        break;
      case 1265: // sort
        implementation_1265();
        break;
      case 1266: // msort
        implementation_1266();
        break;
      case 1267: // argsort
        implementation_1267();
        break;
      case 1268: // argsort
        implementation_1268();
        break;
      case 1269: // argsort
        implementation_1269();
        break;
      case 1270: // argsort
        implementation_1270();
        break;
      case 1271: // argsort
        implementation_1271();
        break;
      case 1272: // argsort
        implementation_1272();
        break;
      case 1273: // topk
        implementation_1273();
        break;
      case 1274: // topk
        implementation_1274();
        break;
      case 1275: // topk
        implementation_1275();
        break;
      case 1276: // topk
        implementation_1276();
        break;
      case 1277: // renorm
        implementation_1277();
        break;
      case 1278: // unfold
        implementation_1278();
        break;
      case 1279: // unfold_backward
        implementation_1279();
        break;
      case 1280: // equal
        implementation_1280();
        break;
      case 1281: // pow
        implementation_1281();
        break;
      case 1282: // pow
        implementation_1282();
        break;
      case 1283: // pow
        implementation_1283();
        break;
      case 1284: // float_power
        implementation_1284();
        break;
      case 1285: // float_power
        implementation_1285();
        break;
      case 1286: // float_power
        implementation_1286();
        break;
      case 1287: // normal_functional
        implementation_1287();
        break;
      case 1288: // normal_functional
        implementation_1288();
        break;
      case 1289: // normal_functional
        implementation_1289();
        break;
      case 1290: // alias
        implementation_1290();
        break;
      case 1291: // _foreach_add
        implementation_1291();
        break;
      case 1292: // _foreach_add
        implementation_1292();
        break;
      case 1293: // _foreach_add
        implementation_1293();
        break;
      case 1294: // _foreach_sub
        implementation_1294();
        break;
      case 1295: // _foreach_sub
        implementation_1295();
        break;
      case 1296: // _foreach_sub
        implementation_1296();
        break;
      case 1297: // _foreach_mul
        implementation_1297();
        break;
      case 1298: // _foreach_mul
        implementation_1298();
        break;
      case 1299: // _foreach_div
        implementation_1299();
        break;
      case 1300: // _foreach_div
        implementation_1300();
        break;
      case 1301: // _foreach_clamp_max
        implementation_1301();
        break;
      case 1302: // _foreach_clamp_max
        implementation_1302();
        break;
      case 1303: // _foreach_clamp_min
        implementation_1303();
        break;
      case 1304: // _foreach_clamp_min
        implementation_1304();
        break;
      case 1305: // _foreach_maximum
        implementation_1305();
        break;
      case 1306: // _foreach_maximum
        implementation_1306();
        break;
      case 1307: // _foreach_minimum
        implementation_1307();
        break;
      case 1308: // _foreach_minimum
        implementation_1308();
        break;
      case 1309: // _foreach_addcdiv
        implementation_1309();
        break;
      case 1310: // _foreach_addcdiv
        implementation_1310();
        break;
      case 1311: // _foreach_addcmul
        implementation_1311();
        break;
      case 1312: // _foreach_addcmul
        implementation_1312();
        break;
      case 1313: // _foreach_abs
        implementation_1313();
        break;
      case 1314: // _foreach_acos
        implementation_1314();
        break;
      case 1315: // _foreach_asin
        implementation_1315();
        break;
      case 1316: // _foreach_atan
        implementation_1316();
        break;
      case 1317: // _foreach_ceil
        implementation_1317();
        break;
      case 1318: // _foreach_cos
        implementation_1318();
        break;
      case 1319: // _foreach_cosh
        implementation_1319();
        break;
      case 1320: // _foreach_erf
        implementation_1320();
        break;
      case 1321: // _foreach_erfc
        implementation_1321();
        break;
      case 1322: // _foreach_exp
        implementation_1322();
        break;
      case 1323: // _foreach_expm1
        implementation_1323();
        break;
      case 1324: // _foreach_floor
        implementation_1324();
        break;
      case 1325: // _foreach_frac
        implementation_1325();
        break;
      case 1326: // _foreach_lerp
        implementation_1326();
        break;
      case 1327: // _foreach_lerp
        implementation_1327();
        break;
      case 1328: // _foreach_lgamma
        implementation_1328();
        break;
      case 1329: // _foreach_log
        implementation_1329();
        break;
      case 1330: // _foreach_log10
        implementation_1330();
        break;
      case 1331: // _foreach_log1p
        implementation_1331();
        break;
      case 1332: // _foreach_log2
        implementation_1332();
        break;
      case 1333: // _foreach_neg
        implementation_1333();
        break;
      case 1334: // _foreach_norm
        implementation_1334();
        break;
      case 1335: // _foreach_norm
        implementation_1335();
        break;
      case 1336: // _foreach_pow
        implementation_1336();
        break;
      case 1337: // _foreach_pow
        implementation_1337();
        break;
      case 1338: // _foreach_pow
        implementation_1338();
        break;
      case 1339: // _foreach_reciprocal
        implementation_1339();
        break;
      case 1340: // _foreach_round
        implementation_1340();
        break;
      case 1341: // _foreach_sigmoid
        implementation_1341();
        break;
      case 1342: // _foreach_sign
        implementation_1342();
        break;
      case 1343: // _foreach_sin
        implementation_1343();
        break;
      case 1344: // _foreach_sinh
        implementation_1344();
        break;
      case 1345: // _foreach_sqrt
        implementation_1345();
        break;
      case 1346: // _foreach_tan
        implementation_1346();
        break;
      case 1347: // _foreach_tanh
        implementation_1347();
        break;
      case 1348: // _foreach_trunc
        implementation_1348();
        break;
      case 1349: // bucketize
        implementation_1349();
        break;
      case 1350: // bucketize
        implementation_1350();
        break;
      case 1351: // bucketize
        implementation_1351();
        break;
      case 1352: // bucketize
        implementation_1352();
        break;
      case 1353: // bucketize
        implementation_1353();
        break;
      case 1354: // bucketize
        implementation_1354();
        break;
      case 1355: // searchsorted
        implementation_1355();
        break;
      case 1356: // searchsorted
        implementation_1356();
        break;
      case 1357: // searchsorted
        implementation_1357();
        break;
      case 1358: // searchsorted
        implementation_1358();
        break;
      case 1359: // searchsorted
        implementation_1359();
        break;
      case 1360: // searchsorted
        implementation_1360();
        break;
      case 1361: // _convert_indices_from_coo_to_csr
        implementation_1361();
        break;
      case 1362: // _convert_indices_from_coo_to_csr
        implementation_1362();
        break;
      case 1363: // _convert_indices_from_csr_to_coo
        implementation_1363();
        break;
      case 1364: // _convert_indices_from_csr_to_coo
        implementation_1364();
        break;
      case 1365: // _convert_indices_from_csr_to_coo
        implementation_1365();
        break;
      case 1366: // mse_loss
        implementation_1366();
        break;
      case 1367: // mse_loss
        implementation_1367();
        break;
      case 1368: // mse_loss_backward
        implementation_1368();
        break;
      case 1369: // l1_loss
        implementation_1369();
        break;
      case 1370: // l1_loss
        implementation_1370();
        break;
      case 1371: // multi_margin_loss
        implementation_1371();
        break;
      case 1372: // multi_margin_loss
        implementation_1372();
        break;
      case 1373: // multi_margin_loss
        implementation_1373();
        break;
      case 1374: // multi_margin_loss
        implementation_1374();
        break;
      case 1375: // multi_margin_loss
        implementation_1375();
        break;
      case 1376: // multi_margin_loss_backward
        implementation_1376();
        break;
      case 1377: // multi_margin_loss_backward
        implementation_1377();
        break;
      case 1378: // multi_margin_loss_backward
        implementation_1378();
        break;
      case 1379: // multilabel_margin_loss
        implementation_1379();
        break;
      case 1380: // multilabel_margin_loss
        implementation_1380();
        break;
      case 1381: // multilabel_margin_loss_forward
        implementation_1381();
        break;
      case 1382: // multilabel_margin_loss_backward
        implementation_1382();
        break;
      case 1383: // nll_loss_nd
        implementation_1383();
        break;
      case 1384: // nll_loss_nd
        implementation_1384();
        break;
      case 1385: // nll_loss_nd
        implementation_1385();
        break;
      case 1386: // nll_loss_nd
        implementation_1386();
        break;
      case 1387: // nll_loss
        implementation_1387();
        break;
      case 1388: // nll_loss
        implementation_1388();
        break;
      case 1389: // nll_loss
        implementation_1389();
        break;
      case 1390: // nll_loss
        implementation_1390();
        break;
      case 1391: // nll_loss_forward
        implementation_1391();
        break;
      case 1392: // nll_loss_backward
        implementation_1392();
        break;
      case 1393: // nll_loss2d
        implementation_1393();
        break;
      case 1394: // nll_loss2d
        implementation_1394();
        break;
      case 1395: // nll_loss2d
        implementation_1395();
        break;
      case 1396: // nll_loss2d
        implementation_1396();
        break;
      case 1397: // nll_loss2d_forward
        implementation_1397();
        break;
      case 1398: // nll_loss2d_backward
        implementation_1398();
        break;
      case 1399: // smooth_l1_loss
        implementation_1399();
        break;
      case 1400: // smooth_l1_loss
        implementation_1400();
        break;
      case 1401: // smooth_l1_loss
        implementation_1401();
        break;
      case 1402: // smooth_l1_loss_backward
        implementation_1402();
        break;
      case 1403: // huber_loss
        implementation_1403();
        break;
      case 1404: // huber_loss
        implementation_1404();
        break;
      case 1405: // huber_loss
        implementation_1405();
        break;
      case 1406: // huber_loss_backward
        implementation_1406();
        break;
      case 1407: // soft_margin_loss
        implementation_1407();
        break;
      case 1408: // soft_margin_loss
        implementation_1408();
        break;
      case 1409: // soft_margin_loss_backward
        implementation_1409();
        break;
      case 1410: // elu
        implementation_1410();
        break;
      case 1411: // elu
        implementation_1411();
        break;
      case 1412: // elu
        implementation_1412();
        break;
      case 1413: // elu
        implementation_1413();
        break;
      case 1414: // elu_backward
        implementation_1414();
        break;
      case 1415: // glu
        implementation_1415();
        break;
      case 1416: // glu
        implementation_1416();
        break;
      case 1417: // glu_backward
        implementation_1417();
        break;
      case 1418: // glu_jvp
        implementation_1418();
        break;
      case 1419: // glu_backward_jvp
        implementation_1419();
        break;
      case 1420: // hardsigmoid
        implementation_1420();
        break;
      case 1421: // hardsigmoid_backward
        implementation_1421();
        break;
      case 1422: // hardtanh
        implementation_1422();
        break;
      case 1423: // hardtanh
        implementation_1423();
        break;
      case 1424: // hardtanh
        implementation_1424();
        break;
      case 1425: // hardtanh_backward
        implementation_1425();
        break;
      case 1426: // hardswish
        implementation_1426();
        break;
      case 1427: // hardswish_backward
        implementation_1427();
        break;
      case 1428: // leaky_relu
        implementation_1428();
        break;
      case 1429: // leaky_relu
        implementation_1429();
        break;
      case 1430: // leaky_relu_backward
        implementation_1430();
        break;
      case 1431: // log_sigmoid
        implementation_1431();
        break;
      case 1432: // log_sigmoid_forward
        implementation_1432();
        break;
      case 1433: // log_sigmoid_backward
        implementation_1433();
        break;
      case 1434: // rrelu_with_noise
        implementation_1434();
        break;
      case 1435: // rrelu_with_noise
        implementation_1435();
        break;
      case 1436: // rrelu_with_noise
        implementation_1436();
        break;
      case 1437: // rrelu_with_noise
        implementation_1437();
        break;
      case 1438: // rrelu_with_noise_backward
        implementation_1438();
        break;
      case 1439: // softplus
        implementation_1439();
        break;
      case 1440: // softplus
        implementation_1440();
        break;
      case 1441: // softplus
        implementation_1441();
        break;
      case 1442: // softplus_backward
        implementation_1442();
        break;
      case 1443: // softshrink
        implementation_1443();
        break;
      case 1444: // softshrink
        implementation_1444();
        break;
      case 1445: // softshrink_backward
        implementation_1445();
        break;
      case 1446: // adaptive_avg_pool2d
        implementation_1446();
        break;
      case 1447: // mkldnn_adaptive_avg_pool2d
        implementation_1447();
        break;
      case 1448: // mkldnn_adaptive_avg_pool2d_backward
        implementation_1448();
        break;
      case 1449: // _adaptive_avg_pool2d
        implementation_1449();
        break;
      case 1450: // _adaptive_avg_pool2d_backward
        implementation_1450();
        break;
      case 1451: // adaptive_avg_pool3d
        implementation_1451();
        break;
      case 1452: // _adaptive_avg_pool3d
        implementation_1452();
        break;
      case 1453: // _adaptive_avg_pool3d_backward
        implementation_1453();
        break;
      case 1454: // adaptive_max_pool2d
        implementation_1454();
        break;
      case 1455: // adaptive_max_pool2d_backward
        implementation_1455();
        break;
      case 1456: // adaptive_max_pool3d
        implementation_1456();
        break;
      case 1457: // adaptive_max_pool3d_backward
        implementation_1457();
        break;
      case 1458: // avg_pool2d
        implementation_1458();
        break;
      case 1459: // avg_pool2d
        implementation_1459();
        break;
      case 1460: // avg_pool2d
        implementation_1460();
        break;
      case 1461: // avg_pool2d
        implementation_1461();
        break;
      case 1462: // avg_pool2d
        implementation_1462();
        break;
      case 1463: // avg_pool3d
        implementation_1463();
        break;
      case 1464: // avg_pool3d
        implementation_1464();
        break;
      case 1465: // avg_pool3d
        implementation_1465();
        break;
      case 1466: // avg_pool3d
        implementation_1466();
        break;
      case 1467: // avg_pool3d
        implementation_1467();
        break;
      case 1468: // fractional_max_pool2d
        implementation_1468();
        break;
      case 1469: // fractional_max_pool2d_backward
        implementation_1469();
        break;
      case 1470: // fractional_max_pool3d
        implementation_1470();
        break;
      case 1471: // fractional_max_pool3d_backward
        implementation_1471();
        break;
      case 1472: // max_pool2d_with_indices
        implementation_1472();
        break;
      case 1473: // max_pool2d_with_indices
        implementation_1473();
        break;
      case 1474: // max_pool2d_with_indices
        implementation_1474();
        break;
      case 1475: // max_pool2d_with_indices
        implementation_1475();
        break;
      case 1476: // max_pool2d_with_indices
        implementation_1476();
        break;
      case 1477: // max_pool2d_with_indices_backward
        implementation_1477();
        break;
      case 1478: // max_pool3d_with_indices
        implementation_1478();
        break;
      case 1479: // max_pool3d_with_indices
        implementation_1479();
        break;
      case 1480: // max_pool3d_with_indices
        implementation_1480();
        break;
      case 1481: // max_pool3d_with_indices
        implementation_1481();
        break;
      case 1482: // max_pool3d_with_indices
        implementation_1482();
        break;
      case 1483: // max_pool3d_with_indices_backward
        implementation_1483();
        break;
      case 1484: // max_unpool2d
        implementation_1484();
        break;
      case 1485: // max_unpool3d
        implementation_1485();
        break;
      case 1486: // reflection_pad1d
        implementation_1486();
        break;
      case 1487: // reflection_pad1d_backward
        implementation_1487();
        break;
      case 1488: // reflection_pad2d
        implementation_1488();
        break;
      case 1489: // reflection_pad2d_backward
        implementation_1489();
        break;
      case 1490: // reflection_pad3d
        implementation_1490();
        break;
      case 1491: // reflection_pad3d_backward
        implementation_1491();
        break;
      case 1492: // replication_pad1d
        implementation_1492();
        break;
      case 1493: // replication_pad1d_backward
        implementation_1493();
        break;
      case 1494: // replication_pad2d
        implementation_1494();
        break;
      case 1495: // replication_pad2d_backward
        implementation_1495();
        break;
      case 1496: // replication_pad3d
        implementation_1496();
        break;
      case 1497: // replication_pad3d_backward
        implementation_1497();
        break;
      case 1498: // _pad_circular
        implementation_1498();
        break;
      case 1499: // _pad_enum
        implementation_1499();
        break;
      case 1500: // pad
        implementation_1500();
        break;
      case 1501: // upsample_linear1d
        implementation_1501();
        break;
      case 1502: // upsample_linear1d_backward
        implementation_1502();
        break;
      case 1503: // upsample_bilinear2d
        implementation_1503();
        break;
      case 1504: // upsample_bilinear2d_backward
        implementation_1504();
        break;
      case 1505: // _upsample_bilinear2d_aa
        implementation_1505();
        break;
      case 1506: // _upsample_bilinear2d_aa_backward
        implementation_1506();
        break;
      case 1507: // upsample_bicubic2d
        implementation_1507();
        break;
      case 1508: // upsample_bicubic2d_backward
        implementation_1508();
        break;
      case 1509: // _upsample_bicubic2d_aa
        implementation_1509();
        break;
      case 1510: // _upsample_bicubic2d_aa_backward
        implementation_1510();
        break;
      case 1511: // upsample_trilinear3d
        implementation_1511();
        break;
      case 1512: // upsample_trilinear3d_backward
        implementation_1512();
        break;
      case 1513: // upsample_nearest1d
        implementation_1513();
        break;
      case 1514: // _upsample_nearest_exact1d
        implementation_1514();
        break;
      case 1515: // upsample_nearest1d_backward
        implementation_1515();
        break;
      case 1516: // _upsample_nearest_exact1d_backward
        implementation_1516();
        break;
      case 1517: // upsample_nearest2d
        implementation_1517();
        break;
      case 1518: // _upsample_nearest_exact2d
        implementation_1518();
        break;
      case 1519: // upsample_nearest2d_backward
        implementation_1519();
        break;
      case 1520: // _upsample_nearest_exact2d_backward
        implementation_1520();
        break;
      case 1521: // upsample_nearest3d
        implementation_1521();
        break;
      case 1522: // _upsample_nearest_exact3d
        implementation_1522();
        break;
      case 1523: // upsample_nearest3d_backward
        implementation_1523();
        break;
      case 1524: // _upsample_nearest_exact3d_backward
        implementation_1524();
        break;
      case 1525: // sigmoid_backward
        implementation_1525();
        break;
      case 1526: // logit_backward
        implementation_1526();
        break;
      case 1527: // tanh_backward
        implementation_1527();
        break;
      case 1528: // slow_conv_transpose2d
        implementation_1528();
        break;
      case 1529: // slow_conv_transpose2d
        implementation_1529();
        break;
      case 1530: // slow_conv_transpose2d
        implementation_1530();
        break;
      case 1531: // slow_conv_transpose2d
        implementation_1531();
        break;
      case 1532: // slow_conv_transpose2d
        implementation_1532();
        break;
      case 1533: // slow_conv_transpose2d
        implementation_1533();
        break;
      case 1534: // slow_conv_transpose3d
        implementation_1534();
        break;
      case 1535: // slow_conv_transpose3d
        implementation_1535();
        break;
      case 1536: // slow_conv_transpose3d
        implementation_1536();
        break;
      case 1537: // slow_conv_transpose3d
        implementation_1537();
        break;
      case 1538: // slow_conv_transpose3d
        implementation_1538();
        break;
      case 1539: // slow_conv_transpose3d
        implementation_1539();
        break;
      case 1540: // thnn_conv2d
        implementation_1540();
        break;
      case 1541: // thnn_conv2d
        implementation_1541();
        break;
      case 1542: // thnn_conv2d
        implementation_1542();
        break;
      case 1543: // thnn_conv2d
        implementation_1543();
        break;
      case 1544: // _slow_conv2d_forward
        implementation_1544();
        break;
      case 1545: // _slow_conv2d_backward
        implementation_1545();
        break;
      case 1546: // _conv_depthwise2d
        implementation_1546();
        break;
      case 1547: // conv_depthwise3d
        implementation_1547();
        break;
      case 1548: // slow_conv3d
        implementation_1548();
        break;
      case 1549: // slow_conv3d
        implementation_1549();
        break;
      case 1550: // slow_conv3d
        implementation_1550();
        break;
      case 1551: // slow_conv3d
        implementation_1551();
        break;
      case 1552: // slow_conv3d_forward
        implementation_1552();
        break;
      case 1553: // slow_conv_dilated2d
        implementation_1553();
        break;
      case 1554: // slow_conv_dilated2d
        implementation_1554();
        break;
      case 1555: // slow_conv_dilated2d
        implementation_1555();
        break;
      case 1556: // slow_conv_dilated2d
        implementation_1556();
        break;
      case 1557: // slow_conv_dilated2d
        implementation_1557();
        break;
      case 1558: // slow_conv_dilated3d
        implementation_1558();
        break;
      case 1559: // slow_conv_dilated3d
        implementation_1559();
        break;
      case 1560: // slow_conv_dilated3d
        implementation_1560();
        break;
      case 1561: // slow_conv_dilated3d
        implementation_1561();
        break;
      case 1562: // slow_conv_dilated3d
        implementation_1562();
        break;
      case 1563: // col2im
        implementation_1563();
        break;
      case 1564: // column_stack
        implementation_1564();
        break;
      case 1565: // im2col
        implementation_1565();
        break;
      case 1566: // isfinite
        implementation_1566();
        break;
      case 1567: // isinf
        implementation_1567();
        break;
      case 1568: // isposinf
        implementation_1568();
        break;
      case 1569: // isneginf
        implementation_1569();
        break;
      case 1570: // _add_batch_dim
        implementation_1570();
        break;
      case 1571: // _remove_batch_dim
        implementation_1571();
        break;
      case 1572: // special_entr
        implementation_1572();
        break;
      case 1573: // special_ndtri
        implementation_1573();
        break;
      case 1574: // special_log_ndtr
        implementation_1574();
        break;
      case 1575: // special_expm1
        implementation_1575();
        break;
      case 1576: // special_exp2
        implementation_1576();
        break;
      case 1577: // special_psi
        implementation_1577();
        break;
      case 1578: // special_digamma
        implementation_1578();
        break;
      case 1579: // special_gammaln
        implementation_1579();
        break;
      case 1580: // special_erf
        implementation_1580();
        break;
      case 1581: // special_erfc
        implementation_1581();
        break;
      case 1582: // special_erfcx
        implementation_1582();
        break;
      case 1583: // special_erfinv
        implementation_1583();
        break;
      case 1584: // special_ndtr
        implementation_1584();
        break;
      case 1585: // special_xlog1py
        implementation_1585();
        break;
      case 1586: // special_xlog1py
        implementation_1586();
        break;
      case 1587: // special_xlog1py
        implementation_1587();
        break;
      case 1588: // special_xlogy
        implementation_1588();
        break;
      case 1589: // special_xlogy
        implementation_1589();
        break;
      case 1590: // special_xlogy
        implementation_1590();
        break;
      case 1591: // special_zeta
        implementation_1591();
        break;
      case 1592: // special_zeta
        implementation_1592();
        break;
      case 1593: // special_zeta
        implementation_1593();
        break;
      case 1594: // special_i0
        implementation_1594();
        break;
      case 1595: // special_i0e
        implementation_1595();
        break;
      case 1596: // special_i1
        implementation_1596();
        break;
      case 1597: // special_i1e
        implementation_1597();
        break;
      case 1598: // special_logit
        implementation_1598();
        break;
      case 1599: // special_polygamma
        implementation_1599();
        break;
      case 1600: // special_logsumexp
        implementation_1600();
        break;
      case 1601: // special_logsumexp
        implementation_1601();
        break;
      case 1602: // special_expit
        implementation_1602();
        break;
      case 1603: // special_sinc
        implementation_1603();
        break;
      case 1604: // special_round
        implementation_1604();
        break;
      case 1605: // special_round
        implementation_1605();
        break;
      case 1606: // special_log1p
        implementation_1606();
        break;
      case 1607: // special_log_softmax
        implementation_1607();
        break;
      case 1608: // special_gammainc
        implementation_1608();
        break;
      case 1609: // special_gammaincc
        implementation_1609();
        break;
      case 1610: // special_multigammaln
        implementation_1610();
        break;
      case 1611: // special_softmax
        implementation_1611();
        break;
      case 1612: // fft_fft
        implementation_1612();
        break;
      case 1613: // fft_ifft
        implementation_1613();
        break;
      case 1614: // fft_rfft
        implementation_1614();
        break;
      case 1615: // fft_irfft
        implementation_1615();
        break;
      case 1616: // fft_hfft
        implementation_1616();
        break;
      case 1617: // fft_ihfft
        implementation_1617();
        break;
      case 1618: // fft_fft2
        implementation_1618();
        break;
      case 1619: // fft_ifft2
        implementation_1619();
        break;
      case 1620: // fft_rfft2
        implementation_1620();
        break;
      case 1621: // fft_irfft2
        implementation_1621();
        break;
      case 1622: // fft_hfft2
        implementation_1622();
        break;
      case 1623: // fft_ihfft2
        implementation_1623();
        break;
      case 1624: // fft_fftn
        implementation_1624();
        break;
      case 1625: // fft_ifftn
        implementation_1625();
        break;
      case 1626: // fft_rfftn
        implementation_1626();
        break;
      case 1627: // fft_irfftn
        implementation_1627();
        break;
      case 1628: // fft_hfftn
        implementation_1628();
        break;
      case 1629: // fft_ihfftn
        implementation_1629();
        break;
      case 1630: // fft_fftshift
        implementation_1630();
        break;
      case 1631: // fft_ifftshift
        implementation_1631();
        break;
      case 1632: // linalg_cholesky_ex
        implementation_1632();
        break;
      case 1633: // linalg_cholesky_ex
        implementation_1633();
        break;
      case 1634: // linalg_cholesky_ex
        implementation_1634();
        break;
      case 1635: // linalg_cholesky
        implementation_1635();
        break;
      case 1636: // linalg_cholesky
        implementation_1636();
        break;
      case 1637: // linalg_cross
        implementation_1637();
        break;
      case 1638: // linalg_cross
        implementation_1638();
        break;
      case 1639: // linalg_lu_factor
        implementation_1639();
        break;
      case 1640: // linalg_lu_factor
        implementation_1640();
        break;
      case 1641: // linalg_lu_factor_ex
        implementation_1641();
        break;
      case 1642: // linalg_lu_factor_ex
        implementation_1642();
        break;
      case 1643: // linalg_lu_factor_ex
        implementation_1643();
        break;
      case 1644: // linalg_lu
        implementation_1644();
        break;
      case 1645: // linalg_lu
        implementation_1645();
        break;
      case 1646: // linalg_lu_solve
        implementation_1646();
        break;
      case 1647: // linalg_lu_solve
        implementation_1647();
        break;
      case 1648: // linalg_lu_solve
        implementation_1648();
        break;
      case 1649: // _linalg_det
        implementation_1649();
        break;
      case 1650: // linalg_det
        implementation_1650();
        break;
      case 1651: // det
        implementation_1651();
        break;
      case 1652: // linalg_ldl_factor_ex
        implementation_1652();
        break;
      case 1653: // linalg_ldl_factor_ex
        implementation_1653();
        break;
      case 1654: // linalg_ldl_factor_ex
        implementation_1654();
        break;
      case 1655: // linalg_ldl_factor
        implementation_1655();
        break;
      case 1656: // linalg_ldl_factor
        implementation_1656();
        break;
      case 1657: // linalg_ldl_solve
        implementation_1657();
        break;
      case 1658: // linalg_ldl_solve
        implementation_1658();
        break;
      case 1659: // linalg_lstsq
        implementation_1659();
        break;
      case 1660: // linalg_matmul
        implementation_1660();
        break;
      case 1661: // linalg_vecdot
        implementation_1661();
        break;
      case 1662: // linalg_vecdot
        implementation_1662();
        break;
      case 1663: // linalg_matrix_exp
        implementation_1663();
        break;
      case 1664: // _linalg_slogdet
        implementation_1664();
        break;
      case 1665: // linalg_slogdet
        implementation_1665();
        break;
      case 1666: // slogdet
        implementation_1666();
        break;
      case 1667: // logdet
        implementation_1667();
        break;
      case 1668: // linalg_eig
        implementation_1668();
        break;
      case 1669: // _linalg_eigvals
        implementation_1669();
        break;
      case 1670: // linalg_eigvals
        implementation_1670();
        break;
      case 1671: // _linalg_eigh
        implementation_1671();
        break;
      case 1672: // linalg_eigh
        implementation_1672();
        break;
      case 1673: // linalg_eigvalsh
        implementation_1673();
        break;
      case 1674: // linalg_householder_product
        implementation_1674();
        break;
      case 1675: // linalg_inv_ex
        implementation_1675();
        break;
      case 1676: // linalg_inv_ex
        implementation_1676();
        break;
      case 1677: // linalg_inv
        implementation_1677();
        break;
      case 1678: // inverse
        implementation_1678();
        break;
      case 1679: // inner
        implementation_1679();
        break;
      case 1680: // outer
        implementation_1680();
        break;
      case 1681: // ger
        implementation_1681();
        break;
      case 1682: // linalg_norm
        implementation_1682();
        break;
      case 1683: // linalg_vector_norm
        implementation_1683();
        break;
      case 1684: // linalg_vector_norm
        implementation_1684();
        break;
      case 1685: // linalg_matrix_norm
        implementation_1685();
        break;
      case 1686: // linalg_matrix_norm
        implementation_1686();
        break;
      case 1687: // linalg_matrix_norm
        implementation_1687();
        break;
      case 1688: // linalg_matrix_norm
        implementation_1688();
        break;
      case 1689: // _linalg_svd
        implementation_1689();
        break;
      case 1690: // _linalg_svd
        implementation_1690();
        break;
      case 1691: // _linalg_svd
        implementation_1691();
        break;
      case 1692: // linalg_svd
        implementation_1692();
        break;
      case 1693: // linalg_svd
        implementation_1693();
        break;
      case 1694: // linalg_svdvals
        implementation_1694();
        break;
      case 1695: // linalg_cond
        implementation_1695();
        break;
      case 1696: // linalg_pinv
        implementation_1696();
        break;
      case 1697: // linalg_pinv
        implementation_1697();
        break;
      case 1698: // linalg_pinv
        implementation_1698();
        break;
      case 1699: // linalg_pinv
        implementation_1699();
        break;
      case 1700: // linalg_pinv
        implementation_1700();
        break;
      case 1701: // linalg_pinv
        implementation_1701();
        break;
      case 1702: // linalg_pinv
        implementation_1702();
        break;
      case 1703: // _linalg_solve_ex
        implementation_1703();
        break;
      case 1704: // _linalg_solve_ex
        implementation_1704();
        break;
      case 1705: // _linalg_solve_ex
        implementation_1705();
        break;
      case 1706: // linalg_solve_ex
        implementation_1706();
        break;
      case 1707: // linalg_solve_ex
        implementation_1707();
        break;
      case 1708: // linalg_solve_ex
        implementation_1708();
        break;
      case 1709: // linalg_solve
        implementation_1709();
        break;
      case 1710: // linalg_solve
        implementation_1710();
        break;
      case 1711: // linalg_tensorinv
        implementation_1711();
        break;
      case 1712: // linalg_tensorinv
        implementation_1712();
        break;
      case 1713: // linalg_tensorsolve
        implementation_1713();
        break;
      case 1714: // linalg_qr
        implementation_1714();
        break;
      case 1715: // linalg_matrix_power
        implementation_1715();
        break;
      case 1716: // linalg_matrix_rank
        implementation_1716();
        break;
      case 1717: // linalg_matrix_rank
        implementation_1717();
        break;
      case 1718: // linalg_matrix_rank
        implementation_1718();
        break;
      case 1719: // linalg_matrix_rank
        implementation_1719();
        break;
      case 1720: // linalg_matrix_rank
        implementation_1720();
        break;
      case 1721: // linalg_matrix_rank
        implementation_1721();
        break;
      case 1722: // linalg_matrix_rank
        implementation_1722();
        break;
      case 1723: // linalg_multi_dot
        implementation_1723();
        break;
      case 1724: // nested_to_padded_tensor
        implementation_1724();
        break;
      case 1725: // _test_serialization_subcmul
        implementation_1725();
        break;
      case 1726: // _test_serialization_subcmul
        implementation_1726();
        break;
      case 1727: // _test_parallel_materialize
        implementation_1727();
        break;
      case 1728: // _test_parallel_materialize
        implementation_1728();
        break;
      case 1729: // _test_string_default
        implementation_1729();
        break;
      case 1730: // _test_ambiguous_defaults
        implementation_1730();
        break;
      case 1731: // _test_ambiguous_defaults
        implementation_1731();
        break;
      case 1732: // _test_ambiguous_defaults
        implementation_1732();
        break;
      case 1733: // _test_warn_in_autograd
        implementation_1733();
        break;
      case 1734: // _test_autograd_multiple_dispatch
        implementation_1734();
        break;
      case 1735: // _test_autograd_multiple_dispatch
        implementation_1735();
        break;
      case 1736: // _test_autograd_multiple_dispatch_view
        implementation_1736();
        break;
      case 1737: // _test_autograd_multiple_dispatch_view_copy
        implementation_1737();
        break;
      case 1738: // pad_sequence
        implementation_1738();
        break;
      case 1739: // pad_sequence
        implementation_1739();
        break;
      case 1740: // pad_sequence
        implementation_1740();
        break;
      case 1741: // flatten_dense_tensors
        implementation_1741();
        break;
      case 1742: // unflatten_dense_tensors
        implementation_1742();
        break;
      case 1743: // _nested_tensor_from_tensor_list
        implementation_1743();
        break;
      case 1744: // _fw_primal_copy
        implementation_1744();
        break;
      case 1745: // _make_dual_copy
        implementation_1745();
        break;
      case 1746: // view_as_real_copy
        implementation_1746();
        break;
      case 1747: // view_as_complex_copy
        implementation_1747();
        break;
      case 1748: // _conj_copy
        implementation_1748();
        break;
      case 1749: // _neg_view_copy
        implementation_1749();
        break;
      case 1750: // as_strided_copy
        implementation_1750();
        break;
      case 1751: // _sparse_broadcast_to_copy
        implementation_1751();
        break;
      case 1752: // diagonal_copy
        implementation_1752();
        break;
      case 1753: // diagonal_copy
        implementation_1753();
        break;
      case 1754: // diagonal_copy
        implementation_1754();
        break;
      case 1755: // diagonal_copy
        implementation_1755();
        break;
      case 1756: // expand_copy
        implementation_1756();
        break;
      case 1757: // expand_copy
        implementation_1757();
        break;
      case 1758: // permute_copy
        implementation_1758();
        break;
      case 1759: // _reshape_alias_copy
        implementation_1759();
        break;
      case 1760: // select_copy
        implementation_1760();
        break;
      case 1761: // detach_copy
        implementation_1761();
        break;
      case 1762: // slice_copy
        implementation_1762();
        break;
      case 1763: // slice_copy
        implementation_1763();
        break;
      case 1764: // split_copy
        implementation_1764();
        break;
      case 1765: // split_copy
        implementation_1765();
        break;
      case 1766: // split_with_sizes_copy
        implementation_1766();
        break;
      case 1767: // split_with_sizes_copy
        implementation_1767();
        break;
      case 1768: // squeeze_copy
        implementation_1768();
        break;
      case 1769: // squeeze_copy
        implementation_1769();
        break;
      case 1770: // t_copy
        implementation_1770();
        break;
      case 1771: // transpose_copy
        implementation_1771();
        break;
      case 1772: // unsqueeze_copy
        implementation_1772();
        break;
      case 1773: // _indices_copy
        implementation_1773();
        break;
      case 1774: // _values_copy
        implementation_1774();
        break;
      case 1775: // indices_copy
        implementation_1775();
        break;
      case 1776: // values_copy
        implementation_1776();
        break;
      case 1777: // crow_indices_copy
        implementation_1777();
        break;
      case 1778: // col_indices_copy
        implementation_1778();
        break;
      case 1779: // ccol_indices_copy
        implementation_1779();
        break;
      case 1780: // row_indices_copy
        implementation_1780();
        break;
      case 1781: // unbind_copy
        implementation_1781();
        break;
      case 1782: // unbind_copy
        implementation_1782();
        break;
      case 1783: // view_copy
        implementation_1783();
        break;
      case 1784: // unfold_copy
        implementation_1784();
        break;
      case 1785: // alias_copy
        implementation_1785();
        break;
      case 1786: // to_padded_tensor
        implementation_1786();
        break;
      case 1787: // _nested_tensor_softmax_with_shape
        implementation_1787();
        break;
      case 1788: // _transformer_encoder_layer_fwd
        implementation_1788();
        break;
      case 1789: // _transformer_encoder_layer_fwd
        implementation_1789();
        break;
      case 1790: // _native_multi_head_attention
        implementation_1790();
        break;
      case 1791: // _native_multi_head_attention
        implementation_1791();
        break;
      case 1792: // _native_multi_head_attention
        implementation_1792();
        break;
      case 1793: // _native_multi_head_attention
        implementation_1793();
        break;
      case 1794: // scaled_dot_product_attention
        implementation_1794();
        break;
      case 1795: // scaled_dot_product_attention
        implementation_1795();
        break;
      case 1796: // scaled_dot_product_attention
        implementation_1796();
        break;
      case 1797: // scaled_dot_product_attention
        implementation_1797();
        break;
      case 1798: // _fused_sdp_choice
        implementation_1798();
        break;
      case 1799: // _fused_sdp_choice
        implementation_1799();
        break;
      case 1800: // _fused_sdp_choice
        implementation_1800();
        break;
      case 1801: // _fused_sdp_choice
        implementation_1801();
        break;
      case 1802: // _scaled_dot_product_attention_math
        implementation_1802();
        break;
      case 1803: // _scaled_dot_product_attention_math
        implementation_1803();
        break;
      case 1804: // _scaled_dot_product_attention_math
        implementation_1804();
        break;
      case 1805: // _scaled_dot_product_attention_math
        implementation_1805();
        break;
      case 1806: // _scaled_dot_product_attention_math
        implementation_1806();
        break;
      case 1807: // _scaled_dot_product_flash_attention_for_cpu
        implementation_1807();
        break;
      case 1808: // _scaled_dot_product_flash_attention_for_cpu
        implementation_1808();
        break;
      case 1809: // _scaled_dot_product_flash_attention_for_cpu
        implementation_1809();
        break;
      case 1810: // _scaled_dot_product_flash_attention_for_cpu
        implementation_1810();
        break;
      case 1811: // _scaled_dot_product_flash_attention_backward
        implementation_1811();
        break;
      case 1812: // _scaled_dot_product_flash_attention_for_cpu_backward
        implementation_1812();
        break;
      case 1813: // _scaled_dot_product_flash_attention_for_cpu_backward
        implementation_1813();
        break;
      case 1814: // _scaled_dot_product_efficient_attention
        implementation_1814();
        break;
      case 1815: // _scaled_dot_product_efficient_attention
        implementation_1815();
        break;
      case 1816: // _scaled_dot_product_efficient_attention
        implementation_1816();
        break;
      case 1817: // _scaled_dot_product_cudnn_attention
        implementation_1817();
        break;
      case 1818: // _scaled_dot_product_cudnn_attention
        implementation_1818();
        break;
      case 1819: // _scaled_dot_product_cudnn_attention
        implementation_1819();
        break;
      case 1820: // _scaled_dot_product_cudnn_attention
        implementation_1820();
        break;
      case 1821: // _flash_attention_forward
        implementation_1821();
        break;
      case 1822: // _flash_attention_backward
        implementation_1822();
        break;
      case 1823: // _efficient_attention_backward
        implementation_1823();
        break;
      case 1824: // _triton_scaled_dot_attention
        implementation_1824();
        break;
      case 1825: // _triton_scaled_dot_attention
        implementation_1825();
        break;
      case 1826: // _triton_multi_head_attention
        implementation_1826();
        break;
      case 1827: // _triton_multi_head_attention
        implementation_1827();
        break;
      case 1828: // special_airy_ai
        implementation_1828();
        break;
      case 1829: // special_bessel_j0
        implementation_1829();
        break;
      case 1830: // special_bessel_j1
        implementation_1830();
        break;
      case 1831: // special_bessel_y0
        implementation_1831();
        break;
      case 1832: // special_bessel_y1
        implementation_1832();
        break;
      case 1833: // special_chebyshev_polynomial_t
        implementation_1833();
        break;
      case 1834: // special_chebyshev_polynomial_t
        implementation_1834();
        break;
      case 1835: // special_chebyshev_polynomial_t
        implementation_1835();
        break;
      case 1836: // special_chebyshev_polynomial_u
        implementation_1836();
        break;
      case 1837: // special_chebyshev_polynomial_u
        implementation_1837();
        break;
      case 1838: // special_chebyshev_polynomial_u
        implementation_1838();
        break;
      case 1839: // special_chebyshev_polynomial_v
        implementation_1839();
        break;
      case 1840: // special_chebyshev_polynomial_v
        implementation_1840();
        break;
      case 1841: // special_chebyshev_polynomial_v
        implementation_1841();
        break;
      case 1842: // special_chebyshev_polynomial_w
        implementation_1842();
        break;
      case 1843: // special_chebyshev_polynomial_w
        implementation_1843();
        break;
      case 1844: // special_chebyshev_polynomial_w
        implementation_1844();
        break;
      case 1845: // special_hermite_polynomial_h
        implementation_1845();
        break;
      case 1846: // special_hermite_polynomial_h
        implementation_1846();
        break;
      case 1847: // special_hermite_polynomial_h
        implementation_1847();
        break;
      case 1848: // special_hermite_polynomial_he
        implementation_1848();
        break;
      case 1849: // special_hermite_polynomial_he
        implementation_1849();
        break;
      case 1850: // special_hermite_polynomial_he
        implementation_1850();
        break;
      case 1851: // special_laguerre_polynomial_l
        implementation_1851();
        break;
      case 1852: // special_laguerre_polynomial_l
        implementation_1852();
        break;
      case 1853: // special_laguerre_polynomial_l
        implementation_1853();
        break;
      case 1854: // special_legendre_polynomial_p
        implementation_1854();
        break;
      case 1855: // special_legendre_polynomial_p
        implementation_1855();
        break;
      case 1856: // special_legendre_polynomial_p
        implementation_1856();
        break;
      case 1857: // special_modified_bessel_i0
        implementation_1857();
        break;
      case 1858: // special_modified_bessel_i1
        implementation_1858();
        break;
      case 1859: // special_modified_bessel_k0
        implementation_1859();
        break;
      case 1860: // special_modified_bessel_k1
        implementation_1860();
        break;
      case 1861: // special_scaled_modified_bessel_k0
        implementation_1861();
        break;
      case 1862: // special_scaled_modified_bessel_k1
        implementation_1862();
        break;
      case 1863: // special_shifted_chebyshev_polynomial_t
        implementation_1863();
        break;
      case 1864: // special_shifted_chebyshev_polynomial_t
        implementation_1864();
        break;
      case 1865: // special_shifted_chebyshev_polynomial_t
        implementation_1865();
        break;
      case 1866: // special_shifted_chebyshev_polynomial_u
        implementation_1866();
        break;
      case 1867: // special_shifted_chebyshev_polynomial_u
        implementation_1867();
        break;
      case 1868: // special_shifted_chebyshev_polynomial_u
        implementation_1868();
        break;
      case 1869: // special_shifted_chebyshev_polynomial_v
        implementation_1869();
        break;
      case 1870: // special_shifted_chebyshev_polynomial_v
        implementation_1870();
        break;
      case 1871: // special_shifted_chebyshev_polynomial_v
        implementation_1871();
        break;
      case 1872: // special_shifted_chebyshev_polynomial_w
        implementation_1872();
        break;
      case 1873: // special_shifted_chebyshev_polynomial_w
        implementation_1873();
        break;
      case 1874: // special_shifted_chebyshev_polynomial_w
        implementation_1874();
        break;
      case 1875: // special_spherical_bessel_j0
        implementation_1875();
        break;
      case 1876: // _foobar
        implementation_1876();
        break;
      case 1877: // _foobar
        implementation_1877();
        break;
      case 1878: // _foobar
        implementation_1878();
        break;
      case 1879: // _foobar
        implementation_1879();
        break;
      case 1880: // bernoulli
        implementation_1880();
        break;
      case 1881: // embedding_renorm
        implementation_1881();
        break;
      case 1882: // resize
        implementation_1882();
        break;
      case 1883: // _index_put_impl
        implementation_1883();
        break;
      case 1884: // _index_put_impl
        implementation_1884();
        break;
      case 1885: // _index_put_impl
        implementation_1885();
        break;
      case 1886: // _native_batch_norm_legit_functional
        implementation_1886();
        break;
      case 1887: // resize_as
        implementation_1887();
        break;
      case 1888: // resize_as_sparse
        implementation_1888();
        break;
      case 1889: // zero
        implementation_1889();
        break;
      case 1890: // sparse_resize
        implementation_1890();
        break;
      case 1891: // sparse_resize_and_clear
        implementation_1891();
        break;
      case 1892: // _coalesced
        implementation_1892();
        break;
      case 1893: // copy_sparse_to_sparse
        implementation_1893();
        break;
      case 1894: // copy_sparse_to_sparse
        implementation_1894();
        break;
      case 1895: // _fused_moving_avg_obs_fq_helper_functional
        implementation_1895();
        break;
      case 1896: // _fused_moving_avg_obs_fq_helper_functional
        implementation_1896();
        break;
      case 1897: // _fused_moving_avg_obs_fq_helper_functional
        implementation_1897();
        break;
      case 1898: // set
        implementation_1898();
        break;
      case 1899: // set
        implementation_1899();
        break;
      case 1900: // random
        implementation_1900();
        break;
      case 1901: // random
        implementation_1901();
        break;
      case 1902: // uniform
        implementation_1902();
        break;
      case 1903: // uniform
        implementation_1903();
        break;
      case 1904: // uniform
        implementation_1904();
        break;
      case 1905: // cauchy
        implementation_1905();
        break;
      case 1906: // cauchy
        implementation_1906();
        break;
      case 1907: // cauchy
        implementation_1907();
        break;
      case 1908: // log_normal
        implementation_1908();
        break;
      case 1909: // log_normal
        implementation_1909();
        break;
      case 1910: // log_normal
        implementation_1910();
        break;
      case 1911: // exponential
        implementation_1911();
        break;
      case 1912: // exponential
        implementation_1912();
        break;
      case 1913: // geometric
        implementation_1913();
        break;
      case 1914: // _amp_foreach_non_finite_check_and_unscale
        implementation_1914();
        break;
      case 1915: // _amp_update_scale
        implementation_1915();
        break;
      case 1916: // _foreach_zero
        implementation_1916();
        break;
      case 1917: // _foreach_copy
        implementation_1917();
        break;
      case 1918: // _foreach_copy
        implementation_1918();
        break;
      case 1919: // _fused_adam
        implementation_1919();
        break;
      case 1920: // _fused_adam
        implementation_1920();
        break;
      case 1921: // _fused_adamw
        implementation_1921();
        break;
      case 1922: // _fused_adamw
        implementation_1922();
        break;
      case 1923: // _fused_sgd
        implementation_1923();
        break;
      case 1924: // _fused_sgd
        implementation_1924();
        break;
      default:
        CAFFE_THROW("Unexpected key value for aten operator");
    }
  }
  USE_OPERATOR_CONTEXT_FUNCTIONS;

  bool RunOnDevice() override {
    return run_op();
  }
private:
  // actual operator implementation is initialized in ctor.
  std::function<bool()> run_op;
  at::Backend backend() const;

  TypeMeta typeMetaFor(const at::Tensor & t) {
    return typeMetaFor(t.scalar_type());
  }
  TypeMeta typeMetaFor(at::ScalarType st) {
    #define DEFINE_CASE(ctype,aten_name) \
      case at::k##aten_name: \
        return TypeMeta::Make<ctype>();
    switch(st) {
      AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, DEFINE_CASE)
    default:
      CAFFE_THROW("Unknown ATen Type");
    }
    #undef DEFINE_CASE
  }

  at::TensorOptions optionsFor(const Tensor& ten) {
    at::Device device = ten.GetDevice();
#if defined(USE_ROCM)
    if (backend() == at::Backend::HIP) {
      device = at::Device(kCUDA, device.index());
    }
#endif
    return at::TensorOptions(device).dtype(ten.dtype());
  }

  at::Tensor tensorWrapping(const Tensor& ten_) {
    auto& ten = const_cast<Tensor&>(ten_);
    return at::from_blob(
        ten.raw_mutable_data(),
        ten.sizes(),
        optionsFor(ten));
  }

  at::Tensor peek(size_t i, size_t N) {
    auto real_idx = InputSize() - N + i;
    return tensorWrapping(Input(real_idx));
  }

  std::vector<at::Tensor> peekSlice(size_t i, size_t len, size_t N) {
    std::vector<at::Tensor> results;
    results.reserve(len);
    for (size_t ii = i; ii < i + len; ++ii) {
      results.push_back(peek(ii, N));
    }
    return results;
  }

  torch::List<c10::optional<at::Tensor>> peekSliceOptionals(size_t i, size_t len, size_t N) {
    torch::List<c10::optional<at::Tensor>> results;
    results.reserve(len);
    for (size_t ii = i; ii < i + len; ++ii) {
      results.push_back(peek(ii, N));
    }
    return results;
  }

  void assignTo(Tensor* dst, const at::Tensor& src_) {
    at::Tensor src = src_.contiguous();
    auto at_sizes = src.sizes();
    caffe2::TypeMeta type_meta = typeMetaFor(src);
    at::Device device = src.device();
#if defined(USE_ROCM)
    if (device.is_cuda()) {
      device = at::Device(at::DeviceType::HIP, device.index());
    }
#endif
    at::TensorImpl* src_impl = src.unsafeReleaseTensorImpl();
    std::vector<int64_t> dims(at_sizes.begin(), at_sizes.end());
    dst->Resize(dims);
    dst->ShareExternalPointer(
        at::DataPtr(
            src_impl->mutable_data(),
            static_cast<void*>(src_impl),
            [](void* t_ptr) -> void {
              at::TensorImpl* local_impl = static_cast<at::TensorImpl*>(t_ptr);
              c10::raw::intrusive_ptr::decref(local_impl);
            },
            device),
        type_meta,
        0);
  }
  void assignListStartingAt(
      size_t offset,
      const std::vector<at::Tensor>& tensors) {
    for (const auto i : c10::irange(tensors.size())) {
      assignTo(Output(offset + i), tensors[i]);
    }
  }

  template<typename T,
          typename std::enable_if<std::numeric_limits<T>::is_integer, bool>::type* =
              nullptr>
  int64_t extract(const at::Scalar &s) {
    return s.toLong();
  }

  template<typename T,
          typename std::enable_if<!std::numeric_limits<T>::is_integer, bool>::type* =
              nullptr>
  int64_t extract(const at::Scalar &s) {
    return s.toDouble();
  }

  void assignTo(Tensor* dst, at::ScalarType scalar_type, const at::Scalar& scalar) {
    switch(scalar_type) {
      #define DEFINE_CASE(ctype,aten_name) \
        case at::k##aten_name: { \
          auto value = extract<ctype>(scalar); \
          assignToValue<ctype>(dst, at::convert<ctype,decltype(value)>(value)); \
        } break;
      AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, DEFINE_CASE)
#undef DEFINE_CASE
      default:
        CAFFE_THROW("Unknown ATen Type");
    }
  }
  template <typename T>
  void assignToValue(Tensor* dst, T v) {
    dst->Resize(std::vector<int64_t>());
    math::Set(1, v, dst->template mutable_data<T>(), &context_);
  }
  int findImplementation(const OperatorDef& operator_def) {
    CAFFE_ENFORCE(HasArgument("operator"));
    std::string op = OperatorBase::GetSingleArgument<std::string>("operator", "");
    // construct descriptor string ([DESCRIPTORS]) given the attributes
    // and inputs of this operator_def, and look up the implementation key
    // for this variant
    std::stringstream descriptor;
    descriptor << op;
    std::vector<std::string> attrs;
    for (const auto i : c10::irange(operator_def.arg_size())) {
      auto & attr = operator_def.arg(i);
      if (attr.name() == "operator" || attr.name() == "type" || attr.name() == "overload_name") {
        continue;
      }
      attrs.push_back(attr.name());
    }
    std::sort(attrs.begin(), attrs.end());
    for(auto & a : attrs)
      descriptor << "-" << a;

    std::string descriptor_sized =
        descriptor.str() + "-" + c10::to_string(InputSize());
    std::string descriptor_var_args = descriptor.str() + "-*";
    if (op_to_key.count(descriptor_sized) > 0) {
      return op_to_key[descriptor_sized];
    }
    if (op_to_key.count(descriptor_var_args) > 0) {
      return op_to_key[descriptor_var_args];
    }
    std::stringstream ss;
    ss << "Attempting to run unknown ATen operator configuration: "
       << descriptor_sized;
    CAFFE_THROW(ss.str());
  }
  at::Scalar readScalarAttribute(const std::string & name) {
    if(OperatorBase::HasSingleArgumentOfType<int64_t>(name)) {
      return OperatorBase::GetSingleArgument<int64_t>(name, 0);
    } else {
      CAFFE_ENFORCE(OperatorBase::HasSingleArgumentOfType<float>(name));
      return OperatorBase::GetSingleArgument<float>(name, 0);
    }
  }
  template<typename T>
  T readAttribute(const std::string & name) {
    CAFFE_ENFORCE(OperatorBase::HasSingleArgumentOfType<T>(name));
    return OperatorBase::GetSingleArgument<T>(name, 0);
  }
  std::vector<int64_t> readIntArrayRef(const std::string & name) {
    CAFFE_ENFORCE(OperatorBase::HasArgument(name));
    return OperatorBase::GetRepeatedArgument<int64_t>(name, {});
  }
  template <int N>
  std::array<bool, N> readBoolMask(const std::string& name) {
    CAFFE_ENFORCE(OperatorBase::HasArgument(name));
    std::vector<int64_t> ints =
        OperatorBase::GetRepeatedArgument<int64_t>(name, {});
    std::array<bool, N> result;
    for (const auto i : c10::irange(N)) {
      result[i] = ints.at(i);
    }
    return result;
  }

  C10_NOINLINE void implementation_0() { // _cast_Byte
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Byte(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1() { // _cast_Byte
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Byte(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_2() { // _cast_Char
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Char(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_3() { // _cast_Char
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Char(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_4() { // _cast_Double
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Double(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_5() { // _cast_Double
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Double(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_6() { // _cast_Float
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Float(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_7() { // _cast_Float
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Float(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_8() { // _cast_Int
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Int(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_9() { // _cast_Int
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Int(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_10() { // _cast_Long
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Long(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_11() { // _cast_Long
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Long(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_12() { // _cast_Short
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Short(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_13() { // _cast_Short
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Short(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_14() { // _cast_Half
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Half(self, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_15() { // _cast_Half
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_cast_Half(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_16() { // data
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.data();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_17() { // is_leaf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.is_leaf();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_18() { // output_nr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.output_nr();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_19() { // _version
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._version();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_20() { // retains_grad
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.retains_grad();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_21() { // _fw_primal
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._fw_primal(level);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_22() { // _make_dual
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto primal = peek(0, 2);
          auto tangent = peek(1, 2);
          auto the_result = at::_make_dual(primal, tangent, level);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_23() { // _unpack_dual
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dual = peek(0, 1);
          auto the_result = at::_unpack_dual(dual, level);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_24() { // _new_zeros_with_same_feature_meta
      int64_t self_num_batch_dims = readAttribute<int64_t>("self_num_batch_dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_new_zeros_with_same_feature_meta(self, other, self_num_batch_dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_25() { // _new_zeros_with_same_feature_meta
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_new_zeros_with_same_feature_meta(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_26() { // _has_same_storage_numel
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_has_same_storage_numel(self, other);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_27() { // align_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = self.align_as(other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_28() { // align_tensors
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::align_tensors(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_29() { // _use_cudnn_ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::_use_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_30() { // _use_cudnn_ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::_use_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_31() { // _cudnn_ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, deterministic, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_32() { // _cudnn_ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, deterministic, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_33() { // _use_cudnn_rnn_flatten_weight
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
  
          auto the_result = at::_use_cudnn_rnn_flatten_weight();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_34() { // _cudnn_rnn_flatten_weight
      int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
      int64_t input_size = readAttribute<int64_t>("input_size");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t hidden_size = readAttribute<int64_t>("hidden_size");
      int64_t proj_size = readAttribute<int64_t>("proj_size");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      bool batch_first = readAttribute<int64_t>("batch_first");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight_arr = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_cudnn_rnn_flatten_weight(weight_arr, weight_stride0, input_size, mode, hidden_size, proj_size, num_layers, batch_first, bidirectional);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_35() { // _cudnn_rnn
      int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t hidden_size = readAttribute<int64_t>("hidden_size");
      int64_t proj_size = readAttribute<int64_t>("proj_size");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      bool batch_first = readAttribute<int64_t>("batch_first");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      auto batch_sizes = readIntArrayRef("batch_sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto weight = peekSlice(1, InputSize() - 5, InputSize());
          auto weight_buf = peek(1, 5);
          auto hx = peek(2, 5);
          auto cx = peek(3, 5);
          auto dropout_state = peek(4, 5);
          auto the_result = at::_cudnn_rnn(input, weight, weight_stride0, weight_buf, hx, cx, mode, hidden_size, proj_size, num_layers, batch_first, dropout, train, bidirectional, batch_sizes, dropout_state);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_36() { // _debug_has_internal_overlap
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_debug_has_internal_overlap(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_37() { // _fused_dropout
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_fused_dropout(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_38() { // _masked_scale
      double scale = readAttribute<float>("scale");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::_masked_scale(self, mask, scale);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_39() { // native_dropout_backward
      double scale = readAttribute<float>("scale");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::native_dropout_backward(grad_output, mask, scale);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_40() { // _reshape_from_tensor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto shape = peek(1, 2);
          auto the_result = at::_reshape_from_tensor(self, shape);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_41() { // _shape_as_tensor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_shape_as_tensor(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_42() { // dropout
      double p = readAttribute<float>("p");
      bool train = readAttribute<int64_t>("train");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::dropout(input, p, train);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_43() { // feature_dropout
      double p = readAttribute<float>("p");
      bool train = readAttribute<int64_t>("train");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::feature_dropout(input, p, train);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_44() { // alpha_dropout
      double p = readAttribute<float>("p");
      bool train = readAttribute<int64_t>("train");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::alpha_dropout(input, p, train);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_45() { // feature_alpha_dropout
      double p = readAttribute<float>("p");
      bool train = readAttribute<int64_t>("train");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::feature_alpha_dropout(input, p, train);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_46() { // abs
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::abs(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_47() { // absolute
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::absolute(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_48() { // angle
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::angle(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_49() { // view_as_real
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::view_as_real(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_50() { // view_as_complex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::view_as_complex(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_51() { // sgn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sgn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_52() { // chalf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.chalf();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_53() { // real
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::real(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_54() { // imag
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::imag(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_55() { // _conj
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_conj(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_56() { // conj
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::conj(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_57() { // _conj_physical
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_conj_physical(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_58() { // conj_physical
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::conj_physical(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_59() { // resolve_conj
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::resolve_conj(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_60() { // resolve_neg
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::resolve_neg(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_61() { // _neg_view
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_neg_view(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_62() { // acos
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::acos(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_63() { // arccos
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arccos(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_64() { // avg_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      bool count_include_pad = readAttribute<int64_t>("count_include_pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool1d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_65() { // avg_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool1d(self, kernel_size, stride, padding, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_66() { // avg_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool1d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_67() { // avg_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool1d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_68() { // avg_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool1d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_69() { // adaptive_avg_pool1d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_avg_pool1d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_70() { // adaptive_max_pool1d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_max_pool1d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_71() { // add
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::add(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_72() { // add
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::add(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_73() { // _add_relu
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_add_relu(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_74() { // _add_relu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_add_relu(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_75() { // _add_relu
      at::Scalar other = readScalarAttribute("other");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_add_relu(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_76() { // _add_relu
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_add_relu(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_77() { // add
      at::Scalar other = readScalarAttribute("other");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::add(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_78() { // add
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::add(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_79() { // addmv
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat = peek(1, 3);
          auto vec = peek(2, 3);
          auto the_result = at::addmv(self, mat, vec, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_80() { // addmv
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat = peek(1, 3);
          auto vec = peek(2, 3);
          auto the_result = at::addmv(self, mat, vec, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_81() { // addmv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat = peek(1, 3);
          auto vec = peek(2, 3);
          auto the_result = at::addmv(self, mat, vec);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_82() { // addr
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto vec1 = peek(1, 3);
          auto vec2 = peek(2, 3);
          auto the_result = at::addr(self, vec1, vec2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_83() { // addr
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto vec1 = peek(1, 3);
          auto vec2 = peek(2, 3);
          auto the_result = at::addr(self, vec1, vec2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_84() { // addr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto vec1 = peek(1, 3);
          auto vec2 = peek(2, 3);
          auto the_result = at::addr(self, vec1, vec2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_85() { // affine_grid_generator
      auto size = readIntArrayRef("size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto theta = peek(0, 1);
          auto the_result = at::affine_grid_generator(theta, size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_86() { // affine_grid_generator_backward
      auto size = readIntArrayRef("size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 1);
          auto the_result = at::affine_grid_generator_backward(grad, size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_87() { // _is_all_true
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_is_all_true(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_88() { // _is_any_true
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_is_any_true(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_89() { // _test_check_tensor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_check_tensor(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_90() { // _test_functorch_fallback
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_test_functorch_fallback(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_91() { // all
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::all(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_92() { // all
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::all(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_93() { // all
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::all(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_94() { // allclose
      double rtol = readAttribute<float>("rtol");
      double atol = readAttribute<float>("atol");
      bool equal_nan = readAttribute<int64_t>("equal_nan");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::allclose(self, other, rtol, atol, equal_nan);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_95() { // allclose
      double rtol = readAttribute<float>("rtol");
      double atol = readAttribute<float>("atol");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::allclose(self, other, rtol, atol);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_96() { // allclose
      double rtol = readAttribute<float>("rtol");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::allclose(self, other, rtol);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_97() { // allclose
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::allclose(self, other);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_98() { // any
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::any(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_99() { // any
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::any(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_100() { // any
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::any(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_101() { // _dim_arange
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto like = peek(0, 1);
          auto the_result = at::_dim_arange(like, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_102() { // argmax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argmax(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_103() { // argmin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argmin(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_104() { // acosh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::acosh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_105() { // arccosh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arccosh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_106() { // asinh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::asinh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_107() { // arcsinh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arcsinh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_108() { // atanh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::atanh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_109() { // arctanh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arctanh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_110() { // as_strided
      auto size = readIntArrayRef("size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::as_strided(self, size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_111() { // asin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::asin(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_112() { // arcsin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arcsin(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_113() { // atan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::atan(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_114() { // arctan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::arctan(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_115() { // atleast_1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::atleast_1d(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_116() { // atleast_1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::atleast_1d(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_117() { // atleast_2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::atleast_2d(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_118() { // atleast_2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::atleast_2d(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_119() { // atleast_3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::atleast_3d(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_120() { // atleast_3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::atleast_3d(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_121() { // baddbmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::baddbmm(self, batch1, batch2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_122() { // baddbmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::baddbmm(self, batch1, batch2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_123() { // baddbmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::baddbmm(self, batch1, batch2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_124() { // batch_norm
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::batch_norm(input, weight, bias, running_mean, running_var, training, momentum, eps, cudnn_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_125() { // quantized_batch_norm
      double eps = readAttribute<float>("eps");
      double output_scale = readAttribute<float>("output_scale");
      int64_t output_zero_point = readAttribute<int64_t>("output_zero_point");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto mean = peek(3, 5);
          auto var = peek(4, 5);
          auto the_result = at::quantized_batch_norm(input, weight, bias, mean, var, eps, output_scale, output_zero_point);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_126() { // _batch_norm_impl_index
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::_batch_norm_impl_index(input, weight, bias, running_mean, running_var, training, momentum, eps, cudnn_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignToValue<int64_t>(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_127() { // _batch_norm_impl_index_backward
      int64_t impl_index = readAttribute<int64_t>("impl_index");
      bool train = readAttribute<int64_t>("train");
      double eps = readAttribute<float>("eps");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 8);
          auto grad_output = peek(1, 8);
          auto weight = peek(2, 8);
          auto running_mean = peek(3, 8);
          auto running_var = peek(4, 8);
          auto save_mean = peek(5, 8);
          auto save_var_transform = peek(6, 8);
          auto reservedSpace = peek(7, 8);
          auto the_result = at::_batch_norm_impl_index_backward(impl_index, input, grad_output, weight, running_mean, running_var, save_mean, save_var_transform, train, eps, output_mask, reservedSpace);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_128() { // bernoulli
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bernoulli(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_129() { // bernoulli
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bernoulli(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_130() { // bilinear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 4);
          auto input2 = peek(1, 4);
          auto weight = peek(2, 4);
          auto bias = peek(3, 4);
          auto the_result = at::bilinear(input1, input2, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_131() { // bilinear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::bilinear(input1, input2, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_132() { // binary_cross_entropy
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::binary_cross_entropy(self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_133() { // binary_cross_entropy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::binary_cross_entropy(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_134() { // binary_cross_entropy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::binary_cross_entropy(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_135() { // binary_cross_entropy_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 4);
          auto self = peek(1, 4);
          auto target = peek(2, 4);
          auto weight = peek(3, 4);
          auto the_result = at::binary_cross_entropy_backward(grad_output, self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_136() { // binary_cross_entropy_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 4);
          auto self = peek(1, 4);
          auto target = peek(2, 4);
          auto weight = peek(3, 4);
          auto the_result = at::binary_cross_entropy_backward(grad_output, self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_137() { // binary_cross_entropy_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::binary_cross_entropy_backward(grad_output, self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_138() { // binary_cross_entropy_with_logits
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto target = peek(1, 4);
          auto weight = peek(2, 4);
          auto pos_weight = peek(3, 4);
          auto the_result = at::binary_cross_entropy_with_logits(self, target, weight, pos_weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_139() { // binary_cross_entropy_with_logits
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto target = peek(1, 4);
          auto weight = peek(2, 4);
          auto pos_weight = peek(3, 4);
          auto the_result = at::binary_cross_entropy_with_logits(self, target, weight, pos_weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_140() { // binary_cross_entropy_with_logits
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::binary_cross_entropy_with_logits(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_141() { // binary_cross_entropy_with_logits
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::binary_cross_entropy_with_logits(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_142() { // bincount
      int64_t minlength = readAttribute<int64_t>("minlength");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weights = peek(1, 2);
          auto the_result = at::bincount(self, weights, minlength);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_143() { // bincount
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weights = peek(1, 2);
          auto the_result = at::bincount(self, weights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_144() { // bincount
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bincount(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_145() { // bitwise_not
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_not(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_146() { // copysign
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::copysign(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_147() { // copysign
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::copysign(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_148() { // _lazy_clone
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_lazy_clone(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_149() { // logical_not
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logical_not(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_150() { // logical_xor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::logical_xor(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_151() { // logical_and
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::logical_and(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_152() { // logical_or
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::logical_or(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_153() { // bmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::bmm(self, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_154() { // broadcast_tensors
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::broadcast_tensors(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_155() { // broadcast_to
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::broadcast_to(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_156() { // _sparse_broadcast_to
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_broadcast_to(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_157() { // cat
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::cat(tensors, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_158() { // cat
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::cat(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_159() { // concat
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::concat(tensors, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_160() { // concat
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::concat(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_161() { // concatenate
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::concatenate(tensors, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_162() { // concatenate
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::concatenate(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_163() { // block_diag
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::block_diag(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_164() { // ceil
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::ceil(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_165() { // chain_matmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto matrices = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::chain_matmul(matrices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_166() { // unsafe_chunk
      int64_t chunks = readAttribute<int64_t>("chunks");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_chunk(self, chunks, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_167() { // unsafe_chunk
      int64_t chunks = readAttribute<int64_t>("chunks");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_chunk(self, chunks);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_168() { // chunk
      int64_t chunks = readAttribute<int64_t>("chunks");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::chunk(self, chunks, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_169() { // chunk
      int64_t chunks = readAttribute<int64_t>("chunks");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::chunk(self, chunks);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_170() { // tensor_split
      int64_t sections = readAttribute<int64_t>("sections");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tensor_split(self, sections, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_171() { // tensor_split
      int64_t sections = readAttribute<int64_t>("sections");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tensor_split(self, sections);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_172() { // tensor_split
      auto indices = readIntArrayRef("indices");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tensor_split(self, indices, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_173() { // tensor_split
      auto indices = readIntArrayRef("indices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tensor_split(self, indices);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_174() { // tensor_split
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto tensor_indices_or_sections = peek(1, 2);
          auto the_result = at::tensor_split(self, tensor_indices_or_sections, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_175() { // tensor_split
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto tensor_indices_or_sections = peek(1, 2);
          auto the_result = at::tensor_split(self, tensor_indices_or_sections);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_176() { // clamp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::clamp(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_177() { // clamp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto min = peek(1, 3);
          auto max = peek(2, 3);
          auto the_result = at::clamp(self, min, max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_178() { // clamp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto min = peek(1, 2);
          auto the_result = at::clamp(self, min);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_179() { // clamp_max
      at::Scalar max = readScalarAttribute("max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::clamp_max(self, max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_180() { // clamp_max
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto max = peek(1, 2);
          auto the_result = at::clamp_max(self, max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_181() { // clamp_min
      at::Scalar min = readScalarAttribute("min");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::clamp_min(self, min);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_182() { // clamp_min
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto min = peek(1, 2);
          auto the_result = at::clamp_min(self, min);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_183() { // clip
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::clip(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_184() { // clip
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto min = peek(1, 3);
          auto max = peek(2, 3);
          auto the_result = at::clip(self, min, max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_185() { // clip
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto min = peek(1, 2);
          auto the_result = at::clip(self, min);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_186() { // cudnn_is_acceptable
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cudnn_is_acceptable(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_187() { // complex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto real = peek(0, 2);
          auto imag = peek(1, 2);
          auto the_result = at::complex(real, imag);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_188() { // polar
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto abs = peek(0, 2);
          auto angle = peek(1, 2);
          auto the_result = at::polar(abs, angle);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_189() { // constant_pad_nd
      auto pad = readIntArrayRef("pad");
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::constant_pad_nd(self, pad, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_190() { // constant_pad_nd
      auto pad = readIntArrayRef("pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::constant_pad_nd(self, pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_191() { // contiguous
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.contiguous();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_192() { // convolution
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::convolution(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_193() { // convolution_overrideable
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::convolution_overrideable(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_194() { // convolution_backward_overrideable
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto input = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::convolution_backward_overrideable(grad_output, input, weight, stride, padding, dilation, transposed, output_padding, groups, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_195() { // _convolution
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      bool allow_tf32 = readAttribute<int64_t>("allow_tf32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_convolution(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups, benchmark, deterministic, cudnn_enabled, allow_tf32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_196() { // _convolution
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_convolution(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups, benchmark, deterministic, cudnn_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_197() { // _convolution_double_backward
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool transposed = readAttribute<int64_t>("transposed");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto ggI = peek(0, 6);
          auto ggW = peek(1, 6);
          auto ggb = peek(2, 6);
          auto gO = peek(3, 6);
          auto weight = peek(4, 6);
          auto self = peek(5, 6);
          auto the_result = at::_convolution_double_backward(ggI, ggW, ggb, gO, weight, self, stride, padding, dilation, transposed, output_padding, groups, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_198() { // conv1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv1d(input, weight, bias, stride, padding, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_199() { // conv1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv1d(input, weight, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_200() { // conv1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv1d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_201() { // conv1d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv1d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_202() { // conv1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv1d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_203() { // conv1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv1d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_204() { // conv2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv2d(input, weight, bias, stride, padding, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_205() { // conv2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv2d(input, weight, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_206() { // conv2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv2d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_207() { // conv2d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv2d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_208() { // conv2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv2d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_209() { // conv2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv2d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_210() { // conv3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv3d(input, weight, bias, stride, padding, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_211() { // conv3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv3d(input, weight, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_212() { // conv3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv3d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_213() { // conv3d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv3d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_214() { // conv3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv3d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_215() { // conv3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv3d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_216() { // conv_tbc
      int64_t pad = readAttribute<int64_t>("pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_tbc(self, weight, bias, pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_217() { // conv_tbc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_tbc(self, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_218() { // conv_tbc_backward
      int64_t pad = readAttribute<int64_t>("pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto input = peek(1, 4);
          auto weight = peek(2, 4);
          auto bias = peek(3, 4);
          auto the_result = at::conv_tbc_backward(self, input, weight, bias, pad);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_219() { // conv_transpose1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding, groups, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_220() { // conv_transpose1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_221() { // conv_transpose1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_222() { // conv_transpose1d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_223() { // conv_transpose1d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_224() { // conv_transpose1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose1d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_225() { // conv_transpose1d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv_transpose1d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_226() { // conv_transpose2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding, groups, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_227() { // conv_transpose2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_228() { // conv_transpose2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_229() { // conv_transpose2d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_230() { // conv_transpose2d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_231() { // conv_transpose2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose2d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_232() { // conv_transpose2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv_transpose2d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_233() { // conv_transpose3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding, groups, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_234() { // conv_transpose3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_235() { // conv_transpose3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_236() { // conv_transpose3d
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_237() { // conv_transpose3d
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_238() { // conv_transpose3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_transpose3d(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_239() { // conv_transpose3d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::conv_transpose3d(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_240() { // copy
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::copy(self, src, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_241() { // copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::copy(self, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_242() { // _copy_from
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto dst = peek(1, 2);
          auto the_result = at::_copy_from(self, dst, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_243() { // _copy_from
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto dst = peek(1, 2);
          auto the_result = at::_copy_from(self, dst);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_244() { // _copy_from_and_resize
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto dst = peek(1, 2);
          auto the_result = at::_copy_from_and_resize(self, dst);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_245() { // cos
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cos(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_246() { // cosh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cosh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_247() { // cosine_embedding_loss
      double margin = readAttribute<float>("margin");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::cosine_embedding_loss(input1, input2, target, margin, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_248() { // cosine_embedding_loss
      double margin = readAttribute<float>("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::cosine_embedding_loss(input1, input2, target, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_249() { // cosine_embedding_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::cosine_embedding_loss(input1, input2, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_250() { // count_nonzero
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::count_nonzero(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_251() { // count_nonzero
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::count_nonzero(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_252() { // cov
      int64_t correction = readAttribute<int64_t>("correction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto fweights = peek(1, 3);
          auto aweights = peek(2, 3);
          auto the_result = at::cov(self, correction, fweights, aweights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_253() { // cov
      int64_t correction = readAttribute<int64_t>("correction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto fweights = peek(1, 2);
          auto the_result = at::cov(self, correction, fweights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_254() { // cov
      int64_t correction = readAttribute<int64_t>("correction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cov(self, correction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_255() { // cov
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cov(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_256() { // corrcoef
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::corrcoef(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_257() { // cudnn_affine_grid_generator
      int64_t N = readAttribute<int64_t>("N");
      int64_t C = readAttribute<int64_t>("C");
      int64_t H = readAttribute<int64_t>("H");
      int64_t W = readAttribute<int64_t>("W");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto theta = peek(0, 1);
          auto the_result = at::cudnn_affine_grid_generator(theta, N, C, H, W);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_258() { // cudnn_affine_grid_generator_backward
      int64_t N = readAttribute<int64_t>("N");
      int64_t C = readAttribute<int64_t>("C");
      int64_t H = readAttribute<int64_t>("H");
      int64_t W = readAttribute<int64_t>("W");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 1);
          auto the_result = at::cudnn_affine_grid_generator_backward(grad, N, C, H, W);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_259() { // cudnn_batch_norm
      bool training = readAttribute<int64_t>("training");
      double exponential_average_factor = readAttribute<float>("exponential_average_factor");
      double epsilon = readAttribute<float>("epsilon");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::cudnn_batch_norm(input, weight, bias, running_mean, running_var, training, exponential_average_factor, epsilon);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_260() { // cudnn_batch_norm_backward
      double epsilon = readAttribute<float>("epsilon");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 8);
          auto grad_output = peek(1, 8);
          auto weight = peek(2, 8);
          auto running_mean = peek(3, 8);
          auto running_var = peek(4, 8);
          auto save_mean = peek(5, 8);
          auto save_var = peek(6, 8);
          auto reserveSpace = peek(7, 8);
          auto the_result = at::cudnn_batch_norm_backward(input, grad_output, weight, running_mean, running_var, save_mean, save_var, epsilon, reserveSpace);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_261() { // cudnn_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool allow_tf32 = readAttribute<int64_t>("allow_tf32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::cudnn_convolution(self, weight, padding, stride, dilation, groups, benchmark, deterministic, allow_tf32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_262() { // cudnn_convolution_transpose
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      bool allow_tf32 = readAttribute<int64_t>("allow_tf32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::cudnn_convolution_transpose(self, weight, padding, output_padding, stride, dilation, groups, benchmark, deterministic, allow_tf32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_263() { // _mps_convolution_transpose
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::_mps_convolution_transpose(self, weight, padding, output_padding, stride, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_264() { // mps_convolution_transpose_backward
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      auto output_mask = readBoolMask<2>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto grad_output = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::mps_convolution_transpose_backward(self, grad_output, weight, padding, output_padding, stride, dilation, groups, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_265() { // cudnn_convolution_relu
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::cudnn_convolution_relu(self, weight, bias, stride, padding, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_266() { // cudnn_grid_sampler
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto grid = peek(1, 2);
          auto the_result = at::cudnn_grid_sampler(self, grid);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_267() { // cudnn_grid_sampler_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto grid = peek(1, 3);
          auto grad_output = peek(2, 3);
          auto the_result = at::cudnn_grid_sampler_backward(self, grid, grad_output);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_268() { // cummax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cummax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_269() { // cummin
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cummin(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_270() { // cummaxmin_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto input = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::cummaxmin_backward(grad, input, indices, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_271() { // cumprod
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cumprod(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_272() { // cumprod_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto input = peek(1, 3);
          auto output = peek(2, 3);
          auto the_result = at::cumprod_backward(grad, input, dim, output);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_273() { // cumsum
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cumsum(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_274() { // cumulative_trapezoid
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::cumulative_trapezoid(y, x, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_275() { // cumulative_trapezoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::cumulative_trapezoid(y, x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_276() { // cumulative_trapezoid
      at::Scalar dx = readScalarAttribute("dx");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::cumulative_trapezoid(y, dx, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_277() { // cumulative_trapezoid
      at::Scalar dx = readScalarAttribute("dx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::cumulative_trapezoid(y, dx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_278() { // cumulative_trapezoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::cumulative_trapezoid(y);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_279() { // ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      int64_t reduction = readAttribute<int64_t>("reduction");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_280() { // ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_281() { // ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_282() { // ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_283() { // ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      int64_t reduction = readAttribute<int64_t>("reduction");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_284() { // ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_285() { // ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_286() { // ctc_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_287() { // _ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_288() { // _ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_289() { // _ctc_loss
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 2);
          auto targets = peek(1, 2);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_290() { // _ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_291() { // _ctc_loss
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_292() { // _ctc_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto log_probs = peek(0, 4);
          auto targets = peek(1, 4);
          auto input_lengths = peek(2, 4);
          auto target_lengths = peek(3, 4);
          auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_293() { // _ctc_loss_backward
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 5);
          auto log_probs = peek(1, 5);
          auto targets = peek(2, 5);
          auto neg_log_likelihood = peek(3, 5);
          auto log_alpha = peek(4, 5);
          auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_294() { // _ctc_loss_backward
      auto input_lengths = readIntArrayRef("input_lengths");
      auto target_lengths = readIntArrayRef("target_lengths");
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 5);
          auto log_probs = peek(1, 5);
          auto targets = peek(2, 5);
          auto neg_log_likelihood = peek(3, 5);
          auto log_alpha = peek(4, 5);
          auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_295() { // _ctc_loss_backward
      int64_t blank = readAttribute<int64_t>("blank");
      bool zero_infinity = readAttribute<int64_t>("zero_infinity");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 7);
          auto log_probs = peek(1, 7);
          auto targets = peek(2, 7);
          auto input_lengths = peek(3, 7);
          auto target_lengths = peek(4, 7);
          auto neg_log_likelihood = peek(5, 7);
          auto log_alpha = peek(6, 7);
          auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank, zero_infinity);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_296() { // _ctc_loss_backward
      int64_t blank = readAttribute<int64_t>("blank");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 7);
          auto log_probs = peek(1, 7);
          auto targets = peek(2, 7);
          auto input_lengths = peek(3, 7);
          auto target_lengths = peek(4, 7);
          auto neg_log_likelihood = peek(5, 7);
          auto log_alpha = peek(6, 7);
          auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_297() { // diag_embed
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag_embed(self, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_298() { // diag_embed
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag_embed(self, offset, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_299() { // diag_embed
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag_embed(self, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_300() { // diag_embed
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag_embed(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_301() { // diagflat
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagflat(self, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_302() { // diagflat
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagflat(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_303() { // diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal(self, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_304() { // diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal(self, offset, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_305() { // diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal(self, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_306() { // diagonal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_307() { // linalg_diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_diagonal(A, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_308() { // linalg_diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_diagonal(A, offset, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_309() { // linalg_diagonal
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_diagonal(A, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_310() { // linalg_diagonal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_diagonal(A);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_311() { // diagonal_backward
      auto input_sizes = readIntArrayRef("input_sizes");
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::diagonal_backward(grad_output, input_sizes, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_312() { // diff
      int64_t n = readAttribute<int64_t>("n");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto prepend = peek(1, 3);
          auto append = peek(2, 3);
          auto the_result = at::diff(self, n, dim, prepend, append);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_313() { // diff
      int64_t n = readAttribute<int64_t>("n");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto prepend = peek(1, 2);
          auto the_result = at::diff(self, n, dim, prepend);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_314() { // diff
      int64_t n = readAttribute<int64_t>("n");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diff(self, n, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_315() { // diff
      int64_t n = readAttribute<int64_t>("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diff(self, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_316() { // diff
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diff(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_317() { // gradient
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gradient(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_318() { // gradient
      at::Scalar spacing = readScalarAttribute("spacing");
      auto dim = readIntArrayRef("dim");
      int64_t edge_order = readAttribute<int64_t>("edge_order");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gradient(self, spacing, dim, edge_order);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_319() { // gradient
      at::Scalar spacing = readScalarAttribute("spacing");
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gradient(self, spacing, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_320() { // gradient
      auto dim = readIntArrayRef("dim");
      int64_t edge_order = readAttribute<int64_t>("edge_order");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gradient(self, dim, edge_order);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_321() { // gradient
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gradient(self, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_322() { // gradient
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto spacing = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::gradient(self, spacing);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_323() { // gradient
      auto dim = readIntArrayRef("dim");
      int64_t edge_order = readAttribute<int64_t>("edge_order");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto spacing = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::gradient(self, spacing, dim, edge_order);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_324() { // gradient
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto spacing = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::gradient(self, spacing, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_325() { // div
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::div(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_326() { // div
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::div(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_327() { // divide
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_328() { // divide
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_329() { // true_divide
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::true_divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_330() { // true_divide
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::true_divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_331() { // dot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto tensor = peek(1, 2);
          auto the_result = at::dot(self, tensor);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_332() { // vdot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::vdot(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_333() { // embedding
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding(weight, indices, padding_idx, scale_grad_by_freq, sparse);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_334() { // embedding
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding(weight, indices, padding_idx, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_335() { // embedding
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding(weight, indices, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_336() { // embedding
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding(weight, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_337() { // embedding_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding_backward(grad, indices, num_weights, padding_idx, scale_grad_by_freq, sparse);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_338() { // embedding_dense_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding_dense_backward(grad_output, indices, num_weights, padding_idx, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_339() { // embedding_sparse_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding_sparse_backward(grad, indices, num_weights, padding_idx, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_340() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      bool include_last_offset = readAttribute<int64_t>("include_last_offset");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_341() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      bool include_last_offset = readAttribute<int64_t>("include_last_offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_342() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_343() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq, mode, sparse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_344() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq, mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_345() { // _embedding_bag_forward_only
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_346() { // _embedding_bag_forward_only
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag_forward_only(weight, indices, offsets);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_347() { // row_stack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::row_stack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_348() { // embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      bool include_last_offset = readAttribute<int64_t>("include_last_offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_349() { // embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_350() { // embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_351() { // embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_352() { // embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_353() { // embedding_bag
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::embedding_bag(weight, indices, offsets);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_354() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      bool include_last_offset = readAttribute<int64_t>("include_last_offset");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_355() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      bool include_last_offset = readAttribute<int64_t>("include_last_offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_356() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 4);
          auto indices = peek(1, 4);
          auto offsets = peek(2, 4);
          auto per_sample_weights = peek(3, 4);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_357() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_358() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_359() { // _embedding_bag
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_360() { // _embedding_bag
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 3);
          auto indices = peek(1, 3);
          auto offsets = peek(2, 3);
          auto the_result = at::_embedding_bag(weight, indices, offsets);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_361() { // _embedding_bag_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 7);
          auto indices = peek(1, 7);
          auto offsets = peek(2, 7);
          auto offset2bag = peek(3, 7);
          auto bag_size = peek(4, 7);
          auto maximum_indices = peek(5, 7);
          auto per_sample_weights = peek(6, 7);
          auto the_result = at::_embedding_bag_backward(grad, indices, offsets, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, sparse, per_sample_weights, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_362() { // _embedding_bag_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      bool sparse = readAttribute<int64_t>("sparse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 7);
          auto indices = peek(1, 7);
          auto offsets = peek(2, 7);
          auto offset2bag = peek(3, 7);
          auto bag_size = peek(4, 7);
          auto maximum_indices = peek(5, 7);
          auto per_sample_weights = peek(6, 7);
          auto the_result = at::_embedding_bag_backward(grad, indices, offsets, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, sparse, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_363() { // _embedding_bag_sparse_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 6);
          auto indices = peek(1, 6);
          auto offsets = peek(2, 6);
          auto offset2bag = peek(3, 6);
          auto bag_size = peek(4, 6);
          auto per_sample_weights = peek(5, 6);
          auto the_result = at::_embedding_bag_sparse_backward(grad, indices, offsets, offset2bag, bag_size, num_weights, scale_grad_by_freq, mode, per_sample_weights, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_364() { // _embedding_bag_sparse_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 6);
          auto indices = peek(1, 6);
          auto offsets = peek(2, 6);
          auto offset2bag = peek(3, 6);
          auto bag_size = peek(4, 6);
          auto per_sample_weights = peek(5, 6);
          auto the_result = at::_embedding_bag_sparse_backward(grad, indices, offsets, offset2bag, bag_size, num_weights, scale_grad_by_freq, mode, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_365() { // _embedding_bag_dense_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 6);
          auto indices = peek(1, 6);
          auto offset2bag = peek(2, 6);
          auto bag_size = peek(3, 6);
          auto maximum_indices = peek(4, 6);
          auto per_sample_weights = peek(5, 6);
          auto the_result = at::_embedding_bag_dense_backward(grad, indices, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, per_sample_weights, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_366() { // _embedding_bag_dense_backward
      int64_t num_weights = readAttribute<int64_t>("num_weights");
      bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 6);
          auto indices = peek(1, 6);
          auto offset2bag = peek(2, 6);
          auto bag_size = peek(3, 6);
          auto maximum_indices = peek(4, 6);
          auto per_sample_weights = peek(5, 6);
          auto the_result = at::_embedding_bag_dense_backward(grad, indices, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, per_sample_weights);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_367() { // _embedding_bag_per_sample_weights_backward
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t padding_idx = readAttribute<int64_t>("padding_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 5);
          auto weight = peek(1, 5);
          auto indices = peek(2, 5);
          auto offsets = peek(3, 5);
          auto offset2bag = peek(4, 5);
          auto the_result = at::_embedding_bag_per_sample_weights_backward(grad, weight, indices, offsets, offset2bag, mode, padding_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_368() { // _embedding_bag_per_sample_weights_backward
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 5);
          auto weight = peek(1, 5);
          auto indices = peek(2, 5);
          auto offsets = peek(3, 5);
          auto offset2bag = peek(4, 5);
          auto the_result = at::_embedding_bag_per_sample_weights_backward(grad, weight, indices, offsets, offset2bag, mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_369() { // erf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::erf(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_370() { // erfc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::erfc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_371() { // exp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::exp(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_372() { // exp2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::exp2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_373() { // expm1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::expm1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_374() { // expand
      auto size = readIntArrayRef("size");
      bool implicit = readAttribute<int64_t>("implicit");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.expand(size, implicit);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_375() { // expand
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.expand(size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_376() { // expand_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = self.expand_as(other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_377() { // flatten
      int64_t start_dim = readAttribute<int64_t>("start_dim");
      int64_t end_dim = readAttribute<int64_t>("end_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::flatten(self, start_dim, end_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_378() { // flatten
      int64_t start_dim = readAttribute<int64_t>("start_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::flatten(self, start_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_379() { // flatten
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::flatten(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_380() { // unflatten
      int64_t dim = readAttribute<int64_t>("dim");
      auto sizes = readIntArrayRef("sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unflatten(self, dim, sizes);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_381() { // fill
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fill(self, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_382() { // fill
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto value = peek(1, 2);
          auto the_result = at::fill(self, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_383() { // floor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::floor(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_384() { // floor_divide
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::floor_divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_385() { // floor_divide
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::floor_divide(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_386() { // frac
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::frac(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_387() { // gcd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::gcd(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_388() { // lcm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::lcm(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_389() { // grid_sampler
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto grid = peek(1, 2);
          auto the_result = at::grid_sampler(input, grid, interpolation_mode, padding_mode, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_390() { // grid_sampler_2d
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto grid = peek(1, 2);
          auto the_result = at::grid_sampler_2d(input, grid, interpolation_mode, padding_mode, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_391() { // grid_sampler_2d_backward
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      auto output_mask = readBoolMask<2>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto input = peek(1, 3);
          auto grid = peek(2, 3);
          auto the_result = at::grid_sampler_2d_backward(grad_output, input, grid, interpolation_mode, padding_mode, align_corners, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_392() { // _grid_sampler_2d_cpu_fallback
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto grid = peek(1, 2);
          auto the_result = at::_grid_sampler_2d_cpu_fallback(input, grid, interpolation_mode, padding_mode, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_393() { // _grid_sampler_2d_cpu_fallback_backward
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto input = peek(1, 3);
          auto grid = peek(2, 3);
          auto the_result = at::_grid_sampler_2d_cpu_fallback_backward(grad_output, input, grid, interpolation_mode, padding_mode, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_394() { // grid_sampler_3d
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto grid = peek(1, 2);
          auto the_result = at::grid_sampler_3d(input, grid, interpolation_mode, padding_mode, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_395() { // grid_sampler_3d_backward
      int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
      int64_t padding_mode = readAttribute<int64_t>("padding_mode");
      bool align_corners = readAttribute<int64_t>("align_corners");
      auto output_mask = readBoolMask<2>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto input = peek(1, 3);
          auto grid = peek(2, 3);
          auto the_result = at::grid_sampler_3d_backward(grad_output, input, grid, interpolation_mode, padding_mode, align_corners, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_396() { // hinge_embedding_loss
      double margin = readAttribute<float>("margin");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::hinge_embedding_loss(self, target, margin, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_397() { // hinge_embedding_loss
      double margin = readAttribute<float>("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::hinge_embedding_loss(self, target, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_398() { // hinge_embedding_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::hinge_embedding_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_399() { // group_norm
      int64_t num_groups = readAttribute<int64_t>("num_groups");
      double eps = readAttribute<float>("eps");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::group_norm(input, num_groups, weight, bias, eps, cudnn_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_400() { // group_norm
      int64_t num_groups = readAttribute<int64_t>("num_groups");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::group_norm(input, num_groups, weight, bias, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_401() { // group_norm
      int64_t num_groups = readAttribute<int64_t>("num_groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::group_norm(input, num_groups, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_402() { // group_norm
      int64_t num_groups = readAttribute<int64_t>("num_groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::group_norm(input, num_groups, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_403() { // group_norm
      int64_t num_groups = readAttribute<int64_t>("num_groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::group_norm(input, num_groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_404() { // native_group_norm
      int64_t N = readAttribute<int64_t>("N");
      int64_t C = readAttribute<int64_t>("C");
      int64_t HxW = readAttribute<int64_t>("HxW");
      int64_t group = readAttribute<int64_t>("group");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::native_group_norm(input, weight, bias, N, C, HxW, group, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_405() { // native_group_norm_backward
      int64_t N = readAttribute<int64_t>("N");
      int64_t C = readAttribute<int64_t>("C");
      int64_t HxW = readAttribute<int64_t>("HxW");
      int64_t group = readAttribute<int64_t>("group");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 5);
          auto input = peek(1, 5);
          auto mean = peek(2, 5);
          auto rstd = peek(3, 5);
          auto weight = peek(4, 5);
          auto the_result = at::native_group_norm_backward(grad_out, input, mean, rstd, weight, N, C, HxW, group, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_406() { // _fft_r2c
      auto dim = readIntArrayRef("dim");
      int64_t normalization = readAttribute<int64_t>("normalization");
      bool onesided = readAttribute<int64_t>("onesided");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_fft_r2c(self, dim, normalization, onesided);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_407() { // _fft_c2r
      auto dim = readIntArrayRef("dim");
      int64_t normalization = readAttribute<int64_t>("normalization");
      int64_t last_dim_size = readAttribute<int64_t>("last_dim_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_fft_c2r(self, dim, normalization, last_dim_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_408() { // _fft_c2c
      auto dim = readIntArrayRef("dim");
      int64_t normalization = readAttribute<int64_t>("normalization");
      bool forward = readAttribute<int64_t>("forward");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_fft_c2c(self, dim, normalization, forward);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_409() { // index
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 1, InputSize());
          auto the_result = internal::index_with_uint8_handling(self,indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_410() { // _unsafe_index
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 1, InputSize());
          auto the_result = at::_unsafe_index(self, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_411() { // index_copy
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::index_copy(self, dim, index, source);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_412() { // index_put
      bool accumulate = readAttribute<int64_t>("accumulate");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::index_put(self, indices, values, accumulate);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_413() { // index_put
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::index_put(self, indices, values);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_414() { // _unsafe_index_put
      bool accumulate = readAttribute<int64_t>("accumulate");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::_unsafe_index_put(self, indices, values, accumulate);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_415() { // _unsafe_index_put
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::_unsafe_index_put(self, indices, values);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_416() { // instance_norm
      bool use_input_stats = readAttribute<int64_t>("use_input_stats");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::instance_norm(input, weight, bias, running_mean, running_var, use_input_stats, momentum, eps, cudnn_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_417() { // isclose
      double rtol = readAttribute<float>("rtol");
      double atol = readAttribute<float>("atol");
      bool equal_nan = readAttribute<int64_t>("equal_nan");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::isclose(self, other, rtol, atol, equal_nan);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_418() { // isclose
      double rtol = readAttribute<float>("rtol");
      double atol = readAttribute<float>("atol");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::isclose(self, other, rtol, atol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_419() { // isclose
      double rtol = readAttribute<float>("rtol");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::isclose(self, other, rtol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_420() { // isclose
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::isclose(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_421() { // isin
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      bool invert = readAttribute<int64_t>("invert");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 2);
          auto test_elements = peek(1, 2);
          auto the_result = at::isin(elements, test_elements, assume_unique, invert);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_422() { // isin
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 2);
          auto test_elements = peek(1, 2);
          auto the_result = at::isin(elements, test_elements, assume_unique);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_423() { // isin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 2);
          auto test_elements = peek(1, 2);
          auto the_result = at::isin(elements, test_elements);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_424() { // isin
      at::Scalar test_element = readScalarAttribute("test_element");
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      bool invert = readAttribute<int64_t>("invert");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 1);
          auto the_result = at::isin(elements, test_element, assume_unique, invert);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_425() { // isin
      at::Scalar test_element = readScalarAttribute("test_element");
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 1);
          auto the_result = at::isin(elements, test_element, assume_unique);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_426() { // isin
      at::Scalar test_element = readScalarAttribute("test_element");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto elements = peek(0, 1);
          auto the_result = at::isin(elements, test_element);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_427() { // isin
      at::Scalar element = readScalarAttribute("element");
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      bool invert = readAttribute<int64_t>("invert");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto test_elements = peek(0, 1);
          auto the_result = at::isin(element, test_elements, assume_unique, invert);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_428() { // isin
      at::Scalar element = readScalarAttribute("element");
      bool assume_unique = readAttribute<int64_t>("assume_unique");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto test_elements = peek(0, 1);
          auto the_result = at::isin(element, test_elements, assume_unique);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_429() { // isin
      at::Scalar element = readScalarAttribute("element");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto test_elements = peek(0, 1);
          auto the_result = at::isin(element, test_elements);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_430() { // isnan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isnan(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_431() { // is_distributed
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_distributed(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_432() { // is_floating_point
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_floating_point(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_433() { // is_complex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_complex(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_434() { // is_conj
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_conj(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_435() { // _is_zerotensor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_is_zerotensor(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_436() { // is_neg
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_neg(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_437() { // isreal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isreal(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_438() { // is_nonzero
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_nonzero(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_439() { // is_same_size
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::is_same_size(self, other);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_440() { // is_signed
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_signed(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_441() { // is_inference
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::is_inference(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_442() { // kl_div
      int64_t reduction = readAttribute<int64_t>("reduction");
      bool log_target = readAttribute<int64_t>("log_target");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::kl_div(self, target, reduction, log_target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_443() { // kl_div
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::kl_div(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_444() { // kl_div
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::kl_div(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_445() { // kron
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::kron(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_446() { // kthvalue
      int64_t k = readAttribute<int64_t>("k");
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::kthvalue(self, k, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_447() { // kthvalue
      int64_t k = readAttribute<int64_t>("k");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::kthvalue(self, k, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_448() { // kthvalue
      int64_t k = readAttribute<int64_t>("k");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::kthvalue(self, k);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_449() { // layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      double eps = readAttribute<float>("eps");
      bool cudnn_enable = readAttribute<int64_t>("cudnn_enable");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::layer_norm(input, normalized_shape, weight, bias, eps, cudnn_enable);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_450() { // layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::layer_norm(input, normalized_shape, weight, bias, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_451() { // layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::layer_norm(input, normalized_shape, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_452() { // layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::layer_norm(input, normalized_shape, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_453() { // layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::layer_norm(input, normalized_shape);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_454() { // native_layer_norm
      auto normalized_shape = readIntArrayRef("normalized_shape");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::native_layer_norm(input, normalized_shape, weight, bias, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_455() { // native_layer_norm_backward
      auto normalized_shape = readIntArrayRef("normalized_shape");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 6);
          auto input = peek(1, 6);
          auto mean = peek(2, 6);
          auto rstd = peek(3, 6);
          auto weight = peek(4, 6);
          auto bias = peek(5, 6);
          auto the_result = at::native_layer_norm_backward(grad_out, input, normalized_shape, mean, rstd, weight, bias, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_456() { // nan_to_num
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nan_to_num(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_457() { // linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::linear(input, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_458() { // linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::linear(input, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_459() { // linear_backward
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto grad_output = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::linear_backward(self, grad_output, weight, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_460() { // mkldnn_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::mkldnn_linear(self, weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_461() { // mkldnn_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::mkldnn_linear(self, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_462() { // mkldnn_linear_backward_input
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::mkldnn_linear_backward_input(input_size, grad_output, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_463() { // mkldnn_linear_backward_weights
      bool bias_defined = readAttribute<int64_t>("bias_defined");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto input = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::mkldnn_linear_backward_weights(grad_output, input, weight, bias_defined);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_464() { // mkldnn_linear_backward
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto grad_output = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::mkldnn_linear_backward(self, grad_output, weight, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_465() { // _cslt_compress
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::_cslt_compress(input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_466() { // _cslt_sparse_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 4);
          auto dense_B = peek(1, 4);
          auto bias = peek(2, 4);
          auto alpha = peek(3, 4);
          auto the_result = at::_cslt_sparse_mm(compressed_A, dense_B, bias, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_467() { // _cslt_sparse_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 3);
          auto dense_B = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_cslt_sparse_mm(compressed_A, dense_B, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_468() { // _cslt_sparse_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 2);
          auto dense_B = peek(1, 2);
          auto the_result = at::_cslt_sparse_mm(compressed_A, dense_B);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_469() { // _cslt_sparse_mm_search
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 4);
          auto dense_B = peek(1, 4);
          auto bias = peek(2, 4);
          auto alpha = peek(3, 4);
          auto the_result = at::_cslt_sparse_mm_search(compressed_A, dense_B, bias, alpha);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_470() { // _cslt_sparse_mm_search
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 3);
          auto dense_B = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_cslt_sparse_mm_search(compressed_A, dense_B, bias);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_471() { // _cslt_sparse_mm_search
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto compressed_A = peek(0, 2);
          auto dense_B = peek(1, 2);
          auto the_result = at::_cslt_sparse_mm_search(compressed_A, dense_B);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_472() { // _sparse_semi_structured_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 4);
          auto weight = peek(1, 4);
          auto meta = peek(2, 4);
          auto bias = peek(3, 4);
          auto the_result = at::_sparse_semi_structured_linear(input, weight, meta, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_473() { // _sparse_semi_structured_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto meta = peek(2, 3);
          auto the_result = at::_sparse_semi_structured_linear(input, weight, meta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_474() { // _mixed_dtypes_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 4);
          auto weight = peek(1, 4);
          auto scale = peek(2, 4);
          auto bias = peek(3, 4);
          auto the_result = at::_mixed_dtypes_linear(input, weight, scale, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_475() { // _mixed_dtypes_linear
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto scale = peek(2, 3);
          auto the_result = at::_mixed_dtypes_linear(input, weight, scale);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_476() { // fbgemm_linear_int8_weight_fp32_activation
      at::Scalar weight_scale = readScalarAttribute("weight_scale");
      at::Scalar weight_zero_point = readScalarAttribute("weight_zero_point");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto packed = peek(2, 5);
          auto col_offsets = peek(3, 5);
          auto bias = peek(4, 5);
          auto the_result = at::fbgemm_linear_int8_weight_fp32_activation(input, weight, packed, col_offsets, weight_scale, weight_zero_point, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_477() { // fbgemm_linear_int8_weight
      at::Scalar weight_scale = readScalarAttribute("weight_scale");
      at::Scalar weight_zero_point = readScalarAttribute("weight_zero_point");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto packed = peek(2, 5);
          auto col_offsets = peek(3, 5);
          auto bias = peek(4, 5);
          auto the_result = at::fbgemm_linear_int8_weight(input, weight, packed, col_offsets, weight_scale, weight_zero_point, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_478() { // fbgemm_pack_gemm_matrix_fp16
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::fbgemm_pack_gemm_matrix_fp16(input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_479() { // fbgemm_linear_fp16_weight_fp32_activation
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto packed_weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::fbgemm_linear_fp16_weight_fp32_activation(input, packed_weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_480() { // fbgemm_linear_fp16_weight
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto packed_weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::fbgemm_linear_fp16_weight(input, packed_weight, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_481() { // fbgemm_pack_quantized_matrix
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::fbgemm_pack_quantized_matrix(input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_482() { // fbgemm_pack_quantized_matrix
      int64_t K = readAttribute<int64_t>("K");
      int64_t N = readAttribute<int64_t>("N");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::fbgemm_pack_quantized_matrix(input, K, N);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_483() { // ldexp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::ldexp(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_484() { // log
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_485() { // log10
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log10(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_486() { // log1p
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log1p(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_487() { // log2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_488() { // logaddexp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::logaddexp(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_489() { // logaddexp2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::logaddexp2(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_490() { // xlogy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_491() { // xlogy
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_492() { // xlogy
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_493() { // log_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_494() { // _log_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      bool half_to_float = readAttribute<int64_t>("half_to_float");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_log_softmax(self, dim, half_to_float);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_495() { // _logcumsumexp
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_logcumsumexp(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_496() { // logcumsumexp
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logcumsumexp(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_497() { // logsumexp
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logsumexp(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_498() { // logsumexp
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logsumexp(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_499() { // margin_ranking_loss
      double margin = readAttribute<float>("margin");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::margin_ranking_loss(input1, input2, target, margin, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_500() { // margin_ranking_loss
      double margin = readAttribute<float>("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::margin_ranking_loss(input1, input2, target, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_501() { // margin_ranking_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input1 = peek(0, 3);
          auto input2 = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::margin_ranking_loss(input1, input2, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_502() { // matmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::matmul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_503() { // matmul_backward
      auto mask = readBoolMask<2>("mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto self = peek(1, 3);
          auto other = peek(2, 3);
          auto the_result = at::matmul_backward(grad, self, other, mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_504() { // matrix_power
      int64_t n = readAttribute<int64_t>("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::matrix_power(self, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_505() { // matrix_exp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::matrix_exp(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_506() { // matrix_exp_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto grad = peek(1, 2);
          auto the_result = at::matrix_exp_backward(self, grad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_507() { // _aminmax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_aminmax(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_508() { // _aminmax
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_aminmax(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_509() { // _aminmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_aminmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_510() { // aminmax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::aminmax(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_511() { // _compute_linear_combination
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto coefficients = peek(1, 2);
          auto the_result = at::_compute_linear_combination(input, coefficients);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_512() { // max
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_513() { // max
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_514() { // value_selecting_reduction_backward
      int64_t dim = readAttribute<int64_t>("dim");
      auto sizes = readIntArrayRef("sizes");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::value_selecting_reduction_backward(grad, dim, indices, sizes, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_515() { // amax
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amax(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_516() { // amax
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_517() { // amax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amax(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_518() { // max_pool1d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_519() { // max_pool1d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_520() { // max_pool1d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_521() { // max_pool1d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_522() { // max_pool1d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d_with_indices(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_523() { // max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_524() { // max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_525() { // max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_526() { // max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_527() { // max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool1d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_528() { // max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_529() { // max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_530() { // max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_531() { // max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_532() { // max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_533() { // max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::max_pool2d_backward(grad_output, self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_534() { // max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::max_pool2d_backward(grad_output, self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_535() { // max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::max_pool2d_backward(grad_output, self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_536() { // max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::max_pool2d_backward(grad_output, self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_537() { // max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::max_pool2d_backward(grad_output, self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_538() { // mkldnn_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_539() { // mkldnn_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_540() { // mkldnn_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_541() { // mkldnn_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_542() { // mkldnn_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool2d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_543() { // mkldnn_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool2d_backward(grad_output, output, input, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_544() { // mkldnn_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool2d_backward(grad_output, output, input, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_545() { // mkldnn_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool2d_backward(grad_output, output, input, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_546() { // mkldnn_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool2d_backward(grad_output, output, input, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_547() { // mkldnn_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool2d_backward(grad_output, output, input, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_548() { // mkldnn_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool3d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_549() { // mkldnn_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool3d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_550() { // mkldnn_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool3d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_551() { // mkldnn_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool3d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_552() { // mkldnn_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_max_pool3d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_553() { // mkldnn_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool3d_backward(grad_output, output, input, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_554() { // mkldnn_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool3d_backward(grad_output, output, input, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_555() { // mkldnn_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool3d_backward(grad_output, output, input, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_556() { // mkldnn_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool3d_backward(grad_output, output, input, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_557() { // mkldnn_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto input = peek(2, 3);
          auto the_result = at::mkldnn_max_pool3d_backward(grad_output, output, input, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_558() { // quantized_max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool1d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_559() { // quantized_max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool1d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_560() { // quantized_max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool1d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_561() { // quantized_max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool1d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_562() { // quantized_max_pool1d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool1d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_563() { // quantized_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_564() { // quantized_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_565() { // quantized_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_566() { // quantized_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool2d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_567() { // quantized_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool2d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_568() { // quantized_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool3d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_569() { // quantized_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool3d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_570() { // quantized_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool3d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_571() { // quantized_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool3d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_572() { // quantized_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantized_max_pool3d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_573() { // max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_574() { // max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_575() { // max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_576() { // max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_577() { // max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_578() { // mean
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mean(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_579() { // nanmean
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nanmean(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_580() { // median
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::median(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_581() { // median
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::median(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_582() { // median
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::median(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_583() { // nanmedian
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nanmedian(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_584() { // nanmedian
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nanmedian(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_585() { // nanmedian
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nanmedian(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_586() { // min
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::min(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_587() { // min
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::min(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_588() { // amin
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amin(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_589() { // amin
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amin(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_590() { // amin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::amin(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_591() { // _mps_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_mps_convolution(self, weight, bias, padding, stride, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_592() { // mps_convolution_backward
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto grad_output = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::mps_convolution_backward(self, grad_output, weight, padding, stride, dilation, groups, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_593() { // mkldnn_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::mkldnn_convolution(self, weight, bias, padding, stride, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_594() { // mkldnn_rnn_layer
      bool reverse = readAttribute<int64_t>("reverse");
      auto batch_sizes = readIntArrayRef("batch_sizes");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t hidden_size = readAttribute<int64_t>("hidden_size");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      bool has_biases = readAttribute<int64_t>("has_biases");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      bool train = readAttribute<int64_t>("train");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 7);
          auto weight0 = peek(1, 7);
          auto weight1 = peek(2, 7);
          auto weight2 = peek(3, 7);
          auto weight3 = peek(4, 7);
          auto hx_ = peek(5, 7);
          auto cx_ = peek(6, 7);
          auto the_result = at::mkldnn_rnn_layer(input, weight0, weight1, weight2, weight3, hx_, cx_, reverse, batch_sizes, mode, hidden_size, num_layers, has_biases, bidirectional, batch_first, train);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_595() { // mkldnn_rnn_layer_backward
      bool reverse = readAttribute<int64_t>("reverse");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t hidden_size = readAttribute<int64_t>("hidden_size");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      bool has_biases = readAttribute<int64_t>("has_biases");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      auto batch_sizes = readIntArrayRef("batch_sizes");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 14);
          auto weight1 = peek(1, 14);
          auto weight2 = peek(2, 14);
          auto weight3 = peek(3, 14);
          auto weight4 = peek(4, 14);
          auto hx_ = peek(5, 14);
          auto cx_tmp = peek(6, 14);
          auto output = peek(7, 14);
          auto hy_ = peek(8, 14);
          auto cy_ = peek(9, 14);
          auto grad_output = peek(10, 14);
          auto grad_hy = peek(11, 14);
          auto grad_cy = peek(12, 14);
          auto workspace = peek(13, 14);
          auto the_result = at::mkldnn_rnn_layer_backward(input, weight1, weight2, weight3, weight4, hx_, cx_tmp, output, hy_, cy_, grad_output, grad_hy, grad_cy, reverse, mode, hidden_size, num_layers, has_biases, train, bidirectional, batch_sizes, batch_first, workspace);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
            if(OutputSize() > 5) {assignTo(Output(5),::std::get<5>(the_result));}
            if(OutputSize() > 6) {assignTo(Output(6),::std::get<6>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_596() { // miopen_batch_norm
      bool training = readAttribute<int64_t>("training");
      double exponential_average_factor = readAttribute<float>("exponential_average_factor");
      double epsilon = readAttribute<float>("epsilon");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::miopen_batch_norm(input, weight, bias, running_mean, running_var, training, exponential_average_factor, epsilon);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_597() { // miopen_batch_norm_backward
      double epsilon = readAttribute<float>("epsilon");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 7);
          auto grad_output = peek(1, 7);
          auto weight = peek(2, 7);
          auto running_mean = peek(3, 7);
          auto running_var = peek(4, 7);
          auto save_mean = peek(5, 7);
          auto save_var = peek(6, 7);
          auto the_result = at::miopen_batch_norm_backward(input, grad_output, weight, running_mean, running_var, save_mean, save_var, epsilon);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_598() { // miopen_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::miopen_convolution(self, weight, bias, padding, stride, dilation, groups, benchmark, deterministic);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_599() { // miopen_convolution_transpose
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::miopen_convolution_transpose(self, weight, bias, padding, output_padding, stride, dilation, groups, benchmark, deterministic);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_600() { // miopen_depthwise_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      bool benchmark = readAttribute<int64_t>("benchmark");
      bool deterministic = readAttribute<int64_t>("deterministic");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::miopen_depthwise_convolution(self, weight, bias, padding, stride, dilation, groups, benchmark, deterministic);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_601() { // miopen_convolution_relu
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::miopen_convolution_relu(self, weight, bias, stride, padding, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_602() { // miopen_rnn
      int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
      int64_t mode = readAttribute<int64_t>("mode");
      int64_t hidden_size = readAttribute<int64_t>("hidden_size");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      bool batch_first = readAttribute<int64_t>("batch_first");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      auto batch_sizes = readIntArrayRef("batch_sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto weight = peekSlice(1, InputSize() - 4, InputSize());
          auto hx = peek(1, 4);
          auto cx = peek(2, 4);
          auto dropout_state = peek(3, 4);
          auto the_result = at::miopen_rnn(input, weight, weight_stride0, hx, cx, mode, hidden_size, num_layers, batch_first, dropout, train, bidirectional, batch_sizes, dropout_state);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_603() { // mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::mm(self, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_604() { // _int_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::_int_mm(self, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_605() { // _convert_weight_to_int4pack
      int64_t innerKTiles = readAttribute<int64_t>("innerKTiles");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_convert_weight_to_int4pack(self, innerKTiles);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_606() { // _weight_int4pack_mm
      int64_t qGroupSize = readAttribute<int64_t>("qGroupSize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat2 = peek(1, 3);
          auto qScaleAndZeros = peek(2, 3);
          auto the_result = at::_weight_int4pack_mm(self, mat2, qGroupSize, qScaleAndZeros);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_607() { // _weight_int8pack_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat2 = peek(1, 3);
          auto scales = peek(2, 3);
          auto the_result = at::_weight_int8pack_mm(self, mat2, scales);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_608() { // _sparse_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sparse = peek(0, 2);
          auto dense = peek(1, 2);
          auto the_result = at::_sparse_mm(sparse, dense);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_609() { // _sparse_sparse_matmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_sparse_sparse_matmul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_610() { // mode
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mode(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_611() { // mode
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mode(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_612() { // mode
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mode(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_613() { // mul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::mul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_614() { // mul
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_615() { // multiply
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::multiply(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_616() { // multiply
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::multiply(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_617() { // mv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto vec = peek(1, 2);
          auto the_result = at::mv(self, vec);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_618() { // mvlgamma
      int64_t p = readAttribute<int64_t>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mvlgamma(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_619() { // narrow_copy
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t start = readAttribute<int64_t>("start");
      int64_t length = readAttribute<int64_t>("length");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::narrow_copy(self, dim, start, length);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_620() { // narrow
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t start = readAttribute<int64_t>("start");
      int64_t length = readAttribute<int64_t>("length");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::narrow(self, dim, start, length);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_621() { // narrow
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t length = readAttribute<int64_t>("length");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto start = peek(1, 2);
          auto the_result = at::narrow(self, dim, start, length);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_622() { // native_batch_norm
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::native_batch_norm(input, weight, bias, running_mean, running_var, training, momentum, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_623() { // _native_batch_norm_legit
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::_native_batch_norm_legit(input, weight, bias, running_mean, running_var, training, momentum, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_624() { // _native_batch_norm_legit_no_training
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::_native_batch_norm_legit_no_training(input, weight, bias, running_mean, running_var, momentum, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_625() { // _native_batch_norm_legit
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_native_batch_norm_legit(input, weight, bias, training, momentum, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_626() { // batch_norm_stats
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::batch_norm_stats(input, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_627() { // batch_norm_elemt
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto mean = peek(3, 5);
          auto invstd = peek(4, 5);
          auto the_result = at::batch_norm_elemt(input, weight, bias, mean, invstd, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_628() { // batch_norm_gather_stats
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      int64_t count = readAttribute<int64_t>("count");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto mean = peek(1, 5);
          auto invstd = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::batch_norm_gather_stats(input, mean, invstd, running_mean, running_var, momentum, eps, count);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_629() { // batch_norm_gather_stats_with_counts
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 6);
          auto mean = peek(1, 6);
          auto invstd = peek(2, 6);
          auto running_mean = peek(3, 6);
          auto running_var = peek(4, 6);
          auto counts = peek(5, 6);
          auto the_result = at::batch_norm_gather_stats_with_counts(input, mean, invstd, running_mean, running_var, momentum, eps, counts);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_630() { // native_batch_norm_backward
      bool train = readAttribute<int64_t>("train");
      double eps = readAttribute<float>("eps");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 7);
          auto input = peek(1, 7);
          auto weight = peek(2, 7);
          auto running_mean = peek(3, 7);
          auto running_var = peek(4, 7);
          auto save_mean = peek(5, 7);
          auto save_invstd = peek(6, 7);
          auto the_result = at::native_batch_norm_backward(grad_out, input, weight, running_mean, running_var, save_mean, save_invstd, train, eps, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_631() { // batch_norm_backward_reduce
      bool input_g = readAttribute<int64_t>("input_g");
      bool weight_g = readAttribute<int64_t>("weight_g");
      bool bias_g = readAttribute<int64_t>("bias_g");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 5);
          auto input = peek(1, 5);
          auto mean = peek(2, 5);
          auto invstd = peek(3, 5);
          auto weight = peek(4, 5);
          auto the_result = at::batch_norm_backward_reduce(grad_out, input, mean, invstd, weight, input_g, weight_g, bias_g);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_632() { // batch_norm_backward_elemt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 8);
          auto input = peek(1, 8);
          auto mean = peek(2, 8);
          auto invstd = peek(3, 8);
          auto weight = peek(4, 8);
          auto sum_dy = peek(5, 8);
          auto sum_dy_xmu = peek(6, 8);
          auto count = peek(7, 8);
          auto the_result = at::batch_norm_backward_elemt(grad_out, input, mean, invstd, weight, sum_dy, sum_dy_xmu, count);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_633() { // batch_norm_update_stats
      double momentum = readAttribute<float>("momentum");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto running_mean = peek(1, 3);
          auto running_var = peek(2, 3);
          auto the_result = at::batch_norm_update_stats(input, running_mean, running_var, momentum);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_634() { // is_vulkan_available
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
  
          auto the_result = at::is_vulkan_available();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_635() { // _nnpack_available
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
  
          auto the_result = at::_nnpack_available();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_636() { // _nnpack_spatial_convolution
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_nnpack_spatial_convolution(input, weight, bias, padding, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_637() { // _nnpack_spatial_convolution
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_nnpack_spatial_convolution(input, weight, bias, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_638() { // pairwise_distance
      double p = readAttribute<float>("p");
      double eps = readAttribute<float>("eps");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::pairwise_distance(x1, x2, p, eps, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_639() { // pairwise_distance
      double p = readAttribute<float>("p");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::pairwise_distance(x1, x2, p, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_640() { // pairwise_distance
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::pairwise_distance(x1, x2, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_641() { // pairwise_distance
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::pairwise_distance(x1, x2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_642() { // cdist
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::cdist(x1, x2, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_643() { // cdist
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::cdist(x1, x2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_644() { // _euclidean_dist
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::_euclidean_dist(x1, x2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_645() { // _cdist_backward
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 4);
          auto x1 = peek(1, 4);
          auto x2 = peek(2, 4);
          auto cdist = peek(3, 4);
          auto the_result = at::_cdist_backward(grad, x1, x2, p, cdist);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_646() { // pdist
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pdist(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_647() { // pdist
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pdist(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_648() { // _pdist_forward
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_pdist_forward(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_649() { // _pdist_forward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_pdist_forward(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_650() { // _pdist_backward
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto self = peek(1, 3);
          auto pdist = peek(2, 3);
          auto the_result = at::_pdist_backward(grad, self, p, pdist);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_651() { // cosine_similarity
      int64_t dim = readAttribute<int64_t>("dim");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::cosine_similarity(x1, x2, dim, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_652() { // cosine_similarity
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::cosine_similarity(x1, x2, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_653() { // cosine_similarity
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x1 = peek(0, 2);
          auto x2 = peek(1, 2);
          auto the_result = at::cosine_similarity(x1, x2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_654() { // permute
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::permute(self, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_655() { // movedim
      auto source = readIntArrayRef("source");
      auto destination = readIntArrayRef("destination");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::movedim(self, source, destination);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_656() { // moveaxis
      auto source = readIntArrayRef("source");
      auto destination = readIntArrayRef("destination");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::moveaxis(self, source, destination);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_657() { // numpy_T
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.numpy_T();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_658() { // matrix_H
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.matrix_H();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_659() { // mT
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.mT();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_660() { // mH
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.mH();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_661() { // adjoint
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adjoint(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_662() { // pixel_shuffle
      int64_t upscale_factor = readAttribute<int64_t>("upscale_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pixel_shuffle(self, upscale_factor);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_663() { // pixel_unshuffle
      int64_t downscale_factor = readAttribute<int64_t>("downscale_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pixel_unshuffle(self, downscale_factor);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_664() { // channel_shuffle
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::channel_shuffle(self, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_665() { // native_channel_shuffle
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::native_channel_shuffle(self, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_666() { // is_pinned
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.is_pinned();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_667() { // pin_memory
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.pin_memory();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_668() { // _pin_memory
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_pin_memory(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_669() { // pinverse
      double rcond = readAttribute<float>("rcond");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pinverse(self, rcond);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_670() { // pinverse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pinverse(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_671() { // poisson_nll_loss
      bool log_input = readAttribute<int64_t>("log_input");
      bool full = readAttribute<int64_t>("full");
      double eps = readAttribute<float>("eps");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::poisson_nll_loss(input, target, log_input, full, eps, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_672() { // rad2deg
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rad2deg(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_673() { // deg2rad
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::deg2rad(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_674() { // ravel
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::ravel(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_675() { // reciprocal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::reciprocal(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_676() { // neg
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::neg(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_677() { // negative
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::negative(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_678() { // repeat
      auto repeats = readIntArrayRef("repeats");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.repeat(repeats);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_679() { // repeat_interleave
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto repeats = peek(0, 1);
          auto the_result = at::repeat_interleave(repeats);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_680() { // repeat_interleave
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto repeats = peek(1, 2);
          auto the_result = at::repeat_interleave(self, repeats);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_681() { // repeat_interleave
      int64_t repeats = readAttribute<int64_t>("repeats");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::repeat_interleave(self, repeats);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_682() { // reshape
      auto shape = readIntArrayRef("shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::reshape(self, shape);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_683() { // _reshape_copy
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_reshape_copy(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_684() { // _reshape_alias
      auto size = readIntArrayRef("size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_reshape_alias(self, size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_685() { // _mkldnn_reshape
      auto shape = readIntArrayRef("shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_mkldnn_reshape(self, shape);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_686() { // reshape_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = self.reshape_as(other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_687() { // round
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::round(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_688() { // round
      int64_t decimals = readAttribute<int64_t>("decimals");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::round(self, decimals);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_689() { // rrelu
      at::Scalar lower = readScalarAttribute("lower");
      at::Scalar upper = readScalarAttribute("upper");
      bool training = readAttribute<int64_t>("training");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rrelu(self, lower, upper, training);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_690() { // rrelu
      at::Scalar lower = readScalarAttribute("lower");
      at::Scalar upper = readScalarAttribute("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rrelu(self, lower, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_691() { // rrelu
      at::Scalar lower = readScalarAttribute("lower");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rrelu(self, lower);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_692() { // rrelu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rrelu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_693() { // relu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::relu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_694() { // relu6
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::relu6(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_695() { // prelu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::prelu(self, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_696() { // _prelu_kernel
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::_prelu_kernel(self, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_697() { // _prelu_kernel_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::_prelu_kernel_backward(grad_output, self, weight);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_698() { // gelu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gelu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_699() { // gelu_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::gelu_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_700() { // infinitely_differentiable_gelu_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::infinitely_differentiable_gelu_backward(grad, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_701() { // hardshrink
      at::Scalar lambd = readScalarAttribute("lambd");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardshrink(self, lambd);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_702() { // hardshrink
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardshrink(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_703() { // hardshrink_backward
      at::Scalar lambd = readScalarAttribute("lambd");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::hardshrink_backward(grad_out, self, lambd);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_704() { // rsqrt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rsqrt(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_705() { // select
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t index = readAttribute<int64_t>("index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::select(self, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_706() { // select_backward
      auto input_sizes = readIntArrayRef("input_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t index = readAttribute<int64_t>("index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::select_backward(grad_output, input_sizes, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_707() { // _nested_select_backward
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t index = readAttribute<int64_t>("index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::_nested_select_backward(grad_output, self, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_708() { // selu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::selu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_709() { // celu
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::celu(self, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_710() { // celu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::celu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_711() { // silu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::silu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_712() { // silu_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::silu_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_713() { // mish
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mish(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_714() { // mish_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::mish_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_715() { // sigmoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sigmoid(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_716() { // logit
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logit(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_717() { // sin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sin(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_718() { // sinc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sinc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_719() { // sinh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sinh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_720() { // detach
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::detach(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_721() { // size
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::size(self, dim);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_722() { // slice
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::slice(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_723() { // slice
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::slice(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_724() { // slice_backward
      auto input_sizes = readIntArrayRef("input_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t start = readAttribute<int64_t>("start");
      int64_t end = readAttribute<int64_t>("end");
      int64_t step = readAttribute<int64_t>("step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::slice_backward(grad_output, input_sizes, dim, start, end, step);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_725() { // slice_inverse
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::slice_inverse(self, src, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_726() { // slice_inverse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::slice_inverse(self, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_727() { // slice_scatter
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::slice_scatter(self, src, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_728() { // slice_scatter
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::slice_scatter(self, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_729() { // select_scatter
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t index = readAttribute<int64_t>("index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::select_scatter(self, src, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_730() { // diagonal_scatter
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::diagonal_scatter(self, src, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_731() { // diagonal_scatter
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::diagonal_scatter(self, src, offset, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_732() { // diagonal_scatter
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::diagonal_scatter(self, src, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_733() { // diagonal_scatter
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::diagonal_scatter(self, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_734() { // as_strided_scatter
      auto size = readIntArrayRef("size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::as_strided_scatter(self, src, size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_735() { // smm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::smm(self, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_736() { // softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_737() { // _softmax
      int64_t dim = readAttribute<int64_t>("dim");
      bool half_to_float = readAttribute<int64_t>("half_to_float");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_softmax(self, dim, half_to_float);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_738() { // unsafe_split
      int64_t split_size = readAttribute<int64_t>("split_size");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_split(self, split_size, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_739() { // unsafe_split
      int64_t split_size = readAttribute<int64_t>("split_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_split(self, split_size);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_740() { // split
      int64_t split_size = readAttribute<int64_t>("split_size");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split(self, split_size, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_741() { // split
      int64_t split_size = readAttribute<int64_t>("split_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split(self, split_size);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_742() { // unsafe_split_with_sizes
      auto split_sizes = readIntArrayRef("split_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_split_with_sizes(self, split_sizes, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_743() { // unsafe_split_with_sizes
      auto split_sizes = readIntArrayRef("split_sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsafe_split_with_sizes(self, split_sizes);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_744() { // split_with_sizes
      auto split_sizes = readIntArrayRef("split_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_with_sizes(self, split_sizes, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_745() { // split_with_sizes
      auto split_sizes = readIntArrayRef("split_sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_with_sizes(self, split_sizes);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_746() { // hsplit
      int64_t sections = readAttribute<int64_t>("sections");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hsplit(self, sections);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_747() { // hsplit
      auto indices = readIntArrayRef("indices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hsplit(self, indices);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_748() { // vsplit
      int64_t sections = readAttribute<int64_t>("sections");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::vsplit(self, sections);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_749() { // vsplit
      auto indices = readIntArrayRef("indices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::vsplit(self, indices);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_750() { // dsplit
      int64_t sections = readAttribute<int64_t>("sections");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::dsplit(self, sections);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_751() { // dsplit
      auto indices = readIntArrayRef("indices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::dsplit(self, indices);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_752() { // squeeze
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::squeeze(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_753() { // squeeze
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::squeeze(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_754() { // sspaddmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sspaddmm(self, mat1, mat2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_755() { // sspaddmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sspaddmm(self, mat1, mat2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_756() { // sspaddmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sspaddmm(self, mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_757() { // _chunk_cat
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t num_chunks = readAttribute<int64_t>("num_chunks");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_chunk_cat(tensors, dim, num_chunks);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_758() { // stack
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::stack(tensors, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_759() { // stack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::stack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_760() { // _stack
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_stack(tensors, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_761() { // _stack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_stack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_762() { // hstack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::hstack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_763() { // vstack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::vstack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_764() { // dstack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::dstack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_765() { // stft
      int64_t n_fft = readAttribute<int64_t>("n_fft");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::stft(self, n_fft);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_766() { // istft
      int64_t n_fft = readAttribute<int64_t>("n_fft");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::istft(self, n_fft);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_767() { // stride
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::stride(self, dim);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_768() { // sum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sum(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_769() { // nansum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nansum(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_770() { // sum_to_size
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.sum_to_size(size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_771() { // sqrt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sqrt(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_772() { // square
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::square(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_773() { // std
      bool unbiased = readAttribute<int64_t>("unbiased");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::std(self, unbiased);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_774() { // std
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::std(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_775() { // std_mean
      bool unbiased = readAttribute<int64_t>("unbiased");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::std_mean(self, unbiased);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_776() { // std_mean
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::std_mean(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_777() { // prod
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::prod(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_778() { // prod
      int64_t dim = readAttribute<int64_t>("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::prod(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_779() { // prod
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::prod(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_780() { // t
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::t(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_781() { // tan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tan(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_782() { // tanh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tanh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_783() { // tensordot
      auto dims_self = readIntArrayRef("dims_self");
      auto dims_other = readIntArrayRef("dims_other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::tensordot(self, other, dims_self, dims_other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_784() { // threshold
      at::Scalar threshold = readScalarAttribute("threshold");
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::threshold(self, threshold, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_785() { // threshold_backward
      at::Scalar threshold = readScalarAttribute("threshold");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::threshold_backward(grad_output, self, threshold);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_786() { // tile
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tile(self, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_787() { // transpose
      int64_t dim0 = readAttribute<int64_t>("dim0");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::transpose(self, dim0, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_788() { // _mkldnn_transpose
      int64_t dim0 = readAttribute<int64_t>("dim0");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_mkldnn_transpose(self, dim0, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_789() { // one_hot
      int64_t num_classes = readAttribute<int64_t>("num_classes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::one_hot(self, num_classes);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_790() { // one_hot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::one_hot(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_791() { // flip
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::flip(self, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_792() { // fliplr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fliplr(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_793() { // flipud
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::flipud(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_794() { // roll
      auto shifts = readIntArrayRef("shifts");
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::roll(self, shifts, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_795() { // roll
      auto shifts = readIntArrayRef("shifts");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::roll(self, shifts);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_796() { // rot90
      int64_t k = readAttribute<int64_t>("k");
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rot90(self, k, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_797() { // rot90
      int64_t k = readAttribute<int64_t>("k");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rot90(self, k);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_798() { // rot90
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rot90(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_799() { // trapezoid
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::trapezoid(y, x, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_800() { // trapezoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::trapezoid(y, x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_801() { // trapezoid
      at::Scalar dx = readScalarAttribute("dx");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapezoid(y, dx, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_802() { // trapezoid
      at::Scalar dx = readScalarAttribute("dx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapezoid(y, dx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_803() { // trapezoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapezoid(y);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_804() { // trapz
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::trapz(y, x, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_805() { // trapz
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 2);
          auto x = peek(1, 2);
          auto the_result = at::trapz(y, x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_806() { // trapz
      double dx = readAttribute<float>("dx");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapz(y, dx, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_807() { // trapz
      double dx = readAttribute<float>("dx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapz(y, dx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_808() { // trapz
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto y = peek(0, 1);
          auto the_result = at::trapz(y);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_809() { // _transform_bias_rescale_qkv
      int64_t num_heads = readAttribute<int64_t>("num_heads");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto qkv = peek(0, 2);
          auto qkv_bias = peek(1, 2);
          auto the_result = at::_transform_bias_rescale_qkv(qkv, qkv_bias, num_heads);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_810() { // _nested_tensor_from_mask
      bool mask_check = readAttribute<int64_t>("mask_check");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto t = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::_nested_tensor_from_mask(t, mask, mask_check);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_811() { // _nested_tensor_from_mask
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto t = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::_nested_tensor_from_mask(t, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_812() { // _nested_tensor_from_mask_left_aligned
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto t = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::_nested_tensor_from_mask_left_aligned(t, mask);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_813() { // _nested_from_padded
      bool fuse_transform_0213 = readAttribute<int64_t>("fuse_transform_0213");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto padded = peek(0, 2);
          auto cpu_nested_shape_example = peek(1, 2);
          auto the_result = at::_nested_from_padded(padded, cpu_nested_shape_example, fuse_transform_0213);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_814() { // _nested_from_padded
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto padded = peek(0, 2);
          auto cpu_nested_shape_example = peek(1, 2);
          auto the_result = at::_nested_from_padded(padded, cpu_nested_shape_example);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_815() { // _nested_tensor_size
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._nested_tensor_size();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_816() { // _nested_tensor_strides
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._nested_tensor_strides();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_817() { // _nested_tensor_storage_offsets
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._nested_tensor_storage_offsets();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_818() { // _nested_from_padded_and_nested_example
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto padded = peek(0, 2);
          auto nt_example = peek(1, 2);
          auto the_result = at::_nested_from_padded_and_nested_example(padded, nt_example);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_819() { // _nested_view_from_buffer
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto nested_size = peek(1, 4);
          auto nested_strides = peek(2, 4);
          auto offsets = peek(3, 4);
          auto the_result = at::_nested_view_from_buffer(self, nested_size, nested_strides, offsets);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_820() { // _nested_view_from_buffer_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto nested_size = peek(1, 4);
          auto nested_strides = peek(2, 4);
          auto offsets = peek(3, 4);
          auto the_result = at::_nested_view_from_buffer_copy(self, nested_size, nested_strides, offsets);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_821() { // _nested_view_from_jagged
      int64_t ragged_idx = readAttribute<int64_t>("ragged_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto offsets = peek(1, 4);
          auto dummy = peek(2, 4);
          auto lengths = peek(3, 4);
          auto the_result = at::_nested_view_from_jagged(self, offsets, dummy, lengths, ragged_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_822() { // _nested_view_from_jagged
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto offsets = peek(1, 4);
          auto dummy = peek(2, 4);
          auto lengths = peek(3, 4);
          auto the_result = at::_nested_view_from_jagged(self, offsets, dummy, lengths);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_823() { // _nested_view_from_jagged
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto offsets = peek(1, 3);
          auto dummy = peek(2, 3);
          auto the_result = at::_nested_view_from_jagged(self, offsets, dummy);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_824() { // _nested_view_from_jagged_copy
      int64_t ragged_idx = readAttribute<int64_t>("ragged_idx");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto offsets = peek(1, 4);
          auto dummy = peek(2, 4);
          auto lengths = peek(3, 4);
          auto the_result = at::_nested_view_from_jagged_copy(self, offsets, dummy, lengths, ragged_idx);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_825() { // _nested_view_from_jagged_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto offsets = peek(1, 4);
          auto dummy = peek(2, 4);
          auto lengths = peek(3, 4);
          auto the_result = at::_nested_view_from_jagged_copy(self, offsets, dummy, lengths);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_826() { // _nested_view_from_jagged_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto offsets = peek(1, 3);
          auto dummy = peek(2, 3);
          auto the_result = at::_nested_view_from_jagged_copy(self, offsets, dummy);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_827() { // _nested_get_values
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_nested_get_values(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_828() { // _nested_get_values_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_nested_get_values_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_829() { // _nested_get_offsets
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_nested_get_offsets(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_830() { // _nested_get_lengths
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_nested_get_lengths(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_831() { // _nested_get_ragged_idx
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_nested_get_ragged_idx(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_832() { // _nested_get_jagged_dummy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto any = peek(0, 1);
          auto the_result = at::_nested_get_jagged_dummy(any);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_833() { // _trilinear
      auto expand1 = readIntArrayRef("expand1");
      auto expand2 = readIntArrayRef("expand2");
      auto expand3 = readIntArrayRef("expand3");
      auto sumdim = readIntArrayRef("sumdim");
      int64_t unroll_dim = readAttribute<int64_t>("unroll_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto i1 = peek(0, 3);
          auto i2 = peek(1, 3);
          auto i3 = peek(2, 3);
          auto the_result = at::_trilinear(i1, i2, i3, expand1, expand2, expand3, sumdim, unroll_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_834() { // _trilinear
      auto expand1 = readIntArrayRef("expand1");
      auto expand2 = readIntArrayRef("expand2");
      auto expand3 = readIntArrayRef("expand3");
      auto sumdim = readIntArrayRef("sumdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto i1 = peek(0, 3);
          auto i2 = peek(1, 3);
          auto i3 = peek(2, 3);
          auto the_result = at::_trilinear(i1, i2, i3, expand1, expand2, expand3, sumdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_835() { // triplet_margin_loss
      double margin = readAttribute<float>("margin");
      double p = readAttribute<float>("p");
      double eps = readAttribute<float>("eps");
      bool swap = readAttribute<int64_t>("swap");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps, swap, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_836() { // triplet_margin_loss
      double margin = readAttribute<float>("margin");
      double p = readAttribute<float>("p");
      double eps = readAttribute<float>("eps");
      bool swap = readAttribute<int64_t>("swap");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps, swap);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_837() { // triplet_margin_loss
      double margin = readAttribute<float>("margin");
      double p = readAttribute<float>("p");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_838() { // triplet_margin_loss
      double margin = readAttribute<float>("margin");
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_839() { // triplet_margin_loss
      double margin = readAttribute<float>("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_840() { // triplet_margin_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto anchor = peek(0, 3);
          auto positive = peek(1, 3);
          auto negative = peek(2, 3);
          auto the_result = at::triplet_margin_loss(anchor, positive, negative);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_841() { // trunc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::trunc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_842() { // fix
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fix(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_843() { // type_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = self.type_as(other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_844() { // _has_compatible_shallow_copy_type
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto from = peek(1, 2);
          auto the_result = at::_has_compatible_shallow_copy_type(self, from);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_845() { // _unique
      bool sorted = readAttribute<int64_t>("sorted");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique(self, sorted, return_inverse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_846() { // _unique
      bool sorted = readAttribute<int64_t>("sorted");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique(self, sorted);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_847() { // _unique
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_848() { // unique_dim
      int64_t dim = readAttribute<int64_t>("dim");
      bool sorted = readAttribute<int64_t>("sorted");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      bool return_counts = readAttribute<int64_t>("return_counts");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim(self, dim, sorted, return_inverse, return_counts);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_849() { // unique_dim
      int64_t dim = readAttribute<int64_t>("dim");
      bool sorted = readAttribute<int64_t>("sorted");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim(self, dim, sorted, return_inverse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_850() { // unique_dim
      int64_t dim = readAttribute<int64_t>("dim");
      bool sorted = readAttribute<int64_t>("sorted");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim(self, dim, sorted);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_851() { // unique_dim
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_852() { // unique_consecutive
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      bool return_counts = readAttribute<int64_t>("return_counts");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_consecutive(self, return_inverse, return_counts);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_853() { // unique_consecutive
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_consecutive(self, return_inverse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_854() { // unique_consecutive
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_consecutive(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_855() { // unique_dim_consecutive
      int64_t dim = readAttribute<int64_t>("dim");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      bool return_counts = readAttribute<int64_t>("return_counts");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim_consecutive(self, dim, return_inverse, return_counts);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_856() { // unique_dim_consecutive
      int64_t dim = readAttribute<int64_t>("dim");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim_consecutive(self, dim, return_inverse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_857() { // unique_dim_consecutive
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unique_dim_consecutive(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_858() { // _unique2
      bool sorted = readAttribute<int64_t>("sorted");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      bool return_counts = readAttribute<int64_t>("return_counts");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique2(self, sorted, return_inverse, return_counts);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_859() { // _unique2
      bool sorted = readAttribute<int64_t>("sorted");
      bool return_inverse = readAttribute<int64_t>("return_inverse");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique2(self, sorted, return_inverse);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_860() { // _unique2
      bool sorted = readAttribute<int64_t>("sorted");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique2(self, sorted);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_861() { // _unique2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unique2(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_862() { // _unsafe_view
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_unsafe_view(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_863() { // unsqueeze
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsqueeze(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_864() { // vander
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::vander(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_865() { // var
      bool unbiased = readAttribute<int64_t>("unbiased");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::var(self, unbiased);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_866() { // var
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::var(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_867() { // var_mean
      bool unbiased = readAttribute<int64_t>("unbiased");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::var_mean(self, unbiased);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_868() { // var_mean
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::var_mean(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_869() { // view_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = self.view_as(other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_870() { // where
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto condition = peek(0, 3);
          auto self = peek(1, 3);
          auto other = peek(2, 3);
          auto the_result = at::where(condition, self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_871() { // where
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto condition = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::where(condition, self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_872() { // where
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto condition = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::where(condition, self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_873() { // where
      at::Scalar self = readScalarAttribute("self");
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto condition = peek(0, 1);
          auto the_result = at::where(condition, self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_874() { // where
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto condition = peek(0, 1);
          auto the_result = at::where(condition);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_875() { // norm_except_dim
      int64_t pow = readAttribute<int64_t>("pow");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 1);
          auto the_result = at::norm_except_dim(v, pow, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_876() { // norm_except_dim
      int64_t pow = readAttribute<int64_t>("pow");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 1);
          auto the_result = at::norm_except_dim(v, pow);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_877() { // norm_except_dim
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 1);
          auto the_result = at::norm_except_dim(v);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_878() { // _weight_norm
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 2);
          auto g = peek(1, 2);
          auto the_result = at::_weight_norm(v, g, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_879() { // _weight_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 2);
          auto g = peek(1, 2);
          auto the_result = at::_weight_norm(v, g);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_880() { // _weight_norm_interface
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 2);
          auto g = peek(1, 2);
          auto the_result = at::_weight_norm_interface(v, g, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_881() { // _weight_norm_interface
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto v = peek(0, 2);
          auto g = peek(1, 2);
          auto the_result = at::_weight_norm_interface(v, g);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_882() { // _weight_norm_interface_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_w = peek(0, 4);
          auto saved_v = peek(1, 4);
          auto saved_g = peek(2, 4);
          auto saved_norms = peek(3, 4);
          auto the_result = at::_weight_norm_interface_backward(grad_w, saved_v, saved_g, saved_norms, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_883() { // _weight_norm_differentiable_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_w = peek(0, 4);
          auto saved_v = peek(1, 4);
          auto saved_g = peek(2, 4);
          auto saved_norms = peek(3, 4);
          auto the_result = at::_weight_norm_differentiable_backward(grad_w, saved_v, saved_g, saved_norms, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_884() { // _standard_gamma_grad
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto output = peek(1, 2);
          auto the_result = at::_standard_gamma_grad(self, output);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_885() { // _standard_gamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_standard_gamma(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_886() { // _dirichlet_grad
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 3);
          auto alpha = peek(1, 3);
          auto total = peek(2, 3);
          auto the_result = at::_dirichlet_grad(x, alpha, total);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_887() { // _sample_dirichlet
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sample_dirichlet(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_888() { // poisson
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::poisson(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_889() { // binomial
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto count = peek(0, 2);
          auto prob = peek(1, 2);
          auto the_result = at::binomial(count, prob);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_890() { // native_norm
      at::Scalar p = readScalarAttribute("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::native_norm(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_891() { // native_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::native_norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_892() { // _sparse_sum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_sum(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_893() { // _sparse_sum
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_sum(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_894() { // _sparse_sum_backward
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::_sparse_sum_backward(grad, self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_895() { // _sparse_csr_sum
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_csr_sum(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_896() { // _sparse_csr_sum
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_csr_sum(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_897() { // _sparse_csr_prod
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_csr_prod(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_898() { // _sparse_csr_prod
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_csr_prod(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_899() { // _sparse_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_900() { // _sparse_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      bool half_to_float = readAttribute<int64_t>("half_to_float");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_softmax(self, dim, half_to_float);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_901() { // _sparse_softmax_backward_data
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto self = peek(2, 3);
          auto the_result = at::_sparse_softmax_backward_data(grad_output, output, dim, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_902() { // _sparse_log_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_log_softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_903() { // _sparse_log_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      bool half_to_float = readAttribute<int64_t>("half_to_float");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_log_softmax(self, dim, half_to_float);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_904() { // _sparse_log_softmax_backward_data
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto self = peek(2, 3);
          auto the_result = at::_sparse_log_softmax_backward_data(grad_output, output, dim, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_905() { // _spdiags
      auto shape = readIntArrayRef("shape");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto diagonals = peek(0, 2);
          auto offsets = peek(1, 2);
          auto the_result = at::_spdiags(diagonals, offsets, shape);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_906() { // norm
      at::Scalar p = readScalarAttribute("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::norm(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_907() { // norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_908() { // frexp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::frexp(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_909() { // frobenius_norm
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::frobenius_norm(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_910() { // frobenius_norm
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::frobenius_norm(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_911() { // nuclear_norm
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nuclear_norm(self, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_912() { // nuclear_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nuclear_norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_913() { // nuclear_norm
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nuclear_norm(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_914() { // nuclear_norm
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nuclear_norm(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_915() { // clone
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::clone(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_916() { // positive
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::positive(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_917() { // sub
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::sub(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_918() { // sub
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::sub(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_919() { // sub
      at::Scalar other = readScalarAttribute("other");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sub(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_920() { // sub
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sub(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_921() { // subtract
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::subtract(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_922() { // subtract
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::subtract(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_923() { // subtract
      at::Scalar other = readScalarAttribute("other");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::subtract(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_924() { // subtract
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::subtract(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_925() { // rsub
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::rsub(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_926() { // rsub
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::rsub(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_927() { // heaviside
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto values = peek(1, 2);
          auto the_result = at::heaviside(self, values);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_928() { // rsub
      at::Scalar other = readScalarAttribute("other");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rsub(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_929() { // rsub
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::rsub(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_930() { // _sparse_addmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_sparse_addmm(self, mat1, mat2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_931() { // _sparse_addmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_sparse_addmm(self, mat1, mat2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_932() { // _sparse_addmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_sparse_addmm(self, mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_933() { // sparse_sampled_addmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sparse_sampled_addmm(self, mat1, mat2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_934() { // sparse_sampled_addmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sparse_sampled_addmm(self, mat1, mat2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_935() { // sparse_sampled_addmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::sparse_sampled_addmm(self, mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_936() { // addmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::addmm(self, mat1, mat2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_937() { // addmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::addmm(self, mat1, mat2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_938() { // addmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::addmm(self, mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_939() { // _addmm_activation
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      bool use_gelu = readAttribute<int64_t>("use_gelu");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_addmm_activation(self, mat1, mat2, beta, alpha, use_gelu);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_940() { // _addmm_activation
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_addmm_activation(self, mat1, mat2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_941() { // _addmm_activation
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_addmm_activation(self, mat1, mat2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_942() { // _addmm_activation
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat1 = peek(1, 3);
          auto mat2 = peek(2, 3);
          auto the_result = at::_addmm_activation(self, mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_943() { // _scaled_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mat2 = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_scaled_mm(self, mat2, bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_944() { // _scaled_mm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::_scaled_mm(self, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_945() { // sparse_mask
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = self.sparse_mask(mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_946() { // _sparse_mask_projection
      bool accumulate_matches = readAttribute<int64_t>("accumulate_matches");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = self._sparse_mask_projection(mask, accumulate_matches);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_947() { // _sparse_mask_projection
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = self._sparse_mask_projection(mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_948() { // _to_cpu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_to_cpu(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_949() { // to_dense
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_dense();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_950() { // _to_dense
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_dense();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_951() { // to_dense_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto input = peek(1, 2);
          auto the_result = at::to_dense_backward(grad, input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_952() { // sparse_dim
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.sparse_dim();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_953() { // _dimI
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._dimI();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_954() { // dense_dim
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.dense_dim();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_955() { // _dimV
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._dimV();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_956() { // _nnz
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._nnz();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_957() { // coalesce
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.coalesce();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_958() { // _coalesce
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_coalesce(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_959() { // is_coalesced
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.is_coalesced();
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_960() { // _indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_961() { // _values
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._values();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_962() { // indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_963() { // values
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.values();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_964() { // crow_indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.crow_indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_965() { // col_indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.col_indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_966() { // ccol_indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.ccol_indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_967() { // row_indices
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.row_indices();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_968() { // hspmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto mat1 = peek(0, 2);
          auto mat2 = peek(1, 2);
          auto the_result = at::hspmm(mat1, mat2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_969() { // unbind
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unbind(self, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_970() { // unbind
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unbind(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_971() { // to_sparse
      int64_t sparse_dim = readAttribute<int64_t>("sparse_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse(sparse_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_972() { // _to_sparse
      int64_t sparse_dim = readAttribute<int64_t>("sparse_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse(sparse_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_973() { // to_sparse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_974() { // _to_sparse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_975() { // to_sparse_csr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse_csr();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_976() { // _to_sparse_csr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse_csr();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_977() { // to_sparse_csc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse_csc();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_978() { // _to_sparse_csc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse_csc();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_979() { // to_sparse_bsr
      auto blocksize = readIntArrayRef("blocksize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse_bsr(blocksize);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_980() { // _to_sparse_bsr
      auto blocksize = readIntArrayRef("blocksize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse_bsr(blocksize);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_981() { // to_sparse_bsc
      auto blocksize = readIntArrayRef("blocksize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_sparse_bsc(blocksize);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_982() { // _to_sparse_bsc
      auto blocksize = readIntArrayRef("blocksize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._to_sparse_bsc(blocksize);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_983() { // _to_sparse_semi_structured
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dense = peek(0, 1);
          auto the_result = at::_to_sparse_semi_structured(dense);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_984() { // to_mkldnn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_mkldnn();
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_985() { // mkldnn_reorder_conv2d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_986() { // mkldnn_reorder_conv2d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_987() { // mkldnn_reorder_conv2d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_988() { // mkldnn_reorder_conv2d_weight
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_989() { // mkldnn_reorder_conv2d_weight
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv2d_weight(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_990() { // mkldnn_reorder_conv3d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      int64_t groups = readAttribute<int64_t>("groups");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv3d_weight(self, padding, stride, dilation, groups);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_991() { // mkldnn_reorder_conv3d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv3d_weight(self, padding, stride, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_992() { // mkldnn_reorder_conv3d_weight
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv3d_weight(self, padding, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_993() { // mkldnn_reorder_conv3d_weight
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv3d_weight(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_994() { // mkldnn_reorder_conv3d_weight
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_reorder_conv3d_weight(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_995() { // to_mkldnn_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto input = peek(1, 2);
          auto the_result = at::to_mkldnn_backward(grad, input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_996() { // dequantize
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::dequantize(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_997() { // dequantize
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::dequantize(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_998() { // q_zero_point
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::q_zero_point(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_999() { // q_per_channel_scales
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::q_per_channel_scales(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1000() { // q_per_channel_zero_points
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::q_per_channel_zero_points(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1001() { // q_per_channel_axis
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::q_per_channel_axis(self);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1002() { // int_repr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::int_repr(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1003() { // _make_per_tensor_quantized_tensor
      double scale = readAttribute<float>("scale");
      int64_t zero_point = readAttribute<int64_t>("zero_point");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_make_per_tensor_quantized_tensor(self, scale, zero_point);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1004() { // _make_per_channel_quantized_tensor
      int64_t axis = readAttribute<int64_t>("axis");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::_make_per_channel_quantized_tensor(self, scale, zero_point, axis);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1005() { // fake_quantize_per_tensor_affine
      double scale = readAttribute<float>("scale");
      int64_t zero_point = readAttribute<int64_t>("zero_point");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fake_quantize_per_tensor_affine(self, scale, zero_point, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1006() { // fake_quantize_per_tensor_affine
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::fake_quantize_per_tensor_affine(self, scale, zero_point, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1007() { // fake_quantize_per_tensor_affine_cachemask
      double scale = readAttribute<float>("scale");
      int64_t zero_point = readAttribute<int64_t>("zero_point");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fake_quantize_per_tensor_affine_cachemask(self, scale, zero_point, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1008() { // _fake_quantize_per_tensor_affine_cachemask_tensor_qparams
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 4);
          auto scale = peek(1, 4);
          auto zero_point = peek(2, 4);
          auto fake_quant_enabled = peek(3, 4);
          auto the_result = at::_fake_quantize_per_tensor_affine_cachemask_tensor_qparams(self, scale, zero_point, fake_quant_enabled, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1009() { // fake_quantize_per_tensor_affine_cachemask_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::fake_quantize_per_tensor_affine_cachemask_backward(grad, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1010() { // _fake_quantize_learnable_per_tensor_affine
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      double grad_factor = readAttribute<float>("grad_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::_fake_quantize_learnable_per_tensor_affine(self, scale, zero_point, quant_min, quant_max, grad_factor);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1011() { // _fake_quantize_learnable_per_tensor_affine
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::_fake_quantize_learnable_per_tensor_affine(self, scale, zero_point, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1012() { // _fake_quantize_learnable_per_tensor_affine_backward
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      double grad_factor = readAttribute<float>("grad_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 4);
          auto self = peek(1, 4);
          auto scale = peek(2, 4);
          auto zero_point = peek(3, 4);
          auto the_result = at::_fake_quantize_learnable_per_tensor_affine_backward(grad, self, scale, zero_point, quant_min, quant_max, grad_factor);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1013() { // _fake_quantize_learnable_per_tensor_affine_backward
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 4);
          auto self = peek(1, 4);
          auto scale = peek(2, 4);
          auto zero_point = peek(3, 4);
          auto the_result = at::_fake_quantize_learnable_per_tensor_affine_backward(grad, self, scale, zero_point, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1014() { // fake_quantize_per_channel_affine
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::fake_quantize_per_channel_affine(self, scale, zero_point, axis, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1015() { // fake_quantize_per_channel_affine_cachemask
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::fake_quantize_per_channel_affine_cachemask(self, scale, zero_point, axis, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1016() { // fake_quantize_per_channel_affine_cachemask_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::fake_quantize_per_channel_affine_cachemask_backward(grad, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1017() { // _fake_quantize_learnable_per_channel_affine
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      double grad_factor = readAttribute<float>("grad_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::_fake_quantize_learnable_per_channel_affine(self, scale, zero_point, axis, quant_min, quant_max, grad_factor);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1018() { // _fake_quantize_learnable_per_channel_affine
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto scale = peek(1, 3);
          auto zero_point = peek(2, 3);
          auto the_result = at::_fake_quantize_learnable_per_channel_affine(self, scale, zero_point, axis, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1019() { // _fake_quantize_learnable_per_channel_affine_backward
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      double grad_factor = readAttribute<float>("grad_factor");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 4);
          auto self = peek(1, 4);
          auto scale = peek(2, 4);
          auto zero_point = peek(3, 4);
          auto the_result = at::_fake_quantize_learnable_per_channel_affine_backward(grad, self, scale, zero_point, axis, quant_min, quant_max, grad_factor);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1020() { // _fake_quantize_learnable_per_channel_affine_backward
      int64_t axis = readAttribute<int64_t>("axis");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 4);
          auto self = peek(1, 4);
          auto scale = peek(2, 4);
          auto zero_point = peek(3, 4);
          auto the_result = at::_fake_quantize_learnable_per_channel_affine_backward(grad, self, scale, zero_point, axis, quant_min, quant_max);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1021() { // fused_moving_avg_obs_fake_quant
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      bool symmetric_quant = readAttribute<int64_t>("symmetric_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::fused_moving_avg_obs_fake_quant(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant, symmetric_quant);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1022() { // fused_moving_avg_obs_fake_quant
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::fused_moving_avg_obs_fake_quant(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1023() { // fused_moving_avg_obs_fake_quant
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::fused_moving_avg_obs_fake_quant(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1024() { // _fused_moving_avg_obs_fq_helper
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      bool symmetric_quant = readAttribute<int64_t>("symmetric_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant, symmetric_quant);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1025() { // _fused_moving_avg_obs_fq_helper
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1026() { // _fused_moving_avg_obs_fq_helper
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1027() { // _saturate_weight_to_fp16
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto weight = peek(0, 1);
          auto the_result = at::_saturate_weight_to_fp16(weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1028() { // choose_qparams_optimized
      int64_t numel = readAttribute<int64_t>("numel");
      int64_t n_bins = readAttribute<int64_t>("n_bins");
      double ratio = readAttribute<float>("ratio");
      int64_t bit_width = readAttribute<int64_t>("bit_width");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::choose_qparams_optimized(input, numel, n_bins, ratio, bit_width);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1029() { // _autocast_to_full_precision
      bool cuda_enabled = readAttribute<int64_t>("cuda_enabled");
      bool cpu_enabled = readAttribute<int64_t>("cpu_enabled");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self._autocast_to_full_precision(cuda_enabled, cpu_enabled);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1030() { // meshgrid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::meshgrid(tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1031() { // cartesian_prod
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::cartesian_prod(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1032() { // combinations
      int64_t r = readAttribute<int64_t>("r");
      bool with_replacement = readAttribute<int64_t>("with_replacement");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::combinations(self, r, with_replacement);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1033() { // combinations
      int64_t r = readAttribute<int64_t>("r");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::combinations(self, r);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1034() { // combinations
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::combinations(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1035() { // item
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.item();
            if(OutputSize() > 0) {assignTo(Output(0),the_result.type(), the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1036() { // _local_scalar_dense
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_local_scalar_dense(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result.type(), the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1037() { // _lstm_mps
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peekSlice(1, InputSize() - 1, InputSize());
          auto params = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::_lstm_mps(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
            if(OutputSize() > 5) {assignTo(Output(5),::std::get<5>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1038() { // lstm_mps_backward
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_y = peek(0, InputSize());
          auto grad_hy = peek(1, InputSize());
          auto grad_cy = peek(2, InputSize());
          auto z_state = peek(3, InputSize());
          auto cell_state_fwd = peek(4, InputSize());
          auto input = peek(5, InputSize());
          auto layersOutputs = peek(6, InputSize());
          auto hx = peekSlice(7, InputSize() - 7, InputSize());
          auto params = peekSlice(7, InputSize() - 7, InputSize());
          auto the_result = at::lstm_mps_backward(grad_y, grad_hy, grad_cy, z_state, cell_state_fwd, input, layersOutputs, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1039() { // _thnn_fused_lstm_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 5);
          auto hidden_gates = peek(1, 5);
          auto cx = peek(2, 5);
          auto input_bias = peek(3, 5);
          auto hidden_bias = peek(4, 5);
          auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx, input_bias, hidden_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1040() { // _thnn_fused_lstm_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 4);
          auto hidden_gates = peek(1, 4);
          auto cx = peek(2, 4);
          auto input_bias = peek(3, 4);
          auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx, input_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1041() { // _thnn_fused_lstm_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 3);
          auto hidden_gates = peek(1, 3);
          auto cx = peek(2, 3);
          auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1042() { // _thnn_fused_lstm_cell_backward_impl
      bool has_bias = readAttribute<int64_t>("has_bias");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_hy = peek(0, 5);
          auto grad_cy = peek(1, 5);
          auto cx = peek(2, 5);
          auto cy = peek(3, 5);
          auto workspace = peek(4, 5);
          auto the_result = at::_thnn_fused_lstm_cell_backward_impl(grad_hy, grad_cy, cx, cy, workspace, has_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1043() { // _thnn_fused_lstm_cell_backward
      bool has_bias = readAttribute<int64_t>("has_bias");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_hy = peek(0, 5);
          auto grad_cy = peek(1, 5);
          auto cx = peek(2, 5);
          auto cy = peek(3, 5);
          auto workspace = peek(4, 5);
          auto the_result = at::_thnn_fused_lstm_cell_backward(grad_hy, grad_cy, cx, cy, workspace, has_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1044() { // _thnn_differentiable_lstm_cell_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_hy = peek(0, 8);
          auto grad_cy = peek(1, 8);
          auto input_gates = peek(2, 8);
          auto hidden_gates = peek(3, 8);
          auto input_bias = peek(4, 8);
          auto hidden_bias = peek(5, 8);
          auto cx = peek(6, 8);
          auto cy = peek(7, 8);
          auto the_result = at::_thnn_differentiable_lstm_cell_backward(grad_hy, grad_cy, input_gates, hidden_gates, input_bias, hidden_bias, cx, cy);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1045() { // _thnn_fused_gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 5);
          auto hidden_gates = peek(1, 5);
          auto hx = peek(2, 5);
          auto input_bias = peek(3, 5);
          auto hidden_bias = peek(4, 5);
          auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx, input_bias, hidden_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1046() { // _thnn_fused_gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 4);
          auto hidden_gates = peek(1, 4);
          auto hx = peek(2, 4);
          auto input_bias = peek(3, 4);
          auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx, input_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1047() { // _thnn_fused_gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input_gates = peek(0, 3);
          auto hidden_gates = peek(1, 3);
          auto hx = peek(2, 3);
          auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1048() { // _thnn_fused_gru_cell_backward
      bool has_bias = readAttribute<int64_t>("has_bias");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_hy = peek(0, 2);
          auto workspace = peek(1, 2);
          auto the_result = at::_thnn_fused_gru_cell_backward(grad_hy, workspace, has_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1049() { // _thnn_differentiable_gru_cell_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_hy = peek(0, 6);
          auto input_gates = peek(1, 6);
          auto hidden_gates = peek(2, 6);
          auto hx = peek(3, 6);
          auto input_bias = peek(4, 6);
          auto hidden_bias = peek(5, 6);
          auto the_result = at::_thnn_differentiable_gru_cell_backward(grad_hy, input_gates, hidden_gates, hx, input_bias, hidden_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1050() { // lstm
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peekSlice(1, InputSize() - 1, InputSize());
          auto params = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::lstm(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1051() { // lstm
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto data = peek(0, InputSize());
          auto batch_sizes = peek(1, InputSize());
          auto hx = peekSlice(2, InputSize() - 2, InputSize());
          auto params = peekSlice(2, InputSize() - 2, InputSize());
          auto the_result = at::lstm(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1052() { // gru
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peek(1, InputSize());
          auto params = peekSlice(2, InputSize() - 2, InputSize());
          auto the_result = at::gru(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1053() { // gru
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto data = peek(0, InputSize());
          auto batch_sizes = peek(1, InputSize());
          auto hx = peek(2, InputSize());
          auto params = peekSlice(3, InputSize() - 3, InputSize());
          auto the_result = at::gru(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1054() { // rnn_tanh
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peek(1, InputSize());
          auto params = peekSlice(2, InputSize() - 2, InputSize());
          auto the_result = at::rnn_tanh(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1055() { // rnn_tanh
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto data = peek(0, InputSize());
          auto batch_sizes = peek(1, InputSize());
          auto hx = peek(2, InputSize());
          auto params = peekSlice(3, InputSize() - 3, InputSize());
          auto the_result = at::rnn_tanh(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1056() { // rnn_relu
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peek(1, InputSize());
          auto params = peekSlice(2, InputSize() - 2, InputSize());
          auto the_result = at::rnn_relu(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1057() { // rnn_relu
      bool has_biases = readAttribute<int64_t>("has_biases");
      int64_t num_layers = readAttribute<int64_t>("num_layers");
      double dropout = readAttribute<float>("dropout");
      bool train = readAttribute<int64_t>("train");
      bool bidirectional = readAttribute<int64_t>("bidirectional");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto data = peek(0, InputSize());
          auto batch_sizes = peek(1, InputSize());
          auto hx = peek(2, InputSize());
          auto params = peekSlice(3, InputSize() - 3, InputSize());
          auto the_result = at::rnn_relu(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1058() { // lstm_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peekSlice(1, InputSize() - 5, InputSize());
          auto w_ih = peek(1, 5);
          auto w_hh = peek(2, 5);
          auto b_ih = peek(3, 5);
          auto b_hh = peek(4, 5);
          auto the_result = at::lstm_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1059() { // gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 6);
          auto hx = peek(1, 6);
          auto w_ih = peek(2, 6);
          auto w_hh = peek(3, 6);
          auto b_ih = peek(4, 6);
          auto b_hh = peek(5, 6);
          auto the_result = at::gru_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1060() { // gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto hx = peek(1, 5);
          auto w_ih = peek(2, 5);
          auto w_hh = peek(3, 5);
          auto b_ih = peek(4, 5);
          auto the_result = at::gru_cell(input, hx, w_ih, w_hh, b_ih);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1061() { // gru_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 4);
          auto hx = peek(1, 4);
          auto w_ih = peek(2, 4);
          auto w_hh = peek(3, 4);
          auto the_result = at::gru_cell(input, hx, w_ih, w_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1062() { // rnn_tanh_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 6);
          auto hx = peek(1, 6);
          auto w_ih = peek(2, 6);
          auto w_hh = peek(3, 6);
          auto b_ih = peek(4, 6);
          auto b_hh = peek(5, 6);
          auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1063() { // rnn_tanh_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto hx = peek(1, 5);
          auto w_ih = peek(2, 5);
          auto w_hh = peek(3, 5);
          auto b_ih = peek(4, 5);
          auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1064() { // rnn_tanh_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 4);
          auto hx = peek(1, 4);
          auto w_ih = peek(2, 4);
          auto w_hh = peek(3, 4);
          auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1065() { // rnn_relu_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 6);
          auto hx = peek(1, 6);
          auto w_ih = peek(2, 6);
          auto w_hh = peek(3, 6);
          auto b_ih = peek(4, 6);
          auto b_hh = peek(5, 6);
          auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1066() { // rnn_relu_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto hx = peek(1, 5);
          auto w_ih = peek(2, 5);
          auto w_hh = peek(3, 5);
          auto b_ih = peek(4, 5);
          auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh, b_ih);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1067() { // rnn_relu_cell
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 4);
          auto hx = peek(1, 4);
          auto w_ih = peek(2, 4);
          auto w_hh = peek(3, 4);
          auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1068() { // quantized_lstm_cell
      at::Scalar scale_ih = readScalarAttribute("scale_ih");
      at::Scalar scale_hh = readScalarAttribute("scale_hh");
      at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
      at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, InputSize());
          auto hx = peekSlice(1, InputSize() - 9, InputSize());
          auto w_ih = peek(1, 9);
          auto w_hh = peek(2, 9);
          auto b_ih = peek(3, 9);
          auto b_hh = peek(4, 9);
          auto packed_ih = peek(5, 9);
          auto packed_hh = peek(6, 9);
          auto col_offsets_ih = peek(7, 9);
          auto col_offsets_hh = peek(8, 9);
          auto the_result = at::quantized_lstm_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1069() { // quantized_gru_cell
      at::Scalar scale_ih = readScalarAttribute("scale_ih");
      at::Scalar scale_hh = readScalarAttribute("scale_hh");
      at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
      at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 10);
          auto hx = peek(1, 10);
          auto w_ih = peek(2, 10);
          auto w_hh = peek(3, 10);
          auto b_ih = peek(4, 10);
          auto b_hh = peek(5, 10);
          auto packed_ih = peek(6, 10);
          auto packed_hh = peek(7, 10);
          auto col_offsets_ih = peek(8, 10);
          auto col_offsets_hh = peek(9, 10);
          auto the_result = at::quantized_gru_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1070() { // quantized_rnn_relu_cell
      at::Scalar scale_ih = readScalarAttribute("scale_ih");
      at::Scalar scale_hh = readScalarAttribute("scale_hh");
      at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
      at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 10);
          auto hx = peek(1, 10);
          auto w_ih = peek(2, 10);
          auto w_hh = peek(3, 10);
          auto b_ih = peek(4, 10);
          auto b_hh = peek(5, 10);
          auto packed_ih = peek(6, 10);
          auto packed_hh = peek(7, 10);
          auto col_offsets_ih = peek(8, 10);
          auto col_offsets_hh = peek(9, 10);
          auto the_result = at::quantized_rnn_relu_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1071() { // quantized_rnn_tanh_cell
      at::Scalar scale_ih = readScalarAttribute("scale_ih");
      at::Scalar scale_hh = readScalarAttribute("scale_hh");
      at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
      at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 10);
          auto hx = peek(1, 10);
          auto w_ih = peek(2, 10);
          auto w_hh = peek(3, 10);
          auto b_ih = peek(4, 10);
          auto b_hh = peek(5, 10);
          auto packed_ih = peek(6, 10);
          auto packed_hh = peek(7, 10);
          auto col_offsets_ih = peek(8, 10);
          auto col_offsets_hh = peek(9, 10);
          auto the_result = at::quantized_rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1072() { // _pack_padded_sequence
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto lengths = peek(1, 2);
          auto the_result = at::_pack_padded_sequence(input, lengths, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1073() { // _pack_padded_sequence_backward
      auto input_size = readIntArrayRef("input_size");
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto batch_sizes = peek(1, 2);
          auto the_result = at::_pack_padded_sequence_backward(grad, input_size, batch_sizes, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1074() { // _pad_packed_sequence
      bool batch_first = readAttribute<int64_t>("batch_first");
      at::Scalar padding_value = readScalarAttribute("padding_value");
      int64_t total_length = readAttribute<int64_t>("total_length");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto data = peek(0, 2);
          auto batch_sizes = peek(1, 2);
          auto the_result = at::_pad_packed_sequence(data, batch_sizes, batch_first, padding_value, total_length);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1075() { // lift
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::lift(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1076() { // lift_fresh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::lift_fresh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1077() { // lift_fresh_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::lift_fresh_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1078() { // is_set_to
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto tensor = peek(1, 2);
          auto the_result = self.is_set_to(tensor);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1079() { // masked_fill
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::masked_fill(self, mask, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1080() { // masked_fill
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mask = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::masked_fill(self, mask, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1081() { // masked_scatter
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto mask = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::masked_scatter(self, mask, source);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1082() { // masked_scatter_backward
      auto sizes = readIntArrayRef("sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::masked_scatter_backward(grad_output, mask, sizes);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1083() { // _masked_softmax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::_masked_softmax(self, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1084() { // _masked_softmax_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto output = peek(1, 3);
          auto mask = peek(2, 3);
          auto the_result = at::_masked_softmax_backward(grad_output, output, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1085() { // view
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.view(size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1086() { // put
      bool accumulate = readAttribute<int64_t>("accumulate");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::put(self, index, source, accumulate);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1087() { // put
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::put(self, index, source);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1088() { // index_add
      int64_t dim = readAttribute<int64_t>("dim");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::index_add(self, dim, index, source, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1089() { // index_add
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto source = peek(2, 3);
          auto the_result = at::index_add(self, dim, index, source);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1090() { // index_fill
      int64_t dim = readAttribute<int64_t>("dim");
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::index_fill(self, dim, index, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1091() { // index_fill
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::index_fill(self, dim, index, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1092() { // scatter
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto src = peek(2, 3);
          auto the_result = at::scatter(self, dim, index, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1093() { // scatter
      int64_t dim = readAttribute<int64_t>("dim");
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::scatter(self, dim, index, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1094() { // scatter_add
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto src = peek(2, 3);
          auto the_result = at::scatter_add(self, dim, index, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1095() { // bitwise_and
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_and(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1096() { // bitwise_and
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::bitwise_and(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1097() { // bitwise_and
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::bitwise_and(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1098() { // __and__
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::__and__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1099() { // __and__
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::__and__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1100() { // bitwise_or
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_or(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1101() { // bitwise_or
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::bitwise_or(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1102() { // bitwise_or
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::bitwise_or(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1103() { // __or__
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::__or__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1104() { // __or__
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::__or__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1105() { // bitwise_xor
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_xor(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1106() { // bitwise_xor
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::bitwise_xor(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1107() { // bitwise_xor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::bitwise_xor(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1108() { // __xor__
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::__xor__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1109() { // __xor__
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::__xor__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1110() { // __lshift__
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::__lshift__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1111() { // __lshift__
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::__lshift__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1112() { // bitwise_left_shift
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::bitwise_left_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1113() { // bitwise_left_shift
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_left_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1114() { // bitwise_left_shift
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::bitwise_left_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1115() { // __rshift__
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::__rshift__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1116() { // __rshift__
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::__rshift__(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1117() { // bitwise_right_shift
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::bitwise_right_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1118() { // bitwise_right_shift
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::bitwise_right_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1119() { // bitwise_right_shift
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::bitwise_right_shift(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1120() { // addbmm
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::addbmm(self, batch1, batch2, beta, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1121() { // addbmm
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::addbmm(self, batch1, batch2, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1122() { // addbmm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto batch1 = peek(1, 3);
          auto batch2 = peek(2, 3);
          auto the_result = at::addbmm(self, batch1, batch2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1123() { // diag
      int64_t diagonal = readAttribute<int64_t>("diagonal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag(self, diagonal);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1124() { // diag
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diag(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1125() { // cross
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::cross(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1126() { // triu
      int64_t diagonal = readAttribute<int64_t>("diagonal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::triu(self, diagonal);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1127() { // triu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::triu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1128() { // tril
      int64_t diagonal = readAttribute<int64_t>("diagonal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tril(self, diagonal);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1129() { // tril
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::tril(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1130() { // trace
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::trace(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1131() { // trace_backward
      auto sizes = readIntArrayRef("sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 1);
          auto the_result = at::trace_backward(grad, sizes);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1132() { // ne
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::ne(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1133() { // ne
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::ne(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1134() { // not_equal
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::not_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1135() { // not_equal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::not_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1136() { // eq
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::eq(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1137() { // eq
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::eq(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1138() { // ge
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::ge(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1139() { // ge
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::ge(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1140() { // greater_equal
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::greater_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1141() { // greater_equal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::greater_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1142() { // le
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::le(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1143() { // le
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::le(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1144() { // less_equal
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::less_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1145() { // less_equal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::less_equal(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1146() { // gt
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::gt(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1147() { // gt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::gt(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1148() { // greater
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::greater(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1149() { // greater
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::greater(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1150() { // lt
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::lt(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1151() { // lt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::lt(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1152() { // less
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::less(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1153() { // less
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::less(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1154() { // take
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::take(self, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1155() { // take_along_dim
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::take_along_dim(self, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1156() { // index_select
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::index_select(self, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1157() { // index_select_backward
      auto self_sizes = readIntArrayRef("self_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::index_select_backward(grad, self_sizes, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1158() { // masked_select
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto mask = peek(1, 2);
          auto the_result = at::masked_select(self, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1159() { // masked_select_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto input = peek(1, 3);
          auto mask = peek(2, 3);
          auto the_result = at::masked_select_backward(grad, input, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1160() { // nonzero
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nonzero(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1161() { // nonzero_static
      int64_t size = readAttribute<int64_t>("size");
      int64_t fill_value = readAttribute<int64_t>("fill_value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nonzero_static(self, size, fill_value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1162() { // nonzero_static
      int64_t size = readAttribute<int64_t>("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nonzero_static(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1163() { // nonzero_numpy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nonzero_numpy(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1164() { // argwhere
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argwhere(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1165() { // gather
      int64_t dim = readAttribute<int64_t>("dim");
      bool sparse_grad = readAttribute<int64_t>("sparse_grad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::gather(self, dim, index, sparse_grad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1166() { // gather
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto index = peek(1, 2);
          auto the_result = at::gather(self, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1167() { // gather_backward
      int64_t dim = readAttribute<int64_t>("dim");
      bool sparse_grad = readAttribute<int64_t>("sparse_grad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad = peek(0, 3);
          auto self = peek(1, 3);
          auto index = peek(2, 3);
          auto the_result = at::gather_backward(grad, self, dim, index, sparse_grad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1168() { // _gather_sparse_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto index = peek(1, 3);
          auto grad = peek(2, 3);
          auto the_result = at::_gather_sparse_backward(self, dim, index, grad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1169() { // addcmul
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto tensor1 = peek(1, 3);
          auto tensor2 = peek(2, 3);
          auto the_result = at::addcmul(self, tensor1, tensor2, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1170() { // addcmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto tensor1 = peek(1, 3);
          auto tensor2 = peek(2, 3);
          auto the_result = at::addcmul(self, tensor1, tensor2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1171() { // addcdiv
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto tensor1 = peek(1, 3);
          auto tensor2 = peek(2, 3);
          auto the_result = at::addcdiv(self, tensor1, tensor2, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1172() { // addcdiv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto tensor1 = peek(1, 3);
          auto tensor2 = peek(2, 3);
          auto the_result = at::addcdiv(self, tensor1, tensor2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1173() { // cross_entropy_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      double label_smoothing = readAttribute<float>("label_smoothing");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::cross_entropy_loss(self, target, weight, reduction, ignore_index, label_smoothing);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1174() { // cross_entropy_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::cross_entropy_loss(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1175() { // cross_entropy_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::cross_entropy_loss(self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1176() { // cross_entropy_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::cross_entropy_loss(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1177() { // cross_entropy_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::cross_entropy_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1178() { // triangular_solve
      bool upper = readAttribute<int64_t>("upper");
      bool transpose = readAttribute<int64_t>("transpose");
      bool unitriangular = readAttribute<int64_t>("unitriangular");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto A = peek(1, 2);
          auto the_result = at::triangular_solve(self, A, upper, transpose, unitriangular);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1179() { // triangular_solve
      bool upper = readAttribute<int64_t>("upper");
      bool transpose = readAttribute<int64_t>("transpose");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto A = peek(1, 2);
          auto the_result = at::triangular_solve(self, A, upper, transpose);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1180() { // triangular_solve
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto A = peek(1, 2);
          auto the_result = at::triangular_solve(self, A, upper);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1181() { // triangular_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto A = peek(1, 2);
          auto the_result = at::triangular_solve(self, A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1182() { // linalg_solve_triangular
      bool upper = readAttribute<int64_t>("upper");
      bool left = readAttribute<int64_t>("left");
      bool unitriangular = readAttribute<int64_t>("unitriangular");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_triangular(self, B, upper, left, unitriangular);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1183() { // linalg_solve_triangular
      bool upper = readAttribute<int64_t>("upper");
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_triangular(self, B, upper, left);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1184() { // linalg_solve_triangular
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_triangular(self, B, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1185() { // linalg_vander
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::linalg_vander(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1186() { // svd
      bool some = readAttribute<int64_t>("some");
      bool compute_uv = readAttribute<int64_t>("compute_uv");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::svd(self, some, compute_uv);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1187() { // svd
      bool some = readAttribute<int64_t>("some");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::svd(self, some);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1188() { // svd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::svd(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1189() { // swapaxes
      int64_t axis0 = readAttribute<int64_t>("axis0");
      int64_t axis1 = readAttribute<int64_t>("axis1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::swapaxes(self, axis0, axis1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1190() { // swapdims
      int64_t dim0 = readAttribute<int64_t>("dim0");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::swapdims(self, dim0, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1191() { // cholesky
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cholesky(self, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1192() { // cholesky
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cholesky(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1193() { // cholesky_solve
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto input2 = peek(1, 2);
          auto the_result = at::cholesky_solve(self, input2, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1194() { // cholesky_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto input2 = peek(1, 2);
          auto the_result = at::cholesky_solve(self, input2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1195() { // _cholesky_solve_helper
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto A = peek(1, 2);
          auto the_result = at::_cholesky_solve_helper(self, A, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1196() { // cholesky_inverse
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cholesky_inverse(self, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1197() { // cholesky_inverse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cholesky_inverse(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1198() { // qr
      bool some = readAttribute<int64_t>("some");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::qr(self, some);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1199() { // qr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::qr(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1200() { // geqrf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::geqrf(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1201() { // orgqr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto input2 = peek(1, 2);
          auto the_result = at::orgqr(self, input2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1202() { // ormqr
      bool left = readAttribute<int64_t>("left");
      bool transpose = readAttribute<int64_t>("transpose");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto input2 = peek(1, 3);
          auto input3 = peek(2, 3);
          auto the_result = at::ormqr(self, input2, input3, left, transpose);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1203() { // ormqr
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto input2 = peek(1, 3);
          auto input3 = peek(2, 3);
          auto the_result = at::ormqr(self, input2, input3, left);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1204() { // ormqr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto input2 = peek(1, 3);
          auto input3 = peek(2, 3);
          auto the_result = at::ormqr(self, input2, input3);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1205() { // _lu_with_info
      bool pivot = readAttribute<int64_t>("pivot");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_lu_with_info(self, pivot, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1206() { // _lu_with_info
      bool pivot = readAttribute<int64_t>("pivot");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_lu_with_info(self, pivot);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1207() { // _lu_with_info
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_lu_with_info(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1208() { // lu_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto LU_data = peek(1, 3);
          auto LU_pivots = peek(2, 3);
          auto the_result = at::lu_solve(self, LU_data, LU_pivots);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1209() { // lu_unpack
      bool unpack_data = readAttribute<int64_t>("unpack_data");
      bool unpack_pivots = readAttribute<int64_t>("unpack_pivots");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU_data = peek(0, 2);
          auto LU_pivots = peek(1, 2);
          auto the_result = at::lu_unpack(LU_data, LU_pivots, unpack_data, unpack_pivots);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1210() { // lu_unpack
      bool unpack_data = readAttribute<int64_t>("unpack_data");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU_data = peek(0, 2);
          auto LU_pivots = peek(1, 2);
          auto the_result = at::lu_unpack(LU_data, LU_pivots, unpack_data);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1211() { // lu_unpack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU_data = peek(0, 2);
          auto LU_pivots = peek(1, 2);
          auto the_result = at::lu_unpack(LU_data, LU_pivots);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1212() { // multinomial
      int64_t num_samples = readAttribute<int64_t>("num_samples");
      bool replacement = readAttribute<int64_t>("replacement");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::multinomial(self, num_samples, replacement);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1213() { // multinomial
      int64_t num_samples = readAttribute<int64_t>("num_samples");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::multinomial(self, num_samples);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1214() { // lgamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::lgamma(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1215() { // digamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::digamma(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1216() { // polygamma
      int64_t n = readAttribute<int64_t>("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::polygamma(n, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1217() { // erfinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::erfinv(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1218() { // i0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::i0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1219() { // sign
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sign(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1220() { // signbit
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::signbit(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1221() { // dist
      at::Scalar p = readScalarAttribute("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::dist(self, other, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1222() { // dist
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::dist(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1223() { // atan2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::atan2(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1224() { // arctan2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::arctan2(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1225() { // lerp
      at::Scalar weight = readScalarAttribute("weight");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto end = peek(1, 2);
          auto the_result = at::lerp(self, end, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1226() { // lerp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto end = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::lerp(self, end, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1227() { // histc
      int64_t bins = readAttribute<int64_t>("bins");
      at::Scalar min = readScalarAttribute("min");
      at::Scalar max = readScalarAttribute("max");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histc(self, bins, min, max);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1228() { // histc
      int64_t bins = readAttribute<int64_t>("bins");
      at::Scalar min = readScalarAttribute("min");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histc(self, bins, min);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1229() { // histc
      int64_t bins = readAttribute<int64_t>("bins");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histc(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1230() { // histc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1231() { // histogram
      bool density = readAttribute<int64_t>("density");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto bins = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::histogram(self, bins, weight, density);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1232() { // histogram
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto bins = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::histogram(self, bins, weight);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1233() { // histogram
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto bins = peek(1, 2);
          auto the_result = at::histogram(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1234() { // histogram
      int64_t bins = readAttribute<int64_t>("bins");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histogram(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1235() { // histogram
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histogram(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1236() { // _histogramdd_bin_edges
      auto bins = readIntArrayRef("bins");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_histogramdd_bin_edges(self, bins);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1237() { // _histogramdd_from_bin_cts
      auto bins = readIntArrayRef("bins");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_histogramdd_from_bin_cts(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1238() { // _histogramdd_from_bin_tensors
      bool density = readAttribute<int64_t>("density");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto bins = peekSlice(1, InputSize() - 2, InputSize());
          auto weight = peek(1, 2);
          auto the_result = at::_histogramdd_from_bin_tensors(self, bins, weight, density);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1239() { // _histogramdd_from_bin_tensors
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto bins = peekSlice(1, InputSize() - 2, InputSize());
          auto weight = peek(1, 2);
          auto the_result = at::_histogramdd_from_bin_tensors(self, bins, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1240() { // histogramdd
      auto bins = readIntArrayRef("bins");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::histogramdd(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1241() { // histogramdd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto bins = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::histogramdd(self, bins);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1242() { // fmod
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fmod(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1243() { // fmod
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::fmod(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1244() { // hypot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::hypot(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1245() { // igamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::igamma(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1246() { // igammac
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::igammac(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1247() { // nextafter
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::nextafter(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1248() { // remainder
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::remainder(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1249() { // remainder
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::remainder(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1250() { // remainder
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::remainder(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1251() { // min
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::min(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1252() { // fmin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::fmin(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1253() { // max
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1254() { // fmax
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::fmax(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1255() { // maximum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::maximum(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1256() { // max
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::max(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1257() { // minimum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::minimum(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1258() { // min
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::min(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1259() { // quantile
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto q = peek(1, 2);
          auto the_result = at::quantile(self, q);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1260() { // quantile
      double q = readAttribute<float>("q");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::quantile(self, q);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1261() { // nanquantile
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto q = peek(1, 2);
          auto the_result = at::nanquantile(self, q);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1262() { // nanquantile
      double q = readAttribute<float>("q");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nanquantile(self, q);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1263() { // sort
      int64_t dim = readAttribute<int64_t>("dim");
      bool descending = readAttribute<int64_t>("descending");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sort(self, dim, descending);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1264() { // sort
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sort(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1265() { // sort
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sort(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1266() { // msort
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::msort(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1267() { // argsort
      int64_t dim = readAttribute<int64_t>("dim");
      bool descending = readAttribute<int64_t>("descending");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self, dim, descending);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1268() { // argsort
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1269() { // argsort
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1270() { // argsort
      bool stable = readAttribute<int64_t>("stable");
      int64_t dim = readAttribute<int64_t>("dim");
      bool descending = readAttribute<int64_t>("descending");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self, stable, dim, descending);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1271() { // argsort
      bool stable = readAttribute<int64_t>("stable");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self, stable, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1272() { // argsort
      bool stable = readAttribute<int64_t>("stable");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::argsort(self, stable);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1273() { // topk
      int64_t k = readAttribute<int64_t>("k");
      int64_t dim = readAttribute<int64_t>("dim");
      bool largest = readAttribute<int64_t>("largest");
      bool sorted = readAttribute<int64_t>("sorted");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::topk(self, k, dim, largest, sorted);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1274() { // topk
      int64_t k = readAttribute<int64_t>("k");
      int64_t dim = readAttribute<int64_t>("dim");
      bool largest = readAttribute<int64_t>("largest");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::topk(self, k, dim, largest);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1275() { // topk
      int64_t k = readAttribute<int64_t>("k");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::topk(self, k, dim);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1276() { // topk
      int64_t k = readAttribute<int64_t>("k");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::topk(self, k);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1277() { // renorm
      at::Scalar p = readScalarAttribute("p");
      int64_t dim = readAttribute<int64_t>("dim");
      at::Scalar maxnorm = readScalarAttribute("maxnorm");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::renorm(self, p, dim, maxnorm);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1278() { // unfold
      int64_t dimension = readAttribute<int64_t>("dimension");
      int64_t size = readAttribute<int64_t>("size");
      int64_t step = readAttribute<int64_t>("step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.unfold(dimension, size, step);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1279() { // unfold_backward
      auto input_sizes = readIntArrayRef("input_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t size = readAttribute<int64_t>("size");
      int64_t step = readAttribute<int64_t>("step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_in = peek(0, 1);
          auto the_result = at::unfold_backward(grad_in, input_sizes, dim, size, step);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1280() { // equal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::equal(self, other);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1281() { // pow
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto exponent = peek(1, 2);
          auto the_result = at::pow(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1282() { // pow
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto exponent = peek(0, 1);
          auto the_result = at::pow(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1283() { // pow
      at::Scalar exponent = readScalarAttribute("exponent");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pow(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1284() { // float_power
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto exponent = peek(1, 2);
          auto the_result = at::float_power(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1285() { // float_power
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto exponent = peek(0, 1);
          auto the_result = at::float_power(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1286() { // float_power
      at::Scalar exponent = readScalarAttribute("exponent");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::float_power(self, exponent);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1287() { // normal_functional
      double mean = readAttribute<float>("mean");
      double std = readAttribute<float>("std");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::normal_functional(self, mean, std);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1288() { // normal_functional
      double mean = readAttribute<float>("mean");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::normal_functional(self, mean);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1289() { // normal_functional
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::normal_functional(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1290() { // alias
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::alias(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1291() { // _foreach_add
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_add(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1292() { // _foreach_add
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_add(self, other, alpha);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1293() { // _foreach_add
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_add(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1294() { // _foreach_sub
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sub(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1295() { // _foreach_sub
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sub(self, other, alpha);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1296() { // _foreach_sub
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sub(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1297() { // _foreach_mul
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_mul(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1298() { // _foreach_mul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_mul(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1299() { // _foreach_div
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_div(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1300() { // _foreach_div
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_div(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1301() { // _foreach_clamp_max
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_clamp_max(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1302() { // _foreach_clamp_max
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_clamp_max(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1303() { // _foreach_clamp_min
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_clamp_min(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1304() { // _foreach_clamp_min
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_clamp_min(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1305() { // _foreach_maximum
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_maximum(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1306() { // _foreach_maximum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_maximum(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1307() { // _foreach_minimum
      at::Scalar scalar = readScalarAttribute("scalar");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_minimum(self, scalar);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1308() { // _foreach_minimum
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto other = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_minimum(self, other);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1309() { // _foreach_addcdiv
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor1 = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor2 = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_addcdiv(self, tensor1, tensor2, value);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1310() { // _foreach_addcdiv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor1 = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor2 = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_addcdiv(self, tensor1, tensor2);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1311() { // _foreach_addcmul
      at::Scalar value = readScalarAttribute("value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor1 = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor2 = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_addcmul(self, tensor1, tensor2, value);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1312() { // _foreach_addcmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor1 = peekSlice(0, InputSize() - 0, InputSize());
          auto tensor2 = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_addcmul(self, tensor1, tensor2);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1313() { // _foreach_abs
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_abs(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1314() { // _foreach_acos
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_acos(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1315() { // _foreach_asin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_asin(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1316() { // _foreach_atan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_atan(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1317() { // _foreach_ceil
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_ceil(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1318() { // _foreach_cos
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_cos(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1319() { // _foreach_cosh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_cosh(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1320() { // _foreach_erf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_erf(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1321() { // _foreach_erfc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_erfc(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1322() { // _foreach_exp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_exp(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1323() { // _foreach_expm1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_expm1(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1324() { // _foreach_floor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_floor(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1325() { // _foreach_frac
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_frac(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1326() { // _foreach_lerp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensors1 = peekSlice(0, InputSize() - 0, InputSize());
          auto weights = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_lerp(self, tensors1, weights);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1327() { // _foreach_lerp
      at::Scalar weight = readScalarAttribute("weight");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto tensors1 = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_lerp(self, tensors1, weight);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1328() { // _foreach_lgamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_lgamma(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1329() { // _foreach_log
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_log(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1330() { // _foreach_log10
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_log10(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1331() { // _foreach_log1p
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_log1p(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1332() { // _foreach_log2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_log2(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1333() { // _foreach_neg
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_neg(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1334() { // _foreach_norm
      at::Scalar ord = readScalarAttribute("ord");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_norm(self, ord);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1335() { // _foreach_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_norm(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1336() { // _foreach_pow
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto exponent = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_pow(self, exponent);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1337() { // _foreach_pow
      at::Scalar exponent = readScalarAttribute("exponent");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_pow(self, exponent);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1338() { // _foreach_pow
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto exponent = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_pow(self, exponent);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1339() { // _foreach_reciprocal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_reciprocal(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1340() { // _foreach_round
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_round(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1341() { // _foreach_sigmoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sigmoid(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1342() { // _foreach_sign
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sign(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1343() { // _foreach_sin
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sin(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1344() { // _foreach_sinh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sinh(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1345() { // _foreach_sqrt
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_sqrt(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1346() { // _foreach_tan
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_tan(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1347() { // _foreach_tanh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_tanh(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1348() { // _foreach_trunc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_trunc(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1349() { // bucketize
      bool out_int32 = readAttribute<int64_t>("out_int32");
      bool right = readAttribute<int64_t>("right");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto boundaries = peek(1, 2);
          auto the_result = at::bucketize(self, boundaries, out_int32, right);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1350() { // bucketize
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto boundaries = peek(1, 2);
          auto the_result = at::bucketize(self, boundaries, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1351() { // bucketize
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto boundaries = peek(1, 2);
          auto the_result = at::bucketize(self, boundaries);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1352() { // bucketize
      at::Scalar self = readScalarAttribute("self");
      bool out_int32 = readAttribute<int64_t>("out_int32");
      bool right = readAttribute<int64_t>("right");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto boundaries = peek(0, 1);
          auto the_result = at::bucketize(self, boundaries, out_int32, right);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1353() { // bucketize
      at::Scalar self = readScalarAttribute("self");
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto boundaries = peek(0, 1);
          auto the_result = at::bucketize(self, boundaries, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1354() { // bucketize
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto boundaries = peek(0, 1);
          auto the_result = at::bucketize(self, boundaries);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1355() { // searchsorted
      bool out_int32 = readAttribute<int64_t>("out_int32");
      bool right = readAttribute<int64_t>("right");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::searchsorted(sorted_sequence, self, out_int32, right);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1356() { // searchsorted
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::searchsorted(sorted_sequence, self, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1357() { // searchsorted
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::searchsorted(sorted_sequence, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1358() { // searchsorted
      at::Scalar self = readScalarAttribute("self");
      bool out_int32 = readAttribute<int64_t>("out_int32");
      bool right = readAttribute<int64_t>("right");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 1);
          auto the_result = at::searchsorted(sorted_sequence, self, out_int32, right);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1359() { // searchsorted
      at::Scalar self = readScalarAttribute("self");
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 1);
          auto the_result = at::searchsorted(sorted_sequence, self, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1360() { // searchsorted
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sorted_sequence = peek(0, 1);
          auto the_result = at::searchsorted(sorted_sequence, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1361() { // _convert_indices_from_coo_to_csr
      int64_t size = readAttribute<int64_t>("size");
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_convert_indices_from_coo_to_csr(self, size, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1362() { // _convert_indices_from_coo_to_csr
      int64_t size = readAttribute<int64_t>("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_convert_indices_from_coo_to_csr(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1363() { // _convert_indices_from_csr_to_coo
      bool out_int32 = readAttribute<int64_t>("out_int32");
      bool transpose = readAttribute<int64_t>("transpose");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto crow_indices = peek(0, 2);
          auto col_indices = peek(1, 2);
          auto the_result = at::_convert_indices_from_csr_to_coo(crow_indices, col_indices, out_int32, transpose);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1364() { // _convert_indices_from_csr_to_coo
      bool out_int32 = readAttribute<int64_t>("out_int32");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto crow_indices = peek(0, 2);
          auto col_indices = peek(1, 2);
          auto the_result = at::_convert_indices_from_csr_to_coo(crow_indices, col_indices, out_int32);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1365() { // _convert_indices_from_csr_to_coo
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto crow_indices = peek(0, 2);
          auto col_indices = peek(1, 2);
          auto the_result = at::_convert_indices_from_csr_to_coo(crow_indices, col_indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1366() { // mse_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::mse_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1367() { // mse_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::mse_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1368() { // mse_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::mse_loss_backward(grad_output, self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1369() { // l1_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::l1_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1370() { // l1_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::l1_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1371() { // multi_margin_loss
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::multi_margin_loss(self, target, p, margin, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1372() { // multi_margin_loss
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::multi_margin_loss(self, target, p, margin, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1373() { // multi_margin_loss
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multi_margin_loss(self, target, p, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1374() { // multi_margin_loss
      at::Scalar p = readScalarAttribute("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multi_margin_loss(self, target, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1375() { // multi_margin_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multi_margin_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1376() { // multi_margin_loss_backward
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 4);
          auto self = peek(1, 4);
          auto target = peek(2, 4);
          auto weight = peek(3, 4);
          auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1377() { // multi_margin_loss_backward
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 4);
          auto self = peek(1, 4);
          auto target = peek(2, 4);
          auto weight = peek(3, 4);
          auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1378() { // multi_margin_loss_backward
      at::Scalar p = readScalarAttribute("p");
      at::Scalar margin = readScalarAttribute("margin");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1379() { // multilabel_margin_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multilabel_margin_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1380() { // multilabel_margin_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multilabel_margin_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1381() { // multilabel_margin_loss_forward
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::multilabel_margin_loss_forward(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1382() { // multilabel_margin_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 4);
          auto self = peek(1, 4);
          auto target = peek(2, 4);
          auto is_target = peek(3, 4);
          auto the_result = at::multilabel_margin_loss_backward(grad_output, self, target, reduction, is_target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1383() { // nll_loss_nd
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss_nd(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1384() { // nll_loss_nd
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss_nd(self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1385() { // nll_loss_nd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss_nd(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1386() { // nll_loss_nd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::nll_loss_nd(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1387() { // nll_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1388() { // nll_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss(self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1389() { // nll_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1390() { // nll_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::nll_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1391() { // nll_loss_forward
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss_forward(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1392() { // nll_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 5);
          auto self = peek(1, 5);
          auto target = peek(2, 5);
          auto weight = peek(3, 5);
          auto total_weight = peek(4, 5);
          auto the_result = at::nll_loss_backward(grad_output, self, target, weight, reduction, ignore_index, total_weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1393() { // nll_loss2d
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss2d(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1394() { // nll_loss2d
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss2d(self, target, weight, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1395() { // nll_loss2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss2d(self, target, weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1396() { // nll_loss2d
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::nll_loss2d(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1397() { // nll_loss2d_forward
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto target = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::nll_loss2d_forward(self, target, weight, reduction, ignore_index);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1398() { // nll_loss2d_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      int64_t ignore_index = readAttribute<int64_t>("ignore_index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 5);
          auto self = peek(1, 5);
          auto target = peek(2, 5);
          auto weight = peek(3, 5);
          auto total_weight = peek(4, 5);
          auto the_result = at::nll_loss2d_backward(grad_output, self, target, weight, reduction, ignore_index, total_weight);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1399() { // smooth_l1_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      double beta = readAttribute<float>("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::smooth_l1_loss(self, target, reduction, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1400() { // smooth_l1_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::smooth_l1_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1401() { // smooth_l1_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::smooth_l1_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1402() { // smooth_l1_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      double beta = readAttribute<float>("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::smooth_l1_loss_backward(grad_output, self, target, reduction, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1403() { // huber_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      double delta = readAttribute<float>("delta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::huber_loss(self, target, reduction, delta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1404() { // huber_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::huber_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1405() { // huber_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::huber_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1406() { // huber_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      double delta = readAttribute<float>("delta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::huber_loss_backward(grad_output, self, target, reduction, delta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1407() { // soft_margin_loss
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::soft_margin_loss(self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1408() { // soft_margin_loss
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto target = peek(1, 2);
          auto the_result = at::soft_margin_loss(self, target);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1409() { // soft_margin_loss_backward
      int64_t reduction = readAttribute<int64_t>("reduction");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto target = peek(2, 3);
          auto the_result = at::soft_margin_loss_backward(grad_output, self, target, reduction);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1410() { // elu
      at::Scalar alpha = readScalarAttribute("alpha");
      at::Scalar scale = readScalarAttribute("scale");
      at::Scalar input_scale = readScalarAttribute("input_scale");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::elu(self, alpha, scale, input_scale);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1411() { // elu
      at::Scalar alpha = readScalarAttribute("alpha");
      at::Scalar scale = readScalarAttribute("scale");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::elu(self, alpha, scale);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1412() { // elu
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::elu(self, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1413() { // elu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::elu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1414() { // elu_backward
      at::Scalar alpha = readScalarAttribute("alpha");
      at::Scalar scale = readScalarAttribute("scale");
      at::Scalar input_scale = readScalarAttribute("input_scale");
      bool is_result = readAttribute<int64_t>("is_result");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self_or_result = peek(1, 2);
          auto the_result = at::elu_backward(grad_output, alpha, scale, input_scale, is_result, self_or_result);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1415() { // glu
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::glu(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1416() { // glu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::glu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1417() { // glu_backward
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::glu_backward(grad_output, self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1418() { // glu_jvp
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto glu = peek(0, 3);
          auto x = peek(1, 3);
          auto dx = peek(2, 3);
          auto the_result = at::glu_jvp(glu, x, dx, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1419() { // glu_backward_jvp
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_x = peek(0, 5);
          auto grad_glu = peek(1, 5);
          auto x = peek(2, 5);
          auto dgrad_glu = peek(3, 5);
          auto dx = peek(4, 5);
          auto the_result = at::glu_backward_jvp(grad_x, grad_glu, x, dgrad_glu, dx, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1420() { // hardsigmoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardsigmoid(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1421() { // hardsigmoid_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::hardsigmoid_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1422() { // hardtanh
      at::Scalar min_val = readScalarAttribute("min_val");
      at::Scalar max_val = readScalarAttribute("max_val");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardtanh(self, min_val, max_val);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1423() { // hardtanh
      at::Scalar min_val = readScalarAttribute("min_val");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardtanh(self, min_val);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1424() { // hardtanh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardtanh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1425() { // hardtanh_backward
      at::Scalar min_val = readScalarAttribute("min_val");
      at::Scalar max_val = readScalarAttribute("max_val");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::hardtanh_backward(grad_output, self, min_val, max_val);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1426() { // hardswish
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::hardswish(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1427() { // hardswish_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::hardswish_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1428() { // leaky_relu
      at::Scalar negative_slope = readScalarAttribute("negative_slope");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::leaky_relu(self, negative_slope);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1429() { // leaky_relu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::leaky_relu(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1430() { // leaky_relu_backward
      at::Scalar negative_slope = readScalarAttribute("negative_slope");
      bool self_is_result = readAttribute<int64_t>("self_is_result");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::leaky_relu_backward(grad_output, self, negative_slope, self_is_result);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1431() { // log_sigmoid
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_sigmoid(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1432() { // log_sigmoid_forward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_sigmoid_forward(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1433() { // log_sigmoid_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto buffer = peek(2, 3);
          auto the_result = at::log_sigmoid_backward(grad_output, self, buffer);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1434() { // rrelu_with_noise
      at::Scalar lower = readScalarAttribute("lower");
      at::Scalar upper = readScalarAttribute("upper");
      bool training = readAttribute<int64_t>("training");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto noise = peek(1, 2);
          auto the_result = at::rrelu_with_noise(self, noise, lower, upper, training);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1435() { // rrelu_with_noise
      at::Scalar lower = readScalarAttribute("lower");
      at::Scalar upper = readScalarAttribute("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto noise = peek(1, 2);
          auto the_result = at::rrelu_with_noise(self, noise, lower, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1436() { // rrelu_with_noise
      at::Scalar lower = readScalarAttribute("lower");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto noise = peek(1, 2);
          auto the_result = at::rrelu_with_noise(self, noise, lower);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1437() { // rrelu_with_noise
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto noise = peek(1, 2);
          auto the_result = at::rrelu_with_noise(self, noise);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1438() { // rrelu_with_noise_backward
      at::Scalar lower = readScalarAttribute("lower");
      at::Scalar upper = readScalarAttribute("upper");
      bool training = readAttribute<int64_t>("training");
      bool self_is_result = readAttribute<int64_t>("self_is_result");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto noise = peek(2, 3);
          auto the_result = at::rrelu_with_noise_backward(grad_output, self, noise, lower, upper, training, self_is_result);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1439() { // softplus
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar threshold = readScalarAttribute("threshold");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softplus(self, beta, threshold);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1440() { // softplus
      at::Scalar beta = readScalarAttribute("beta");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softplus(self, beta);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1441() { // softplus
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softplus(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1442() { // softplus_backward
      at::Scalar beta = readScalarAttribute("beta");
      at::Scalar threshold = readScalarAttribute("threshold");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::softplus_backward(grad_output, self, beta, threshold);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1443() { // softshrink
      at::Scalar lambd = readScalarAttribute("lambd");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softshrink(self, lambd);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1444() { // softshrink
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::softshrink(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1445() { // softshrink_backward
      at::Scalar lambd = readScalarAttribute("lambd");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::softshrink_backward(grad_output, self, lambd);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1446() { // adaptive_avg_pool2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_avg_pool2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1447() { // mkldnn_adaptive_avg_pool2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::mkldnn_adaptive_avg_pool2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1448() { // mkldnn_adaptive_avg_pool2d_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::mkldnn_adaptive_avg_pool2d_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1449() { // _adaptive_avg_pool2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_adaptive_avg_pool2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1450() { // _adaptive_avg_pool2d_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::_adaptive_avg_pool2d_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1451() { // adaptive_avg_pool3d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_avg_pool3d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1452() { // _adaptive_avg_pool3d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_adaptive_avg_pool3d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1453() { // _adaptive_avg_pool3d_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::_adaptive_avg_pool3d_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1454() { // adaptive_max_pool2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_max_pool2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1455() { // adaptive_max_pool2d_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::adaptive_max_pool2d_backward(grad_output, self, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1456() { // adaptive_max_pool3d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::adaptive_max_pool3d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1457() { // adaptive_max_pool3d_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::adaptive_max_pool3d_backward(grad_output, self, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1458() { // avg_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      bool count_include_pad = readAttribute<int64_t>("count_include_pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool2d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1459() { // avg_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool2d(self, kernel_size, stride, padding, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1460() { // avg_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool2d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1461() { // avg_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool2d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1462() { // avg_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool2d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1463() { // avg_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      bool count_include_pad = readAttribute<int64_t>("count_include_pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool3d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1464() { // avg_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool3d(self, kernel_size, stride, padding, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1465() { // avg_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool3d(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1466() { // avg_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool3d(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1467() { // avg_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::avg_pool3d(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1468() { // fractional_max_pool2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto random_samples = peek(1, 2);
          auto the_result = at::fractional_max_pool2d(self, kernel_size, output_size, random_samples);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1469() { // fractional_max_pool2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::fractional_max_pool2d_backward(grad_output, self, kernel_size, output_size, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1470() { // fractional_max_pool3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto random_samples = peek(1, 2);
          auto the_result = at::fractional_max_pool3d(self, kernel_size, output_size, random_samples);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1471() { // fractional_max_pool3d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::fractional_max_pool3d_backward(grad_output, self, kernel_size, output_size, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1472() { // max_pool2d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1473() { // max_pool2d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1474() { // max_pool2d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1475() { // max_pool2d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1476() { // max_pool2d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool2d_with_indices(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1477() { // max_pool2d_with_indices_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::max_pool2d_with_indices_backward(grad_output, self, kernel_size, stride, padding, dilation, ceil_mode, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1478() { // max_pool3d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1479() { // max_pool3d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1480() { // max_pool3d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1481() { // max_pool3d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1482() { // max_pool3d_with_indices
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::max_pool3d_with_indices(self, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1483() { // max_pool3d_with_indices_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      bool ceil_mode = readAttribute<int64_t>("ceil_mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto indices = peek(2, 3);
          auto the_result = at::max_pool3d_with_indices_backward(grad_output, self, kernel_size, stride, padding, dilation, ceil_mode, indices);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1484() { // max_unpool2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::max_unpool2d(self, indices, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1485() { // max_unpool3d
      auto output_size = readIntArrayRef("output_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::max_unpool3d(self, indices, output_size, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1486() { // reflection_pad1d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::reflection_pad1d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1487() { // reflection_pad1d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::reflection_pad1d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1488() { // reflection_pad2d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::reflection_pad2d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1489() { // reflection_pad2d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::reflection_pad2d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1490() { // reflection_pad3d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::reflection_pad3d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1491() { // reflection_pad3d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::reflection_pad3d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1492() { // replication_pad1d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::replication_pad1d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1493() { // replication_pad1d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::replication_pad1d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1494() { // replication_pad2d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::replication_pad2d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1495() { // replication_pad2d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::replication_pad2d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1496() { // replication_pad3d
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::replication_pad3d(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1497() { // replication_pad3d_backward
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::replication_pad3d_backward(grad_output, self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1498() { // _pad_circular
      auto pad = readIntArrayRef("pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_pad_circular(self, pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1499() { // _pad_enum
      auto pad = readIntArrayRef("pad");
      int64_t mode = readAttribute<int64_t>("mode");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_pad_enum(self, pad, mode);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1500() { // pad
      auto pad = readIntArrayRef("pad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::pad(self, pad);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1501() { // upsample_linear1d
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_linear1d(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1502() { // upsample_linear1d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_linear1d_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1503() { // upsample_bilinear2d
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_bilinear2d(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1504() { // upsample_bilinear2d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_bilinear2d_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1505() { // _upsample_bilinear2d_aa
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_upsample_bilinear2d_aa(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1506() { // _upsample_bilinear2d_aa_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::_upsample_bilinear2d_aa_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1507() { // upsample_bicubic2d
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_bicubic2d(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1508() { // upsample_bicubic2d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_bicubic2d_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1509() { // _upsample_bicubic2d_aa
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_upsample_bicubic2d_aa(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1510() { // _upsample_bicubic2d_aa_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::_upsample_bicubic2d_aa_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1511() { // upsample_trilinear3d
      auto output_size = readIntArrayRef("output_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_trilinear3d(self, output_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1512() { // upsample_trilinear3d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      bool align_corners = readAttribute<int64_t>("align_corners");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_trilinear3d_backward(grad_output, output_size, input_size, align_corners);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1513() { // upsample_nearest1d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_nearest1d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1514() { // _upsample_nearest_exact1d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact1d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1515() { // upsample_nearest1d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_nearest1d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1516() { // _upsample_nearest_exact1d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact1d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1517() { // upsample_nearest2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_nearest2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1518() { // _upsample_nearest_exact2d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact2d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1519() { // upsample_nearest2d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_nearest2d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1520() { // _upsample_nearest_exact2d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact2d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1521() { // upsample_nearest3d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::upsample_nearest3d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1522() { // _upsample_nearest_exact3d
      auto output_size = readIntArrayRef("output_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact3d(self, output_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1523() { // upsample_nearest3d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::upsample_nearest3d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1524() { // _upsample_nearest_exact3d_backward
      auto output_size = readIntArrayRef("output_size");
      auto input_size = readIntArrayRef("input_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 1);
          auto the_result = at::_upsample_nearest_exact3d_backward(grad_output, output_size, input_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1525() { // sigmoid_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto output = peek(1, 2);
          auto the_result = at::sigmoid_backward(grad_output, output);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1526() { // logit_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto self = peek(1, 2);
          auto the_result = at::logit_backward(grad_output, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1527() { // tanh_backward
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 2);
          auto output = peek(1, 2);
          auto the_result = at::tanh_backward(grad_output, output);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1528() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding, output_padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1529() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding, output_padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1530() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1531() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1532() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1533() { // slow_conv_transpose2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1534() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding, output_padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1535() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_padding = readIntArrayRef("output_padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding, output_padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1536() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1537() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1538() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1539() { // slow_conv_transpose3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1540() { // thnn_conv2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1541() { // thnn_conv2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1542() { // thnn_conv2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1543() { // thnn_conv2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::thnn_conv2d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1544() { // _slow_conv2d_forward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_slow_conv2d_forward(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1545() { // _slow_conv2d_backward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto output_mask = readBoolMask<3>("output_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_output = peek(0, 3);
          auto self = peek(1, 3);
          auto weight = peek(2, 3);
          auto the_result = at::_slow_conv2d_backward(grad_output, self, weight, kernel_size, stride, padding, output_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1546() { // _conv_depthwise2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::_conv_depthwise2d(self, weight, kernel_size, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1547() { // conv_depthwise3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::conv_depthwise3d(self, weight, kernel_size, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1548() { // slow_conv3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv3d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1549() { // slow_conv3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv3d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1550() { // slow_conv3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv3d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1551() { // slow_conv3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::slow_conv3d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1552() { // slow_conv3d_forward
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv3d_forward(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1553() { // slow_conv_dilated2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1554() { // slow_conv_dilated2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1555() { // slow_conv_dilated2d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1556() { // slow_conv_dilated2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1557() { // slow_conv_dilated2d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1558() { // slow_conv_dilated3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      auto dilation = readIntArrayRef("dilation");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride, padding, dilation);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1559() { // slow_conv_dilated3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      auto padding = readIntArrayRef("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1560() { // slow_conv_dilated3d
      auto kernel_size = readIntArrayRef("kernel_size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1561() { // slow_conv_dilated3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto weight = peek(1, 3);
          auto bias = peek(2, 3);
          auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1562() { // slow_conv_dilated3d
      auto kernel_size = readIntArrayRef("kernel_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto weight = peek(1, 2);
          auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1563() { // col2im
      auto output_size = readIntArrayRef("output_size");
      auto kernel_size = readIntArrayRef("kernel_size");
      auto dilation = readIntArrayRef("dilation");
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::col2im(self, output_size, kernel_size, dilation, padding, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1564() { // column_stack
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::column_stack(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1565() { // im2col
      auto kernel_size = readIntArrayRef("kernel_size");
      auto dilation = readIntArrayRef("dilation");
      auto padding = readIntArrayRef("padding");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::im2col(self, kernel_size, dilation, padding, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1566() { // isfinite
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isfinite(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1567() { // isinf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isinf(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1568() { // isposinf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isposinf(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1569() { // isneginf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::isneginf(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1570() { // _add_batch_dim
      int64_t batch_dim = readAttribute<int64_t>("batch_dim");
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_add_batch_dim(self, batch_dim, level);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1571() { // _remove_batch_dim
      int64_t level = readAttribute<int64_t>("level");
      int64_t batch_size = readAttribute<int64_t>("batch_size");
      int64_t out_dim = readAttribute<int64_t>("out_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_remove_batch_dim(self, level, batch_size, out_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1572() { // special_entr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_entr(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1573() { // special_ndtri
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_ndtri(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1574() { // special_log_ndtr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_log_ndtr(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1575() { // special_expm1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_expm1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1576() { // special_exp2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_exp2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1577() { // special_psi
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_psi(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1578() { // special_digamma
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_digamma(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1579() { // special_gammaln
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_gammaln(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1580() { // special_erf
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_erf(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1581() { // special_erfc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_erfc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1582() { // special_erfcx
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_erfcx(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1583() { // special_erfinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_erfinv(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1584() { // special_ndtr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_ndtr(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1585() { // special_xlog1py
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::special_xlog1py(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1586() { // special_xlog1py
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::special_xlog1py(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1587() { // special_xlog1py
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_xlog1py(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1588() { // special_xlogy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::special_xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1589() { // special_xlogy
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::special_xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1590() { // special_xlogy
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_xlogy(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1591() { // special_zeta
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::special_zeta(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1592() { // special_zeta
      at::Scalar self = readScalarAttribute("self");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto other = peek(0, 1);
          auto the_result = at::special_zeta(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1593() { // special_zeta
      at::Scalar other = readScalarAttribute("other");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_zeta(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1594() { // special_i0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_i0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1595() { // special_i0e
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_i0e(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1596() { // special_i1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_i1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1597() { // special_i1e
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_i1e(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1598() { // special_logit
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_logit(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1599() { // special_polygamma
      int64_t n = readAttribute<int64_t>("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_polygamma(n, self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1600() { // special_logsumexp
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_logsumexp(self, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1601() { // special_logsumexp
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_logsumexp(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1602() { // special_expit
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_expit(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1603() { // special_sinc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_sinc(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1604() { // special_round
      int64_t decimals = readAttribute<int64_t>("decimals");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_round(self, decimals);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1605() { // special_round
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_round(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1606() { // special_log1p
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_log1p(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1607() { // special_log_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_log_softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1608() { // special_gammainc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::special_gammainc(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1609() { // special_gammaincc
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::special_gammaincc(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1610() { // special_multigammaln
      int64_t p = readAttribute<int64_t>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_multigammaln(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1611() { // special_softmax
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_softmax(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1612() { // fft_fft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_fft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1613() { // fft_ifft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ifft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1614() { // fft_rfft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_rfft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1615() { // fft_irfft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_irfft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1616() { // fft_hfft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_hfft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1617() { // fft_ihfft
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ihfft(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1618() { // fft_fft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_fft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1619() { // fft_ifft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ifft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1620() { // fft_rfft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_rfft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1621() { // fft_irfft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_irfft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1622() { // fft_hfft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_hfft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1623() { // fft_ihfft2
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ihfft2(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1624() { // fft_fftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_fftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1625() { // fft_ifftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ifftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1626() { // fft_rfftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_rfftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1627() { // fft_irfftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_irfftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1628() { // fft_hfftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_hfftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1629() { // fft_ihfftn
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ihfftn(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1630() { // fft_fftshift
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_fftshift(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1631() { // fft_ifftshift
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::fft_ifftshift(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1632() { // linalg_cholesky_ex
      bool upper = readAttribute<int64_t>("upper");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cholesky_ex(self, upper, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1633() { // linalg_cholesky_ex
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cholesky_ex(self, upper);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1634() { // linalg_cholesky_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cholesky_ex(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1635() { // linalg_cholesky
      bool upper = readAttribute<int64_t>("upper");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cholesky(self, upper);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1636() { // linalg_cholesky
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cholesky(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1637() { // linalg_cross
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::linalg_cross(self, other, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1638() { // linalg_cross
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::linalg_cross(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1639() { // linalg_lu_factor
      bool pivot = readAttribute<int64_t>("pivot");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu_factor(A, pivot);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1640() { // linalg_lu_factor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu_factor(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1641() { // linalg_lu_factor_ex
      bool pivot = readAttribute<int64_t>("pivot");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu_factor_ex(A, pivot, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1642() { // linalg_lu_factor_ex
      bool pivot = readAttribute<int64_t>("pivot");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu_factor_ex(A, pivot);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1643() { // linalg_lu_factor_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu_factor_ex(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1644() { // linalg_lu
      bool pivot = readAttribute<int64_t>("pivot");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu(A, pivot);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1645() { // linalg_lu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_lu(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1646() { // linalg_lu_solve
      bool left = readAttribute<int64_t>("left");
      bool adjoint = readAttribute<int64_t>("adjoint");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU = peek(0, 3);
          auto pivots = peek(1, 3);
          auto B = peek(2, 3);
          auto the_result = at::linalg_lu_solve(LU, pivots, B, left, adjoint);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1647() { // linalg_lu_solve
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU = peek(0, 3);
          auto pivots = peek(1, 3);
          auto B = peek(2, 3);
          auto the_result = at::linalg_lu_solve(LU, pivots, B, left);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1648() { // linalg_lu_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LU = peek(0, 3);
          auto pivots = peek(1, 3);
          auto B = peek(2, 3);
          auto the_result = at::linalg_lu_solve(LU, pivots, B);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1649() { // _linalg_det
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_det(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1650() { // linalg_det
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_det(A);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1651() { // det
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::det(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1652() { // linalg_ldl_factor_ex
      bool hermitian = readAttribute<int64_t>("hermitian");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_ldl_factor_ex(self, hermitian, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1653() { // linalg_ldl_factor_ex
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_ldl_factor_ex(self, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1654() { // linalg_ldl_factor_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_ldl_factor_ex(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1655() { // linalg_ldl_factor
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_ldl_factor(self, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1656() { // linalg_ldl_factor
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_ldl_factor(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1657() { // linalg_ldl_solve
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LD = peek(0, 3);
          auto pivots = peek(1, 3);
          auto B = peek(2, 3);
          auto the_result = at::linalg_ldl_solve(LD, pivots, B, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1658() { // linalg_ldl_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto LD = peek(0, 3);
          auto pivots = peek(1, 3);
          auto B = peek(2, 3);
          auto the_result = at::linalg_ldl_solve(LD, pivots, B);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1659() { // linalg_lstsq
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto b = peek(1, 2);
          auto the_result = at::linalg_lstsq(self, b);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1660() { // linalg_matmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::linalg_matmul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1661() { // linalg_vecdot
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto y = peek(1, 2);
          auto the_result = at::linalg_vecdot(x, y, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1662() { // linalg_vecdot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto y = peek(1, 2);
          auto the_result = at::linalg_vecdot(x, y);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1663() { // linalg_matrix_exp
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_exp(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1664() { // _linalg_slogdet
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_slogdet(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1665() { // linalg_slogdet
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_slogdet(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1666() { // slogdet
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::slogdet(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1667() { // logdet
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::logdet(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1668() { // linalg_eig
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_eig(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1669() { // _linalg_eigvals
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_linalg_eigvals(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1670() { // linalg_eigvals
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_eigvals(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1671() { // _linalg_eigh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_eigh(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1672() { // linalg_eigh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_eigh(self);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1673() { // linalg_eigvalsh
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_eigvalsh(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1674() { // linalg_householder_product
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto tau = peek(1, 2);
          auto the_result = at::linalg_householder_product(input, tau);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1675() { // linalg_inv_ex
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_inv_ex(A, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1676() { // linalg_inv_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_inv_ex(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1677() { // linalg_inv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_inv(A);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1678() { // inverse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::inverse(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1679() { // inner
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::inner(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1680() { // outer
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto vec2 = peek(1, 2);
          auto the_result = at::outer(self, vec2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1681() { // ger
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto vec2 = peek(1, 2);
          auto the_result = at::ger(self, vec2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1682() { // linalg_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1683() { // linalg_vector_norm
      at::Scalar ord = readScalarAttribute("ord");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_vector_norm(self, ord);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1684() { // linalg_vector_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_vector_norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1685() { // linalg_matrix_norm
      at::Scalar ord = readScalarAttribute("ord");
      auto dim = readIntArrayRef("dim");
      bool keepdim = readAttribute<int64_t>("keepdim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_norm(self, ord, dim, keepdim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1686() { // linalg_matrix_norm
      at::Scalar ord = readScalarAttribute("ord");
      auto dim = readIntArrayRef("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_norm(self, ord, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1687() { // linalg_matrix_norm
      at::Scalar ord = readScalarAttribute("ord");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_norm(self, ord);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1688() { // linalg_matrix_norm
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_norm(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1689() { // _linalg_svd
      bool full_matrices = readAttribute<int64_t>("full_matrices");
      bool compute_uv = readAttribute<int64_t>("compute_uv");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_svd(A, full_matrices, compute_uv);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1690() { // _linalg_svd
      bool full_matrices = readAttribute<int64_t>("full_matrices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_svd(A, full_matrices);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1691() { // _linalg_svd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::_linalg_svd(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1692() { // linalg_svd
      bool full_matrices = readAttribute<int64_t>("full_matrices");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_svd(A, full_matrices);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1693() { // linalg_svd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_svd(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1694() { // linalg_svdvals
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_svdvals(A);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1695() { // linalg_cond
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_cond(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1696() { // linalg_pinv
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto atol = peek(1, 3);
          auto rtol = peek(2, 3);
          auto the_result = at::linalg_pinv(self, atol, rtol, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1697() { // linalg_pinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto atol = peek(1, 3);
          auto rtol = peek(2, 3);
          auto the_result = at::linalg_pinv(self, atol, rtol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1698() { // linalg_pinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto atol = peek(1, 2);
          auto the_result = at::linalg_pinv(self, atol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1699() { // linalg_pinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_pinv(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1700() { // linalg_pinv
      double rcond = readAttribute<float>("rcond");
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_pinv(self, rcond, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1701() { // linalg_pinv
      double rcond = readAttribute<float>("rcond");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_pinv(self, rcond);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1702() { // linalg_pinv
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto rcond = peek(1, 2);
          auto the_result = at::linalg_pinv(self, rcond, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1703() { // _linalg_solve_ex
      bool left = readAttribute<int64_t>("left");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::_linalg_solve_ex(A, B, left, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1704() { // _linalg_solve_ex
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::_linalg_solve_ex(A, B, left);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1705() { // _linalg_solve_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::_linalg_solve_ex(A, B);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1706() { // linalg_solve_ex
      bool left = readAttribute<int64_t>("left");
      bool check_errors = readAttribute<int64_t>("check_errors");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_ex(A, B, left, check_errors);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1707() { // linalg_solve_ex
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_ex(A, B, left);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1708() { // linalg_solve_ex
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve_ex(A, B);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1709() { // linalg_solve
      bool left = readAttribute<int64_t>("left");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve(A, B, left);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1710() { // linalg_solve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 2);
          auto B = peek(1, 2);
          auto the_result = at::linalg_solve(A, B);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1711() { // linalg_tensorinv
      int64_t ind = readAttribute<int64_t>("ind");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_tensorinv(self, ind);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1712() { // linalg_tensorinv
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_tensorinv(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1713() { // linalg_tensorsolve
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::linalg_tensorsolve(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1714() { // linalg_qr
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto A = peek(0, 1);
          auto the_result = at::linalg_qr(A);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1715() { // linalg_matrix_power
      int64_t n = readAttribute<int64_t>("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_power(self, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1716() { // linalg_matrix_rank
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto atol = peek(1, 3);
          auto rtol = peek(2, 3);
          auto the_result = at::linalg_matrix_rank(input, atol, rtol, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1717() { // linalg_matrix_rank
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 3);
          auto atol = peek(1, 3);
          auto rtol = peek(2, 3);
          auto the_result = at::linalg_matrix_rank(input, atol, rtol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1718() { // linalg_matrix_rank
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto atol = peek(1, 2);
          auto the_result = at::linalg_matrix_rank(input, atol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1719() { // linalg_matrix_rank
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 1);
          auto the_result = at::linalg_matrix_rank(input);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1720() { // linalg_matrix_rank
      double tol = readAttribute<float>("tol");
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_rank(self, tol, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1721() { // linalg_matrix_rank
      double tol = readAttribute<float>("tol");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::linalg_matrix_rank(self, tol);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1722() { // linalg_matrix_rank
      bool hermitian = readAttribute<int64_t>("hermitian");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 2);
          auto tol = peek(1, 2);
          auto the_result = at::linalg_matrix_rank(input, tol, hermitian);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1723() { // linalg_multi_dot
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::linalg_multi_dot(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1724() { // nested_to_padded_tensor
      double padding = readAttribute<float>("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::nested_to_padded_tensor(self, padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1725() { // _test_serialization_subcmul
      at::Scalar alpha = readScalarAttribute("alpha");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_test_serialization_subcmul(self, other, alpha);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1726() { // _test_serialization_subcmul
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto other = peek(1, 2);
          auto the_result = at::_test_serialization_subcmul(self, other);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1727() { // _test_parallel_materialize
      int64_t num_parallel = readAttribute<int64_t>("num_parallel");
      bool skip_first = readAttribute<int64_t>("skip_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_parallel_materialize(self, num_parallel, skip_first);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1728() { // _test_parallel_materialize
      int64_t num_parallel = readAttribute<int64_t>("num_parallel");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_parallel_materialize(self, num_parallel);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1729() { // _test_string_default
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dummy = peek(0, 1);
          auto the_result = at::_test_string_default(dummy);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1730() { // _test_ambiguous_defaults
      int64_t a = readAttribute<int64_t>("a");
      int64_t b = readAttribute<int64_t>("b");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dummy = peek(0, 1);
          auto the_result = at::_test_ambiguous_defaults(dummy, a, b);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1731() { // _test_ambiguous_defaults
      int64_t a = readAttribute<int64_t>("a");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dummy = peek(0, 1);
          auto the_result = at::_test_ambiguous_defaults(dummy, a);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1732() { // _test_ambiguous_defaults
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto dummy = peek(0, 1);
          auto the_result = at::_test_ambiguous_defaults(dummy);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1733() { // _test_warn_in_autograd
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_warn_in_autograd(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1734() { // _test_autograd_multiple_dispatch
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_autograd_multiple_dispatch(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1735() { // _test_autograd_multiple_dispatch
      bool b = readAttribute<int64_t>("b");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_autograd_multiple_dispatch(self, b);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1736() { // _test_autograd_multiple_dispatch_view
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_autograd_multiple_dispatch_view(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1737() { // _test_autograd_multiple_dispatch_view_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_test_autograd_multiple_dispatch_view_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1738() { // pad_sequence
      bool batch_first = readAttribute<int64_t>("batch_first");
      double padding_value = readAttribute<float>("padding_value");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sequences = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::pad_sequence(sequences, batch_first, padding_value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1739() { // pad_sequence
      bool batch_first = readAttribute<int64_t>("batch_first");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sequences = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::pad_sequence(sequences, batch_first);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1740() { // pad_sequence
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto sequences = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::pad_sequence(sequences);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1741() { // flatten_dense_tensors
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto tensors = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::flatten_dense_tensors(tensors);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1742() { // unflatten_dense_tensors
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto flat = peek(0, InputSize());
          auto tensors = peekSlice(1, InputSize() - 1, InputSize());
          auto the_result = at::unflatten_dense_tensors(flat, tensors);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1743() { // _nested_tensor_from_tensor_list
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto list = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_nested_tensor_from_tensor_list(list);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1744() { // _fw_primal_copy
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_fw_primal_copy(self, level);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1745() { // _make_dual_copy
      int64_t level = readAttribute<int64_t>("level");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto primal = peek(0, 2);
          auto tangent = peek(1, 2);
          auto the_result = at::_make_dual_copy(primal, tangent, level);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1746() { // view_as_real_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::view_as_real_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1747() { // view_as_complex_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::view_as_complex_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1748() { // _conj_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_conj_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1749() { // _neg_view_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_neg_view_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1750() { // as_strided_copy
      auto size = readIntArrayRef("size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::as_strided_copy(self, size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1751() { // _sparse_broadcast_to_copy
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_sparse_broadcast_to_copy(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1752() { // diagonal_copy
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      int64_t dim2 = readAttribute<int64_t>("dim2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal_copy(self, offset, dim1, dim2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1753() { // diagonal_copy
      int64_t offset = readAttribute<int64_t>("offset");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal_copy(self, offset, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1754() { // diagonal_copy
      int64_t offset = readAttribute<int64_t>("offset");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal_copy(self, offset);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1755() { // diagonal_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::diagonal_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1756() { // expand_copy
      auto size = readIntArrayRef("size");
      bool implicit = readAttribute<int64_t>("implicit");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::expand_copy(self, size, implicit);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1757() { // expand_copy
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::expand_copy(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1758() { // permute_copy
      auto dims = readIntArrayRef("dims");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::permute_copy(self, dims);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1759() { // _reshape_alias_copy
      auto size = readIntArrayRef("size");
      auto stride = readIntArrayRef("stride");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_reshape_alias_copy(self, size, stride);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1760() { // select_copy
      int64_t dim = readAttribute<int64_t>("dim");
      int64_t index = readAttribute<int64_t>("index");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::select_copy(self, dim, index);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1761() { // detach_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::detach_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1762() { // slice_copy
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::slice_copy(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1763() { // slice_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::slice_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1764() { // split_copy
      int64_t split_size = readAttribute<int64_t>("split_size");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_copy(self, split_size, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1765() { // split_copy
      int64_t split_size = readAttribute<int64_t>("split_size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_copy(self, split_size);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1766() { // split_with_sizes_copy
      auto split_sizes = readIntArrayRef("split_sizes");
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_with_sizes_copy(self, split_sizes, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1767() { // split_with_sizes_copy
      auto split_sizes = readIntArrayRef("split_sizes");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::split_with_sizes_copy(self, split_sizes);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1768() { // squeeze_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::squeeze_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1769() { // squeeze_copy
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::squeeze_copy(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1770() { // t_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::t_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1771() { // transpose_copy
      int64_t dim0 = readAttribute<int64_t>("dim0");
      int64_t dim1 = readAttribute<int64_t>("dim1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::transpose_copy(self, dim0, dim1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1772() { // unsqueeze_copy
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unsqueeze_copy(self, dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1773() { // _indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1774() { // _values_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_values_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1775() { // indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1776() { // values_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::values_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1777() { // crow_indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::crow_indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1778() { // col_indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::col_indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1779() { // ccol_indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::ccol_indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1780() { // row_indices_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::row_indices_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1781() { // unbind_copy
      int64_t dim = readAttribute<int64_t>("dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unbind_copy(self, dim);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1782() { // unbind_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unbind_copy(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1783() { // view_copy
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::view_copy(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1784() { // unfold_copy
      int64_t dimension = readAttribute<int64_t>("dimension");
      int64_t size = readAttribute<int64_t>("size");
      int64_t step = readAttribute<int64_t>("step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::unfold_copy(self, dimension, size, step);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1785() { // alias_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::alias_copy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1786() { // to_padded_tensor
      double padding = readAttribute<float>("padding");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = self.to_padded_tensor(padding);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1787() { // _nested_tensor_softmax_with_shape
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto query = peek(1, 2);
          auto the_result = at::_nested_tensor_softmax_with_shape(self, query);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1788() { // _transformer_encoder_layer_fwd
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_heads = readAttribute<int64_t>("num_heads");
      bool use_gelu = readAttribute<int64_t>("use_gelu");
      bool norm_first = readAttribute<int64_t>("norm_first");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto src = peek(0, 14);
          auto qkv_weight = peek(1, 14);
          auto qkv_bias = peek(2, 14);
          auto proj_weight = peek(3, 14);
          auto proj_bias = peek(4, 14);
          auto norm_weight_1 = peek(5, 14);
          auto norm_bias_1 = peek(6, 14);
          auto norm_weight_2 = peek(7, 14);
          auto norm_bias_2 = peek(8, 14);
          auto ffn_weight_1 = peek(9, 14);
          auto ffn_bias_1 = peek(10, 14);
          auto ffn_weight_2 = peek(11, 14);
          auto ffn_bias_2 = peek(12, 14);
          auto mask = peek(13, 14);
          auto the_result = at::_transformer_encoder_layer_fwd(src, embed_dim, num_heads, qkv_weight, qkv_bias, proj_weight, proj_bias, use_gelu, norm_first, eps, norm_weight_1, norm_bias_1, norm_weight_2, norm_bias_2, ffn_weight_1, ffn_bias_1, ffn_weight_2, ffn_bias_2, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1789() { // _transformer_encoder_layer_fwd
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_heads = readAttribute<int64_t>("num_heads");
      bool use_gelu = readAttribute<int64_t>("use_gelu");
      bool norm_first = readAttribute<int64_t>("norm_first");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto src = peek(0, 13);
          auto qkv_weight = peek(1, 13);
          auto qkv_bias = peek(2, 13);
          auto proj_weight = peek(3, 13);
          auto proj_bias = peek(4, 13);
          auto norm_weight_1 = peek(5, 13);
          auto norm_bias_1 = peek(6, 13);
          auto norm_weight_2 = peek(7, 13);
          auto norm_bias_2 = peek(8, 13);
          auto ffn_weight_1 = peek(9, 13);
          auto ffn_bias_1 = peek(10, 13);
          auto ffn_weight_2 = peek(11, 13);
          auto ffn_bias_2 = peek(12, 13);
          auto the_result = at::_transformer_encoder_layer_fwd(src, embed_dim, num_heads, qkv_weight, qkv_bias, proj_weight, proj_bias, use_gelu, norm_first, eps, norm_weight_1, norm_bias_1, norm_weight_2, norm_bias_2, ffn_weight_1, ffn_bias_1, ffn_weight_2, ffn_bias_2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1790() { // _native_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      bool need_weights = readAttribute<int64_t>("need_weights");
      bool average_attn_weights = readAttribute<int64_t>("average_attn_weights");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 8);
          auto key = peek(1, 8);
          auto value = peek(2, 8);
          auto qkv_weight = peek(3, 8);
          auto qkv_bias = peek(4, 8);
          auto proj_weight = peek(5, 8);
          auto proj_bias = peek(6, 8);
          auto mask = peek(7, 8);
          auto the_result = at::_native_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias, mask, need_weights, average_attn_weights);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1791() { // _native_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      bool need_weights = readAttribute<int64_t>("need_weights");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 8);
          auto key = peek(1, 8);
          auto value = peek(2, 8);
          auto qkv_weight = peek(3, 8);
          auto qkv_bias = peek(4, 8);
          auto proj_weight = peek(5, 8);
          auto proj_bias = peek(6, 8);
          auto mask = peek(7, 8);
          auto the_result = at::_native_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias, mask, need_weights);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1792() { // _native_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 8);
          auto key = peek(1, 8);
          auto value = peek(2, 8);
          auto qkv_weight = peek(3, 8);
          auto qkv_bias = peek(4, 8);
          auto proj_weight = peek(5, 8);
          auto proj_bias = peek(6, 8);
          auto mask = peek(7, 8);
          auto the_result = at::_native_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias, mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1793() { // _native_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 7);
          auto key = peek(1, 7);
          auto value = peek(2, 7);
          auto qkv_weight = peek(3, 7);
          auto qkv_bias = peek(4, 7);
          auto proj_weight = peek(5, 7);
          auto proj_bias = peek(6, 7);
          auto the_result = at::_native_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1794() { // scaled_dot_product_attention
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::scaled_dot_product_attention(query, key, value, attn_mask, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1795() { // scaled_dot_product_attention
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::scaled_dot_product_attention(query, key, value, attn_mask, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1796() { // scaled_dot_product_attention
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::scaled_dot_product_attention(query, key, value, attn_mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1797() { // scaled_dot_product_attention
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::scaled_dot_product_attention(query, key, value);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1798() { // _fused_sdp_choice
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_fused_sdp_choice(query, key, value, attn_mask, dropout_p, is_causal);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1799() { // _fused_sdp_choice
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_fused_sdp_choice(query, key, value, attn_mask, dropout_p);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1800() { // _fused_sdp_choice
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_fused_sdp_choice(query, key, value, attn_mask);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1801() { // _fused_sdp_choice
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_fused_sdp_choice(query, key, value);
            if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1802() { // _scaled_dot_product_attention_math
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 5);
          auto key = peek(1, 5);
          auto value = peek(2, 5);
          auto attn_mask = peek(3, 5);
          auto dropout_mask = peek(4, 5);
          auto the_result = at::_scaled_dot_product_attention_math(query, key, value, attn_mask, dropout_p, is_causal, dropout_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1803() { // _scaled_dot_product_attention_math
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_scaled_dot_product_attention_math(query, key, value, attn_mask, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1804() { // _scaled_dot_product_attention_math
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_scaled_dot_product_attention_math(query, key, value, attn_mask, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1805() { // _scaled_dot_product_attention_math
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_scaled_dot_product_attention_math(query, key, value, attn_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1806() { // _scaled_dot_product_attention_math
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_attention_math(query, key, value);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1807() { // _scaled_dot_product_flash_attention_for_cpu
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_mask = peek(3, 4);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu(query, key, value, dropout_p, is_causal, attn_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1808() { // _scaled_dot_product_flash_attention_for_cpu
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu(query, key, value, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1809() { // _scaled_dot_product_flash_attention_for_cpu
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu(query, key, value, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1810() { // _scaled_dot_product_flash_attention_for_cpu
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu(query, key, value);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1811() { // _scaled_dot_product_flash_attention_backward
      int64_t max_q = readAttribute<int64_t>("max_q");
      int64_t max_k = readAttribute<int64_t>("max_k");
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 10);
          auto query = peek(1, 10);
          auto key = peek(2, 10);
          auto value = peek(3, 10);
          auto out = peek(4, 10);
          auto logsumexp = peek(5, 10);
          auto cum_seq_q = peek(6, 10);
          auto cum_seq_k = peek(7, 10);
          auto philox_seed = peek(8, 10);
          auto philox_offset = peek(9, 10);
          auto the_result = at::_scaled_dot_product_flash_attention_backward(grad_out, query, key, value, out, logsumexp, cum_seq_q, cum_seq_k, max_q, max_k, dropout_p, is_causal, philox_seed, philox_offset);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1812() { // _scaled_dot_product_flash_attention_for_cpu_backward
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 7);
          auto query = peek(1, 7);
          auto key = peek(2, 7);
          auto value = peek(3, 7);
          auto out = peek(4, 7);
          auto logsumexp = peek(5, 7);
          auto attn_mask = peek(6, 7);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu_backward(grad_out, query, key, value, out, logsumexp, dropout_p, is_causal, attn_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1813() { // _scaled_dot_product_flash_attention_for_cpu_backward
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 6);
          auto query = peek(1, 6);
          auto key = peek(2, 6);
          auto value = peek(3, 6);
          auto out = peek(4, 6);
          auto logsumexp = peek(5, 6);
          auto the_result = at::_scaled_dot_product_flash_attention_for_cpu_backward(grad_out, query, key, value, out, logsumexp, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1814() { // _scaled_dot_product_efficient_attention
      bool compute_log_sumexp = readAttribute<int64_t>("compute_log_sumexp");
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_bias = peek(3, 4);
          auto the_result = at::_scaled_dot_product_efficient_attention(query, key, value, attn_bias, compute_log_sumexp, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1815() { // _scaled_dot_product_efficient_attention
      bool compute_log_sumexp = readAttribute<int64_t>("compute_log_sumexp");
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_bias = peek(3, 4);
          auto the_result = at::_scaled_dot_product_efficient_attention(query, key, value, attn_bias, compute_log_sumexp, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1816() { // _scaled_dot_product_efficient_attention
      bool compute_log_sumexp = readAttribute<int64_t>("compute_log_sumexp");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 4);
          auto key = peek(1, 4);
          auto value = peek(2, 4);
          auto attn_bias = peek(3, 4);
          auto the_result = at::_scaled_dot_product_efficient_attention(query, key, value, attn_bias, compute_log_sumexp);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1817() { // _scaled_dot_product_cudnn_attention
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      bool return_debug_mask = readAttribute<int64_t>("return_debug_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_cudnn_attention(query, key, value, dropout_p, is_causal, return_debug_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1818() { // _scaled_dot_product_cudnn_attention
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_cudnn_attention(query, key, value, dropout_p, is_causal);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1819() { // _scaled_dot_product_cudnn_attention
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_cudnn_attention(query, key, value, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1820() { // _scaled_dot_product_cudnn_attention
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 3);
          auto key = peek(1, 3);
          auto value = peek(2, 3);
          auto the_result = at::_scaled_dot_product_cudnn_attention(query, key, value);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1821() { // _flash_attention_forward
      int64_t max_q = readAttribute<int64_t>("max_q");
      int64_t max_k = readAttribute<int64_t>("max_k");
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      bool return_debug_mask = readAttribute<int64_t>("return_debug_mask");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 5);
          auto key = peek(1, 5);
          auto value = peek(2, 5);
          auto cum_seq_q = peek(3, 5);
          auto cum_seq_k = peek(4, 5);
          auto the_result = at::_flash_attention_forward(query, key, value, cum_seq_q, cum_seq_k, max_q, max_k, dropout_p, is_causal, return_debug_mask);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1822() { // _flash_attention_backward
      int64_t max_q = readAttribute<int64_t>("max_q");
      int64_t max_k = readAttribute<int64_t>("max_k");
      double dropout_p = readAttribute<float>("dropout_p");
      bool is_causal = readAttribute<int64_t>("is_causal");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out = peek(0, 10);
          auto query = peek(1, 10);
          auto key = peek(2, 10);
          auto value = peek(3, 10);
          auto out = peek(4, 10);
          auto logsumexp = peek(5, 10);
          auto cum_seq_q = peek(6, 10);
          auto cum_seq_k = peek(7, 10);
          auto philox_seed = peek(8, 10);
          auto philox_offset = peek(9, 10);
          auto the_result = at::_flash_attention_backward(grad_out, query, key, value, out, logsumexp, cum_seq_q, cum_seq_k, max_q, max_k, dropout_p, is_causal, philox_seed, philox_offset);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1823() { // _efficient_attention_backward
      int64_t max_seqlen_q = readAttribute<int64_t>("max_seqlen_q");
      int64_t max_seqlen_k = readAttribute<int64_t>("max_seqlen_k");
      double dropout_p = readAttribute<float>("dropout_p");
      int64_t custom_mask_type = readAttribute<int64_t>("custom_mask_type");
      bool bias_requires_grad = readAttribute<int64_t>("bias_requires_grad");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto grad_out_ = peek(0, 11);
          auto query = peek(1, 11);
          auto key = peek(2, 11);
          auto value = peek(3, 11);
          auto bias = peek(4, 11);
          auto out = peek(5, 11);
          auto cu_seqlens_q = peek(6, 11);
          auto cu_seqlens_k = peek(7, 11);
          auto logsumexp = peek(8, 11);
          auto philox_seed = peek(9, 11);
          auto philox_offset = peek(10, 11);
          auto the_result = at::_efficient_attention_backward(grad_out_, query, key, value, bias, out, cu_seqlens_q, cu_seqlens_k, max_seqlen_q, max_seqlen_k, logsumexp, dropout_p, philox_seed, philox_offset, custom_mask_type, bias_requires_grad);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1824() { // _triton_scaled_dot_attention
      double dropout_p = readAttribute<float>("dropout_p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto q = peek(0, 3);
          auto k = peek(1, 3);
          auto v = peek(2, 3);
          auto the_result = at::_triton_scaled_dot_attention(q, k, v, dropout_p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1825() { // _triton_scaled_dot_attention
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto q = peek(0, 3);
          auto k = peek(1, 3);
          auto v = peek(2, 3);
          auto the_result = at::_triton_scaled_dot_attention(q, k, v);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1826() { // _triton_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 8);
          auto key = peek(1, 8);
          auto value = peek(2, 8);
          auto qkv_weight = peek(3, 8);
          auto qkv_bias = peek(4, 8);
          auto proj_weight = peek(5, 8);
          auto proj_bias = peek(6, 8);
          auto mask = peek(7, 8);
          auto the_result = at::_triton_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias, mask);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1827() { // _triton_multi_head_attention
      int64_t embed_dim = readAttribute<int64_t>("embed_dim");
      int64_t num_head = readAttribute<int64_t>("num_head");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto query = peek(0, 7);
          auto key = peek(1, 7);
          auto value = peek(2, 7);
          auto qkv_weight = peek(3, 7);
          auto qkv_bias = peek(4, 7);
          auto proj_weight = peek(5, 7);
          auto proj_bias = peek(6, 7);
          auto the_result = at::_triton_multi_head_attention(query, key, value, embed_dim, num_head, qkv_weight, qkv_bias, proj_weight, proj_bias);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1828() { // special_airy_ai
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_airy_ai(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1829() { // special_bessel_j0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_bessel_j0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1830() { // special_bessel_j1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_bessel_j1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1831() { // special_bessel_y0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_bessel_y0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1832() { // special_bessel_y1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_bessel_y1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1833() { // special_chebyshev_polynomial_t
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1834() { // special_chebyshev_polynomial_t
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1835() { // special_chebyshev_polynomial_t
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1836() { // special_chebyshev_polynomial_u
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1837() { // special_chebyshev_polynomial_u
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1838() { // special_chebyshev_polynomial_u
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1839() { // special_chebyshev_polynomial_v
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1840() { // special_chebyshev_polynomial_v
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1841() { // special_chebyshev_polynomial_v
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1842() { // special_chebyshev_polynomial_w
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1843() { // special_chebyshev_polynomial_w
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1844() { // special_chebyshev_polynomial_w
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1845() { // special_hermite_polynomial_h
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_hermite_polynomial_h(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1846() { // special_hermite_polynomial_h
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_hermite_polynomial_h(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1847() { // special_hermite_polynomial_h
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_hermite_polynomial_h(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1848() { // special_hermite_polynomial_he
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_hermite_polynomial_he(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1849() { // special_hermite_polynomial_he
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_hermite_polynomial_he(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1850() { // special_hermite_polynomial_he
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_hermite_polynomial_he(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1851() { // special_laguerre_polynomial_l
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_laguerre_polynomial_l(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1852() { // special_laguerre_polynomial_l
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_laguerre_polynomial_l(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1853() { // special_laguerre_polynomial_l
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_laguerre_polynomial_l(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1854() { // special_legendre_polynomial_p
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_legendre_polynomial_p(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1855() { // special_legendre_polynomial_p
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_legendre_polynomial_p(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1856() { // special_legendre_polynomial_p
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_legendre_polynomial_p(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1857() { // special_modified_bessel_i0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_modified_bessel_i0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1858() { // special_modified_bessel_i1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_modified_bessel_i1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1859() { // special_modified_bessel_k0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_modified_bessel_k0(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1860() { // special_modified_bessel_k1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::special_modified_bessel_k1(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1861() { // special_scaled_modified_bessel_k0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_scaled_modified_bessel_k0(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1862() { // special_scaled_modified_bessel_k1
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_scaled_modified_bessel_k1(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1863() { // special_shifted_chebyshev_polynomial_t
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_shifted_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1864() { // special_shifted_chebyshev_polynomial_t
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1865() { // special_shifted_chebyshev_polynomial_t
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_t(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1866() { // special_shifted_chebyshev_polynomial_u
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_shifted_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1867() { // special_shifted_chebyshev_polynomial_u
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1868() { // special_shifted_chebyshev_polynomial_u
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_u(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1869() { // special_shifted_chebyshev_polynomial_v
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_shifted_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1870() { // special_shifted_chebyshev_polynomial_v
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1871() { // special_shifted_chebyshev_polynomial_v
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_v(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1872() { // special_shifted_chebyshev_polynomial_w
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 2);
          auto n = peek(1, 2);
          auto the_result = at::special_shifted_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1873() { // special_shifted_chebyshev_polynomial_w
      at::Scalar x = readScalarAttribute("x");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto n = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1874() { // special_shifted_chebyshev_polynomial_w
      at::Scalar n = readScalarAttribute("n");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_shifted_chebyshev_polynomial_w(x, n);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1875() { // special_spherical_bessel_j0
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto x = peek(0, 1);
          auto the_result = at::special_spherical_bessel_j0(x);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1876() { // _foobar
      bool arg1 = readAttribute<int64_t>("arg1");
      bool arg2 = readAttribute<int64_t>("arg2");
      bool arg3 = readAttribute<int64_t>("arg3");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_foobar(self, arg1, arg2, arg3);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1877() { // _foobar
      bool arg1 = readAttribute<int64_t>("arg1");
      bool arg2 = readAttribute<int64_t>("arg2");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_foobar(self, arg1, arg2);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1878() { // _foobar
      bool arg1 = readAttribute<int64_t>("arg1");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_foobar(self, arg1);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1879() { // _foobar
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_foobar(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1880() { // bernoulli
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto p = peek(1, 2);
          auto the_result = at::bernoulli(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1881() { // embedding_renorm
      double max_norm = readAttribute<float>("max_norm");
      double norm_type = readAttribute<float>("norm_type");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto indices = peek(1, 2);
          auto the_result = at::embedding_renorm(self, indices, max_norm, norm_type);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1882() { // resize
      auto size = readIntArrayRef("size");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::resize(self, size);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1883() { // _index_put_impl
      bool accumulate = readAttribute<int64_t>("accumulate");
      bool unsafe = readAttribute<int64_t>("unsafe");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::_index_put_impl(self, indices, values, accumulate, unsafe);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1884() { // _index_put_impl
      bool accumulate = readAttribute<int64_t>("accumulate");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::_index_put_impl(self, indices, values, accumulate);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1885() { // _index_put_impl
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, InputSize());
          auto indices = peekSliceOptionals(1, InputSize() - 2, InputSize());
          auto values = peek(1, 2);
          auto the_result = at::_index_put_impl(self, indices, values);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1886() { // _native_batch_norm_legit_functional
      bool training = readAttribute<int64_t>("training");
      double momentum = readAttribute<float>("momentum");
      double eps = readAttribute<float>("eps");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto input = peek(0, 5);
          auto weight = peek(1, 5);
          auto bias = peek(2, 5);
          auto running_mean = peek(3, 5);
          auto running_var = peek(4, 5);
          auto the_result = at::_native_batch_norm_legit_functional(input, weight, bias, running_mean, running_var, training, momentum, eps);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1887() { // resize_as
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto the_template = peek(1, 2);
          auto the_result = at::resize_as(self, the_template);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1888() { // resize_as_sparse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto the_template = peek(1, 2);
          auto the_result = at::resize_as_sparse(self, the_template);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1889() { // zero
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::zero(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1890() { // sparse_resize
      auto size = readIntArrayRef("size");
      int64_t sparse_dim = readAttribute<int64_t>("sparse_dim");
      int64_t dense_dim = readAttribute<int64_t>("dense_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sparse_resize(self, size, sparse_dim, dense_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1891() { // sparse_resize_and_clear
      auto size = readIntArrayRef("size");
      int64_t sparse_dim = readAttribute<int64_t>("sparse_dim");
      int64_t dense_dim = readAttribute<int64_t>("dense_dim");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::sparse_resize_and_clear(self, size, sparse_dim, dense_dim);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1892() { // _coalesced
      bool coalesced = readAttribute<int64_t>("coalesced");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::_coalesced(self, coalesced);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1893() { // copy_sparse_to_sparse
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::copy_sparse_to_sparse(self, src, non_blocking);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1894() { // copy_sparse_to_sparse
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto src = peek(1, 2);
          auto the_result = at::copy_sparse_to_sparse(self, src);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1895() { // _fused_moving_avg_obs_fq_helper_functional
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      bool symmetric_quant = readAttribute<int64_t>("symmetric_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper_functional(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant, symmetric_quant);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
            if(OutputSize() > 5) {assignTo(Output(5),::std::get<5>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1896() { // _fused_moving_avg_obs_fq_helper_functional
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      bool per_row_fake_quant = readAttribute<int64_t>("per_row_fake_quant");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper_functional(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis, per_row_fake_quant);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
            if(OutputSize() > 5) {assignTo(Output(5),::std::get<5>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1897() { // _fused_moving_avg_obs_fq_helper_functional
      double averaging_const = readAttribute<float>("averaging_const");
      int64_t quant_min = readAttribute<int64_t>("quant_min");
      int64_t quant_max = readAttribute<int64_t>("quant_max");
      int64_t ch_axis = readAttribute<int64_t>("ch_axis");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 7);
          auto observer_on = peek(1, 7);
          auto fake_quant_on = peek(2, 7);
          auto running_min = peek(3, 7);
          auto running_max = peek(4, 7);
          auto scale = peek(5, 7);
          auto zero_point = peek(6, 7);
          auto the_result = at::_fused_moving_avg_obs_fq_helper_functional(self, observer_on, fake_quant_on, running_min, running_max, scale, zero_point, averaging_const, quant_min, quant_max, ch_axis);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignTo(Output(2),::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignTo(Output(3),::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignTo(Output(4),::std::get<4>(the_result));}
            if(OutputSize() > 5) {assignTo(Output(5),::std::get<5>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1898() { // set
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 2);
          auto source = peek(1, 2);
          auto the_result = at::set(self, source);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1899() { // set
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::set(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1900() { // random
      int64_t to = readAttribute<int64_t>("to");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::random(self, to);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1901() { // random
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::random(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1902() { // uniform
      double from = readAttribute<float>("from");
      double to = readAttribute<float>("to");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::uniform(self, from, to);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1903() { // uniform
      double from = readAttribute<float>("from");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::uniform(self, from);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1904() { // uniform
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::uniform(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1905() { // cauchy
      double median = readAttribute<float>("median");
      double sigma = readAttribute<float>("sigma");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cauchy(self, median, sigma);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1906() { // cauchy
      double median = readAttribute<float>("median");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cauchy(self, median);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1907() { // cauchy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::cauchy(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1908() { // log_normal
      double mean = readAttribute<float>("mean");
      double std = readAttribute<float>("std");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_normal(self, mean, std);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1909() { // log_normal
      double mean = readAttribute<float>("mean");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_normal(self, mean);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1910() { // log_normal
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::log_normal(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1911() { // exponential
      double lambd = readAttribute<float>("lambd");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::exponential(self, lambd);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1912() { // exponential
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::exponential(self);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1913() { // geometric
      double p = readAttribute<float>("p");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 1);
          auto the_result = at::geometric(self, p);
            if(OutputSize() > 0) {assignTo(Output(0),the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1914() { // _amp_foreach_non_finite_check_and_unscale
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 2, InputSize());
          auto found_inf = peek(0, 2);
          auto inv_scale = peek(1, 2);
          auto the_result = at::_amp_foreach_non_finite_check_and_unscale(self, found_inf, inv_scale);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1915() { // _amp_update_scale
      double scale_growth_factor = readAttribute<float>("scale_growth_factor");
      double scale_backoff_factor = readAttribute<float>("scale_backoff_factor");
      int64_t growth_interval = readAttribute<int64_t>("growth_interval");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peek(0, 3);
          auto growth_tracker = peek(1, 3);
          auto found_inf = peek(2, 3);
          auto the_result = at::_amp_update_scale(self, growth_tracker, found_inf, scale_growth_factor, scale_backoff_factor, growth_interval);
            if(OutputSize() > 0) {assignTo(Output(0),::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignTo(Output(1),::std::get<1>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1916() { // _foreach_zero
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_zero(self);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1917() { // _foreach_copy
      bool non_blocking = readAttribute<int64_t>("non_blocking");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto src = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_copy(self, src, non_blocking);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1918() { // _foreach_copy
  
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 0, InputSize());
          auto src = peekSlice(0, InputSize() - 0, InputSize());
          auto the_result = at::_foreach_copy(self, src);
            if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
          return true;
      };
  }
  C10_NOINLINE void implementation_1919() { // _fused_adam
      double lr = readAttribute<float>("lr");
      double beta1 = readAttribute<float>("beta1");
      double beta2 = readAttribute<float>("beta2");
      double weight_decay = readAttribute<float>("weight_decay");
      double eps = readAttribute<float>("eps");
      bool amsgrad = readAttribute<int64_t>("amsgrad");
      bool maximize = readAttribute<int64_t>("maximize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 2, InputSize());
          auto grads = peekSlice(0, InputSize() - 2, InputSize());
          auto exp_avgs = peekSlice(0, InputSize() - 2, InputSize());
          auto exp_avg_sqs = peekSlice(0, InputSize() - 2, InputSize());
          auto max_exp_avg_sqs = peekSlice(0, InputSize() - 2, InputSize());
          auto state_steps = peekSlice(0, InputSize() - 2, InputSize());
          auto grad_scale = peek(0, 2);
          auto found_inf = peek(1, 2);
          auto the_result = at::_fused_adam(self, grads, exp_avgs, exp_avg_sqs, max_exp_avg_sqs, state_steps, lr, beta1, beta2, weight_decay, eps, amsgrad, maximize, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignListStartingAt(3, ::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignListStartingAt(4, ::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1920() { // _fused_adam
      double beta1 = readAttribute<float>("beta1");
      double beta2 = readAttribute<float>("beta2");
      double weight_decay = readAttribute<float>("weight_decay");
      double eps = readAttribute<float>("eps");
      bool amsgrad = readAttribute<int64_t>("amsgrad");
      bool maximize = readAttribute<int64_t>("maximize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 3, InputSize());
          auto grads = peekSlice(0, InputSize() - 3, InputSize());
          auto exp_avgs = peekSlice(0, InputSize() - 3, InputSize());
          auto exp_avg_sqs = peekSlice(0, InputSize() - 3, InputSize());
          auto max_exp_avg_sqs = peekSlice(0, InputSize() - 3, InputSize());
          auto state_steps = peekSlice(0, InputSize() - 3, InputSize());
          auto lr = peek(0, 3);
          auto grad_scale = peek(1, 3);
          auto found_inf = peek(2, 3);
          auto the_result = at::_fused_adam(self, grads, exp_avgs, exp_avg_sqs, max_exp_avg_sqs, state_steps, lr, beta1, beta2, weight_decay, eps, amsgrad, maximize, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignListStartingAt(3, ::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignListStartingAt(4, ::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1921() { // _fused_adamw
      double lr = readAttribute<float>("lr");
      double beta1 = readAttribute<float>("beta1");
      double beta2 = readAttribute<float>("beta2");
      double weight_decay = readAttribute<float>("weight_decay");
      double eps = readAttribute<float>("eps");
      bool amsgrad = readAttribute<int64_t>("amsgrad");
      bool maximize = readAttribute<int64_t>("maximize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 2, InputSize());
          auto grads = peekSlice(0, InputSize() - 2, InputSize());
          auto exp_avgs = peekSlice(0, InputSize() - 2, InputSize());
          auto exp_avg_sqs = peekSlice(0, InputSize() - 2, InputSize());
          auto max_exp_avg_sqs = peekSlice(0, InputSize() - 2, InputSize());
          auto state_steps = peekSlice(0, InputSize() - 2, InputSize());
          auto grad_scale = peek(0, 2);
          auto found_inf = peek(1, 2);
          auto the_result = at::_fused_adamw(self, grads, exp_avgs, exp_avg_sqs, max_exp_avg_sqs, state_steps, lr, beta1, beta2, weight_decay, eps, amsgrad, maximize, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignListStartingAt(3, ::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignListStartingAt(4, ::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1922() { // _fused_adamw
      double beta1 = readAttribute<float>("beta1");
      double beta2 = readAttribute<float>("beta2");
      double weight_decay = readAttribute<float>("weight_decay");
      double eps = readAttribute<float>("eps");
      bool amsgrad = readAttribute<int64_t>("amsgrad");
      bool maximize = readAttribute<int64_t>("maximize");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 3, InputSize());
          auto grads = peekSlice(0, InputSize() - 3, InputSize());
          auto exp_avgs = peekSlice(0, InputSize() - 3, InputSize());
          auto exp_avg_sqs = peekSlice(0, InputSize() - 3, InputSize());
          auto max_exp_avg_sqs = peekSlice(0, InputSize() - 3, InputSize());
          auto state_steps = peekSlice(0, InputSize() - 3, InputSize());
          auto lr = peek(0, 3);
          auto grad_scale = peek(1, 3);
          auto found_inf = peek(2, 3);
          auto the_result = at::_fused_adamw(self, grads, exp_avgs, exp_avg_sqs, max_exp_avg_sqs, state_steps, lr, beta1, beta2, weight_decay, eps, amsgrad, maximize, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
            if(OutputSize() > 3) {assignListStartingAt(3, ::std::get<3>(the_result));}
            if(OutputSize() > 4) {assignListStartingAt(4, ::std::get<4>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1923() { // _fused_sgd
      double weight_decay = readAttribute<float>("weight_decay");
      double momentum = readAttribute<float>("momentum");
      double lr = readAttribute<float>("lr");
      double dampening = readAttribute<float>("dampening");
      bool nesterov = readAttribute<int64_t>("nesterov");
      bool maximize = readAttribute<int64_t>("maximize");
      bool is_first_step = readAttribute<int64_t>("is_first_step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 2, InputSize());
          auto grads = peekSlice(0, InputSize() - 2, InputSize());
          auto momentum_buffer_list = peekSlice(0, InputSize() - 2, InputSize());
          auto grad_scale = peek(0, 2);
          auto found_inf = peek(1, 2);
          auto the_result = at::_fused_sgd(self, grads, momentum_buffer_list, weight_decay, momentum, lr, dampening, nesterov, maximize, is_first_step, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
          return true;
      };
  }
  C10_NOINLINE void implementation_1924() { // _fused_sgd
      double weight_decay = readAttribute<float>("weight_decay");
      double momentum = readAttribute<float>("momentum");
      double dampening = readAttribute<float>("dampening");
      bool nesterov = readAttribute<int64_t>("nesterov");
      bool maximize = readAttribute<int64_t>("maximize");
      bool is_first_step = readAttribute<int64_t>("is_first_step");
      run_op = [=] {
          at::AutoDispatchBelowAutograd guard;
          auto self = peekSlice(0, InputSize() - 3, InputSize());
          auto grads = peekSlice(0, InputSize() - 3, InputSize());
          auto momentum_buffer_list = peekSlice(0, InputSize() - 3, InputSize());
          auto lr = peek(0, 3);
          auto grad_scale = peek(1, 3);
          auto found_inf = peek(2, 3);
          auto the_result = at::_fused_sgd(self, grads, momentum_buffer_list, weight_decay, momentum, lr, dampening, nesterov, maximize, is_first_step, grad_scale, found_inf);
            if(OutputSize() > 0) {assignListStartingAt(0, ::std::get<0>(the_result));}
            if(OutputSize() > 1) {assignListStartingAt(1, ::std::get<1>(the_result));}
            if(OutputSize() > 2) {assignListStartingAt(2, ::std::get<2>(the_result));}
          return true;
      };
  }
};

}
